{
  "cells": [
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "# GCN Algorithm Example 1\n",
        "\n",
        "SEOYEON CHOI  \n",
        "2023-01-11\n",
        "\n",
        "> Our method; GNAR Dataset Example(fiveVTS, fiveNet)\n",
        "\n",
        "# import"
      ],
      "id": "53184a3f-381a-4f10-9494-1cc978fa473d"
    },
    {
      "cell_type": "code",
      "execution_count": 1,
      "metadata": {},
      "outputs": [],
      "source": [
        "import rpy2\n",
        "import rpy2.robjects as ro \n",
        "from rpy2.robjects.vectors import FloatVector \n",
        "from rpy2.robjects.packages import importr\n",
        "\n",
        "import torch\n",
        "import numpy as np\n",
        "from tqdm import tqdm\n",
        "\n",
        "import torch.nn.functional as F\n",
        "from torch_geometric_temporal.nn.recurrent import GConvGRU\n",
        "\n",
        "import matplotlib.pyplot as plt\n",
        "import pandas as pd\n",
        "\n",
        "import time\n",
        "\n",
        "from scipy.interpolate import interp1d"
      ],
      "id": "7eed5cac-27aa-42f2-a2bf-f5346d8e82ca"
    },
    {
      "cell_type": "code",
      "execution_count": 2,
      "metadata": {},
      "outputs": [],
      "source": [
        "class RecurrentGCN(torch.nn.Module):\n",
        "    def __init__(self, node_features, filters):\n",
        "        super(RecurrentGCN, self).__init__()\n",
        "        self.recurrent = GConvGRU(node_features, filters, 2)\n",
        "        self.linear = torch.nn.Linear(filters, 1)\n",
        "\n",
        "    def forward(self, x, edge_index, edge_weight):\n",
        "        h = self.recurrent(x, edge_index, edge_weight)\n",
        "        h = F.relu(h)\n",
        "        h = self.linear(h)\n",
        "        return h"
      ],
      "id": "2f0e266e-f036-4449-95ce-f67694988030"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "# R"
      ],
      "id": "dd2a463f-6715-4340-8a6f-f34b43a1912d"
    },
    {
      "cell_type": "code",
      "execution_count": 3,
      "metadata": {},
      "outputs": [],
      "source": [
        "%load_ext rpy2.ipython"
      ],
      "id": "956cb163-e10a-4864-aa7a-02457ec8fb4f"
    },
    {
      "cell_type": "code",
      "execution_count": 225,
      "metadata": {},
      "outputs": [],
      "source": [
        "%%R\n",
        "library(GNAR)\n",
        "library(igraph)"
      ],
      "id": "d4de9446-0e52-4c24-9956-de76e0ca04bd"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "# 시간측정 방법\n",
        "\n",
        "``` python\n",
        "t1= time.time()\n",
        "for epoc in range(1000):\n",
        "    ## 1 \n",
        "    yhat = net(x) \n",
        "    ## 2 \n",
        "    loss = loss_fn(yhat,y)\n",
        "    ## 3 \n",
        "    loss.backward()\n",
        "    ## 4 \n",
        "    optimizr.step()\n",
        "    optimizr.zero_grad()\n",
        "t2 = time.time()\n",
        "t2-t1\n",
        "```\n",
        "\n",
        "# EbayesThresh"
      ],
      "id": "d68a5d29-faa3-446f-b64c-b34792fa5f61"
    },
    {
      "cell_type": "code",
      "execution_count": 5,
      "metadata": {},
      "outputs": [],
      "source": [
        "%%R\n",
        "library(EbayesThresh)\n",
        "set.seed(1)\n",
        "epsilon = rnorm(1000)\n",
        "signal = sample(c(runif(25,-2,-1.5), runif(25,1.5,2), rep(0,950)))\n",
        "index_of_trueoutlier = which(signal!=0)\n",
        "x_ebayes=signal+epsilon"
      ],
      "id": "e1e3756a-a00d-425b-8b9b-495217caa44f"
    },
    {
      "cell_type": "code",
      "execution_count": 6,
      "metadata": {},
      "outputs": [],
      "source": [
        "%R -o x_ebayes\n",
        "%R -o index_of_trueoutlier\n",
        "%R -o signal"
      ],
      "id": "d74c90f2-db31-49bf-a22e-ff91f6cb1bc4"
    },
    {
      "cell_type": "code",
      "execution_count": null,
      "metadata": {},
      "outputs": [],
      "source": [
        "%R -i "
      ],
      "id": "99602a73-371b-41f1-ae3e-f5ca91752268"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "------------------------------------------------------------------------"
      ],
      "id": "a7bd6a7a-6e83-44cd-9793-b2415df89b1d"
    },
    {
      "cell_type": "code",
      "execution_count": 355,
      "metadata": {},
      "outputs": [],
      "source": [
        "arr = np.array([1,2,3])"
      ],
      "id": "b18dea0c-fff6-4f54-bf23-7f7931e99221"
    },
    {
      "cell_type": "code",
      "execution_count": 356,
      "metadata": {},
      "outputs": [],
      "source": [
        "%R -i arr"
      ],
      "id": "c45c5bcc-b593-4dbf-92e3-2dbeda9e6cdc"
    },
    {
      "cell_type": "code",
      "execution_count": 357,
      "metadata": {},
      "outputs": [
        {
          "output_type": "stream",
          "name": "stdout",
          "text": [
            "[1] 1 2 3"
          ]
        }
      ],
      "source": [
        "%%R\n",
        "arr"
      ],
      "id": "8d78cda2-885b-47f5-8222-e8233a61e9ea"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "------------------------------------------------------------------------"
      ],
      "id": "5c2a46a1-db7b-4fcc-9091-d6bfe6b77ed8"
    },
    {
      "cell_type": "code",
      "execution_count": 7,
      "metadata": {},
      "outputs": [],
      "source": [
        "ebayesthresh = importr('EbayesThresh').ebayesthresh"
      ],
      "id": "e946bc10-0200-42b4-b01f-1e9c36e4870c"
    },
    {
      "cell_type": "code",
      "execution_count": 8,
      "metadata": {},
      "outputs": [],
      "source": [
        "outlier_true_index = index_of_trueoutlier"
      ],
      "id": "9f4501b1-585c-44fb-9093-b14eae0dfcd6"
    },
    {
      "cell_type": "code",
      "execution_count": 9,
      "metadata": {},
      "outputs": [],
      "source": [
        "outlier_true_value = x_ebayes[index_of_trueoutlier]"
      ],
      "id": "437a78f6-9635-40e0-be58-0c15880ce4d5"
    },
    {
      "cell_type": "code",
      "execution_count": 10,
      "metadata": {},
      "outputs": [],
      "source": [
        "outlier_true_one = signal.copy()"
      ],
      "id": "71441f71-cf87-458e-a1f1-b3c8fa59bde4"
    },
    {
      "cell_type": "code",
      "execution_count": 11,
      "metadata": {},
      "outputs": [],
      "source": [
        "outlier_true_one = list(map(lambda x: -1 if x!=0 else 1,outlier_true_one))"
      ],
      "id": "b395b9c5-2c34-4119-9a67-c9f7fdaa5e68"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "# 0. 데이터 가정\n",
        "\n",
        "데이터가정: missing (결측값) 이 있는 자료를 가정\n",
        "\n",
        "-   missing이 있는상태: ST-GCN 을 사용할 수 X $\\to$ **코드에 에러는 나지\n",
        "    않지만 yhat이 산출되지 않았습니다.**\n",
        "-   missing이 없어야만: ST-GCN 을 사용할 수 O\n",
        "\n",
        "# 예제 1 GNAR fiveVT\n",
        "\n",
        "**증명 - missing이 있는상태: ST-GCN 을 사용할 수 X**"
      ],
      "id": "134ce9fb-0cff-4cf4-959b-1bc9eb290e25"
    },
    {
      "cell_type": "code",
      "execution_count": 12,
      "metadata": {},
      "outputs": [
        {
          "output_type": "stream",
          "name": "stdout",
          "text": [
            "GNARnet with 5 nodes and 10 edges\n",
            " of equal length  1"
          ]
        }
      ],
      "source": [
        "%%R\n",
        "summary(fiveNet)"
      ],
      "id": "bf673cc6-4495-4406-9bd3-f6d840dcd7bd"
    },
    {
      "cell_type": "code",
      "execution_count": 13,
      "metadata": {},
      "outputs": [],
      "source": [
        "%%R\n",
        "edges <- as.matrix(fiveNet)\n",
        "data(\"fiveNode\")"
      ],
      "id": "60aa1796-74c6-49d8-a481-20b06eb3927f"
    },
    {
      "cell_type": "code",
      "execution_count": 14,
      "metadata": {},
      "outputs": [],
      "source": [
        "%R -o fiveVTS\n",
        "%R -o edges"
      ],
      "id": "4e72b915-a5b1-4f4c-a677-5635fc5578dc"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "-   node: 5\n",
        "-   time 200"
      ],
      "id": "ac12290e-8737-4d73-84ed-b7c90e9277c2"
    },
    {
      "cell_type": "code",
      "execution_count": 15,
      "metadata": {},
      "outputs": [],
      "source": [
        "edges_tensor = torch.tensor(edges)"
      ],
      "id": "7b021b83-7f82-48bc-b47c-02545d081ba2"
    },
    {
      "cell_type": "code",
      "execution_count": 16,
      "metadata": {},
      "outputs": [],
      "source": [
        "nonzero_indices = edges_tensor.nonzero()"
      ],
      "id": "81119219-36bb-4703-aec3-15728936ba3c"
    },
    {
      "cell_type": "code",
      "execution_count": 17,
      "metadata": {},
      "outputs": [],
      "source": [
        "fiveNet_edge = np.array(nonzero_indices).T"
      ],
      "id": "4adbc9b7-4df3-4a49-a652-d4cdc4527bc3"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "## 데이터 일부 missing 처리\n",
        "\n",
        "### 1) Block 처리\n",
        "\n",
        "#### \\[1\\] ST-GCN"
      ],
      "id": "8e9f9069-24ff-4779-917a-0e8c7db393d3"
    },
    {
      "cell_type": "code",
      "execution_count": 18,
      "metadata": {},
      "outputs": [],
      "source": [
        "%%R\n",
        "fiveVTS0 <- fiveVTS\n",
        "fiveVTS0[50:150, 3] <- NA"
      ],
      "id": "08799dd2-162e-4311-abb2-6de8464b87c8"
    },
    {
      "cell_type": "code",
      "execution_count": 20,
      "metadata": {},
      "outputs": [
        {
          "output_type": "display_data",
          "metadata": {},
          "data": {
            "image/png": "iVBORw0KGgoAAAANSUhEUgAAAXIAAAD4CAYAAADxeG0DAAAAOXRFWHRTb2Z0d2FyZQBNYXRwbG90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\nPWhYFxPLAAAAAElFTkSuQmCC\n"
          }
        }
      ],
      "source": [
        "plt.plot(fiveVTS0[:,2])"
      ],
      "id": "75368062-1937-435e-b005-ea5c3e5e5cee"
    },
    {
      "cell_type": "code",
      "execution_count": 228,
      "metadata": {},
      "outputs": [],
      "source": [
        "T = 200\n",
        "N = 5 # number of Nodes\n",
        "E = fiveNet_edge\n",
        "V = np.array([1,2,3,4,5])\n",
        "t = np.arange(0,T)\n",
        "node_features = 1"
      ],
      "id": "322fac88-4efa-4dd8-80b4-c2311517de07"
    },
    {
      "cell_type": "code",
      "execution_count": 229,
      "metadata": {},
      "outputs": [],
      "source": [
        "f = torch.tensor(fiveVTS0).reshape(200,5,1).float()"
      ],
      "id": "eef32cc2-cd99-43a8-8ba2-afcface0903f"
    },
    {
      "cell_type": "code",
      "execution_count": 230,
      "metadata": {},
      "outputs": [],
      "source": [
        "X = f[:199,:,:]\n",
        "y = f[1:,:,:]"
      ],
      "id": "1126e385-76b1-4c46-8eb8-73b96c554480"
    },
    {
      "cell_type": "code",
      "execution_count": 231,
      "metadata": {},
      "outputs": [],
      "source": [
        "edge_index = torch.tensor(E)\n",
        "edge_attr = torch.tensor(np.array([1,1,1,1,1,1,1,1,1,1]),dtype=torch.float32)"
      ],
      "id": "fdb73885-3f12-44f6-b17b-2b72fed88f09"
    },
    {
      "cell_type": "code",
      "execution_count": 232,
      "metadata": {},
      "outputs": [],
      "source": [
        "_ee = enumerate(zip(X,y))"
      ],
      "id": "626f3ee7-8e05-4a53-9bed-e9c47803e1b5"
    },
    {
      "cell_type": "code",
      "execution_count": 233,
      "metadata": {},
      "outputs": [
        {
          "output_type": "stream",
          "name": "stderr",
          "text": [
            "100%|██████████| 50/50 [00:32<00:00,  1.53it/s]"
          ]
        }
      ],
      "source": [
        "model = RecurrentGCN(node_features=1, filters=4)\n",
        "\n",
        "optimizer = torch.optim.Adam(model.parameters(), lr=0.01)\n",
        "\n",
        "model.train()\n",
        "\n",
        "for epoch in tqdm(range(50)):\n",
        "    for time, (xt,yt) in enumerate(zip(X,y)):\n",
        "        y_hat = model(xt, edge_index, edge_attr)\n",
        "        cost = torch.mean((y_hat-yt)**2)\n",
        "        cost.backward()\n",
        "        optimizer.step()\n",
        "        optimizer.zero_grad()"
      ],
      "id": "6adfec32-de84-4b49-8302-9f80d664f1a6"
    },
    {
      "cell_type": "code",
      "execution_count": 234,
      "metadata": {},
      "outputs": [],
      "source": [
        "yhat = torch.stack([model(xt, edge_index, edge_attr) for xt in X]).detach().numpy()"
      ],
      "id": "11560d09-9f84-4879-a2f5-6ef474919ae4"
    },
    {
      "cell_type": "code",
      "execution_count": 235,
      "metadata": {},
      "outputs": [
        {
          "output_type": "display_data",
          "metadata": {},
          "data": {
            "image/png": "iVBORw0KGgoAAAANSUhEUgAAAYIAAAD4CAYAAADhNOGaAAAAOXRFWHRTb2Z0d2FyZQBNYXRwbG90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\n"
          }
        }
      ],
      "source": [
        "plt.plot(yhat[:,0].data)\n",
        "plt.plot(yhat[:,1].data)\n",
        "plt.plot(yhat[:,2].data)\n",
        "plt.plot(yhat[:,3].data)"
      ],
      "id": "6cd02af4-25db-469c-8190-7706e9ce9712"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "### 2) Random missing values"
      ],
      "id": "7cd814f1-5e97-4203-a1e5-38f24c30b20e"
    },
    {
      "cell_type": "code",
      "execution_count": 31,
      "metadata": {},
      "outputs": [],
      "source": [
        "%%R\n",
        "set.seed(1)\n",
        "fiveVTSrandom <- fiveVTS\n",
        "sampleindex = sort(sample(1:200, 100))\n",
        "fiveVTSrandom[sampleindex,3] <- NA"
      ],
      "id": "316e21a5-5a10-4a6e-9b32-65f094e6a0b0"
    },
    {
      "cell_type": "code",
      "execution_count": 32,
      "metadata": {},
      "outputs": [],
      "source": [
        "%R -o fiveVTSrandom\n",
        "%R -o sampleindex"
      ],
      "id": "e6527461-65c5-4dfb-b62b-00aa604584da"
    },
    {
      "cell_type": "code",
      "execution_count": 33,
      "metadata": {},
      "outputs": [
        {
          "output_type": "display_data",
          "metadata": {},
          "data": {
            "image/png": "iVBORw0KGgoAAAANSUhEUgAAAXIAAAD4CAYAAADxeG0DAAAAOXRFWHRTb2Z0d2FyZQBNYXRwbG90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\nAABJRU5ErkJggg==\n"
          }
        }
      ],
      "source": [
        "plt.plot(fiveVTSrandom[:,2],'o')"
      ],
      "id": "8decdcca-e77e-4fb8-831b-b5a2477c35a9"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "### 3) By 2"
      ],
      "id": "b2773ee1-3b9a-4670-b116-6dc1a3e5016d"
    },
    {
      "cell_type": "code",
      "execution_count": 34,
      "metadata": {},
      "outputs": [],
      "source": [
        "%%R\n",
        "fiveVTStwo <- fiveVTS\n",
        "indextwo <- rep(seq(1, by = 2, 200))\n",
        "fiveVTStwo[indextwo, 3] <- NA"
      ],
      "id": "d019d3bb-c4f6-458d-b6b5-8b91459d7f64"
    },
    {
      "cell_type": "code",
      "execution_count": 35,
      "metadata": {},
      "outputs": [],
      "source": [
        "%R -o fiveVTStwo\n",
        "%R -o indextwo"
      ],
      "id": "420fab24-1cfc-4205-8d7f-be97a86c676a"
    },
    {
      "cell_type": "code",
      "execution_count": 36,
      "metadata": {},
      "outputs": [
        {
          "output_type": "display_data",
          "metadata": {},
          "data": {
            "image/png": "iVBORw0KGgoAAAANSUhEUgAAAXIAAAD4CAYAAADxeG0DAAAAOXRFWHRTb2Z0d2FyZQBNYXRwbG90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\n"
          }
        }
      ],
      "source": [
        "plt.plot(fiveVTStwo[:,2],'o')"
      ],
      "id": "64632301-3d90-4a08-9a8e-ee20059caf73"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "# 1. missing을 채움. (mean, linear interpolation)\n",
        "\n",
        "## 1.1. Mean\n",
        "\n",
        "### 1) Block"
      ],
      "id": "42487b97-924a-4614-84c5-7ee1ef13ffd3"
    },
    {
      "cell_type": "code",
      "execution_count": 37,
      "metadata": {},
      "outputs": [],
      "source": [
        "fiveVTS0_mean = fiveVTS0.copy()"
      ],
      "id": "45e6f44b-926b-4433-acb8-73392523b39b"
    },
    {
      "cell_type": "code",
      "execution_count": 38,
      "metadata": {},
      "outputs": [],
      "source": [
        "fiveVTS0_mean[49:150,2] = np.mean(fiveVTS0[:49,2].tolist()+fiveVTS0[150:,2].tolist())"
      ],
      "id": "c0b904cc-19fe-48b4-b69f-c99665b11591"
    },
    {
      "cell_type": "code",
      "execution_count": 39,
      "metadata": {},
      "outputs": [
        {
          "output_type": "display_data",
          "metadata": {},
          "data": {
            "image/png": "iVBORw0KGgoAAAANSUhEUgAAAXIAAAD4CAYAAADxeG0DAAAAOXRFWHRTb2Z0d2FyZQBNYXRwbG90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\nDTnDMEzJ+f/pSJrJewilAwAAAABJRU5ErkJggg==\n"
          }
        }
      ],
      "source": [
        "plt.plot(fiveVTS0_mean[:,2])"
      ],
      "id": "2965ff08-3dd2-4b37-9cff-3fbd7a74cc64"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "### 2) Random missing values"
      ],
      "id": "f4ae862d-40e7-4e37-84b1-034619cbdf86"
    },
    {
      "cell_type": "code",
      "execution_count": 40,
      "metadata": {},
      "outputs": [],
      "source": [
        "fiveVTSrandom_mean = fiveVTSrandom.copy()"
      ],
      "id": "e69fd5ed-0927-44d9-9e68-58eb06c8c8a5"
    },
    {
      "cell_type": "code",
      "execution_count": 41,
      "metadata": {},
      "outputs": [],
      "source": [
        "df = pd.DataFrame(fiveVTSrandom[:,2])\n",
        "mean_value = df.mean() # finds the mean value of the column A\n",
        "df = df.fillna(mean_value) # replace missing values with the mean value"
      ],
      "id": "505b174b-4462-4495-b76b-76729283029a"
    },
    {
      "cell_type": "code",
      "execution_count": 42,
      "metadata": {},
      "outputs": [],
      "source": [
        "fiveVTSrandom_mean[:,2] = np.array(df).reshape(200,)"
      ],
      "id": "ac761678-3a14-458d-8468-619180b88db4"
    },
    {
      "cell_type": "code",
      "execution_count": 43,
      "metadata": {},
      "outputs": [
        {
          "output_type": "display_data",
          "metadata": {},
          "data": {
            "image/png": "iVBORw0KGgoAAAANSUhEUgAAAXIAAAD4CAYAAADxeG0DAAAAOXRFWHRTb2Z0d2FyZQBNYXRwbG90\nbGliIHZlcnNpb24zLjUuMSwgaHR0cHM6Ly9tYXRwbG90bGliLm9yZy/YYfK9AAAACXBIWXMAAAsT\nAAALEwEAmpwYAABT0ElEQVR4nO29ebQkV3Xm+50Ycrxj3ZonVZVUVaAJJMpCgBBCEmYwBoMBg23A\nBi8Zv6YBtzG2F69tntvuXnigH90eQG3zwMYYLAYjM0mAQWAGiSpJJVRSaahBNVfduvOQU0Sc90fE\nPnEiMjIzMjNyrPNbS0v3ZuXNPBkZseM7395nH8Y5h0KhUCgGF63XA1AoFApFe6hArlAoFAOOCuQK\nhUIx4KhArlAoFAOOCuQKhUIx4Bi9eNO1a9fyHTt29OKtFQqFYmA5cODARc75uvDjPQnkO3bswP79\n+3vx1gqFQjGwMMaeiXpcWSsKhUIx4KhArlAoFAOOCuQKhUIx4KhArlAoFAOOCuQKhUIx4KhArlAo\nFAOOCuQKhUIx4KhA3md867HzOL9Y7PUwFArFAKECeR/BOce7Pn0A//zAiV4PRaFQDBAqkPcRDgcs\nh6NsOb0eikKhGCBUIO8jLMcN4Lajdm1SKBTxUYG8j/DiuArkCoWiKdoO5IyxDGPsAcbYQcbYIcbY\n/5PEwC5FSJFbKpArFIomSKL7YQnArZzzZcaYCeA/GGNf55z/OIHXvqQgJa4UuUKhaIa2AznnnANY\n9n41vf9UJGoBEci5OnwKhSI+iXjkjDGdMfYwgAsAvsk5vz/iOXcwxvYzxvZPT08n8bZDhwjktgrk\nCoUiPokEcs65zTl/LoCtAG5gjF0d8Zw7Oef7OOf71q2r2uBCAV+JK0WuUCiaIdGqFc75PIDvAnhF\nkq97qWDZyiNXKBTNk0TVyjrG2IT3cxbA7QAOt/u6lyIUwFXVikKhaIYkqlY2AfgUY0yHe2P4F875\nVxJ43UsOslQcFcgVCkUTJFG18giA6xIYyyWPr8jVEn2FQhEftbKzj/DryHs8EIVCMVCoQN5H+IFc\nRXKFQhEfFcj7CEslOxUKRQuoQN5HkCJ3VB25QqFoAhXI+wiR7FQrOxUKRROoQN5HqKZZCoWiFVQg\n7yNU0yyFQtEKKpD3EWqHIIVC0QoqkPcRlORUgVyhUDSDCuR9hGqapVAoWkEF8j6CFLmqI1coFM2g\nAnkfQQFcNc1SKBTNoAJ5H6Ha2CoUilZQgbyPUHXkCoWiFVQg7yMsFcgVCkULqEDeRzjKWlEoFC2g\nAnkfYammWQqFogVUIO8j/KZZqh+5QqGIjwrkfYTfxrbHA1EoFAOFCuR9hNqzU6FQtMLABnLLdrBS\nsno9jESxVa8VhULRAgMbyD/5w+O4/SP39XoYiaLqyBUKRSsMbCA/PrOCswtF8CGq8KCmWQ7HUH0u\nhULRWQY2kC8VXVulPEQVHvKGEkqVKxSKuLQdyBlj2xhj32GMPc4YO8QYe28SA2vEYqECAChbQxTI\npSSnWhSkUCjiYiTwGhaA3+GcP8gYGwVwgDH2Tc75Ywm8dk1IkVeGaKNieXKhFLlCoYhL24qcc36W\nc/6g9/MSgMcBbGn3dRuxWBxuRa727VQoFHFJ1CNnjO0AcB2A+yP+7Q7G2H7G2P7p6em232ux4Hnk\nQxTIZTvFHqKZhkKh6CyJBXLG2AiALwB4H+d8MfzvnPM7Oef7OOf71q1b1/b7LZEiH6Jkp7yhhFLk\nCoUiLokEcsaYCTeI/xPn/ItJvGY9LNvBStkGMMSKXHnkCoUiJklUrTAAfw/gcc75R9ofUmOWpRWd\nQ6XIJRWuqlYUCkVcklDkLwLwVgC3MsYe9v57VQKvWxPyx4EhU+SSL6727VQoFHFpu/yQc/4fAFgC\nY4kNVawAQGWIFLlspyhFrlAo4jKQKzvlQD5Milyt7FQoFK0wmIFcslZKQxTIVbJToVC0wkAG8iVZ\nkQ+RteIErJXh+VwKhaKzDGQgXyz6irwypIpcxXGFQhGXgQzkw6rIbaXIe0qxYvd6CApFSwxkIB/W\n8kM5kDtqZWdXmV4q4doP3YufHJ/t9VAUXebU3Cr2/t9fxxPnlno9lJYZyEC+VKxgNO1WTg5t+aHq\ntdJVLi6XULYdnJ4r9Hooii5zaq6AkuXgmZmVXg+lZQYykC8WK5gaSQEYrqoVW1Wt9Aw63sNk1Sni\nQbP6QY4lgxnICxamRtIAhs9aSenuV6KaZnUXsrKGaYaniAd954OcIxnIQL5UqmA8a8LU2VApKMtx\nkDI072cVyLsJHW9laV16KEXeIxYLFsYyBlK6NlTlhzaHCOSq10p3oeOtFHlnuO0vv4t/+cnJXg8j\nEhKDKpB3maViBWNZE6ahDZUitx1HWCtKkXcX5ZF3Dst2cGR6BUcv+snE+4/O4Na//C4K5d7bGRTA\nlbXSRTjnWCxaGPUU+XB55L4iV8nO7kI5iYqljnszFMo23vWPB3BiZrXmc+jmaEk3ycPnlnB0egUX\nl0sdHyMA/NLHf4S/uOeJ6PEpa6X7FCo2bIdjNGMiNYSKPK0CeU+wlbXSEsdnVvCNQ+fw7cPnaz6H\nAqU8y6THunX9Hp9ZwfEa5YUikCtF3j2KFfeg51J6Q0W+UKjg4/cdGRi/2Xa4UuQ9QgXy1iAVe3S6\ndg12SQRyR3rMDZqlSvB4V2wH/7L/ZOLXbMlyaipu5ZH3ADoB0obmKvI6B//eQ+fwP75+GEcvLndr\neG2hAnnvoPLDYZrhdQNSsUema19jQpFLFUElYWcEVfCPjszgA59/BAdPzSc8ztqBvFJjLIPE4AVy\n7w6eNvSG1srsShmAr+L7HUuuI+9yIJ9eKuHvvn8U/BKtX6fTSCny5oinyN0AWbEjrJVQcF0tu+03\nkkyCcs5Rsuya1klZ1JEP7nc/eIHcokCuueWH9QL5atn7m8G40zqSIu921cqXHz6NP/nq4zi/2J3k\nU79hO9Wqsdd8/adn8eI/+/eO3FyKFRsnZ2snKONCgfjcYhEr0l66MnTN2gFrJdrOqPV4O1gOh8Nr\nv2ZZKfLuQwc7ZWgwG3jkc54iD/tw/YrlcKQNHUD3V3ZeWHID+CCXYLUDxcp+slaevrCMk7MFrJaS\n/07+5jtP49X/+z/afh05OB67GK3K6TkVR7ZW3M8Uvn7p/EvyPKyl/sPjU4q8i/iKXG/okZO1MihJ\nDIdzv2qlywHl/GIRAFAcYFXSDqL8sI8UuVCndvLfyQPHZ7FQqLRt4ckqtpZP7nvkvVHktfx4MT5b\nKfKuIzxy00t21rnwfI98ML4gS052djmeiEA+wKqE+Oi3nsIPj1xs6m/Eys4+uunXquxoF8fhePT0\nIoD2cwJywD1SwycXVSsxkp30WZMMquI4NrJWBvjcH7xALlet6BrKdb7wudWK9zeD8QXZtpzs7O6Y\nL3je+CDX0hIf/94RfP2n55r6G6sPyw/pvE3a7jl6cRnLnp/d7rVB58toxsDRBoo8YK1Uou2ORkG3\ntTHWV/miaVYbN48LS0X87XeP9KxYYAADefNVK4MyZbJ575KdwiMfkJteLTjnKFbsplf8On24RF8E\noISV4sMnF8TP7a6Mpuvx2RvH8PSF6EBO158sTmrVbpc6oI7pvWp91iQU+T2HzuPD3ziMMwvFll+j\nHQYwkIcVefTBt2wHC4XBUuRusrP7TbOWS5av0AZckVdst0KhWWVt92EbW5EQTHhMj0g12u1+Xrr+\nbt6z1lt2Xx3MhSKXrZUKKe/g+daJZGcju4bG144iL3rlkr3qHZNIIGeMfYIxdoEx9mgSr1ePsEde\nKzlFtor8N/1Or8oPLyz6KmLQFXmh0lrw81d29l+yM+l+QgdPJavIDY3hTfu2QdcYPhfR4dD3yKsV\nebW10olkp2/XRFkfYnbQRpwodOAG1AxJKfJPAnhFQq9VF9laqVd+OOfVkAODkezknMNyOAxdA2Pd\nVeRy7figK3Iaf7MBigK51UeKvBP1zRXbweNnF7F5POO+R9vJThspQ8P6sQxue9Z6fP7AqapjH9Vr\npZZv3Zlkp/uanEffqJO4eXRiJtEMiQRyzvn3AMwm8VqNiLtEn/xx92/65+KsBZ3jOmMwNNZdRb40\nPIqcqm6atlaERz7cinxutYyy5eDy9SOJvHbJ8hu9veWG7ZhZKeO+J6dDz3Gv2WDVSnRSsyPJTumm\nEHWDENZKG0GYFHlhkAN5HBhjdzDG9jPG9k9PTzf+gxr4S/Q1keyMmi7NBQJ5/6tMCiSGzqAx1tUl\n+heGSJG3aq3041ZvnQhqi17eaP1oQoq84ohFbNdvnwQAnAitGPUVeRPWSpLJTuk9om5cchvbVqtO\nSED0qny3a4Gcc34n53wf53zfunXrWn6dkuVA1xgMXUNKZwCip0szA6bIKXDrmqvIuxnIzy8WYXrH\nchCOVT1IVTXbV7wfux92QpHPe7mjdaPJ7HlbsmykTTeMjGQMAO7GL8HnRNSR17BQhEXRAWsl/DNR\niVio1CzFS0WRJ0XJssVUjhKDUaqCFPlUPjUQyU6qmtAZg95la+X8UgmbJ7JgbPAVOV1QpSYDstWP\nC4I64BdTJRcF8rarVmzfWtE1hnxKx1Ix2HPFryOvDpjha7MTilx+rahAXU4gkFO1SnGQq1a6iezJ\n0eKZKFUxu1rGaNrASMYYiGXntu0rcl1jYqrfDc4vFrFhNIO0oQ28R14QirzVOvJ+8shbS9zWI3FF\nXvE3DAeA0YwZS5ELO8OuEcg7sLKz1uuWA4q9tfelGNOrWJNU+eE/A/gRgL2MsVOMsXcm8bpRyJ5c\nyvt/lKqYWyljMp9C2tAGQpGTf+gGcq2rinx6qYT1Y2lkTD3xrPvL/+f38IUDpxJ9zXqQR9l0+WFf\neuTJl+LNkyIfScpa8a9HwLVXworc31jCPcbUVhaIUuSdSHZKgToiFpQlcdhqrCj0uI7cSOJFOOdv\nSeJ14iB7cuTrRp2MM14gl0+afkZYKxqDrvkKvRtcXCph7UgaGUNP9KZn2Q6eOL+Ew+cWE3vNRvi9\nr1tT5P1UftiJQL5QqIAxYO1ICkAy5YfpgCKPCuRUteIHdNIp1R55+xUk1WOsTrLKlC0HoxkTpeVS\nG4r8Ekl2JoXsydGULupEn1stY03OdBX5ANgFwWSn1rU2to7DsVSyMJY1kTa1RKeGdNEsd6ANay1I\nETWrNK1+XBDUYk18PRY8yzFj6om8tmx1AtHWSniHoHpVJL1Q5CXbwZiXqG01EIuVnSrZGQ/Zk6MT\nKOpknFupeNZK8nZBJ5ADud7FqpVlb0eWsYyRuCKn74V2fYnD9FKprZ3VRdVKi9ZKrXLWXtCJvSQX\nChVM5FJ1CwWaQbY6gVqKPJjsrFdF0qjBVUtjrOORc85RsR2MeoG8VUU+LCs7u4bsyZlesjPqol0q\nVjCWGTxFbmjdrVpZ9i66kbSRvCL3jnutnWOePL+E1/zVfwQU3PvvOogPfP6Rlt+zUKOrXiPklbTd\nblgWhe1wMTtINNlZqGAiZ/rXTpuvXbYdYXUCriBY9M6pT/zHMZycXRXjp3M8GFi7kOysU7ViORyc\nuzOJ8HObIc7KzguLbofEEzPt78wUJhGPvJvEKT/knGOlbIvgNAiB3Aop8m4t0Sf1NNIBRV4SgTz6\n5H709AIeObWAM/NF7N3oXkjnF4swvNxHKxRb7rXi/1yxHRHoekXAfkhwY4mFQgXjWTNBRW6L6jHA\nt1Zmlkv44688hkLFlvIWHJzzkLUS6kfegR7swRlA8P1oLGNZz1ppU5HXs1aemV3Fh79xGFdvGcP2\nqVxL71OLAVXk9csPixUHtsP94NTHyU7LdvCmj/8I3/eWNesag85YYBVcPe45dA7ffOx8y++/XHLV\n8Gimcx75Sg1rhWZS8oxquWSJWUIrFKWg0Qxyi9VmFxO1yxcfPIV3f+bBwGMB1ZpgUFtY9QK5mM22\nu0NQUJGPpg2ULAdn5t22D0tFK3B92g4XgTUTElluC+Lkk51ly4HG/J/D/+aOuz1FXooxbnn2mzSD\np8gD5YfRqmLJC055UuR9XH44s1LGA8dmMZV3qwhoQVBcofQ33z0CBuBlV25o6f2XZGvF0DGzXG7w\nF/Gh417LWqEgIlsZS0WrLTVMSSfb4bAdDl2Lp+7l5HK3e5L/8MhM1c24UaVFq8x7ijyplbzh8kPy\nmo/NuLsFLRUrgfewHC7Oi9GMGZp5tL8wJ3qMNkYzJhYKlarXpff0PfLm39d2uHidQp1Ys+RdB2Tj\nJMkAKnK5/DBakdOdb9QLTv2c7KQujfR/t/0Ai71D0FKhgvnV1oMvBfKxTAc8clLkNawVUuJUlsY5\nx3LJqhn44yBXHTST8AxbK91k0QswtVR4UkKEc+4lO00wxur2849LdfmhG6SOTVMgDypyy+HCKhrN\nGJGJzxFP1SeVdC5ZUjIzdCx9a8UddyuxQv6bOIqcxpIkAxjIfWulVtUKBQ5XZfa3R04r7ej/1DQr\nbsJtsWgFOj02C20o0QmPvFGykwImBXyyxAoVu+V67mKdRFo9AsnOLpcg0s1UrvaQg3pSiny5ZMF2\nOMa9oGXqrK2bluMlZKMU+dGLy+I9A4rcdgKKPOrmReNL6nOXLAdjlMwMe+QJKPJC3EDuOQWdsFYG\nNJCHrJXQwSdrZSTjB/J+KSkLQwGcFLnmtbGNu0R/sVjBYtFq+oK878lpXFgqioqRkbTheZYdqFop\nW5HHX1gr3v/pe3P/psWkk/R3zRwT+cbZbWtl0fsOqDMhELJWEhIi1GdlIuvaePXaQMeBjlN4iT4A\nHLvoWyvye1Rs3yMfyxgoS9cmBcHRNmu6q8ZpuYUPjNXxyDOtK3L5nKu3snO5aIExIJfSaz6nVQYv\nkFf8qVyt8sNgSZ238KGPVuzJzAtrxVPkmgZNY7FUobw35fxqpcGzfTjneOcnf4JP/fC4OLnyKbKh\nElTk3hTa4dEXZbi9qZzkXG7RXim2GADlG2e3rZVGijypmyudI2QjtBvI5ZbShPDIJWulZNnCk7cc\nRwrkJhzu30RLIZsjqc9NCdmo2bkfyJtX5OcXi7hr/0kxzpRe35pcKlneDaX1qqxaDF4gl7LktZKd\nwi7wrBX6u36Eel/QCaVpiK3IF6X667kmfPKK7e5GdH6xhMWihZGUAU1jHVPkQHTlil+14ilyKZC1\n6pPLiqo5j7x3gVwo8mL19oRZU09MkZPin8iRtaK19VnFJi+BOnL3tSmxRx55LuUGSsv2W2aEgyc9\nPtZmTXfVOCuuHZs29JrJzlxKh66xps7/u/afxO9+/hGcW3AXsE3kTBTKtce8XLQw2gFbBRiwQG7Z\njrdBcX1rZUXyfUmR92vCMxyADU2LvSBIDnzN+OSkgC8ul7BcssQFlTZ0VGye2KpS+aKJCsz+snhP\nkZcSUOTS99xMALR7pMg55+J7XCxIilzybpMSISQaxiVF3my7Xxl520UinMijqhXyhS2p/JCeK2/s\nII8vqc/tJmR19/PWqCNP6a5ib2ZGSnsenJkvAAAmc6m6baCXS5bo2Z40AxXI6e5ZVUdeVX4Yocj7\ntARxIWSJNLNEX/ZU55oI5FQnfXG5hOWif3JlTJq9JHPTCyjyiMqVcA8O+cbUai15sWL7NcPNKPJA\ni9Xu5VNWy7b4rpciFPlY1kzeI/cUebtVK/K2i0Q4UC2XLFgOF76wZTtVvnR4ERAtzknUWjG0yE6o\nIpAbGjJmc2tOyKo67QXyiZxZd0HQsmetdIKBCuRhT67WgqDlogVDY+LLA/rYWokI5HF3CFqUgt1M\nM4HcU+Qzy2UslSrigqJjlZRPXoptrVQr8tatFUd8nmYWu/RKkct2SsBakeyHxBT5anWys53PWozw\nyE1dQ9abBacNTXQ5zHkBLJzsBKTFNN5nHhelgEklOyWPvEb/85TRvCKnWfDZBV+RWw6veUyXihZG\nOlBDDgxaIKepnHeiaJ56rUp2elMYxpiY9vXr6s5qa6ULityWAnnRVwnUEa8ziryxR74sBbJWrZVC\nxRaKrqlkZ488cnkWEkx2yiV6SVkrZaR0Tcy82lXkUVUrgG+Z7JjKi8fypMgdR7pJBcsMhSKvUSrY\nKiXL8ayT6vJa+q7d41LtodeDrt2zC+4q1klvUV8tG3e5pDxyANFTObcWNhj0lgPBqb8V+UIhqMg1\n1kQglwLfbDPJTsvv9HdmviCmw5S0SkwJ2XIgrz65/ZWd7vOWkqhaqdgiEDSV7OQ8sWXrzSDfjKPK\nD90SvYSqVlYqGPcWAwFJVq0Ey+kokO9cKwVyySOn9xwJKXKR7OyER27qXt+lGh65sF7iH2tS5KeF\nR+6Ou5a9slSsdGQxEDBwgbz6xInKvMteFD23n5Odcl2pobs7BMUJ5BT41o6km1Pk0qrRi8tlMcXN\nJDx7aVS1Ug4r8pJriQGtWyulir/4o6lkp8PFjax31oqkyCu+ak0qoM2slEUrCKAzVSsAhH2wc12E\nIveslZRkwYR7kItkZwKCwt1YxvXIU3pE+aEdDOTNbHVIVtVZr6/MZC5Vd9yywEyawQrkNTy5uoG8\nzxX5/GoF2yb9Tmhu0yy/ouPJ80v4L//ycOQFt1iowNAYtkxkMNtEHXn4tcLWSpLeJBFprYhkp6fI\nS5bbK1vXRMK6GajnhbBWmiw/pM/fyUDuOBx/9/2jYsZBN+OsqQeTnVJXvqR6pM+ulDA14gfyVJur\nnn1hFQwjYxGKnDxyWtmZkvJXomqlYgf+PglB4XZcdMeYjrBOAlUrph5bkZcsW3yHpMAn6ihy2/E6\nsipF7n+xqbC1EqoykMt8+rlqpVixUbIcbFsjBXIWVOT3HjqHLz54WqyUk1n0pmpr8qmmFHl4sVE4\n2dnM9LIeZdupq7Cryg+LbinkSMZoSZEXRSBoTZFnuqDIn55exp989XF87ZGzAHw7ZctkNlh+SPZD\nygDnrds99x+dwee9PVNnV8pYk0+Lf0sZWlsL5aJmyIBvrexaW63IK16vlbShVe3wJRR5LjlFHlbc\ntVZ2Cmsl5jkTtQBvIlfbI6cZqVLkiFYApq4FrAIgOIXp52QnJUsumwoqcrlq5eRswft/dTP6xYK7\nRdtkPtVUHXn44vVnL54iT2j2UrYc5NMGTJ1FLrmvXhBUwUjaQD6t12y0VY9iJZhEayYgO5wLa6nc\nQY+cgtPJOff7JDtly0S2qmrFVZHt9Q2/83tH8T++9jiAamsl1aS1cjwkJuiGH1bko2m3Te6miax4\njBYE2Y6syKOtlSSTnf4YdS9QR/daofLDuBZs+HpLG5q4WUUt0+9kwyxg4AI5eXJhj7xakY9W1Ub3\nnyKnu/q2Sf+E1zUGTWOiHI4u+KhATrsgrcmlmlvZGToW1bOXBKsFDA25VLTCrlqi71liI2mzaruw\nONCUtpWqFUu2Vjp4rlDbAvo+F4sVpHQNa0fSwaoVaTUi0Hq/leMzK5hZKWO5ZGGpaFUF8vDrWraD\nJ84tVb3Oj47M4Ja/+C4ePb0gfZZoa+V112/B+162OxC0RkLlh/JNqiRZK4xJSdAEvgdZ/EVVrdDn\nN7VoxV4LmgHTJtYZU68rhPzV5qr8sIZHzqo65UUlO5MKTklCwVfeLcQIKfJTc4XA/2UWixbGsgYm\n8ymslu3YaiK8alQkOxNW5CXL3T1mJG3UqFohj9xfEDSaMTCS1lu0VoKKrilF3iVrhRYbnaBAXnC/\nw7GsEahaKdsOUt5qRKA1dWo7XMzonji3CABYE/LIw4Hrc/tP4pUf/Z6ojSZ+enoeAAKBvFbVyo27\npvB/3XIFRlJuoyoAyKX9ZGfZa3xHVUKytZI2NCnpnmAgN7XInEDZdmDqrnhqpuU19UbatW4EgJvj\noORtlCKXd+LqBIMVyCOsFUMLTg9th2O1bItyp35OdtKqzo1jWeEl08pOy3ZbutLyX1LmMouFCkbT\nJtZ4KiuuKq+2VsILgpKrWkkbGnKp6MAs9qSUFgSNZAw38DexYTMhPPIWytds7ivyTu7ZSZ/1pHdj\ndkvSTIxmTCyXLVHP7ivy2huMN+LsQkG832Nn3EBeXbUS/KwPHJuFw4FDpxcDjz913m1L+9SFZfGY\nHCSj0DSGEc9SyVOvFa+OPCXbRt7rFCvuUnpTZ2AsmfPQT2bqnuKuLj+kG0p4x6J6ULnv5V4gz5h+\nfX7UuOX+T51goAJ5WZw4krViaAFPM3zA+nllJ/W+mMybIviIPTu5eyFaIa9cZrFYcRW5l2SJ65OT\nAqYyr9GQIk/qWJU9ayVfIzCHFTktmMinjZaW6BdDVQ9Nrex00LaNEQeybaaXSiiUbXdWlTEwlnGT\nmlStQxuohBOCzfCMtMnvY2c9RR5OdoZe96ET8wCAw+eCgfzpaTeAPx0I5H7Xv1qQAqUS24C1ElLe\n9Li7kC+ZfQTktSdR+/fSOeo+J/6CILJWLvdKLDOmjmwqutT51NzqYHjkjLFXMMaeYIw9zRj7/SRe\nM4qoBUGpkLVCyo8OWErXwFh3rJX3fvYhfOTeJ2I/nxT0ZC4lgg8lOy3HEXbKrnV5nIpU5BbGMqbw\n6aietREUQDeNZwCgakFQklUrbiCPVuSkFi3HEc2jSJG3siCIrJXRlqpW3AqbdjdbaIQ8Gzo1t+rm\nObL+jZxKEKnvfjs3F7nSiRT5mnzIWpFKGy8ul4Tl87jkk3PO8fT5qEDuqlmtznZ6dB2SsLIdJ7Bk\n3n0dP9lJ52CmiVLAesizBgrUcilnIJCbWlPJztG0gXWj7o0xm5KsFek17ntyGjd9+Dv4wZGLAPpY\nkTPGdAB/DeCVAK4E8BbG2JXtvm4UcayVcFIhybt7PWZXyrj74Bn8+xMXYv/NwmrF9QRNXQQfSnY6\njp8Qe8GuKSwWrcAq0IrteMvRTVy1eRwpQxMnSyPoeG32qgpGqxYEJafI3Wy+gdUI35CUeNniYneg\n0YzpeeqtK/J8WofGmm9j695E21sk0wj5tU/Orbr2mKfIAb8DoljE0oZH/szMirBnDnuBea3skXs9\nwmnmQmp83Wgah8/6ivzCUglLJQsbxtI4PV8Q3w1Vn9SDzutwr5WUrlX1SipZtjgHE1Pkko8vbCrp\nOyCxAbjnv+XwWLtTza2WMZlPidlwxtAj12F887FzANwyYqC/PfIbADzNOT/KOS8D+CyA1ybwulVE\nruwMWSuUVMin/ed0Y9/O+568AM7dhvpxF2/8+OiMSJZQpYWsyE/OFcAYcMPONQCClStL0lQtm9Lx\ngl1TuO+J6VjvSxfu7g0jyKd0kRw0dQYtIW8S8NVOLYVdkRT5krQNlmvF2IH+J3EgJZQ19aYbQjnc\n9XSjWj4kiaysT84WPGvFFN8BlSDSBirhhGAtLi6XcHG5FHjs+MwqLpvKYcNYBiXLga4x8T5AdT//\nh07MwdAYXnfdFhy7uCLOA/LHX37VRgDAUW/TCKoHrwcp0BGR7HREslPTWGC1ZaniK/JmbI56yGtP\nomxWN9npK/Lwv9dibrWCyXxKzHCyKf9GQech5xzf9a7Ji96m5pQzSJokAvkWACel3095jwVgjN3B\nGNvPGNs/PR0v4ISh8iTabQSotlaWS9VeVDcU+bcfd5X4StnGhaVSg2e72f+Dpxbwpn1bAbi1t4C7\nIEhjrkd+anYVG8cyIqEiV65QhQNdmLfsXYejF1dwYqbagglDAe5Xn38ZvvP+W4SSoCZjiSly21Ve\nuRrWiuyRyx4ifXdxEp6rZQtHPP+WAk/G1GFGLMeuh+1wGBpre5FMI+TXPjm7KvpvkHKlG7RrM+hV\nCcEoCmUbr/ubH+B37zoYePyZmRVcNpXHxjHXQpvMpQI2iOgtY1Egn8ezN43hum0TcLgfwJ++4Kr5\nV1ztBvKnvN8pIVuPUeGRy/3IbXETSUmtZYte33AAXifC5JKdtRLHgWRnE/mIuZUy1uRM0Sgra+pg\njCErWULHLq7g1FxBupkZdW2odkgikEeNrErScM7v5Jzv45zvW7duXUtvJCdDiPBUeCWiXjMqyVGP\nQ2cWcPDkfOznV2wH9z05jW1rXKuCAks9/vmBE0gbGl5/nRvIw4occGuAt03mxBJ+2Scn5Ube6i17\n1wMAvvtkY2uHbnzZlI713kVOZJrwCRsRTHbW7kdesR2/PMtT5EDjxlkzyyW84W9/hJd95D588cFT\nomyS/NdmrRWNMbeSowvJzrUjaRyZXkbR6w1D3z/doOX+IPR7Lf73vz+Fk7OFQCtjx+F4ZmYVO6Zy\n2ODlQuSKFcCdzQLuzeVrPz2LB47P4vk71+DZm8YAAI97Cc+nLixjLGPgZ3asgaEx4ZPTzaYeFMjz\ngUAe3ECdauvlG0Oz12wtwnXk8mOAb/+57xl/8eDsimutrPGsFd/b14Qiv+9JV7C+86adADrnjwNA\nEq98CsA26fetAM4k8LpVyBsvE6YRLKFajmGtzK6U8VufPoDlkoXbn70Bv/2yPd7r23jznT/GQyfm\nkTV1PPSHL8MPj1zE//zmU3W3XitbbiD67dv34I+/8hiOTq/gsTOLSBka3vaCHbhr/0nMrZZxx82X\n418fOo3/8/2jeOrCMn7+2s1iOfJYxoTGXFWsezOOR08v4tXXbsJY1sBo2sDH7juCLz10GgCE5yx3\nmtsxlcN9T0zjbS/YAcBVqO+/6yDee9tu7N4w6o/XO16mVn0fTxs6/u3gGRyZXsadb90ngirgruz7\nb195DH/6umuwcdy/AayWLfzuXY/gPbftxu71I/jAFx7B215wmbcgSEc+5W6y+6qPfh+MARvGMvj4\nW58nvreK7QSqjSjor5QsLBUreNenD4jFU6au4b+/7ho8a+Mo3vr3D+DI9DKu3jKO37nrINZ7iSdS\n5GXLwX//2uP4wdMXMZlL4c63PQ/LJQv/9V8fxZ+94Tmiagcgj9x9/ZWyhV/7/x7AdIOZFWPAu196\nBV5x9Sb88b89hvuPzWAiZwaO2999/yi+9NBp5FI6/tdbrhOKfNe6PH54ZEZ8hzSz+ot7n8B3nrgg\nrBUqafvpqQXcffAM/t9feq6wAj76radw72PnxAIeEjGfuf8E/uFHx1GyHOyQlsmvCQVyukl8/6mL\n+L0vPILrtk3gvbfvRj5lIGvq+PN7nsCnfngcJ2ZWsWfjKExdw461eXzmgRO478lpnJhdxebxLOpB\nM41Myn0vslZSUiD/yiNn8dCJeRyZXsYLdk25zzd03H90Bj/3v74PAHjZlRvwvtv3iOtHPg/+02ce\nFEnaMHTeyOWOv/aJB/DrL9qJX37+9qqxAK7H/eWHT+PO7x2t+bnOLRYxmUsJS4VmtVlTx90Hz+DA\nM3M4M1/ArrV5/OL1W/HRbz/VMX8cSCaQ/wTAbsbYTgCnAbwZwC8n8LpVXLF+BLc+a33gsXCVwUJo\nOyvAbaEpq7snzy/h/mOzGM+a+MQPjuG9t+2GpjFcWCzhoRPzuGHnGjxwbBY/ePoiPn7fUZyZL+C6\n7RN1x3bN1nG8+YZt+LN7DuPJ80v40oOnsWfjKN72gh24++AZnF0o4o6bL8c3Hj2HZ2ZWceve9fit\nWy4Xf/8L120RizVufdZ6HDw5D9sB3vQz28AYw7tvvQI/OT4beM/nbB3HNVvGxe97N44GSs4OnVnE\nVx45i32XTQYCOR0v06ieTP3Gi3fi64+eww+ensHjZxexb4frz6+WLbzr0wdw+NwSfunUPDaObxR/\n88UHT+OrPz2Ln9kxiamRFD5/4BS2r8mJaevLrtyAQ2cWvLr4Iv798AVcWCpJHjkXiyjyaQOj3s/L\nJRtnTszjB0/P4Iada5AxdXzvyWkceGYWmycyeOzsIn735Xvxzpt24sPfOIyTs6t41TU5jKYN4ZG7\nm+M6OFRexNHpFZycXcU9h87jrTcu4Kbda8VnsDmHrmkwdYZHTi3g1FwB12+fqAp+Mg+emMenf3wC\nN+1eh0/96DgmcyYOnVnE0xeW8ZxtEwCArz/qBlrL4Xj87KK4eb3jRTvx+QMnYeoabtm7HhM5E7/2\nwh145NQ8vvLIWTAGXLd9EindDRCf238S00slfODle3GZ1+f7ywdPY6Vk4XXXbcHcagWHzix473kW\nZxeK+LlrNuGle9fja2W3r4vcMAvwPfJvPXYeDMAn33GDUI2//bLdeOCYe75tGs/gdd7M8Tdv3oV7\nvMTdpvEMXhq6HsO85jmbMZ41Ay2CV8qWKEd8x0078eOjM+L13vA8931++fnb8bWfuuM+dGYR//rQ\nabzv9j34+qNn8fSFZZQsBwdOzGHrmiy+/ug57F4/Emh1QWwaz+DmPeuwaTyLG3Yy/Nw1m/D9p6bx\nzcfOuYHcdkS1idyP/5uPncfxiyt4weVTkZ9r80QWr752EwDgd1++V8SH8Od57XO3YNuaLNaNpvtb\nkXPOLcbYuwHcA0AH8AnO+aG2RxbBr954GX71xssCj5kha2W+UIauscBBm8iagcUyNLX6uWs34TP3\nn8DT08vYs2FUrKZ8w/Vb8diZRfzjj5/BA8dn8Tsv24P/fNvuWGPcuXYE//rQaSyVLKGaV8u2mCks\nlyzs2TCCj731eYG/u3rLOK72gvKzNo7h42/dF/j333zJ5fjNl1yOeoR7RVAt8GKoJpusFTOi/vc3\nXrwLt+xdj9s/ch9OzRWwb4f7+J994wlR+SAvJeec4x9+dFx8Nvqci4WKWKL/7E3+57n74Bm8558f\nQqFsBZpmFaXSUlIu86tlMY3/21+5HhlTx1V/dA8KFVtMX6fyKWRMHX/081cFPoepu1Pc+UIFN+xY\ng/uPzWKxUBGW1MxKUG07kiI/4iXz/uKNzxHJ6Cg+dPchfPYnJ/CjIzOwHY5fe+EO/MW9TwZ6w1u2\ng6mRFM4vllCq+DvIv/yqDcJzFq/3mquwVKxg3598S5TiUbCl2UF4g+pb9qzHh99wLT509yE8cGxG\nfA/XbBnHX//K9QAgZk9ha4WC68m5VawPBZo7br4cd9xcfb69cd82vHHftqrHayGf1+7mxg6KFUfM\nWH7jxbvwGy/eVfV3r79+K15/vRvUP3T3IXzhQb/x1861eRw+t4SK5Qir6ldvvAxvf+GOumPZNJ7F\nX//K9Xjjx34oKkuKFRsT2eodsgplGzvW5vF3b/+Zhp9RHn+tz/Oul1yODtnjABKqI+ecf41zvodz\nfjnn/E+TeM24mAYLdPObX61gImsGfPTxrBko3aNkBE3jHnxmDoDf8yOb0vGSPetExvnVz9kcezy7\n1uZF4Fz1knVkEQD+Sr5OkDH0QA3r4bNu4F0MbV5B1opR48za6vV+kT35R08vYK+n6uV2qz8+Oosn\nvaTYUtESgWahUEHZqq5qIPUj31wsmwfKxK7wgufjZ5fwxLklrB1JY2okLRRToewIBZ9NRXu0KV3D\nhaUSOPfbqS4WK6K8b2Y5uHjKcjh0zyOnv9++plrhydy4awrFioM7v3cEps5w27M3AABmpdeu2FwE\nrZLloOItCZfPT5nRjInbr9wgxhA+fuF9Temml0/rWC3b4JxjtWQHrEVKdsqLgQBfkZ+YXRU+eicx\nNCauw2bU6WQuhaWihYrtYHaljA3e57EcR4iBKFFSCzehH127DrjxYbVsB/YJaJd33rQTv/6inYm9\nXpiBWtkZhaEFqwzmVyuiLzAxkQsFcu8u/qyNo5jMmTjgBXKa9roXpTtlvGbLeKCvciN2Sc30SZEX\nKjZWvE12l4qd20nbTVT6x8JX5MFAbjUIJhlTx9qRtNj5BHDbj9LUXA7C//rQaYxmDIxnTSwW/RvW\nYrESqNElRCAP1cTLCzcm8ynsmMrh4Ml5PHlhGXs2uIFd96pKZEWeqZFsMw0N570tuOj7WyhUxHkQ\nXgXrOFyUH9LfGA2Cw/O9stCfHJ/Dc7dNYIt3A5Rnf5bj7yBfsmxULKdh0PmF524RxyJ8/MgidLz+\n1nSTyKUMd/cdL98g5za2TubAGLBpIhis6bWXipYI9p3EDeReGV4TgZwsx7mVMmZXymKsFdvfbcjQ\n48tdeSl+uHbdfczBasVGtkOlgp1g4AN5uF54vlAWfYEJUuSij4VUj3799kk8eMJT5F4g1zUNL927\nHiNpQ3h2caFAPpVPYbVEitzzfIuWWJLdCTIp31rhnEuKPGitVGwHRkSiU2bLZDZQ7mg7jmgMJCvy\nc4tF7Fybx5p8CkvFigjyriKvLk/Lekkv+WZQsblfOuhdVM/ZNoGHTs7hqfNL2CP5+1nPPhKKvEYg\nT+saznt2BCX8FguWZK0EA7nNubey0x3fFRtqWyrEZD6FZ210x/b8nVMY9Vr2yq9t2VwK5E7kzS3M\nS/asw1Wbx3DlprEIRe6On0ozaQ9IaqG6WrKxUg7uRLNxPIMv/NYL8drnBmeW8g1lQzcCua6J5GO+\nmUDuXc8XlkqYL1SwfsydWVRsJ7DnZlzk4odw7ToA7/yykK3RQ6YfGZxbTg3c7odBayWsLsazpuhj\nMZ41A1tUXX/ZJL59+ALmVsqir7mhM0zmU/jhH9za9Gapt+7dIMqNPvGDY+5U17volkoVLJc6a63Q\nEuTT8wXRtyOsyCs2D9TiR7F1MiuWdQNuQNI1htGMEZjez62Wxeq25ZIlFOPcSgUOr77AMhGK3G2k\nFGzA9JytE/jyw27x096NwUBeKPuKvJa1Yhp+B8nta3LQWFiRBz1y21PkFGR3r28cyAHXXjl8bgk3\n7poCYwyTuVTQWnF8P7hUIWulfoBIGRq++p4Xi9815tbzcu5bK6LKh+q0037t/UpIkQPA9dsnI9+H\n2NQFa8XUmQjkTSlyz9s/dnEFnLsiiTZdb81a8RU5NeoCgi2vCxVb1L4PAoNzy6mBoWmwHC7Utmut\nVCtywO82KLfDpRP84Kl5ceFTWd5YxqxpP9RiPGfiv776SqwbTYNz116hoDO3UkGx4nQsey03vSI1\nPpEzIwJ5Y1W4dTKL03MFcVwth8PUNYxmjOCmz95mBSNpw/PI3X+b9lYZ1rRWirK1wqsaMFHVB4Cg\nIk+5eYBGily+gUyNpDCWNT2P3FPkIY/cDnnkV8QM5G943lb87JUbsG+Hex6tyacCyc6KxQPWCi1P\nb4aUoeHqzW7CcLnk510AX9lSnfb8agUVaRZQ93WlcWzsikeuiRtpU4rcC+SU+F4zkhYrcFuxVtIB\na0Wuafevn0LZrikS+pGBD+QUKEhNz6+WIzxy90Sgk8hviK+LpjcLhYqYpjVzUtSCprqzK2VQCfoZ\nr8dzpzqgyW00yR/fd9lkS9bK1skcyrYjArJlO54iD276MOctjHCVekX8G3nQVYE8RYrcfR5jvkee\nMvwGTFdtHhPJ2D2SzZEx9XgeuRSk3KZkZl2P3C0/9D3y3etHEYert4zjzrftE+OYGgnu1mQ5DjKm\n2/vFTXbyhjfRMFsnc7j1WeuR0jVxAxQtGsgj95KbF5bcvEA+RhCSx9ENa0XXGOZXW/DIKZB7C+3W\n5FJir95WrZVSxQ5szAwEr5/Vso1cg8VO/cTAB3K68Khh/UrZLyciSJHPe4kWUuQpQwv8vSUlO9uF\nEiXTUv+Ls/MUyDtkrUjd145Or2DLRBabxrMRyU4eWUMu41euuGO2HA5DZ56ydYNI0Uvirsmn3H7a\nRatqNWYjRZ41dVieRy77wRlTx7M3jWHLRDZwvLLeytNiA2uF3ncsY8DUNTcZW/A9fNnH5tzdoFfX\nGAxdg64x7Fhbv2KlFpO5YCAnG4taH5S9zTaa4avvuQnvuc3dcWc5ZK2EFfmFxVLg8XoEFHkXArm8\n5V8zgZyE2RFS5Hk/kJO10qwiL3r5Cvd3SnZKHnkl2aqVTjM4JlANSFlWbEckgCZC9bJ0IiyI5c82\nTJ2JCxegUib3i9UbqNU4kCK6KK0OPOtVUXRekTtY8ra7o51nOOfCJirbTuSqTpmtE34J4vMum4Rl\nu8nA0YwhyhLJ75zMpXAxUwpYK0Qtj5wUpVtt4USu2v2dn91TteVbNuV55DGtlakRd8Y1ljWwWLSE\ntUIzMFP3N7rWGcOutXk877LJqrHEZSq0f6rlzX7SpoZSxXYDe4ObaBgay4iUn1iRVsICfr9v6vMT\ny1oxumytSOeCXB7ZCLoRU7MuN5C7m65THXmz5Ydlr57d/T3YNMu9XjBQVSuDM9IaUL+Iis2FB15T\nkZNHLgUNU6PgxkX5Ya366mYgpSgrcirnazaBGvs9TV9RrJbdhNdYxoTD3WZedHFbNm944m+pUuQO\nDF3DWIYJW4QC1pq8idG0geVysNUuUK3I06LkzX1eLqVjfrUc2YCJ+seEP+P8agUF7yKsFcjp89G0\nfDxr4vziMhYKFeRTOlbKNuZWylg/lhGqTtMYfue2vbG7V0axJp8O3CQqDilyzVPkzXvkBNlXQLD7\nJeArcGGtxDjH6BhN5MyaFlWSyNdVMx454N4gjxbcQD6ZN8Wm66Sqm012An7C3Vfk7uOU4xikqpXB\nGWkNKBBXbEfsozdZK9kpKXL60oQi97ZWA5o7KWpBJ+rFJV+dnemwtZIOBHJ3akhNtcJ1241UYS5l\nYCqfClorwiN3X0veGGM041YGnVsIbm4RDs7UIY7Gk0u5PaCLli1mFPUIe+S1uu/RDYQC+VjGxPRS\nKdB/hOwV6qOje+dSswlumTV593jTsbG8gC6slRhVK7UYTZt1kp2eIm/GWvGOUTdsFcC/rgyNNeya\nGIa6DI6mDW87OLfHUit2aCZk79FYGHOrlkjwqaqVLkInR8V2RCIlnOzMmG5jGxHIJfUne+RJJjtp\nqiv3iO64tSI8PgerJS+Qh/pcA6610ijZCbgbDNDScNda0TCWMYSy9BV5SnymswvFgOKMSuxlU7rw\nqrMpXazsjGNnZE0dRW+j6YxZe3caOi+mJEVO3z8tEKLx0w08iZkYrZ6cW3HXLTjcPZ9cRW7Hqhiq\nhWyt+B65e8xyQpHHt1boGuhGohPwb5QjGaPpmyXdkCmg06brlTYUOZ0P8mwkIwVyVbXSRWRrhfbA\nHM9WK96JnOmXH0odz8SNwHH8u3sCHjndzeUOeucX3UDeyZWdgNvXebViIZcyRHvUpdCS+DjT+5Sh\nibyBa60wqW92xVfk+ZT4TOcXi8KWAap3WAcQUOT5lIGKtyFvrU18A38rlR/WslVo7ICkyKVzggI5\n3WS9jwitDSVO0PvNrJREJZWpk0eehLVCaxIsbwm/33UP8M+3OB40nfvdU+Tu8c23oHRpUdAaEcjd\nZGd71ooV+B1wZ7V0gx+kZOfgB3LJWpmXAkuY8azpV61IDexJhVk295OdCZYfUrBgzN2FBuhkstNT\n5GW7WpGHrJU4sw5D8ztLyslOwF2ZSSf8RNYUAd7hwJYJP5BHqc+M6ZfRZVO6qLePM93OStZK3UDu\nfT7fWvGPeViR+0nu5AL57Eo5kHMha6UdRT4m2VorpWCrB11zLavpJhS5rjFsHs/gqi1jLY2nWWgW\n2Mo6ClqmT8fX0N2dwdqyVgpBa4V+pjgySIp8cEygGgStlQoMjUXW0E5kU5JH7i/L1aUbgei1kmCy\nkwL52hHXpkhJDe6TRgRyK8IjlxfgOBz5GArG8HxIznnAIwc8Rb5SxnjWhOEtFCICgTzifbIpXVQM\nkOpZKVmxKifcDo8OVssWMnUuNAqW1B9GVuSXTbkrPYW1wv1kZ7tQoJlbKYsuk4bX/Kpk2SjH6LVS\nC9oyj3N3R6VwQMyndbGlWNxk4n0feCn0BGYicSDx0EzFChFW5KkErRX5esyYuqjKUh55FwlbKxO5\n6NWYY1kTC7SxreSRM+buG1ixue+VJpDspJOALqwNXn+ITvVZAXxrhVaTZlPVm/oCiNW4CfB9SPm4\n0OstFS3MrlYiFe+G8Yxo2RnpkUtKOiuVI8ZS5F7wnl+t1FXkftUKlR/6gXw8626aS98NWStJeOST\nXn5mRlLkctVKJUbFUC1GMwYcb/YSbowF+Oecuz4i3nuYeu08Q9LQ8W22YgXwA/hUyFqptLJEP5Ts\nlJPs7hZzQZExCAx+IA9ZK+Hl+YTrkbsXbtkOJtaM0N09iWSnrjFkTE0kpdaPumqzk83lKbCJxkQp\nXSjoqqqVGJ/R1N32B1Sep0cocgpc8tZ6YxlDBM5oa8U/9hR8lktW7GQn4KrpOB65nOwU48sa3gpM\nd7ZEijwJZWp4Nc+zK2Vh2RiaV7VScQL5mWaR9/VcLllVZawUeDp5jrUDCaRWrMVwspOsFb+OvIkF\nQeHyw5AiJ+qdX/3G4Adyg8oHuehFHoVctVAK9cl2d633A1YSyU7AD1IZUxOBpFOlh+77+EHOfX93\nN/msqWOhUMHnD5zChcWi6JvSCHc/VOm46JJHXnA9crrA5IuT2toC0dZKMJD71kpcjxxwy/vqeZgU\nzGj7N3n3+LGMiXWjaZz3SvVsOzlrBXBvHjMr5YB/6/b38KpWWhQKI2I2VPEUefDz50OLg/qNtpKd\n+eSsFTr/hLUSUuTEIHnkAx/IjYAir+5FTkxkTayU3QtJbl0JuCdB2XaEp5lE0gvwL6h8yt8ZvlOJ\nTkBa0CACufteY1kDD56Yw/vvOogvPXQaZSteslNYK1J7X7mcUe58mEvpwk4ZzZjieVHBOWCteMfI\ncnisRSnki8+tVOo+/+efsxmfu+NGsbk03Vhof8Xta/Jin0ehyBO6GvJpAwXvXAO8qhVhrbSjyL1A\nXrKwUrIxEhIFfa/IPYHUirWyd+MofmnfNty8e514rXa6HwKyRx4dyPv1hhjFwAdy+gLLDayVcWmZ\nfng5uKlr3t09uV4rgK88sildXISdvMgYc73YmVD51FjGxIMn5gG403LLiVcCZ3jWil9GxyRVGFTk\njPnb6wUUeYNALl8szShyea/FKDKmjufv8vdbpDJMGteOqRxmV8pYKFT8JfoJzcRShrvxs9wHxO+1\n0nqyU85PLEUkO4Vw6NdA7l1XrVwDGVPHh99wrUiI06br5XasFa+UM1BHHqgpV4G8a6Qka2WhUAlM\noWXkZfpV1orX09zdSb32zjnNkpUUOXnInbRWAPdEnKNAniZF7r/ncslCxebxFLlXfmhLHjnth3ph\nqYiS5QRKPemzjaT9+vVaC4IIeZodq468RQ8zbejImJo4FrSB8YmZVX9lZ0Lfe0p3A7nIuWiuIi+U\nbVhO890PCTqH3OZkFYyErZVUcLl+v2FIC4LahTZddzt5NnfNimRnHUWeNfWuJYGTYOADOZ0cJcvG\nasWuOrkJeZl+OOFEPTEqjpNI5QLhr7rTu2KtAK4fH17QIFeUrJSs2FUrdIMTFoHmJ6uOXfQaGOXk\nQE6f0YztkWcDijxGsjPVuoc5ljHFsaDuhsdmVqSdoZp6uZqYhoaS7VR55NRWoJ2qFcDND7h97UPW\nSpqslf5UkpTsTOJGY0rWSrPHM1On/JB+HiRbBRiCQE5f4lLRAue1TxK6CJZLVlWDJkNjqFhOrGZS\nzZA1/eRTtwJ5NmJlGqlQjbk7yFSaslaCihxwP8P9x2YBAFdu9heT0GcbyxiYyqeRMbXIUs5srals\nzF4r4nWavNgmcqaw3i5b4yryZy6uCEWexMpOIEKR61ooWLS+RB/wVwhXJTtJkfdp/TNVmCVxo6FN\n1+Pme2TSUrKTsaAtQ+fgICU6gSFYEJQK3V1zNQI5qZelYiWwshPwAxZtnpAUQpF3KdkJ+E2l6H0B\nt0XpVD6FTRMZbzfyZqwVqSuk9zdjXoOsX9q3DVdvGRfPF9ZKxsCvv2gHbt6zLvJ1SVWndC0wjmbK\nD8M/x+GPfv4q4c9mUzo2jmVwfGZVqpNP5rtPGxrKlh1YYJYOzQBbYSRlgLHaPXty/W6tkCJP4EZD\nBQpuFVBzx1PeZDlr6gFbhoL8IJUeAkMQyMkKkWuno/Cnpe5ekvKFlfK2jaKWo0khLiypnrvTHnk6\nIpH4nlt349deuAPvv+sglksW7Ljlh96iC7+plPs3a0fSmMyZ+P1XPivw/NGMIZaK51KG6AUehi4S\nU2eBi7CZBUHy68TlRVesDfx+2VQOz8ys+Cs7k1LkBpVtepaUoQXPtxYVuaYxjKQMnPV2mgpbK3lh\nrfTnZS088iSsFdpYooVZtKExaF7LjHBehmyXQbNW+vMbbwKqI6c+KrWW1dK0dMZbMi9/gcJC8Dr8\nJQWdDNmUIeqZaYVnp8hElE/l04b7X8rAmXlXzcVb2alFdoX8o9dciWLFqepps2Esgw2j6YaJJ7rZ\nmIYWyEnEKT8M2DJtXmw7pvL49uHzVdZRu5C1Qh65obHADbYd+24sa+LJ8+5OOWFrpf8VebLJTjo3\nm51JMcaQMfXI/j5CkQ9YIG8rajHG3sgYO8QYcxhj+5IaVDNQAo46G9bq4zDineTkHwesFbIQnOZP\ninrkRdWKjsum8vjqe27CLXuqN0tIkqhVk8RI2hANgeKt7GSoOE5Vm9dN41nReErm3bdegc/e8YKG\nr+sr8qCHHkeRJ7nybsfaPC4ul0X1QmJVK4Y/7Qf8OnL531vlV27cLhpjha2VfL8nO9uoIw9Dq45L\nLVgrgLQrUMjOSwtF3p83w1q0Kz8fBfB6AN9LYCwtQQGJWtjWOkk0r2yOmliFPctWp2n1oK2iSBlf\ntXm84yVNlKxJG1qVwsynDZFLiLuyk3N/s+pGPWjGMia2TzXe65ICcErXAjeUOOWHaUMDxdu2A7k3\nVtpCLClFburRdeREqys7AeBdN1+OW/a6uYdwqW2/K3KzjTry6tdyz5VC2W7pmqXvI5xgH1RF3tYR\n5Zw/DrS3o0q7uHXffrKzXiLFDeSeIg+s7GSijW1Hkp1dvLBIsUZ5fPm0IVrpxmkMRrMT2h8zqdJM\nukhMnQUuwjjJTtphaLVsB0oRW4EWl9AWfIlZK0Z0HTnRjljQNIaPvvk63HPoHK5YPxL4t3yfLwga\ny5owdVZzrUcz0E1htWy1NIv2BU8NRa6SndEwxu4AcAcAbN++PcnXhanJ2zPV/gJGM4bvkYeqVqiN\nbZJ15HKys1tkRSCv/mrlqXgcVUgXC+1Yn9SxoZuNEVLkccoPAYhA3u4+kxTwqLFZUrMl31oJ1pHL\n/94O41kTb9q3rerx3RtGcc2WcVy1uTv9xZvljc/bhuu3TyaidulmuNqmIg/befWEUD/TMJAzxr4F\nYGPEP32Qc/7luG/EOb8TwJ0AsG/fvtZ3t43A1BkWCo37MI9kDDGNln01U3ebZsWt5oiLnOzsFnUV\nufRYnKQuPYfKGZPKHwQ8cq05RQ74n7Fda4WOEW3WkJRHTsGhUHZvEOE68iTPMZl1o2n823++qSOv\nnQTZlB4oV20HQwrka2q05agH3VjDdh59d+0m0rtNwwjDOb+9GwNpB9PQsFKm2un6HfGiOp5RA55W\nMuD1yEnJzm5BnyvKzpFvcmYMVUhquVTxLYIkIEWW0lmojjymIhc3yHYDeVCRJ1m1AkCck9SPXPx7\nm4pc4c8oC2Ubxmjz35sI2DWtlf60p2oxFGcUBRi9we7csjdX3TTL3TYqqRa2QHUP5W5AJ2aUxycn\nmeJYK6R6SJEnFehkRZ5q0iOX/z45RZ5wIPfOwVXvBmFqWtBa6ZAiv5Sga361bLU0w6FZXVUd+YBa\nK+2WH76OMXYKwAsAfJUxdk8yw2oOCkr5lF438SoHsmDyiXl9G5JNdl6zZRyfveNGPH/nmsResxGN\nkp1EPGsl6JEnZQnUKj9sxiOX/98qaUODxvzmSUlWrQDutB+IqFpRirxtaEbZukdeP9l5qVWtfAnA\nlxIaS8vEbcYjL0QILghyPfKKzZExkwvkjDHcKLVS7QaZRK2VzihyOvam0fwSfcD3L9v1MRljyKcM\nP9mZYB05IFsryVWtKFxIvJWseLtdhRm2ZOdQnFH0RTY6+HLVRnBBkL8UfdAvMnEiNrBW4mwwHQ7k\nSbUvoFrwlM4CVlacOnIAyFJjowRKxHJpXfSlTqoqR1grZf91lUeeLPKMsh1FHq582rk2j1dfuwk3\ndHEWnQSD5ejXwIyryGtYK25vDL+38SAjyg8jVvfJq17jKHJSy8VysoqcasENLVh+GNc7dv+WJXLT\nzaUMseVb4snOkn/cgkv0B/sc6wfMNmc49H1EKfK/+uXr2xtcDxgKaUBfZHOKXK5aoQVBw6DIax+L\nkYBH3kwdefP7IjYia+owpdWnKSP+bu7ZlJ5Ydzr5OCVVR07n1krJgqkzsXOT+Hd9sKbt/Yh8M2zN\nWtEC/x90hkSRx1v6K3celBUSbWmWdBvbXpAWHl8DjzzmEn0geY8ccGuep/Ipd0GXXr/aKMzPXbMZ\nG8eyiYwjF6itT95aoeMsd9wzjcE+x/oB+fxtTZFTHflw3FSHJJDHa3QTLL+TTgTvAi5U7ETryHtB\nps4OJ6auieXjcXxaYa2QR55gaeY/vPMG8X25S9jjX1A37V6Lm3avbfzEGMjnTFLJTjofV8q2uDm4\nqtztFT/os75+oN1AnqmR7BxUhuJT+B55/WBAVSvhXUFEvXTZTjRY9QKyVmr1nKGbWTxrJaTIE7zJ\nrR/NiLE0q8iTRL7hJV1HHm7olDbdJO+g52H6gbatlSFT5IMdtTz8qpX6ipz2a3SrJqpPhGIL20b1\nG7RX5nguujER3eziWSvhlZ2dOTamrsWuIU8a+ZxJcvNlwN1WL7xy1dS1njaZGxbatlaGTJEPhbXi\nbyHVQJF7O6qEp/F0IpRjbkrcz+xaN4JPveMGvPDy6Pp1UupxN5YApF4rHQrk4QUz3SSgyBO6ifsr\nO+3AzCht6EjrdiLvcanTfiBXyc6+gxRQo3axI5Iil5FV06AnOwHgJTX2ygQQsDMaEfbIO3VsTF2L\nXUOeNHKZZtJNs8p2cLFK2tBilX0qGhO0RltpY6sH/j/oDMVZRV9qozpydwl/9cIT2RcfdGulEXSM\nYtWRS1UrVEbXCUxdq2pe1C1kxZxUekROJBshj1z1WUkGWYW3t0PQcHwfQ/Ep4lorjLm7BFVZK1I5\n2KAnOxtBs5I4n5MukGLF7uhMxd3Tsg+SnQlXrYR/Thu6Kj1MiOAxbqeOfDgU+VBYK3HLDwG3A2KV\ntXIJKfKRVPPWSqerea7ZOo7N48nUhTdLINmZcNUKgCprRSnyZIiqOmuGy6bySOkatk725rxLmqEI\n5KL7YYxNZ11FHrJWAqVMw32hkbUSJ2gZUjVPeKPfJPnIm57bsdduBClyjSW3ZaEcrOUEMVWtKNqn\nXWtl78ZRPPmnr0xySD1lKAK50YQiXzearlKjsiIfhmRnPW7YuQbPzKzEClqkwm2HJ7apRL9BgTzJ\n772WWnzLDdvFJuGK9ghYK8quGo5ATl9qnN25P/yGaxH+2uXE37Av1njF1Rvxiqujdu6rRraZhvW4\n0M0/qVWdgKvsaQWtHNR/9qp4x13RGNp0nfPkdq4aZIYkkMdrYwsAWyaqPTG5paua+vrIx2JYcwdU\nfpj0jSqtu4FcBZnOYeraUKz9SIKhOAJx29jWwrgEAlYryMFteBW555En/Plolqda1nYO8sbVMR6S\nQL55IovJnBnLWoniUrAQWkH2jVupDBgEqI486dyIH2SG87j1A3TdqmM8JNbK66/bgldevbHlnVcC\nC4LUVFhALWYrNh/aG5xIdia82InOxWG9AfYDprpZCobiCGgaa9lWAYJZb2WtBKEb27Ael1ynFDlZ\nK0N6A+wHlLXiMxSBvF3a3f9vmKGLRB/SmUrGay3bKWtlWG+A/YCyVnzUEUCo7lcpqABi+jqkx4Ux\nhpypJ1p+CChrpRsoa8VHHQGoqpV6GEKRD+9xyaWNziU7h/i49RpTWSuCoUh2tktQkat7mwwdj2FW\nPbmUrpKdA4iprBVBW0eAMfbnjLHDjLFHGGNfYoxNJDSurnIptbFtFvNSUOQpI/E6cpHsVEGmYwhF\nPiStaNuh3SPwTQBXc86vBfAkgD9of0jdx7iEmmY1i3EJTF87osgvgePWa4QiH2KREZe2ohbn/F7O\nueX9+mMAW9sfUvcJLEVXJ0UAOh7Drcj1jilyZdV1DpXs9EnSI38HgM/V+kfG2B0A7gCA7du3J/i2\n7RMM5OqkkDH14fd63/C8rVhIuCuh75EP7w2w1yhrxadhIGeMfQtAVNu2D3LOv+w954MALAD/VOt1\nOOd3ArgTAPbt28dbGm2HCHRSUxdeADoewzxTee1ztyT+mqqiovPQOTnM52ZcGgZyzvnt9f6dMfZ2\nAK8GcBvnvK8CdDOYmla1Wa5CUuRqptIUaWWtdBxTJZQFbVkrjLFXAPg9AC/hnK8mM6TeYOgMZVtd\neGHMS0CRd4KU6n7YcVK6Bl1jQ52/iUu7UeuvAIwC+CZj7GHG2McSGFNPMNWS6kiGvddKp1DdDzuP\noTElMDzaUuSc8yuSGkiv8ZWnuvBklCJvDbUgqPOYajNrgVrZ6aGUZzT+cVEXTDMoa6XzXLNlHGfm\nC70eRl+gArmH6KSmFHmAS6FqpROoJHHnecsN2/GWG/qrlLlXqLPMQ3nk0ajj0hqqjlzRTVQg9xBe\nsLrwAvgrO9Wp0gxpVUeu6CLq6vQQXrAKWAEM1Y61JdQSfUU3UWeZh6mzjuwUM+iI7odKWTaF6n6o\n6CbqLPMwdE0lOiPwdwhSx6YZVPdDRTdRV6eHqTPlj0dwKewQ1Amu3DyGn9kxicvXjfR6KIpLAFV+\n6GHqmiqxi8DUlLJshc0TWdz1rhf2ehiKSwSlyD0MjalFLxH4ilwdG4WiX1FXp4ehFHkkqo5coeh/\nVCD3SOmaqjCIQPV8Vij6HxW5PCZyJiZyZq+H0XcYl8AOQQrFoKOSnR4fePmzsFqxGj/xEkN1P1Qo\n+h8VyD3GcybGoRR5GH/FqwrkCkW/oubLiroYqgeNQtH3qECuqEtKtWNVKPoedXUq6qL6kSsU/Y8K\n5Iq6qB2CFIr+R12dirqkDNVrRaHod1QgV9Tlhp1T+M2bd+HqLWO9HopCoaiBKj9U1GUkbeAPXvXs\nXg9DoVDUQSlyhUKhGHBUIFcoFIoBp61Azhj7b4yxRxhjDzPG7mWMbU5qYAqFQqGIR7uK/M8559dy\nzp8L4CsA/rD9ISkUCoWiGdoK5JzzRenXPADe3nAUCoVC0SxtV60wxv4UwNsALAB4aZ3n3QHgDgDY\nvn17u2+rUCgUCg/GeX0RzRj7FoCNEf/0Qc75l6Xn/QGADOf8jxq96b59+/j+/fubHatCoVBc0jDG\nDnDO94Ufb6jIOee3x3yPzwD4KoCGgVyhUCgUydGWtcIY2805f8r79TUADsf5uwMHDlxkjD3T4tuu\nBXCxxb/tJP06LqB/x6bG1Rz9Oi6gf8c2bOO6LOrBhtZKPRhjXwCwF4AD4BkA7+Kcn275BeO95/6o\nqUWv6ddxAf07NjWu5ujXcQH9O7ZLZVxtKXLO+S8mNRCFQqFQtIZa2alQKBQDziAG8jt7PYAa9Ou4\ngP4dmxpXc/TruID+HdslMa62PHKFQqFQ9J5BVOQKhUKhkFCBXKFQKAacgQrkjLFXMMaeYIw9zRj7\n/R6OYxtj7DuMsccZY4cYY+/1Hv8QY+y01w3yYcbYq3owtuOMsZ9677/fe2wNY+ybjLGnvP9PdnlM\ne6Vj8jBjbJEx9r5eHS/G2CcYYxcYY49Kj9U8RoyxP/DOuScYYy/v8rj+nDF22Osy+iXG2IT3+A7G\nWEE6dh/r8rhqfnc9Pl6fk8Z0nDH2sPd4N49XrfjQuXOMcz4Q/wHQARwBsAtACsBBAFf2aCybAFzv\n/TwK4EkAVwL4EID39/g4HQewNvTYnwH4fe/n3wfw4R5/j+fgLmzoyfECcDOA6wE82ugYed/rQQBp\nADu9c1Dv4rh+FoDh/fxhaVw75Of14HhFfne9Pl6hf/9LAH/Yg+NVKz507BwbJEV+A4CnOedHOedl\nAJ8F8NpeDIRzfpZz/qD38xKAxwFs6cVYYvJaAJ/yfv4UgF/o3VBwG4AjnPNWV/a2Def8ewBmQw/X\nOkavBfBZznmJc34MwNNwz8WujItzfi/n3PJ+/TGArZ1472bHVYeeHi+CMcYAvAnAP3fivetRJz50\n7BwbpEC+BcBJ6fdT6IPgyRjbAeA6APd7D73bmwZ/otsWhgcHcC9j7IDXcRIANnDOzwLuSQZgfQ/G\nRbwZwYur18eLqHWM+um8eweAr0u/72SMPcQYu48x9uIejCfqu+uX4/ViAOe530IE6MHxCsWHjp1j\ngxTIWcRjPa2dZIyNAPgCgPdxtzf73wK4HMBzAZyFO7XrNi/inF8P4JUA/hNj7OYejCESxlgKbk+e\nu7yH+uF4NaIvzjvG2AcBWAD+yXvoLIDtnPPrAPwXAJ9hjI11cUi1vru+OF4A3oKgYOj68YqIDzWf\nGvFYU8dskAL5KQDbpN+3AjjTo7GAMWbC/ZL+iXP+RQDgnJ/nnNuccwfA/0GHppT14Jyf8f5/AcCX\nvDGcZ4xt8sa9CcCFbo/L45UAHuScn/fG2PPjJVHrGPX8vGOMvR3AqwH8CvdMVW8aPuP9fACur7qn\nW2Oq8931w/EyALwewOfosW4fr6j4gA6eY4MUyH8CYDdjbKen7N4M4O5eDMTz3/4ewOOc849Ij2+S\nnvY6AI+G/7bD48ozxkbpZ7iJskfhHqe3e097O4AvR79CxwmopF4frxC1jtHdAN7MGEszxnYC2A3g\ngW4NijH2CgC/B+A1nPNV6fF1jDHd+3mXN66jXRxXre+up8fL43YAhznnp+iBbh6vWvEBnTzHupHF\nTTAb/Cq4GeAjcDe26NU4boI79XkEwMPef68C8I8Afuo9fjeATV0e1y642e+DAA7RMQIwBeDbAJ7y\n/r+mB8csB2AGwLj0WE+OF9ybyVkAFbhq6J31jhGAD3rn3BMAXtnlcT0N1z+l8+xj3nN/0fuODwJ4\nEMDPd3lcNb+7Xh4v7/FPwu3EKj+3m8erVnzo2DmmlugrFArFgDNI1opCoVAoIlCBXKFQKAYcFcgV\nCoViwFGBXKFQKAYcFcgVCoViwFGBXKFQKAYcFcgVCoViwPn/AZi+cz46vWCqAAAAAElFTkSuQmCC\n"
          }
        }
      ],
      "source": [
        "plt.plot(fiveVTSrandom_mean[:,2])"
      ],
      "id": "b201a288-ddf6-48a9-a718-9ad11db7e968"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "### 3) By 2"
      ],
      "id": "bbd207d2-c601-4b8c-a08e-0aba4f23e28c"
    },
    {
      "cell_type": "code",
      "execution_count": 44,
      "metadata": {},
      "outputs": [],
      "source": [
        "fiveVTStwo_mean = fiveVTStwo.copy()"
      ],
      "id": "e51689cc-ec56-45b0-9fc8-114919cd9c32"
    },
    {
      "cell_type": "code",
      "execution_count": 45,
      "metadata": {},
      "outputs": [],
      "source": [
        "df = pd.DataFrame(fiveVTStwo[:,2])\n",
        "mean_value = df.mean() # finds the mean value of the column A\n",
        "df = df.fillna(mean_value) # replace missing values with the mean value"
      ],
      "id": "f61688bb-f056-44a5-898a-8fa56291ab53"
    },
    {
      "cell_type": "code",
      "execution_count": 46,
      "metadata": {},
      "outputs": [],
      "source": [
        "fiveVTStwo_mean[:,2] = np.array(df).reshape(200,)"
      ],
      "id": "4e087e5a-bf8e-48b0-b9c1-42a2961fa6fe"
    },
    {
      "cell_type": "code",
      "execution_count": 47,
      "metadata": {},
      "outputs": [
        {
          "output_type": "display_data",
          "metadata": {},
          "data": {
            "image/png": "iVBORw0KGgoAAAANSUhEUgAAAXIAAAD4CAYAAADxeG0DAAAAOXRFWHRTb2Z0d2FyZQBNYXRwbG90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\nBQWFAYcicgUFBYUBx/8FavvZDcWFu5MAAAAASUVORK5CYII=\n"
          }
        }
      ],
      "source": [
        "plt.plot(fiveVTStwo_mean[:,2])"
      ],
      "id": "d6bd772f-6e64-4e9d-8deb-0b1d66541ca0"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "## 1.2. linear interpolation\n",
        "\n",
        "### 1) Block"
      ],
      "id": "4a5e577b-fb65-4ead-aaf4-229253b1e9c3"
    },
    {
      "cell_type": "code",
      "execution_count": 48,
      "metadata": {},
      "outputs": [],
      "source": [
        "fiveVTS0_linearinterpolation = fiveVTS0.copy()"
      ],
      "id": "118d23c4-06f5-4a69-88ce-a1acbbf71bb1"
    },
    {
      "cell_type": "code",
      "execution_count": 49,
      "metadata": {},
      "outputs": [],
      "source": [
        "# Sample data points\n",
        "x = np.array([48,150])\n",
        "y = np.array([fiveVTS0_linearinterpolation[48,2],fiveVTS0_linearinterpolation[150,2]])\n",
        "\n",
        "# Create interpolating function\n",
        "f = interp1d(x, y, kind='linear')\n",
        "\n",
        "# Estimate y value for x = 2.5\n",
        "y_interp = f(range(49,150))"
      ],
      "id": "bd06e2a5-dee6-4e38-a7d4-9a5f8b9f0c1a"
    },
    {
      "cell_type": "code",
      "execution_count": 50,
      "metadata": {},
      "outputs": [],
      "source": [
        "fiveVTS0_linearinterpolation[49:150,2] = y_interp"
      ],
      "id": "34f92184-4918-4b96-91ff-06e307146745"
    },
    {
      "cell_type": "code",
      "execution_count": 51,
      "metadata": {},
      "outputs": [
        {
          "output_type": "display_data",
          "metadata": {},
          "data": {
            "image/png": "iVBORw0KGgoAAAANSUhEUgAAAXIAAAD4CAYAAADxeG0DAAAAOXRFWHRTb2Z0d2FyZQBNYXRwbG90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\n"
          }
        }
      ],
      "source": [
        "plt.plot(fiveVTS0_linearinterpolation[:,2])"
      ],
      "id": "02398785-dd3e-4da5-b8c2-1b08dcfd203d"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "### 2) Random missing values"
      ],
      "id": "98bf89e1-2ef7-48f3-bd79-838197a7c44b"
    },
    {
      "cell_type": "code",
      "execution_count": 52,
      "metadata": {},
      "outputs": [],
      "source": [
        "fiveVTSrandom_linearinterpolation = fiveVTSrandom.copy()"
      ],
      "id": "0bcce78b-14ef-46d7-916f-bf26a1e28695"
    },
    {
      "cell_type": "code",
      "execution_count": 53,
      "metadata": {},
      "outputs": [],
      "source": [
        "_df = pd.DataFrame(fiveVTSrandom_linearinterpolation[:,2])\n",
        "_df.interpolate(method='linear', inplace=True)\n",
        "_df = _df.fillna(0)"
      ],
      "id": "9202c145-8fad-497f-89fb-70faea90ebf2"
    },
    {
      "cell_type": "code",
      "execution_count": 54,
      "metadata": {},
      "outputs": [],
      "source": [
        "fiveVTSrandom_linearinterpolation[:,2] = np.array(_df).reshape(200,)"
      ],
      "id": "39f092f8-85e6-406d-808c-52c8f23e997b"
    },
    {
      "cell_type": "code",
      "execution_count": 55,
      "metadata": {},
      "outputs": [
        {
          "output_type": "display_data",
          "metadata": {},
          "data": {
            "image/png": "iVBORw0KGgoAAAANSUhEUgAAAXIAAAD4CAYAAADxeG0DAAAAOXRFWHRTb2Z0d2FyZQBNYXRwbG90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\nAABJRU5ErkJggg==\n"
          }
        }
      ],
      "source": [
        "plt.plot(fiveVTSrandom_linearinterpolation[:,2])"
      ],
      "id": "c6d718c4-c1bd-4500-ab19-bdb5f68229b5"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "### 3) By 2"
      ],
      "id": "fe41ae57-d28d-46c3-9631-8690206770c2"
    },
    {
      "cell_type": "code",
      "execution_count": 56,
      "metadata": {},
      "outputs": [],
      "source": [
        "fiveVTStwo_linearinterpolation = fiveVTStwo.copy()"
      ],
      "id": "05c04570-2e31-404a-8b5c-f7107df726e8"
    },
    {
      "cell_type": "code",
      "execution_count": 57,
      "metadata": {},
      "outputs": [],
      "source": [
        "_df = pd.Series(fiveVTStwo_linearinterpolation[:,2])\n",
        "_df.interpolate(method='linear', inplace=True)\n",
        "_df = _df.fillna(0)"
      ],
      "id": "dde50064-1e64-485d-b278-cd3d38301381"
    },
    {
      "cell_type": "code",
      "execution_count": 58,
      "metadata": {},
      "outputs": [],
      "source": [
        "fiveVTStwo_linearinterpolation[:,2] = _df"
      ],
      "id": "67ed370d-62fa-46b4-b488-15a86c2d70aa"
    },
    {
      "cell_type": "code",
      "execution_count": 59,
      "metadata": {},
      "outputs": [
        {
          "output_type": "display_data",
          "metadata": {},
          "data": {
            "image/png": "iVBORw0KGgoAAAANSUhEUgAAAXIAAAD4CAYAAADxeG0DAAAAOXRFWHRTb2Z0d2FyZQBNYXRwbG90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\nQmCC\n"
          }
        }
      ],
      "source": [
        "plt.plot(fiveVTStwo_linearinterpolation[:,2])"
      ],
      "id": "84d203e6-62aa-4f87-8c40-d7ecd47c0f85"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "# 2. ST-GCN 을 사용하여 fhat을 구함. (스무딩1)"
      ],
      "id": "0aad133f-1b6c-404a-aefa-b0f13745a050"
    },
    {
      "cell_type": "code",
      "execution_count": 70,
      "metadata": {},
      "outputs": [],
      "source": [
        "T = 200\n",
        "N = 5 # number of Nodes\n",
        "E = fiveNet_edge\n",
        "V = np.array([1,2,3,4,5])\n",
        "t = np.arange(0,T)\n",
        "node_features = 1"
      ],
      "id": "5cd7efb0-7dee-45c0-af1b-74db7c7a3e60"
    },
    {
      "cell_type": "code",
      "execution_count": 71,
      "metadata": {},
      "outputs": [],
      "source": [
        "edge_index = torch.tensor(E)\n",
        "edge_attr = torch.tensor(np.array([1,1,1,1,1,1,1,1,1,1]),dtype=torch.float32)"
      ],
      "id": "6852bdcf-de92-43d2-90db-26d2454a22f0"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "GNAR이랑 비교 - MSE 등 평가지표\n",
        "\n",
        "## 2.1. Mean\n",
        "\n",
        "### 1) Block"
      ],
      "id": "69b66361-b7dc-40f8-af87-bf2c91a0e907"
    },
    {
      "cell_type": "code",
      "execution_count": 72,
      "metadata": {},
      "outputs": [],
      "source": [
        "f_mean = torch.tensor(fiveVTS0_mean).reshape(200,5,1).float()"
      ],
      "id": "adac417b-4316-457e-b06e-7ad639e00aa9"
    },
    {
      "cell_type": "code",
      "execution_count": 73,
      "metadata": {},
      "outputs": [],
      "source": [
        "X_mean = f_mean[:199,:,:]\n",
        "y_mean = f_mean[1:,:,:]"
      ],
      "id": "47fe455f-4994-432d-81cf-61b71e4ebc78"
    },
    {
      "cell_type": "code",
      "execution_count": 74,
      "metadata": {},
      "outputs": [
        {
          "output_type": "stream",
          "name": "stderr",
          "text": [
            "100%|██████████| 50/50 [00:32<00:00,  1.56it/s]"
          ]
        }
      ],
      "source": [
        "model = RecurrentGCN(node_features=1, filters=4)\n",
        "\n",
        "optimizer = torch.optim.Adam(model.parameters(), lr=0.01)\n",
        "\n",
        "model.train()\n",
        "\n",
        "for epoch in tqdm(range(50)):\n",
        "    for time, (xt,yt) in enumerate(zip(X_mean,y_mean)):\n",
        "        y_hat = model(xt, edge_index, edge_attr)\n",
        "        cost = torch.mean((y_hat-yt)**2)\n",
        "        cost.backward()\n",
        "        optimizer.step()\n",
        "        optimizer.zero_grad()"
      ],
      "id": "d2972563-b290-46a4-abb6-609778db1595"
    },
    {
      "cell_type": "code",
      "execution_count": 75,
      "metadata": {},
      "outputs": [],
      "source": [
        "fhat_mean = torch.stack([model(xt, edge_index, edge_attr) for xt in X_mean]).detach().numpy()"
      ],
      "id": "b45434e8-bd5c-4b3f-a727-9d5bb6a4dae9"
    },
    {
      "cell_type": "code",
      "execution_count": 76,
      "metadata": {},
      "outputs": [
        {
          "output_type": "display_data",
          "metadata": {},
          "data": {
            "image/png": "iVBORw0KGgoAAAANSUhEUgAAAXwAAAD4CAYAAADvsV2wAAAAOXRFWHRTb2Z0d2FyZQBNYXRwbG90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\n"
          }
        }
      ],
      "source": [
        "plt.plot(fhat_mean[:,2].data)"
      ],
      "id": "52915bbe-0243-43b7-9aeb-b2af2874a840"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "### 2) Random missing values"
      ],
      "id": "93974d44-0b58-4f0a-a8f6-626b2ec4fddf"
    },
    {
      "cell_type": "code",
      "execution_count": 77,
      "metadata": {},
      "outputs": [],
      "source": [
        "f_fiveVTSrandom_mean = torch.tensor(fiveVTSrandom_mean).reshape(200,5,1).float()"
      ],
      "id": "bf2533b1-2c44-47af-8d75-cf4bfcbc48a7"
    },
    {
      "cell_type": "code",
      "execution_count": 78,
      "metadata": {},
      "outputs": [],
      "source": [
        "X_fiveVTSrandom_mean = f_fiveVTSrandom_mean[:199,:,:]\n",
        "y_fiveVTSrandom_mean = f_fiveVTSrandom_mean[1:,:,:]"
      ],
      "id": "cfab16cf-dff8-41f6-aeff-6fa51fb65eb2"
    },
    {
      "cell_type": "code",
      "execution_count": 79,
      "metadata": {},
      "outputs": [
        {
          "output_type": "stream",
          "name": "stderr",
          "text": [
            "100%|██████████| 50/50 [00:32<00:00,  1.55it/s]"
          ]
        }
      ],
      "source": [
        "model = RecurrentGCN(node_features=1, filters=4)\n",
        "\n",
        "optimizer = torch.optim.Adam(model.parameters(), lr=0.01)\n",
        "\n",
        "model.train()\n",
        "\n",
        "for epoch in tqdm(range(50)):\n",
        "    for time, (xt,yt) in enumerate(zip(X_fiveVTSrandom_mean,y_fiveVTSrandom_mean)):\n",
        "        y_hat = model(xt, edge_index, edge_attr)\n",
        "        cost = torch.mean((y_hat-yt)**2)\n",
        "        cost.backward()\n",
        "        optimizer.step()\n",
        "        optimizer.zero_grad()"
      ],
      "id": "2f53f120-b931-4597-85f0-07a3934293f3"
    },
    {
      "cell_type": "code",
      "execution_count": 80,
      "metadata": {},
      "outputs": [],
      "source": [
        "fhat_fiveVTSrandom_mean = torch.stack([model(xt, edge_index, edge_attr) for xt in X_fiveVTSrandom_mean]).detach().numpy()"
      ],
      "id": "ce4ec776-45ce-4e99-a961-3bfe6f5dac63"
    },
    {
      "cell_type": "code",
      "execution_count": 81,
      "metadata": {},
      "outputs": [
        {
          "output_type": "display_data",
          "metadata": {},
          "data": {
            "image/png": "iVBORw0KGgoAAAANSUhEUgAAAYIAAAD4CAYAAADhNOGaAAAAOXRFWHRTb2Z0d2FyZQBNYXRwbG90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\nAABJRU5ErkJggg==\n"
          }
        }
      ],
      "source": [
        "plt.plot(fhat_fiveVTSrandom_mean[:,2].data)"
      ],
      "id": "6bac35eb-b019-47c6-9140-0580ddfec880"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "### 3) By 2"
      ],
      "id": "9612e814-8190-463a-9c79-cf23045fbccc"
    },
    {
      "cell_type": "code",
      "execution_count": 82,
      "metadata": {},
      "outputs": [],
      "source": [
        "f_fiveVTStwo_mean = torch.tensor(fiveVTStwo_mean).reshape(200,5,1).float()"
      ],
      "id": "e4681084-9bdf-4fd5-93a0-d784dd43b2aa"
    },
    {
      "cell_type": "code",
      "execution_count": 83,
      "metadata": {},
      "outputs": [],
      "source": [
        "X_fiveVTStwo_mean = f_fiveVTStwo_mean[:199,:,:]\n",
        "y_fiveVTStwo_mean = f_fiveVTStwo_mean[1:,:,:]"
      ],
      "id": "7a8e0409-023b-4486-b0e3-b06a54c10257"
    },
    {
      "cell_type": "code",
      "execution_count": 84,
      "metadata": {},
      "outputs": [
        {
          "output_type": "stream",
          "name": "stderr",
          "text": [
            "100%|██████████| 50/50 [00:32<00:00,  1.54it/s]"
          ]
        }
      ],
      "source": [
        "model = RecurrentGCN(node_features=1, filters=4)\n",
        "\n",
        "optimizer = torch.optim.Adam(model.parameters(), lr=0.01)\n",
        "\n",
        "model.train()\n",
        "\n",
        "for epoch in tqdm(range(50)):\n",
        "    for time, (xt,yt) in enumerate(zip(X_fiveVTStwo_mean,y_fiveVTStwo_mean)):\n",
        "        y_hat = model(xt, edge_index, edge_attr)\n",
        "        cost = torch.mean((y_hat-yt)**2)\n",
        "        cost.backward()\n",
        "        optimizer.step()\n",
        "        optimizer.zero_grad()"
      ],
      "id": "8a42ec9d-bda7-4ebf-8564-82e83e646a83"
    },
    {
      "cell_type": "code",
      "execution_count": 85,
      "metadata": {},
      "outputs": [],
      "source": [
        "fhat_fiveVTStwo_mean = torch.stack([model(xt, edge_index, edge_attr) for xt in X_fiveVTStwo_mean]).detach().numpy()"
      ],
      "id": "0a36a1b9-bf03-4da1-b33a-3baccdb49813"
    },
    {
      "cell_type": "code",
      "execution_count": 86,
      "metadata": {},
      "outputs": [
        {
          "output_type": "display_data",
          "metadata": {},
          "data": {
            "image/png": "iVBORw0KGgoAAAANSUhEUgAAAYIAAAD4CAYAAADhNOGaAAAAOXRFWHRTb2Z0d2FyZQBNYXRwbG90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\nc+SGIEeOHDnGHLkhyJEjR44xx/8PuyCP72o7ny4AAAAASUVORK5CYII=\n"
          }
        }
      ],
      "source": [
        "plt.plot(fhat_fiveVTStwo_mean[:,2].data)"
      ],
      "id": "26721574-42d1-4f8a-a560-eb00b6473402"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "## 2.2. linear interpolation\n",
        "\n",
        "### 1) Block"
      ],
      "id": "9341ae3b-0f7f-444c-ac79-9aa00c45a57a"
    },
    {
      "cell_type": "code",
      "execution_count": 87,
      "metadata": {},
      "outputs": [],
      "source": [
        "f_linearinterpolation = torch.tensor(fiveVTS0_linearinterpolation).reshape(200,5,1).float()"
      ],
      "id": "3ca7a2f9-47bf-46b2-b21f-a2c6edfff353"
    },
    {
      "cell_type": "code",
      "execution_count": 88,
      "metadata": {},
      "outputs": [],
      "source": [
        "X_linearinterpolation = f_linearinterpolation[:199,:,:]\n",
        "y_linearinterpolation = f_linearinterpolation[1:,:,:]"
      ],
      "id": "10abc96a-2d4e-4d8c-8603-6b78bb287477"
    },
    {
      "cell_type": "code",
      "execution_count": 89,
      "metadata": {},
      "outputs": [
        {
          "output_type": "stream",
          "name": "stderr",
          "text": [
            "100%|██████████| 50/50 [00:32<00:00,  1.55it/s]"
          ]
        }
      ],
      "source": [
        "model = RecurrentGCN(node_features=1, filters=4)\n",
        "\n",
        "optimizer = torch.optim.Adam(model.parameters(), lr=0.01)\n",
        "\n",
        "model.train()\n",
        "\n",
        "for epoch in tqdm(range(50)):\n",
        "    for time, (xt,yt) in enumerate(zip(X_linearinterpolation,y_linearinterpolation)):\n",
        "        y_hat = model(xt, edge_index, edge_attr)\n",
        "        cost = torch.mean((y_hat-yt)**2)\n",
        "        cost.backward()\n",
        "        optimizer.step()\n",
        "        optimizer.zero_grad()"
      ],
      "id": "5900aa64-8c6f-4cb9-ab2d-da4d51b2485a"
    },
    {
      "cell_type": "code",
      "execution_count": 90,
      "metadata": {},
      "outputs": [],
      "source": [
        "fhat_linearinterpolation = torch.stack([model(xt, edge_index, edge_attr) for xt in X_linearinterpolation]).detach().numpy()"
      ],
      "id": "ba6c23d7-b8fa-455b-ab60-2ec6089f6cc6"
    },
    {
      "cell_type": "code",
      "execution_count": 91,
      "metadata": {},
      "outputs": [
        {
          "output_type": "display_data",
          "metadata": {},
          "data": {
            "image/png": "iVBORw0KGgoAAAANSUhEUgAAAYIAAAD4CAYAAADhNOGaAAAAOXRFWHRTb2Z0d2FyZQBNYXRwbG90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\nAAAASUVORK5CYII=\n"
          }
        }
      ],
      "source": [
        "plt.plot(fhat_linearinterpolation[:,2].data)"
      ],
      "id": "f2d0e1d7-7688-458b-bc04-85327ddc4b21"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "### 2) Random missing values"
      ],
      "id": "f57ba66d-eb04-42a4-b723-a8d38b4af60c"
    },
    {
      "cell_type": "code",
      "execution_count": 92,
      "metadata": {},
      "outputs": [],
      "source": [
        "f_fiveVTSrandom_linearinterpolation = torch.tensor(fiveVTSrandom_linearinterpolation).reshape(200,5,1).float()"
      ],
      "id": "e3b46719-db67-4d62-a9b2-df8037144782"
    },
    {
      "cell_type": "code",
      "execution_count": 93,
      "metadata": {},
      "outputs": [],
      "source": [
        "X_fiveVTSrandom_linearinterpolation = f_fiveVTSrandom_linearinterpolation[:199,:,:]\n",
        "y_fiveVTSrandom_linearinterpolation = f_fiveVTSrandom_linearinterpolation[1:,:,:]"
      ],
      "id": "d7beb8e8-c876-415b-be74-767a09ce1b62"
    },
    {
      "cell_type": "code",
      "execution_count": 94,
      "metadata": {},
      "outputs": [
        {
          "output_type": "stream",
          "name": "stderr",
          "text": [
            "100%|██████████| 50/50 [00:32<00:00,  1.55it/s]"
          ]
        }
      ],
      "source": [
        "model = RecurrentGCN(node_features=1, filters=4)\n",
        "\n",
        "optimizer = torch.optim.Adam(model.parameters(), lr=0.01)\n",
        "\n",
        "model.train()\n",
        "\n",
        "for epoch in tqdm(range(50)):\n",
        "    for time, (xt,yt) in enumerate(zip(X_fiveVTSrandom_linearinterpolation,y_fiveVTSrandom_linearinterpolation)):\n",
        "        y_hat = model(xt, edge_index, edge_attr)\n",
        "        cost = torch.mean((y_hat-yt)**2)\n",
        "        cost.backward()\n",
        "        optimizer.step()\n",
        "        optimizer.zero_grad()"
      ],
      "id": "a281f7da-8f2c-4073-9717-e03c50bb7bee"
    },
    {
      "cell_type": "code",
      "execution_count": 95,
      "metadata": {},
      "outputs": [],
      "source": [
        "fhat_fiveVTSrandom_linearinterpolation = torch.stack([model(xt, edge_index, edge_attr) for xt in X_fiveVTSrandom_linearinterpolation]).detach().numpy()"
      ],
      "id": "787ab7b4-8339-4a1d-9502-da41747f1178"
    },
    {
      "cell_type": "code",
      "execution_count": 96,
      "metadata": {},
      "outputs": [
        {
          "output_type": "display_data",
          "metadata": {},
          "data": {
            "image/png": "iVBORw0KGgoAAAANSUhEUgAAAXwAAAD4CAYAAADvsV2wAAAAOXRFWHRTb2Z0d2FyZQBNYXRwbG90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\nUWKX4P8Hiadi/nAPKhoAAAAASUVORK5CYII=\n"
          }
        }
      ],
      "source": [
        "plt.plot(fhat_fiveVTSrandom_linearinterpolation[:,2].data)"
      ],
      "id": "5fae3f6e-67e3-4d06-bdf4-017f1f176477"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "### 3) By 2"
      ],
      "id": "64f5c03a-ee04-4ef7-92a1-c528a9dc0c9c"
    },
    {
      "cell_type": "code",
      "execution_count": 97,
      "metadata": {},
      "outputs": [],
      "source": [
        "f_fiveVTStwo_linearinterpolation = torch.tensor(fiveVTStwo_linearinterpolation).reshape(200,5,1).float()"
      ],
      "id": "811764ae-aa28-4d1d-81a4-f03d594ff766"
    },
    {
      "cell_type": "code",
      "execution_count": 98,
      "metadata": {},
      "outputs": [],
      "source": [
        "X_fiveVTStwo_linearinterpolation = f_fiveVTSrandom_linearinterpolation[:199,:,:]\n",
        "y_fiveVTStwo_linearinterpolation = f_fiveVTSrandom_linearinterpolation[1:,:,:]"
      ],
      "id": "3ac046d4-1586-47be-be95-996175dfbe88"
    },
    {
      "cell_type": "code",
      "execution_count": 99,
      "metadata": {},
      "outputs": [
        {
          "output_type": "stream",
          "name": "stderr",
          "text": [
            "100%|██████████| 50/50 [00:32<00:00,  1.55it/s]"
          ]
        }
      ],
      "source": [
        "model = RecurrentGCN(node_features=1, filters=4)\n",
        "\n",
        "optimizer = torch.optim.Adam(model.parameters(), lr=0.01)\n",
        "\n",
        "model.train()\n",
        "\n",
        "for epoch in tqdm(range(50)):\n",
        "    for time, (xt,yt) in enumerate(zip(X_fiveVTStwo_linearinterpolation,y_fiveVTStwo_linearinterpolation)):\n",
        "        y_hat = model(xt, edge_index, edge_attr)\n",
        "        cost = torch.mean((y_hat-yt)**2)\n",
        "        cost.backward()\n",
        "        optimizer.step()\n",
        "        optimizer.zero_grad()"
      ],
      "id": "8a59f6d8-0a13-4fca-91e8-b04edf697aef"
    },
    {
      "cell_type": "code",
      "execution_count": 100,
      "metadata": {},
      "outputs": [],
      "source": [
        "fhat_fiveVTStwo_linearinterpolation = torch.stack([model(xt, edge_index, edge_attr) for xt in X_fiveVTStwo_linearinterpolation]).detach().numpy()"
      ],
      "id": "77fcd30c-de20-4da4-a2e1-95807cf24aed"
    },
    {
      "cell_type": "code",
      "execution_count": 101,
      "metadata": {},
      "outputs": [
        {
          "output_type": "display_data",
          "metadata": {},
          "data": {
            "image/png": "iVBORw0KGgoAAAANSUhEUgAAAXwAAAD4CAYAAADvsV2wAAAAOXRFWHRTb2Z0d2FyZQBNYXRwbG90\nbGliIHZlcnNpb24zLjUuMSwgaHR0cHM6Ly9tYXRwbG90bGliLm9yZy/YYfK9AAAACXBIWXMAAAsT\nAAALEwEAmpwYAAB92klEQVR4nO29abglWVkm+q6Y9nDmzDyZlZWZNVchBVgFJAgWAjaDFCql3TZi\na8tFu6txumLb3eCj3c3Tdt+L2tLdCoo0DqhcmURBrQakmFQGKwuKgqKoqqwxszIr82TmyTzDnmJY\n90fEt2JF7BWxY9r77HNOvM+TT56zzx5ix/DFu97v/b6Pcc5Ro0aNGjV2PrSt3oAaNWrUqDEZ1AG/\nRo0aNXYJ6oBfo0aNGrsEdcCvUaNGjV2COuDXqFGjxi6BsdUbkIZ9+/bxq666aqs3o0aNGjW2De6+\n++5znPNl1d+mOuBfddVVOHbs2FZvRo0aNWpsGzDGHk/6Wy3p1KhRo8YuQSUBnzH2KsbYA4yx44yx\ntyj+vsAY+yvG2NcYY/cxxt5QxefWqFGjRo3sKB3wGWM6gHcCuBXAjQB+hDF2Y+xpPwPgm5zzmwC8\nFMBvMsassp9do0aNGjWyowqG/3wAxznnj3DOBwDeD+C22HM4gDnGGAMwC+ACAKeCz65Ro0aNGhlR\nRcA/BOCE9PvJ4DEZ7wDwdACnAHwdwM9zzr0KPrtGjRo1amREFQGfKR6Ld2T7HgD3ALgcwM0A3sEY\nm1e+GWO3M8aOMcaOraysVLB5NWrUqFEDqCbgnwRwRPr9MHwmL+MNAD7CfRwH8CiAb1O9Gef83Zzz\no5zzo8vLSitpjRo1atQogCoC/l0ArmeMXR0kYl8H4GOx5zwB4GUAwBg7AOBpAB6p4LN3HVyP4+7H\nL+AP/+FRXNgcbPXm1KhRYxuhdOEV59xhjP0sgE8A0AH8Aef8PsbYG4O/vwvArwL4I8bY1+FLQG/m\nnJ8r+9m7Eb/+iW/h9z4X3ivfcMvVW7g1NWrU2E6opNKWc34HgDtij71L+vkUgFdW8Vm7HScudHB4\nqYVTF7s1w69Ro0YuTHVrhRrD2Oi72DvbwGbfwWqnDvg1atTIjrq1wjbDRs/GXMPAUtvCxY691ZtT\no0aNbYQ64G8zbPZdzDR0LLTNOuDXqFEjF2pJZ5tho+9gtmHCdjnOrve2enNq1KixjVAz/G0GP+Dr\nWGyZWN2sGX6NGjWyow742wiccz/gNw0sti1c6tYBv8b2welLXfy3v/kmXC9eiF9jUqgD/jZC3/Hg\nehwzDQOLbRMbfQcDp25JNGn8yl9+Hf/tb7651Zux7fDZB1bwv//uUTx2fnOrN2XXotbwtxHWe36D\n0blGeNgudW0szzW2apN2Jb7+5BoMTdVCqkYa+rYLIDyPa0weNcPfRtjs+xfKbNPAQtsfJ3Cx9uJP\nHK7nYa2W03Jj4Pqr0Sr23R1fP43jZzdKv89uQx3wtxE2goA/YxlYapsAgNXamjlxuN70sdQ//dLj\n+OLD57d6M1JB8mMV++7Nf34v/vRLiaNbaySgDvjbCBsSw19s1Qx/q+B6HtZ603Wj/e1PP4QP3PXE\nVm9GKvpBwK9i3/VtT6wYamRHHfC3ETYCZjQbJG0B1MVXWwDH4+gMXDhTFHBs19+maUbI8Muds5xz\nDFwPdm1YyI064G8jCIYvB/xuNob/c3/2VfyXv6qdJVXAC2yF0yTr2K6Hrj3dAV8w/G65/UbM3p6i\nG+52QR3wtxHkgD/bMGBoLJOG3xk4+Pg3TuOhs+vj3sRdAScI+NMk69iuJ5L604qqJB1aKdi1nz83\ndmzA3+g7+MwDZ7d6MyqFrOEzxrCYsZ/OXY+twnY5HLe+QKrANDJ8Z1tJOiUZPgX8WtLJjR0b8P/i\nq0/iDX94147qGb/Zd6AxoGXqAIDFtpUpafuF4/6smbrCsRoIhj8l1kzOORyPbwNJx9++svutlnSK\nY8cG/EtBINxJLpb1noOZhs/uAWCxlY3h/8PDfsB3vPoCqQIeJ0lnOhi+HazcNvvTHfAHFUs6Tk1g\ncqOSgM8YexVj7AHG2HHG2FsSnvNSxtg9jLH7GGOfq+Jz07A52HlVfZt9B7NSle1i2xo5BOViZ4D7\nTq0BqBl+VZg2DZ+Ybncw3ec6MfOi1+QH7zqBExc6IuDXbUXyo3TAZ4zpAN4J4FYANwL4EcbYjbHn\nLAL4HQCv4Zw/A8A/L/u5o9AJ9O6dFPA3YgF/qW2mNlDjnOMdnz4OzoF9s1bNiAJwzvGhYycKN59z\np0zDp9xMx3bB+fQe475dvNLWdj38hz+/Fx+++2Qt6ZRAFQz/+QCOc84f4ZwPALwfwG2x5/wLAB/h\nnD8BAJzzsWdTQ4Y/HSysCmz0fUmHsDBC0vntTx/He/7+UfzYC67Ac69cqhl+gMfPd/DvP3wvfvGD\nXysUIN0p0/ApAHIO9OzpDYJZGf6j5zZFYpxADp+e4w5JOj/1p3fjnZ85XvXm7khUEfAPATgh/X4y\neEzGDQCWGGOfZYzdzRj78aQ3Y4zdzhg7xhg7trKyUnijNncow59rhgG/aeroO8ms7kN3n8CLrtuH\n//KaZ8LQtUKM6Hc+exx3P75aeJunEb0gefip+8/gfV/OX506dQxfys10pljWoaTtet9JJB8PPLWO\nf/Kbn8XnHoxe+xTk+7Y3JOnce/ISHniqthxnQRUBX9U2MH40DQDPBfC9AL4HwH9kjN2gejPO+bs5\n50c550eXl5cLb5Rg+FPuTc6Dzb6DGSsM+A1Dg8eTk1d928ORPS1oGoOhsUIM/7fvPI6/ufd04W2e\nRpAE0jA0/N7nH879enfaNHwnPK7TbM2UNfeNhJvl5x9cAefA+Zi7jm4WfccbknT6jicS6TXSUUXA\nPwngiPT7YQCnFM/5OOd8k3N+DsDnAdxUwWcnItTwp+OirAIbPX/4CcEy/MOXlLzqOx4ahm/h1DVW\nSMN3Od9x7h4KFHtnLHQH+b+by6dT0gG2T8BPull+IXCUxc9pwfAlSYfcSQPHRR3vs6GKgH8XgOsZ\nY1czxiwArwPwsdhzPgrguxhjBmOsDeA7ANxfwWcnYie6dOJJ20YQ8PuJAd8VzynK8D2Piwtrp4Bu\nfE1Th5vzZuZ5XASXaTm35Bvy5lRLOh7mA8KiCvi26+EfH70AwA/i8dcCUUnHccPAX+ensqH0ABTO\nucMY+1kAnwCgA/gDzvl9jLE3Bn9/F+f8fsbYxwHcC8AD8B7O+TfKfnYaNncYwxfjDeWAHxRg9Z1h\nVsc5Dxi+H/B1TSvO8HeYG4IkHcvIv09ciUpOo6TTnXKGv2+ugbWeo7xZ3nvyoiBq8U6YEYYf/G1A\nDN+tJZ2sqGTiFef8DgB3xB57V+z33wDwG1V8XhZQ8mpaWFhZ9GwPHkfEpWPpyZKOEzBRqwTD59x/\nj51m5yRG7DP8nAFfev60nFu2zPCnOGc1cDzsm2ngkZVNpRz2hePnI8+VIWv4fSfU8F3PZ/d1wM+G\nHVtpS1WH03JRlsV6379AZA2/YSZLOvRYRMPPydQptu24gO+SpFOA4XvTyPDD4zrN7RX6jod9c/4c\nB1WV8r1PXsJ1+2cBqAK+WtKhfMwOO0XHhh0Z8F2pr8hOkXToBjbb0MVjFMz7Cu81zQ+lm4Kp52f4\n9PxplHTuPXkRv3XnQ4VeS0GiCMOnG0TL1LHec6ai0Em+aRVJ2vZsFydXO1Vu0hCoh/2+WX/+suq6\n7AwcLLRMWIaGvpsQ8GNJW3q8ag2fc46nLvUqfc9pwI4M+LIXeafYMqknEE26AsKk7cAdvshDhl9c\nw6dl8jQmbf/63tN4+98+WCjgiqSt4Qf8PO9BBUFLbROuNx0dKmW9u4ik80dfeAy3/q+/Gyp2qhJ0\nPu6d8QO+qid+d+CiZepo6FqKS8eTNPyQ7Vct6Xz+oXP4zrfdidOXupW+71ZjhwZ8/yLU2M6RdKhn\nDg0+AUJ9XsnwY5KOUcCWSRfRNNoy6aae5FBKAzF8Wv3kYYe0DxeDIfLTcH7Jba+LJG3PrvWx3nNG\n9mUqAwrSMw0dbUtXymE920PT1GAZw0WCotLWdiMSVi9YyVa90HpkZQMeB85v7Jzmi8AODfjEcvbN\nNnaMpLO66X+PpfYww1cFPWI+lmD4LDebDSWd6WP4dFPvFdCs5cIrIF+Ogm6CSzP+jXcadHw5OG4W\nCPhd279eVjb6lW1THPL5ON80lddlz3HRNHWYGRk+EM6IqFrSWVnvB5+39Su4KrEjAz4Fg8sWmujZ\n3o5oskTsKxrwk22Z9JjswwfyXRhE7Kdx/1GgL5KkpH3QDGyteeSAOMOfhuIr+fgU6ZhJ1wsFuXFA\nlhgPLjZFB1cZvYEf8C1jOOBHKm2lv9FKr2pJ51xw81OtnrczdmTAp7v+gfkmgOlYdpfFxY4NXWOR\nXjpWCsMfcunofsDPw2bJcz6NRS0hwy8g6Ui2TCAnww+eO9/0GX4RRl015BxLke2hfXluQgz/B24+\nhPtOreG+U5ciz+k5oaST6MO33cj5TmaG6gO+T7CKSIbTjB0Z8Omuf5kI+FvPwspitTPAYsuEpoWt\ni9IkHWImpFMXYfj0XJod+vDKxliDQh5QkCqiWQtbZrD/3BySFd0cZiz/ZlFEUqoa5KJqW3qh/dGd\nCMP3P8PSddx28+WwDA0fvOtE5DmUtLUUkk4/QdIh+bZqTlJLOtsIdNe/bGHnMPzVziCSsAXSffjk\n3KHiLF3Lr1eT3k8B5fY/Pob/+akHc275eEBBqlfgggyTtvkZPt0E20EB3DQEfPo+Cy2zULdMksXO\njTFBOZAkncW2he95xmX4y3tOidU451xo+JahDZ3Tcktk+aZGK5qqV6FC0qkZ/vSDTvqdJOmsbtoR\n/R4AGrofsFSVtpUwfB5N2q71nMQuh5MGBaleEYYf0/CLrHqoHmIaNF6SdBZaZilJZ5wMP24i+PEX\nXon1no0f+t0v4InzHQxcD5xjpIYPRFfsm9INoypwzkXAn4YbepXYkQF/gxj+TpN04gFfMPw0H35g\nyxQafvYAFUo6Uin7lMj5ZRg+rVhCl07+fdIO2lQX+fyqQQx/vmUWlHT8oDlOuS5eF/K8q/bgj97w\nfDy52sWv/s030RuEeZVGioYPRKt0NwfVSzqXura4idYMfxuAWiNftkBVfdPBSsvgYsfGUkzSIblG\n7cOvzqVDDN92vNzdJccFWsUVSdpWw/D9gD8NDF84h1pmoW6ZVTP8Dx47ge//7b+PPBZn+ADw4huW\ncfMVi1hZ74sbZ9PUUjV8IHo9b47Blinf+Kbh+FaJHRnwNwcuLF0TEoiK4d/9+KpoxbodsNoZYM9M\nlOFrGvMvDoVtsh+7wISGn4OiezGXju1NTxvasklbjfntJoB8Gj6tBtpTlLSl4Fic4Vcb8O89eRFf\nf/JSpOo3fj4SZhsGOgNH7MemoZZ0BpGAL0s61bt0zkr7oU7abgN0Bg7aDR1zgXVOxfDf/rcP4Nc/\n/q1Jb1ohdAe+FS0u6QD+BaRiIYPYEpoYfhFbpu164JyL7oRbDc8Le6gUStp6Hgxdg6Hlr7SlwNI0\ndegamwpJx/E8GBrDjKXnbvXAOUcnCLYXOoNCfZPiM2gvBW0TVhSBkyRGQtsysNl3RU6mZemptkwg\nej2Pw4cvJ69rSWcbYLPvYsYyYBkaGoYmnAAyBlKb1WnHBVF0ZQ79rWFomTR8XUg62b8zXcROwOyn\npVWyXGxVlOGbGhP7JM+qh56rawxNQ5uKoeG2y2HoDO2ALed9retxXDbfBOfAhc18Tp1TF7t42W9+\nFp/85lPisUtBMZpcuRsnIISZho7NgSP2I0k6dqqkY4v3CRl+rs1ORfRGtfXHt0rs0IDvYCZwUcw1\nDWUrVtvlU1lBqsLqJvXRGWb4DYWFDfALVJgkW5Rl+JTEmgaGL7PYIhek4xLDL+5c0jWGpqlPhaRj\nux5MXUPb1GG7PHHkpQp0w7xibxtA/vYKJ1e78DjwyLlN8ZgI+IrAGQ/4bctAp++K7WiaOkwFw5eP\ns8fDHIpI2las4Zs6w0LLFF1ndwoqCfiMsVcxxh5gjB1njL0l5XnPY4y5jLEfquJzk7A5cISLomWp\nL0rH85Ta9zTiYof66AwzfJXeCfgXiKVrYMwPakXYrJy0JafONAT8XkmGb3scps6k6uP8Lh1dY2hM\nDcMPAn4QBPPsk07QR+eKPUHAz6njU4LzjNRKeE0R8FVJW8C3tw5cT6zCm0HhVfxGHl/FtgNC1xmD\nhr+y3sfemQaa5nQc3ypROuAzxnQA7wRwK4AbAfwIY+zGhOf9GvxRiGNFZ+AKhq/K+AN+EMvDhLYS\noo/OjIrh64mSjsymyJZZRK92PE8ssach4MsMv1jzNA+6xkpVHwuGPw0avuvfwCiRTEE8C2hfUsDP\nW3xFAf+ptTDgE8OX3S5EruIBn4jZ+eC5TSOwZSqStlTdDAAzwes2xlBpe26jj+W5RuK1tZ1RBcN/\nPoDjnPNHOOcDAO8HcJvieT8H4M8BnK3gM1Ox2Q8ZvmXoymW/7W6fpmoXFY3TCA0zQdJxPFFJChSr\ntHUlDX+6JJ0woBXy4XschqaFq54iAZ8xNEx9Kmx7A9eDoWlhwM/B8LuxgJ+X4dPzn1rz/+ecqyWd\nYD+RlZhAxOx8IFvKSVu5mKrveJhvhStcknToXCh7Xj68siHcP+c2+tg3ayXKpdsZVQT8QwDkphgn\ng8cEGGOHAPwggMicWxUYY7czxo4xxo6trKwU2qDNQTjsW5XxB6JBbNpxIWiNHG+tAEDJhgB/CRxh\n+CX0as5DJu1W3Xi8AGTJojsoouH7jLiISyfK8NUJ80nDdjksI3Qd5ZHt6Oawd9aCpWu42C3G8EnS\n2eg7Yh9FJB3X9VdVQwGfGL7/uZS0jRsEBo4XaRxI8hUVWZattP3h3/sS3vGZ4wD8+QDLc41EMrWd\nUUXAZ4rH4nv/fwJ4M+d85NXBOX835/wo5/zo8vJyoQ3q9F3Bdhq6pky8OC4fcgJMK1Y7A8w1DJj6\n8OFS9R0BAg1fEfDz6NVyIoycMdPA8GWXTjGG7ydtSzF8jaFpTEfS1nF9WybJdnlWrrQv25YOU2fK\nm8XZtV5i3/+VdT9Qr2z04Xohu6fHCIMgpxQHSTPnN0NJh85bmcj0HVd0KAXC1haC4ZcM+Je6Azyy\nsom+4+Lseh+HFtu1pJOAkwCOSL8fBnAq9pyjAN7PGHsMwA8B+B3G2A9U8NlKbA4cwRwapprh2+52\nStoOsDgzzO6BFA3f9iKeZ9FaIVfhVfgzMcFpGIZC22IZWqFeOrbL/QBZwKpKgcUIGP40JPUoaVtk\nFUdtFVqmATM2acpxPbz9kw/gll/7NP7rX39T+Xpi+K7n95+hgD/XMIZcOtQKRAYRM2L4JOkA0YA/\ncKMMn24UdC6U4SF+jQnHk6tdnL7or1QuX2z6K7gpOL5VooqAfxeA6xljVzPGLACvA/Ax+Qmc86s5\n51dxzq8C8GEAP805/8sKPluJ99/+QvzLF1wJICVp6/EhnXBacalrR2bZykiSdAZuNGmrl5AvgFBG\nqbrveBHQtuxpW+g5Lj7+jadwy9s+nTkJ7wQBsohzifaJprBlntvo4+GVjczvVRVskqj0/L2BKGD6\nDF+LyJx/8/XT+K1PH4fHQ1kxjnMbfRGIn7rUEwH/2v2zOLfRF6vERIZPkk6g4TcMLQz40s2nb0c1\nfHodoYwtk47pqUtdnLroz7A9tNRCw5iOpHyVKB3wOecOgJ+F7765H8AHOef3McbeyBh7Y9n3L4Kb\njyziSJCESrIt2kF3vmmQKEZho+9E2I2MREnHVmv4Rcb5AeHSeRoKr2hb9sxY6A5cfPPUJTx5sZu5\n6MjxeKAnF3fpGAqXzv/42wfxr//4WOb3qgpxhl9Ew29ZOkyNRRj+N0+vwdI1PO3AnHIVRF0ln3H5\nPADfqUOWzOv2z8J2Q4knieGHGn4fTdO3EdONIZXhN6IVu2WICJ3TFzs2HjyzDgA4vNj2k7YVMPx/\n8yfH8If/8Gjp96kC6iiSE5zzOwDcEXtMmaDlnP9fVXxmViQFRNEQzOWIVXtPHdZ7jnBRxJF0UvZj\nSa4ilbauQsOvssClKLrB990zY+HC5gCrQZ1CVonOD5Cs0E2QnquxYUnnYtcWNROThBNU2hb5Pl05\n4McknYfPbuKqfW00TE35nht9v0L2mZcv4EuPXMDZtZ5g59ftnwXg6/hLM1aKhu9ffBc2B5hthkYL\nIFps1be9cDiK6w0z/BKnpXze3PXYKhjzZ2lU5dI59tiqaNS31diRlbYykiQPWvZuBx1/o++IiyGO\ndB++pOGXZPgkXUwDwyfdeaFtome7uBiwyKyuK1fYMgv00iGGrzN/30uSTt/2tiSJOyCGX6AZnJB0\nguHh8urgkZUNXLs8C1PTlKsG8uw/7bI5GBrDU2uhpHPdchDwxeQoD5aCWVHgdjyOphHWzgDDDJ9a\npQBAKxZAyxAR+bt9+dEL2D/XCD6rmqRt3/Fy9zgaF3Z8wFfZMilJA6iHh0wbNvoO5hrJko5Sw3fc\nyBJaL5DQi0o60+PS6QSj8FqBhk51ClldV9R7RmfFGb7vw9fQiwWlru1OPC/keCTpkC0zn0vH0jXR\naoKulYHj4fELHVy7PAtdY8rjTgnb/fNN7J9r4KlLftJW1xiu2jcDIDoqMN5WAYgG7lbA9onh02rD\nCZr2NQxdnNOWoUVWDKUkHWl/ndvo49BiC0ByjUteDByvUEX4OLDzA76uDwVE+eSd9uIrzjk2emkM\nP6XwKqLh5/doy7tmqgK+7dtuW6aOnuOJSuSsx5ICpK7nl7k8uZeO4Z9bxC77tgvOJ99wy3aCVhGF\nJB0nEmhpHz5xYROux3Ht/hkYOlMmgs8FwXzfrIUDC02cCRj+fNPA8pw/i4IC/iBmEyZoWlghTOdr\nPGkrV+k2pFUArWiAcrZMO7a/Di358mmzgsI6zn1zSJHRk+PAzg/4CgbsbKOA37M9OB7HbCPZlknd\nLGXEA75eIkHpb8f0SDq9gYuWpaNpaugOXKGbZ5XnnJgtMxfDl7tlBuxUHrANTL5HPrV7pjqNvElb\nCriypHP8rN8M7brluZEMf3m2gQNzzUDScbDQMjHfNLB3xsI9Jy4CGD4fZVBVPO3PuKQjxnUaWoTh\nmxGGn/krDyG+Irp8sSk+r++UW7HROVFLOhMCSTpeQpCf9oC/3veDWSLDN4f1ToBcOuFy2Szt0pke\nWyYFqVbgkqGAn1XDJ1cLMeI8+m+E4Qf7ngI8HYPupAO+6ydEQ4afw5Zpu0JWkSUdspdeszwDQ2PK\n82ZlYwDG/OT5NcszeOzcJk5d7GKhbYExhlufdRnu/NYZbPYdDFICPhVR0XbEffgqht+IB/wSET8e\nAw6TpGNo8Hj280oF2vZJnxNJ2PEBvxFbHgJR5jrtpdM0NDxRw6cxh7Hk0rAPv0ClrSLgFxmQUTUo\nSDVMHZyHDbSySzo80jytkIYvMXyyZtIxmHQxFq1YzALFdd1gtQREJZ2HVzZwcKGJmYYBIzFp28dS\n24Kha3jR9fvgeBxfeWIVC4Ff/vu//XL0bA+fuv+MSLqqEDL8qKTTH2L4ekT2MSVJpwwRoYBO7VgO\nLVHApxVc8WA9qBn+ZKEK+PIde9r76VAwm00I+OEg8/D7cc4r0vCHJZ0pUHSE7hy3umVN2pKNsUgi\nO95LBwgDvGBzE764bdeDaWiFvk9n4CglnYdXNnFt4LTREzT8CxsD7A06uD73yiW0ghswBfznXbUH\nB+Yb+Ot7TwdJW7U1kTz1dDzj1+zADSurRcDX9QolHf/FVwYzAS6XkrZAOVJIr62TthOCqkxbPnmn\nXdIhhp9mywSi3892/elUVkkNX2ZNdMLmWSGMC13bRdsyhqx5mTV8z4OpSa6Wgt0yyUZIN0NiopOX\ndPwJXkLDz5O0tT20AoZtSIVXT652cWRPSzyuOm+6ttSzytDxgmv2AAAWWv77aRrD9z7rctx5/xmc\nvthT+vCB0JopJB09ek73Ihp+uBqRGT5QXNahWQ/f/bT9eM4Vi7hq74z4PKBcwKfvsDlwpqKqf+cH\nfIWnV2a5095AbX0Eww+Xv/IUqOH5oYUmXskunSlqntaRkrYysq5eqmL4cQZIN5yJJ23jrSJy3JS7\nAwftIIjKhVcDiZHrCRp+L5Yn+q7r/WaHC1ILhDe94nr8+AuvwmzTEMVYcVBfnEYGDb8ZkXSix7+o\nrEMx4IXX7sVHfvoWaaURSDoljid9h61wb6lQSaXtNENVtSez+v42YfhJrRWIhci6sRgnp/ThF9Pw\nuxX1Ha8CXcmHLyPraq1MKwLX49AYwFIY/qQDvn8D02AWbI8sJB2NhfUpUg4oieH3HA/z0nn54hv2\nAYjObZhvmnjra56Bt77mGYnbQJ8/nLSNJsMbusTw9eGA73JeKKDRzYzOB0KzEkknPBc6A3fLK253\nfMBXSR4RW+YU3HXTMFLDV9zQVAOjixQZyUtkuSsh51yMTtwKkJQQv3iySzp+klPTGBjL3y2TpCAK\nPsKlswWODPJ5WwVHNnYHLpqShh8y/DDJasSaqhH6totm4LcHgOv2z+F3f/Q5eME1e3N9B5J04klb\n2p8ygUlK2gI+iy4C+s7xXv1h0ra8pAP4+ZI9iql1k8SOD/gqDd9OSOBOI0TAT2meBsR7h4euBoKm\nMWis2AAUIBrEXI9Hil4mjVDSiTP87JIOBccky2ESXI8jiPeRpC1VgwKTTdCJZm7yiiVna4WopMPh\nuB48HsqhPsNXF/fFj8GtzzqY+zvEk7YUyIWkQ/Nw9dCl0zA0EaDpGBZdfdKKKJ5jCFfP5SUdYDoS\ntztfwxdsIdzZEQ1/yiWd9Z4DS9cSHQ4q6xj9HLfBGZq6CVYSZIYv953fyuIr1/NnEbdNY0jDzyzp\nBElbAIlFRUnwLZD+a8PCKzfCAicp6dBNrohE5Xk8knilbpnx+bPpGn75EEK2zFZS4RXlpEyp0lZq\nrUCvK6zhC4YfJTFVunSA6bBm7nyGTz51W5Z0ov1PphkbfTuR3QNqSUeuTJSRN7jJz+1IQWwri69o\npdGyNBFwieFlCfie5zuYDMHwc94Eua/hA2HA79lulMlNMuAH53KR1gp0zpBLhyQdwahHaPg+wy8f\n8KljJr0XtUjuOR5+5S+/jrlg0pWla+I5ph5KOg1Tx3rfKWzNpNYKcYmoiqRtHfAnDHGXTpBxpr15\n2kbPSdTvgfAiiXcWBDC0KjB0lmtFo5p4BWwtw6eci6lrgtntm23gqbVepmMZBsiCDD9oYwBAOEZ6\nthdj+JM7p+T9wZhfTJa1OC50cwVB1PB9+PGArycUXvVsVySuyyCcThe+l2VoOH52A5/+1llx/scZ\nPh0H2v6itkzaX7RyI1Riy3RlIrD1/XR2vqQzypY59Qw/PeCTZ1nJ8M24pJMvuMlMXt5/7hbmPShg\nG3rI8PfP+4nDLBo+HXuSP/zVQY6kref3wgeiks5WMXzHCyUdwL+pZz3GcTeXGbRW6AvNnNj08D7i\nnPuSThUMP+bDB/yA/kjQ3oHyWJau4ehVS3jJDctoB73xgbDLZtGVpzgn9LhLp3zSVl4dbPa3nuFX\nEvAZY69ijD3AGDvOGHuL4u8/yhi7N/j3BcbYTVV8bhY0VEnbbVR4tZ7SKROQdUaFhq/HJZ188kVS\n4Cg7MLoM6OI0NSYCxPIsBfzRxzK8uIsxfNfzxM2iEWH44f6fZHKOzmtZosqavB4MBXb/f7phyRq+\nxxHrR8XhcVTC8NtWNGlL23RitRt5XsPUcct1+/Den3g+NKmVBK1yi56XFA+SkralWivIDH8KJJ3S\nAZ8xpgN4J4BbAdwI4EcYYzfGnvYogJdwzr8dwK8CeHfZz80KZaXtNmutkNRHB1Df0FQ+fCBg+Hk8\n5wkX0FZ68eWATd9v76wFjWUL+GKFIDP8nC2jSSsnZ0zP3sqkbTRY+Qw/q6QTlW7M4H9i1LIPH4ie\nDxQEq/CVH15qgTHg4EJTPGYZ2tB5Fg/IobTmb0NhW6YTrhplhBp+dbbMrUYVGv7zARznnD8CAIyx\n9wO4DYAYc885/4L0/C8BOFzB52aCqvBK1jinofotDWnTroCEcXCKSlsg2W2RhKQLaCsDvpykbBh+\nwN0z0xgawJ2E+PJdzyGBAD7Dp4APIBhkHtfwJy/pGJLNNN7fPQnx84QC+yZJKJKGD/jHneI75Smq\nSNpet38OX/mVV2BJ8qjTZx9abKHveDi/2R9KqtKKhG46hW2ZsX1IIEJRZpB5JGkbOy9s1wPD8I1m\nnKjikw4BOCH9fjJ4LAk/CeD/JP2RMXY7Y+wYY+zYyspK6Y0LC6/CnW1HlqZTHvBHJG0bsWpPANjo\nR5NxhDzsD0iRdKaB4Wt+kvJ3fvQ5+PEXXglL17Ix/OA5ZMvM69JxebQis2lq6DluVNKZYMAfSElb\nwP8+WVdx8QI9CrKkNZuShg9ErxU635LswnmxFCtIIjZ/ZE8LL7puL1qmPlTsZ+nRXEpxWybJhNHr\nReXwy4s0H/6/+9DX8KYP3FP4vYugCoavqsBR7nnG2HfDD/gvSnozzvm7EUg+R48eLR1Z4lV7QJTh\nT3ul7foIhq9rgYVNOik/+tUncWRPCwfmm0PPrUTD30qGH/NMv/IZlwHA0ADuJLgxNldEw9ekgN8w\ndIUtc3LnVJi0Db+PnfGmHnfjUIDflJKk9J6Auq14FUlbFUKG38YvvOJ6fP9Nlw89R0g6wTYUlXQo\nHsRXEFpwbZWttNWYn5CO2zIfeGp9aBj7uFHFp50EcET6/TCAU/EnMca+HcB7ANzKOT9fwedmgtKl\ns00YPrk/0jR8wHcpEOP62omLOPb4Kv7j990YkR6AYi4dxvy2DPI+20pbZlLfEzOj5dSRXD70Pvlc\nOnyI4fclSWe+aUSK1MYNsWKR2Hhul05Mqyet2Yo9Lh93Ot/G1RuGrtvDSy0cXmrjcDB2UAZ9Z1pl\nFCUitA/j1wtAc23LSDouLENDu2EMBfxzG4OIFXUSqOL2fBeA6xljVzPGLACvA/Ax+QmMsSsAfATA\nv+ScP1jBZ2YG3bX7CUnbqguvzqz1KnsvWlqnSToAsQf/Iv39v38Usw0Drz06nCYp4tLRGRvSNrdW\n0lEn2AxNw8AZvV225PIBihWjaSyq4cu2zIW2OdnCq5iHXM+RhI4zfEskbeMunVDDJ1SZtFVBMPxg\nGInyOcF52bICH35hl44/E1jVH6ph6KUZfsPQ0bZ00YAQ8B1Pq51BLom1CpQO+JxzB8DPAvgEgPsB\nfJBzfh9j7I2MsTcGT/tPAPYC+B3G2D2MsWNlPzcrGPOTe6p++C1TzxQksuKRlQ284P+9U8zxLIuw\nF756ni2hZelCRvjMA2fxvc86KKoTZZh69qIcwC+80hgbKkjZ0oDvRQM2wcoo6cRtmUV66cg3wHjS\ndqFlDiVtz673cMfXT2f+jDygG5hl+Ntk6lrmFUu8hUJc0okzf3k/JVVzVwXapsMpAT/u0inuw/eG\nznFCw9DKafjBpK+WqWNTYviXujZcj+dyiFWBSgQkzvkdAO6IPfYu6ed/BeBfVfFZRWAZUR2OLpK2\npVcq6Tx1qQfOgZX1fiXvJ+bZZmD43YE/bHmz72BZ6mAoI6+G73G/Udh0MfxowCZklXTitsz8lbZx\nhq9FNPyFlonHO53Ia371r+/HX33tFO596ysxP+LmnRfxKtEiDH/IpUOSTlDUR8dfJgu9cTN8Stoq\npBxC3KVTuLWCy4f0e4JK0nn8/Cau2NPO1DG2b/vzhn2GH77P+c0BgMnLozu+0hbw79KqpG2r4oBP\nGl1V70mSDnUTTILP8B30Hb/LIVUexpFXwxeSDrUDNsoVuFSBsNJ22KKXj+GHAT8Py/J4VMOnZBwF\nhcWWFWH4py91Bbt/MlZIVAXiGr6hZ5ft4k32TCPK8OXCKyCu4Vdny1TBMjRoDLhsoZn4nKHCqxIa\nfry3PsFPyofn1SMrG3jJb3wWX3w4Wxqy73pomBralhHx4Z/f6Cdu89/cexpv/+QDeb5CZuyKgG/p\ncUnH38m+pFNdwCdmlBR4vvDwObz1Y/dlfj8KHPFBH3EQw6cbzkxCwC/i0pErGulGMmndUYaTYKEz\ndQ2DLD58b5gR5+2WKbt05pomNvqOOI/mW2aEyf3JFx8X7z+egB916eRJQg9V2mpRW2aYtB0OqFXb\nMuNYnmvgmuXZxEAMqBh+8dYKSe2+41Lh4xf81duZ9Wy5uoHjM/yWFXXpXBAMf/hY/d1DK/jgsZOZ\ntz8PdkfAH5J0/J/bll5p0pYu9KSbyKfvP4s//dLjmd8vqxOiafoaPjEIajcbh6ENVy+mgXNfvqCL\noSncEJnfonI4rprhW7qWyWLrDAXI7Jo3MMzw55sG1np2VMN3PHDO4Xkcf/aPT+DolUsAgJOrHeV7\nlsEQw8+xYhmqtNVjkk6c4UvvS68dF8P/xVfegA/c/oLU5yy2TegaEyMVC1faeskaPrWMJpwL5Nqs\nnS8HjoeGGSRtpZXfuSDgq2omurY7tv2647tlAj4LkQuvHNdvcdswxyXpqM+8ru3mkkN6GS8qcgDQ\n57cTJKDcDJ9z6BoTzI8Y/lYOMk9qZWsaLNNqLW7L1DWGPHkzx+NomlGGv9a10bNd6BrDbEOH63F/\nkIjnYbVj42VPP4BvnLqEJy9Wz/DjEpWhs8zdOuO2zCFJR7qJANHjLsjImBh+2zISiQvh1c86iBsP\nzuNEcCMtMwAlPjuCEJcKz234gTprX5y+46IRaPgRhr+RrOF3xzgKcdcw/HjzNEPXgurM6vTozghJ\np2d74Dx7G9esy+aW6bMHEfBTNfw8nnPfpUMMT2j402DLLCjp0PGWe+nkmvPr8Yhfe75lwOPAasdG\nwwg7eHZtVwTelqnh0GILJ8cg6QinjVRpm3ZT55zjj7/4GC517ERJZ0NU2oY3ESBJw9+6Ga2mruH6\nA3MieVpmAEq8rkN8hhGNEec28jN8y/A1/GjSNlnD79puYh6uLHYFw7eGkrYcZqBNr/XGm7S9//Qa\nHj+/iVc986AI4C7n0JQFylFkrWZsBQ6ATj9d0smdoPQ4dE2uaCxX4FIFklrZmjklnaJJWydIZBPI\ndXNuo+/b76yw1QXtp4ap49BSeywB/1LXd3K1AyfXqH74Jy508Z8+ep8wMpg6EzkJ0wgLryxDE4FU\npeHHe+lvJfTSAZ8n9rOxYu6v3AHf9bBkEMN3xDzoNJdOz3ZH5u2KYuuP1gQwlLR1fYZvxh4vC5Wk\n856/exS/8pffABAy9syVkBk1/JaVkeHnbRQWaPhVuSGqQHyACSFrL5140jb3Phli+GHAbxjhUJbu\nwI3o3IeXWmORdI6f3cDBhaaw7o76Pms9/wax2XfRt73I6lH24Tek/avS8HuB3VBLYMaThCYCfrHX\nO56XaMsclnT8gN/N2Pmyb3uCCHg8JHFpLp1uHfDLwffSypKO77uNM/+yUEk6l7oDEYi7OQN+Vp20\nZeqwXS4u5mRJp8g4PyaWu60pYvhDbSOy+vBjSVs9ZyI7HvDngj5HK+t9NIxwsHrPcSPH7/BSCxc2\nB5W3yH3o7Dqu2z8rfvf74SfvB9Lnu7aLgetGtGvZpSM/TquhuEtnXH108oLUvTIafpKkY8Rk35W8\nSdug8IoGxdPr0lw6PdtDc0ySznQcsTFDyfA1LTMrzAqVpLPWddC1XTEhCMjuY+/ZHhgbTlDGQYGY\nTqJkl06+vjGkV0+TpBPvdkkY1R757HoPP/FHd+FUwLILV9ryGMOPSzoSw5ddVocW/YrRKq2Znsdx\n/OwGbjgwJx4bZTMlB0534ArLIIEkna4dDfj0feWmbH3HG5slMy+0CjT8JPunqUfNAJS0zeXSCTR8\n/3X+/j8fvI+S4Q9qhl8K8aQt+W593be64CVsmRGGb4MHSzlqf5C1fW3f8WeGjqroI92YTsYkhq/n\nHoDivyaUdMils3UBP97tkuAnbZNvZh86dhKf/tZZfOkRv2CmTC8dlaTTs73EpG3D0ETzryp1/BOr\nHfRsDzcckBi+zlJvfJSQ7QbVwTJLl4OeivnL505/jNbBvKDjUdiWmRLwLalVheN6WO1QwI+u1DyP\n46ffdzfueuxC5PF+kLSlrpgbfQeux3Ghk67hj2vfTscRGzOGfPge96feG6xSSUcUXkk3EUqqdQau\n0OTzMPwsB57YAOmCiQxfz9lawfPtq9Q8q2yBSxVIGlYRT67J4Jzjo/c8CQBCRy/TLVMl6QAYStqK\nxKapi54wJyvU8R884898vV5i+KOqqSmx3wlyDBGGL62aLJWGL0s6zvisg3lBh6PMAJSkwit55Xhh\ncyBuKnGG37Fd3PH1p4YqcP1VlC5qBda6Di52/PfZM2OB8+HtrjX8kmjEAr4T2LAsXa+0H35XIelQ\nwO/abiENP8tFRUHmwubA/14Jzom8bJY0fGLDdPOZdMMnGamSTsKxvP/0ugiOpy/6FZLF++FHXTpy\nwJeTtj3bi7QfWJ5twNK1SiWdh86uA0BUwx/RPI3GF1L/nwiTN8LvNVrDz0ZGJoHytkyeXHglnVcr\nG2GPrHhHVFr9bMaYP62i5lv+ebLWtYVDZ3/Q80o+XpzzOuCXRbzwimxYVTN8uuvTARw4njgxugMn\nt0unF+h/oyAknc1BopwDFJjuJDT8qKSz1UPMNYYhd0jcLy3jo/c8CUNjWGqb4nhHZtrmbJ4ms0E/\nUUvthcOfu1J/nYahQ9MYZhq6SJpWgYfO+A4duSHbqO9DbRM6AwcDN3p+JUk6IcOXNXx3ajT8srZM\nx/VEt9E4TD2MESSZHphvDDF8uiY6/fBxz+N+0lbXBMO/1LWFfr8/GFAUHyzDOeqkbRnE3ThuYMMa\nV9KWWi6Ta4b+lpfh97MyfEnSSatOLMrw421ot9qWqfJMk4bPFRf9V55YxbOvWMTV+2bEY2Evnewj\nAQGSuaLBgQKuzPA7tiva6tJNwCce1Z1vD55Zj8g5QHBTT/k+Imlre8IyGL5WYvj68ONxW+a0MHyR\ntC24a+2U9siyLZPaKlyxpz1UaUs3Q5nhy+2n6RxZ69kiDxAy/OEeRTXDLwFV8zRD85O2HkdqoUoe\nxG2ZJOf4fwuTeLkYfq6AP0hsqwAU16tJ0qFBE1tty4z3wgfCYRiqbRs4HmYaBvbPhZ0X5SrS3Aw/\n9vkk68gafnfgDLUQrtoG/Ni5TVwj3cQA+j6jJZ3uwEHf9WBJLJ1JNRdRSUfdPG1cbRXyQtgySxVe\nJWv4XqCzkwf/yJ72kHRD+0Zm+HSsG4YmzpFLXVu46fbN+gHfjd1IgfEF/F1TaUuB3Qju2IamiZPa\nP+DlPyduy1yTAv7FTvhz1gDjX1Sj78kk43RtN1XSyc/w/YQYXfDT4cNPZviA+lgOXD9Jf2Dev8B0\nLZxulHufeHxITiKnTtR+F174csAvMy4vjp7jDbXOHtU8rSP58F1vuFLWZ7Ru5HHlABTHm6KkLbl0\niiZtvaGcEIHyGrbrYWW9j5apY3l2WNJxFBq+PCTG0DXMNgysdR2xP/fNWsHnh9tNKsC4WitUwvAZ\nY69ijD3AGDvOGHuL4u+MMfZbwd/vZYw9p4rPzQoK7JS4lW2ZQDVjDl2Pi/dXMXxaxgHZtca+7WZi\n+PKF1zaT7+GG5lv2sl4Y/gCUkPU1StgyuwMXj5/fzP06wrHHLsB2PVE0F0fasbQDHZU0U5mh5131\nqBh+KOno0DV/wprvyoo2J4tPXisD1+NwPS6GlBBIw086xhtCw3fFvNX46wG1hu/GmqdNQ1sFoIJK\nW5dHEtYyLEEkPJzb6GPfnIWW5UtzMlGga1q+EcQnis03jYDh25ixdEEO5PchqWhc+ZHSR4wxpgN4\nJ4BbAdwI4EcYYzfGnnYrgOuDf7cD+N2yn5sHdGLSxWZ7PGieFt69Cec2+vjmqbXcn9GJaHf+AZQD\nPi3jgOwul77jZWL4MhtIlXSCkzfrhUGOFLrghS2zwJX1x198DK/8H5/HqrQfsuLMWg8/9K4v4uPf\neAqO6ymHTZuKY0mwg54xpJmaMcuhx7N/J5enM3wAmGn4wy56jhvUMVBSN+oWG4XjZzfwj49eUP6N\nzuV4oFLJLzIoadwLCq8asdWSmG+r0vBjLp1JD+BOAm1q0ZXnIEXDp+9uuxznNwfYM9PATKyICgj3\njZyUj08Um2+ZWOvZuNgZYGnGkprShefEdmD4zwdwnHP+COd8AOD9AG6LPec2AH/MfXwJwCJj7GAF\nn50JdBLTHddxvaB5WvRGAADv/Mxx/MQf3ZXpfT907ATuvP8MgGi7VLJxrfXCgy8HuqwMP6stU5Zx\nRkk6QPb2xjQAhS4GuvkUYfirHb9n/Cfueyr3a9eD/bjWs4My+DRJRxHwHb+whhi+HmP4QHb9103R\n8Cngt0wdnb6fs5Fv2JaeL+D/9qcfwi984B7l3+JdMgkqz7wMkhw6ClsmgMjNaeg9p7Twqqwt00kZ\ncWga4XnVtz20TV3K04TXvNDwpcfiE8XmW34r7QudAfbMWOG5t82StocAnJB+Pxk8lvc5Y4MVC+wk\n6VjGcJC41LEjbDwNv/f5R/BrH/8WgOiBpoAqa/gXJEknu4afzQkhJ8/SXDqqEywNvksnZM90ohe5\nsCgx/lf3nsr/2mB/9u3Rko6qcnrgcphGqOHLr9cVnSCTwDkf8uEDoaRjCYavB0n66A07XvE9Cus9\nB2fWesrVR8ge4wE7PeCHSVt3yJYJhJ77iD9fH77RT1NrhdK2zATnF4AIKexTXxwr2hcHkAO+iuGT\npGPiUtfGasfGYttS3pzpJjLNAV91a4zv+SzP8Z/I2O2MsWOMsWMrKyulNw6QNfwgqeqF3TKBaMDv\nOf6FkCW5ZrseHjyzgZOrnZgdK5R06GYjM/zMtsyM1YxaoBsDWRl+1oAPZS+dIoVXtI+/+PD53EPe\n6fP6jgc3yZYZW8XFP9vSNeHSkVcIKrkiCfQUPbbCoKIawfAtA5sDJwiK4XPz2jI3+w4cqQw//p2A\n4a6huqINggxykfQdD93BsIZP7xeXvYBQw3cDf/m0MPwytkzO/WE1KucXEJJFx+N+Tm1EwN+UXTqx\niWILLRPrPQermwPsaZvKttOhpDO9rRVOAjgi/X4YQJzGZXkOAIBz/m7O+VHO+dHl5eUKNk/W8P0d\nG/bDjz4OhHdY+cAlgQLRZx9YkZItYWXeWtfGYtuEpWu4ILl0slfaZiu8AkL2nYnhZwzYrhettC0z\nxNwO2jR4HPj4N07ne60bFrLZCZ0NVfkY+fWm7hdemTqLWPD0HPskqY/PXJzhB/MJ4gyfetBnBQWU\nM2vD81PjwYRgKnRhGbLG3FdJOppC0mHRm2I/ZjfdapSxZdJ3Sm6eFpJCGlfYStHwu9IcBDFCUidJ\nxwgY/iDK8CO2zPHu2yoC/l0ArmeMXc0YswC8DsDHYs/5GIAfD9w6LwBwiXOe76ovgTiTJ2ufZQwH\nCfLBZqmIpNd99oGz4uJcbJsRl85Cy0TL0nFhM2S1WeWDPP1KqP1qKsNXLM3T4PFot0xT13JPiCLY\njocD8000DA0ncrYXcKVA4yQ0ukrT8AeBhs8Yw/65ZuT1qsTZqO0YLrwihh8eg82g7qIRk3Ty2DJp\n1Xh2bXhFlMzwk1csnHNsDhxR9SlvM4GSwHIyV9MYNCattKigbMpcOkVsmeFAnISkbXB+DBxP9B5S\nM/zw/KEbgZB0gnNgoeUPvF/vORENXzU6cmolHc65A+BnAXwCwP0APsg5v48x9kbG2BuDp90B4BEA\nxwH8bwA/XfZz8yCetBX98ANLm8y6aEm13hsd8Omi+ofj54XtcqEVDfjzLRNtS8fqZsjws2iNftVo\n9jt90xod8PNq+HGXjhkMvCiStKWWBKaeXgmqArVMGDheYqOrpIDveRyOF84sXZ5rRFYIFCyy7BNi\nkEO2zFaU4fvj7JxAkpMlnXwaPpEOFcOPDyAnEENXzkq1XXjc3weELElbINqWoyc1hZsGlLFlhgN1\nRtsy+0FfHFFNHQn44Wvo8SGGL7XAWGqb0BX5lu6YGX4lhVec8zvgB3X5sXdJP3MAP1PFZxVBmNCT\nGL6mhVY+Z/gOG6+kU8F2PFyxp40nLnRE2935ponTl/wLdK1nY/9cE6ubA/EYkI1hxwdMj0LLHC3p\niL7mGWUFj8eqLwOGX8SWOQiYuV5ghSCSto7nyzOpLp3otsUnZD394Hxk8lQeDZ9knyFbZjNqyySG\n349JcnmTtqS3n0lh+IkuHcUxpoTtvlkLx89C+XqVpAPQJC3/PXuxlhFbjTIDUATDT5ppK51Xfv+g\nsNVx15YlnXB/041a5dIhLCW4dLoD2rdTHPCnHSJpKySdgG0Gj//N10+jael4zhVLIuBvZJF0PA83\nHVnEExc6+OoTFwH4DP/xCx0APsO/fv/ckKc2S8AUA8yzSjpjYPhipq00DlBnBRl+EKjzNivzXysx\nfJcPBSMASnnO/91/LQW2/3LbMyIrLD3HPkli+JcvNmFoDJcFtk8aWN1zXOyZscJtzGHLJPkFAM6s\nZ9fwVQPHCXQDWZZaTMSnVpGko7qRDGn4U+LSKSfpUD1DkoYf3kAp55GWtJUfj7t0ZCltT9sSVhZ5\nxUvDZ1S1JlVgOm7RY4YVY/i257PNy+absAwN7/vyE3jzh+8FEC6pNrJIOi7HkaUW5poGHjzjt6pd\naJviJLrUCTT8WNDOxPBz6qTNDBq+kVPDp+lOe2ctWIaG2aYBXS/G8O2gmjGplcFHvnISn3ngbMJr\nieG7omguDropDQV8J7pkN3UtolunBcg4iMXFGf7BhRa++Esvwwuv3QuAGL4z1G+mYWZn+H3HExLF\nWYWkE45qHJZeALWTSmb4hCGGLySd4QpeOm5kUJiWpK2eQ5aLg+Tc5NYKIVkcBFbUNB8+EDJ8uZcO\nEOZ6AGCxbSldOuMcYA7sloAv9cwBwhmWly+2cO9/fiX+6bMPic6WWZO2nPvasKlreNqBOXFxzjdN\n2C6H53Gs9x3MN40hhp/lxMybrc8i6RRh+Bpj+N5nHcSd//YlmG+ahRk+9S9KYvjv/Mxx/MkXH1e+\nNmSWnphlEIfKcUWfCyQzuDw+fFq1qz5/ea4hCoDaDR2c+ys8mUFbug4naIkwCvL595TKpeNG5QJC\nWhJ6UwT8ZA3fSJB0dC1sP022Wvl9thJlNPwwaZsg6QT7g1ZHDWk+rezkUzH8cOJZkLRtSwx/xlIW\nQtYBvwKEfVZcEahlb/lC2xQHtJtR0pGHYd9wmd+ilkbcDVwP630HnEMkbWVkueBp6Z/ZpUOSTkpr\nhdyVtlJ75CN72uI9ihS4kBde19UMvztwh1rOyq8FQklHactMkHQGCW4WQp6bIO23eOFVHBQQVjft\nCMMX5oEMLJ+ChqVrSg2fbmzxZKOqlTGBJKJlKVDHXTq0H1U9dkjDPxMEfCpk22oQOS9UEBh8p8TC\nq2B/bPR9QkiN0CxdQ8cetmUC4X6+1LXBWFiJLSdtFwOLMDDswx9XWwVglwR8wfCdkF3JQWMmKJTx\nPC4uxlEBXz5Rnhb0JG9bOsxg1B5V2c4rJJ0sfmGh4ef24Veo4ccGdtN7FCm8orxJ0hCWju2iY6sD\nvlx4RXJcHEkunbiGH0eemyA9ZZS+2g6SevHipHhPpzRQ0LhybxvnNvpDSdi4XEBIk+02hIYvB/wE\nSScuFUltpM+u9aAxYO/UMfxiUiMQ1nHEQftjox+9HltBrQUhwvCD5651bcw1DCEBUtK2belomnpi\npe04pbJdEfDpTtp3PeVM1HZDh8ejzc5GSTqyhnqDCPgGTF0Ty3kAmG0YolCDkMWlEjohMtoyg+fN\nZHDpZPbhe8Oecy1nO2GCPcKl0xm46CUwfHmCGN044kgO+GNg+CMCvnwM4q0VAKDvjvbi0/l3zfIM\nOA+nLRFsYfkb1toBtUunk0PSGbqRSMf9zFoPy3ONsSUW86KULVNMQFOfH3Tjo+NBK6IZS09M2soM\nX5ZxZiw/yC+1rchnxhn+ON1PuyLgN4KLwg5sfUA0SUMX6Hmp/cHGiErbMJAw3HDAnynqM3z/fYnh\ntyx9mOFnUFRCDT/bISJmn7YcVJ1gaXADl070PVixStugQZVqheAECTF5iRx/LeAnbf3mZckMfxB7\n70EsaRtHnpsgMciRDF86BnFbJhAm5NNA+vA1y/65FffiC6kq3i0z5QYmkrZzYdI2HtiTJB3ZpXNm\nrY8D801MC8rYMu1RGr5g+EHANzMw/OBxKrwkMMYw3zSwNOM/phwOX2v45UEXxcD1lEkaukDPS0OK\nR0o6wr+rYe9sA/tmG0LSAcLxhm1TH7JMZmH4eTX8uaYJjaUzfNL3v3biYqb3JA1fRtHCqyjDj76e\npBzyIMfhCJeOJ9okxBF3YsmfCyQnbfPcBOl75wr45nDwz9Jegao1aSxjPOAn+fDpvLYV34duIntn\nChZeBZ95Zq0XmR621ajEljmi0pbiAe3vtmUoWysA4WrgYmcQCfiAb80MGX60RxGAsQ4wB3aLD18K\nBrYiSUPOFrlL5mhJh97HP2gvvHYvDC3swLnWdcR7E+v2+6S7uRh+Vg3/h48ewY0H51MZ/s2HF/HS\npy3j1z/+AJ5/9R58++HF1Pfkit7vRQuvKFGucukQU+omFLvR81MrbTP68ONQ9TNJgps54KslnVwa\nfhCcr9/vM/wngtoOQtgPXy3JqEjF5sBBw/AnvTWC3vyJLh2FD5++/9n1Po5etTTyO0wKoS0z/2uF\nxDui8Ips2jLD35QYvpfA8C9biN4Y/8V3XCFyKKpzrztwxzbAHNglDN8faRdl+HJ3PGK+UUknW8Cn\nC+N//fDNePtrbxInyCWFpDPboAk3GTT8nA2qlmYsvPiG9GZzmsbwP157M/bMWHjb//nWyPdUtQLW\nCtoy/X42ah8+XSBd21WyNFtO2iYMq1C18PVfm43BZSq8ooA/yqUjOaVkSS4+eS0NxB6P7Gnj0GJL\nFPYRRvXDj1ccA/45TecgrUKSeumomrI5nl9temFzgANTxPDpcBRJ2g5GrACtuKQj9UuSJR067zQW\nksVLXQcLLUt+O9z+4mvxg88+DEBdA9KzvVrSKQvGmD/IPCLpDGv4xPAtXRtZeBVP/moaC9oQDAf8\ntmD42WfCiqRtxdWMSzMWnnloPjJjNwk0xFyGUbDwiuaG+i6daMCj4OZxdTCUJZ2kYRXE0OLseSDl\nWlTI49IRAT/hvQhRDV9K2lLvpkwuHT+YzFgGnnPlEr76xCpcj+OXPvJ1fO3ExbDSNqFwSnWOdfqO\naAtAQSUe2K0ESYdu1CvCkjlNAd8ndMXmNBABTK+0FZKO1D5DlnSIxM23THQGPnFZi2n4cdQa/hhh\n6X6Vo6pZUlzD3zdrjeylk5Tdp/elgC9PyKEbS7ZeOtRaofpDpAq6Mj507ASevNgNhphHg5ueYKsc\nhbRKW5kp9RTWTNKj+46bOKyCev4kV9qWd+lkZvgRSUeyZZo5fPh9B4z5r3/2kUWcutTDX3z1SfzZ\nPz6Bzz24Eqx02JDkltYvaUMO+ME5OZQDSJB0DE2D7Xoil7B/Sjz4BJ0Vqw9xYtLs0PsG6kDo0gnr\nd3pS8p2uifmmGVRZexi4XmrAF/JbrHlj7cOvAKbhn7ByspVAF8G5gOHvm2uM1PDpfayYSyKLpJPl\nxOzFBmBXCUNP9tJ3Bg7+/YfvxV985WTQDz/6d50VdUMElbb6sCQk29s6CmtmNGmrLrwC/H2fqOEn\nVtrmaJ42Qu8lyAw/Unilk6Qz2pa50XcxYxlgjOE5V/p6+a8H09W6wXhCdT1C8g1sveeIIiAR8OPS\nDbVHTmD4VAQ2TQwf8IlJsW6Z6gI2AmMMpqYNSTpNU48cR9rfc00Dnb6Li92we24S4uce59y3ZY6x\n7fSuCfiWrsF2+FCyFfD9sQBwIfA6752xRrZHTmb4YcDXWFCKHTC+GaHhj95emq7DRrDJIjB1Tax0\n4qBkc8/2EgqvtMIB3zKon35ywO8qGL6ctKVtUMEP+Dk1/BwuHdEPf0TAN4NKTEDtw89WaeuIG8eN\nB+dhGRrOBnJKd6CeRwukJ6HXew7mSMM3o1O6CBTQ4to+3aiJ4U9dwNeyD6KXMcql4/+NCYmX9nnT\niDJ8N8bwifClM/zozbnvBC3Ra4ZfHqbBfA1fcUcntkMa/vJcQ/RtSUKSf1e2ZbYDhkbjymbyJG0z\nDjAvgrRqWSoh7zuuP9M2Ftw0rXgbWkNjviQU+2y5zayqvUKctSctv5fnGvjMA2dxScpPZNfws9sy\nRzF8IDynGqpK2wx3/M2BK84Xy9DwrEML4m/+PFqeWnGsrrQNGX4zQdJ5zU2X4zd+6NsjBUNAWHh1\nZq0PS9ew1E4OZFsBraCkExLAlIBvyAyfbuRaRH4Ukk7Ld+LROZiH4Y97+AmwiwJ+mLQdZontWOEV\nVSKmjTkkDTx+wVgSw6eLvhWwqVmRtB29vX1nfDNDjRgT7tkubnvH3+Puxy9grUe9vD2lS8fQtNyF\nVzSEJJyYlZPhx24QScH7bf/0WTh1sYufe/9Xhdsnya9OUHmhk0DfexTDB8JVo6qXTpbCq07fiUhD\nL3/6AVy/fxZX7GkLSUcl96Ulodd7NmabxPD9mpH4d1mea+CfHz0y9Fq6UZ9d62H/fGMsK88y0Bkr\nZMu0Fa69OEyprTXt84bhN8KjeOIJScfEZj8bw48n2Lt1wK8OJiVtFcxc1xiapibGEFKPkPV+spMl\niRmQvWutaw9Vv7YsA4xtPcM39Wh7g9OXevjayUv4yuMXxdK1F0xHil8HRQqv5ES5rrOhYNQdpeHH\nnp8k6Ry9ag/e9PIb8PkHV3Digj/kZFTSNi6BfPSeJ3FytaN8ruvmZ/hKW2Ymhh8mWAHgp156LT75\nCy/GTMNA13YTC9DExKvYTZJzHjB8U2xfXLZJg18/4eHMeg/756YrYQughEtnNMOXyYIlMXwA6NFQ\nJVnDH7i4GAT8xZSVEJ1G9NqHz24CAA4sjE8uKxXwGWN7GGN/yxh7KPh/qBqDMXaEMfYZxtj9jLH7\nGGM/X+Yzi6JBSVtPHQBmLEMkfahfeBrDtxMuflnDD1sWE9PXfSaSMWk7joQtQFWT4TasB1XBl7q2\nyF2QPqkqvMo9sUrqOzSS4SslnWwMHwCuXfYrU2kJLhhcUqWtlOT0PI43feAefOjYSfX3EF7rDAy/\nEZ1zK/+ctVvmTEzLZYyhFUgJiRp+QntkSniTcWCxbUb6s4+CHmj4q5t2ZKjLtEAr2MVVJfHGIf9N\nTtoCoQxDFua5ht+I8XyQD5xPYfiMscj19PmHVmDpGr7j6j25v0dWlI0obwFwJ+f8egB3Br/H4QD4\nRc750wG8AMDPMMZuLPm5uUEMv5/gb6diGVNnYhmWVnzlJLg/6AZgu1ywvIWWiT0zFq7eNxPpSZKG\nPAPM88LUWSRpS6z+UtcWGj4F4bik47s18n2evBpSff+opDO8z+O5lDQ2RvKcGCSdQ8O3PT9plqSx\n041RbnObBLrZq7plZnHpbPYd0XUz8r5BwQ8lweNIGtlIN3IK8j/z3dfhD97wvJHbIb+v63Exp3na\nUNSWOap9NhCeb4yF55Fg+EHAd4KAf+3+WXAO3P34qt8aWXEMI9stXQ+ff3AFR69aSp1pURZlA/5t\nAN4b/PxeAD8QfwLn/DTn/CvBz+vwB50fKvm5uWEFDJ/6tlAilUAe+aahCxaUFvBDl040kMgXYdsK\n2cBX/uMr8KpnXub3k8/iw7e9sY2Qi9sy16SAvy5JOsAww/e10nwRX25Bq2L4cksFVT+deF+YNEmF\nituocEnVLC/6XiSBhHJfvB8PgYrVFmdGBzzB8GWXjhjSkq21QpzhA/6NpGu7YkZwHEn98OlmRRr+\nvtkGvu2y+ZHbEb6vvyocVUy0VWAKW+Y7Pv0Q/utffzP1daNm2gLRltGUuwgZfqDhcz/fRcn1Lz1y\nHvNNc2S+x9AYXNd3P33rqXV81/Xp1fJlUTbgH+Ccnwb8wA5gf9qTGWNXAXg2gC+nPOd2xtgxxtix\nlZWVkpsXghg+teCNs2ehuVq6uFjTvPhJdj/5d0rWysjK8DsDZ2wFGNSTnhKbKkmHGPJQ4VXCAJM0\nyPtKVbglyxcdRcFbnOGnsTHa53QTSSpQIsjl7XZMj43jYncglu2joNLwNc2/4WXth69iek0K+I6n\nTEQnuY6IvMw1igVrQ2NisM80BnxdYcv88qMX8MVHzqe+js6ttP5I1CtfllhJ2hEMP3ChXbV3BrMN\nAxsZ9xPFg88/6Me6F9+wb+RrymBkwGeMfYox9g3Fv9vyfBBjbBbAnwN4E+d8Lel5nPN3c86Pcs6P\nLi9Xd7ezDA0DlydmwgXDN7VMDF/VVx9QV/DKyMrwVzt2asKnDEw9GhTWFQxfSDqxM8Rn+PkCvtzO\nQqnh265IlKsqbeNsNcmWCUgMvx8Okk67QQjW7Yats5MkndWOjcWWmcmhMmPpYGzYHURNy9LAOfdv\ngorpZS1TD2yZakmHdOH4TZKO62wO3V6GrjOsBi62LJLWpKGyZQ6kduhJsD2/VUfaMaXzR16t0Y2c\njqXredAD19MzLvdXTlkCvqH7Ve9feuQC9s1aeHqOVVcRjDz6nPOXJ/2NMXaGMXaQc36aMXYQgHIK\nNWPMhB/s38c5/0jhrS0Bv7WCKwJ+nD3JiVUR8FOKr5IKNuQLXBXwk2a6xrHaGYg2qlVDTEVyOUw9\nDAZrXVuwfSHpDNky8/fDl3V0XRGMOn0H8y0DhsaULp08kg4xa5LuqA9/EsTgFIeL7UyWdAaZb8Iz\nDQNNQx8KJJYxepA5WWJVDL9t6cKlk9YBNH5TpWM8VzDgy+ftNDJ8TWHLdDw+cl/bIwgBIAV86QZL\nCkGfkrY8tDA/69ACvvzohcwM3/U4LnYGODDfzGT5LYOy2YGPAXg9gLcF/380/gTmn/G/D+B+zvnb\nS35eYfgaPhcBJe6AIRmnaepYaPnzJqmyUYWB8O+mSDqKgJ+lQMRxPaz3nLExfJFY9jy0oItE7VrP\nFquakOHHC6+YsCdmheyMSnLptE1D6NNDrw+C20DkTZIvUFqp0XSnJCZM0DUGjfnSjxhynyTpdOzM\nN+Efe8GVeM4Vwy2EswT8jmicNnz+NIOkbdrKRVVxTDfy4pJO+FlTGfC14X748jFNguMlt+og0IrS\nUgR86morNxp81mFfx48XrynfOyiCHKdJQ0ZZDf9tAF7BGHsIwCuC38EYu5wxdkfwnFsA/EsA/4Qx\ndk/w79UlPzc3qLFWLxghFr+TyglWTWM4tNjCiQQ/NpDcdEk1WEWGnlLlSiAP77gYvikxfEAt6XQT\nAn7WFYoMWwzc1oS9T0bXdtFu6ENThAiOyyPyRpqkQ1KdSNomaN0yqAdPJkkn40342uVZfP9Nlw89\n3jD0kS4dyh0pXTqmjr7jKXvZE1RjJIWGX5ThS/s8SyCbNDSF3XngeCOrmu2E5LcMSzD8YUmHkrak\n4QPAM4PEbR6G37PHV2gpoxTD55yfB/AyxeOnALw6+PnvAWx5WR4xq+5A3X5UDviA34f85Go38f1C\n/25a0lYd8EdJIhc7vlY6NoZPGn5wMVCQt12Os+t+rxSSROKShF7A7xwOnVG7dDoDF4eXgoCv7Jbp\noW0ZWA1cMmkXqKaxQOcOk7ZJHnyCn98JA36apEP6bFHQZ6WBOrWqppfRObXWtVMYPhuSwUpr+NKN\nfxoZvq5w6cg38SQkzUiWoZR0Yklb1+OiBuLqvTM4sqeFG4LhNWkgAtWzXSxOYL/uiolXQODScT1f\nPlBqo9Qn3D+oh5da+Ntvnkl8v6RZqVFJR+3SGZX0pMA2NoYfLM8pKNA4RgB4MrjJJbUCzuoykhEO\n3A5dOpxzcTPxb8K+pKPulhkWDAGjK11nGrpky1T3nJFhCYafRdIpd1FSm+40EMNXBWeSCdd6TjrD\nj60iN/oOmqY2cl8kwZjygK+qtLXdDBp+BoZPhEEp6QQMX9bwNY3hc//uuzPp8YauBQx/e0g62wbE\n8EnSiYMkA9rph5faOLcxUNoEAV+X1rXh7L6uMcGGkiSdkQE/cEOML2mrZvgAImPbAIVLJ8P2xyE3\nHaPAIb8FdYZsWbq6H77rxSSd9NNWloaS/OoyzFgnVRUr7Nl+wn+x5DFpmKNdOlQXMauQdOj8dD0u\n7IJxGNpwN9T1no3Zgvo9sA0YvsL95mRg+LY3mhCYCltmUuEVIWvylVpW9B1vLLMv4tg9AT9gcUkD\nBkKGTwG/BSBkvHEkTV4CwhNEGfAzJG1Fgc+YJJ34GLyNvpNYZj/kwy9gy5THyKmae/mrLj2YIjQc\n8F2PR/rKpLluAF8K2eyHkk5SYBTvZ/j5HVqJqFhhVcfE0kcH/I0UR40sEyYxfENRK7HeSz7GWSAP\nN58EE80LpS3T5bBdnjrc3AnqNNJAK2JVmwyRtHV5qpkgCVENv2b4lcHUNXjcv5hU2rqK4QNITNza\nLk8Zi+Y/nqThj07aBgx/TD1Lwha6xPBt8X2B6PK9isIreYxcvAe463H0HS8YFGOok7Yej+jZoy4s\n+caRackeyH10Y1JJOuKYlGT4WVw6aQlWmUQkBnzFObbecwrr90BIEqaR3QN+rilO5sMVW/L5art8\n5IpRNRSGfpYlnSKWStLwaf7FuLFrAj5dHH7b4mQNXyRtA4aflLi1XS8x2UNZfVWuIEvSc7Vjw9SZ\n0pZXBeLl9+s9R6xoAGDvbBjU4i6dIgxfVNoaTGL40ZawJOkok7auFwl0oxh+2zKEFGc7+TV8lQyw\nuhkw/JIBz3fpZGP4KklHJhFpQ13izdPkXvhFYEx5wNcTbJlA+vwBx8uwAlQkbTWNwTK00Iefwd6p\n3u6A4W8TW+a2QbSL5fDXbsdK4ZfnGmgYWmLAd7xk5kg3ApV0lMXW6Bf4WGPrOS6KjYL5AJ2Bi0NS\nwKd5AIC6W2bupK3knxcMPwiuFJhbloF2UEX6vi8/jvd9+XHxeidIvNJNexQjkxn+IINLh3zrIkAo\nJR1yTpXU8A2/ADAN6/1kl04zA8P3JaphH77qBpIV087wVbbMUa4res6o80nYMmNxo2loiRp+Vhia\nJjqZjqt3loxdE/Dp4ljr2Qm2zKiGzxjDoaUWTlxIkXRSCl/891QUXmVK2pZ3g6RB7h9D8sGhRXXA\nH3bp+N8tzzi5sHmaBj02kYkkHBr23hk4+L3PPRJpUewEZeuN4LVZZsrKks5oBsciFj61pBM4pzI0\nTktDFlsmBWeVRBDR8BPOv4ahD920NnphL/wimHaGH59pyzlPXbER0mYkE+TmaTLkQeZeCYZP+aZJ\n+PB3T8APLvrOQJ20JQ1f/tvhpWQvfhZJR3VjUfnQ41gNGP64QBq4HVT0An7fblryy5JO/Bymcz4P\ny5eL1OIavqgqDQqv1vsOnrjQibij/HwJEwxrlG+63ZAknawavjNC0iGG3yqp4evayIlXG71k+SVL\n0tZPDEdXEes9pxTDJxY8vQE/KunI52eahOZkOD/ofGvErmd5kLnjecU0fF0O+DXDrwzyxaHqYrnU\ntsBYdMl+ZCm52tZJYQapDD+DBl6F3zsNonmayyN90uliXk6RdATDz1F8Fe2WGXXpUMBvWb4Pn95W\ndus4wbKbnBEjk7amzPAzaPhGtNJWlVS/2LHRMLTSHUwb5miGv9FPDs4ta7SGH7d+eh7HxqCcS2fa\nJZ24XVi+aacxfMcrVngF0Fxbap5WnOFv9KmDb83wK0O0IGr4ax+Yb+Ivf/oW3PrMy8Rjy3MNXOzY\nSvkijTlSVl+p4WdwuYyzcZq/DaFLR/RYaZriYo4kbYckHQSvzS/pmAqGLySdwJZJkAO+HVyUdNMe\nmbRt+GPmvKB5ViYfvqzhKwLExYqOSZbCq41+sqNGPqeSJZ3oZ2wOHHBevMoWCCWdaRx+AlA/fCng\nO3LwTz5Xs5wfVpqk45TV8GuGPxbIBytpSPBNRxYjB190xFNcoDSUW4WQ4Q9fYKrkkgzOOS527DFL\nOqEPX+6iSAE/ouEnMPw8Th0Vw6eLkNoItEw9csLLko7jejA1TTCsUUk2cjeJrpLGaA1/4HgiSKol\nnWraVVsZ2iOvpcgvEZdOkqQTcwKFNs/yhVfTyvA1BsjGpEEOhj+KQIjCq6GkbVgoWEbDJ2dabcus\nEKYxHMhHoRm8JskqmLQUJEeJ6o4/SsPvBL3OxyvphM3T5GCgCvjDE6/8//MEfHl2gBG7YdAF04ox\n/J7tiTmzHkeE4WdJ2gL+vsyq4UdaKyglneytkdPQMHS4Hk/dfxs9O7HnPHUcBdIZfl86Z9dTbJ5Z\nQcdtWgN+3O4sB/lRGv4oiZBiR3zoe0OSdMq4dML3qxl+ZWhIF0fWmZG0fE4q909rXqXS74HRrQko\nOTheSSfU0cXou4aB+abfFlpOGA4lbWNFW1kg+g5pwxo+JTAbhibY6/45/4bTtV3RIsDUQ4Y/KoDL\nc22z9tIZNQDlYscunbAFwlxSmqyTpuEDIctPWrk0Yk4gOTFeFHTOTGvAj6+c5Zv2SJfOKIYvKm1V\nLp3h9sh5IH92bcusEDLDV2n4KtBKQN2jPa21goZ2wt16VNJ23G0VAKl5mstF35a5poGXPG0Z33/T\n5ZEVUFzDF71wPF9//++feEB5Q5RBfYdoxB8QMnwKTJahYTkI9C++wZ901hk4kZmjDcOfIjXqwpIZ\nfpZeOpS0JTeRKkBspujqeZAp4I+oiiUvvqWrzzG/ICh8fzo+ZQKKuQ0CvnxZZZV00gbJECgnF3dF\nNU1dmnhVvLVC+H61pFMZsmj4cYQd8RIknZTWCklujlFJW8Hwx9RWgbYBCAetWLrfH+XVzzqIt7/2\n5qGKQhl0A3A8D3c9dgHv+MxxfPWJi6mfJ0+d0sXqIgj4wQXT0HU898olfOrfvhjfee1eAECn70bG\nI1qGltjOQkZbmkmczYfvJ21pqA3nw5JVx3YTV215IEryE4qvXI9jc+BmZPjJPnxZxqCfyzTnesE1\ne/Gml1+Pm48sFn6PcSJuyxyPSydmy5QKr1yveGsF8X4TkHR2VXtkQmYNP9YCVUaaVPATt1wtAncc\noxh+2VF0WUAnuO1xrPfsoc+StcThpG3I8CmQjBroMXA8EajTGD5jDNftn8Pxs5sAfIY+2wzbUDcM\nbeTFCYRJ2/We707J1i3TGwoSuhZ1DVUxVJ729XrPwQFFa/0sg0oo4CetMEnSoRbUfZEULL79bcvA\nm15+Q+HXjxtptsy01VQacSMk2TJ9DT906RRL2uaPS2VQKqowxvYA+ACAqwA8BuC1nPPVhOfqAI4B\neJJz/n1lPrcIZDaUVcOnpK1ysLbnJV5wLwwYqgqjZsKG4+3GF/Ap+Dquh82+E+lECcR6hgwVXoUM\nnwJ9UlJsZb2PM2s9f18F7yle70YZfvT4kCTjwHH9lY4RuHSyXFQUmC8F1bEjWysYLKLhA/6NiC5A\nx/UdPG1F/UZehAHfVv49U8C3RjB8acC2LDtMQjLYKrCYpBM9lmndMke7dIQtMy7pGHrEh1/Uline\nbxtIOm8BcCfn/HoAdwa/J+HnAdxf8vMKo4ikk560Hd1lT4VRrRXC3jLju9sTS6a2rPH9YUUCvprh\nu9KA6KSA/45PP4TX/8E/wnZC9hN36QwcLzJDABh22dA2W4aWaZ/TzZL632RvnhZ+Dznp15EavJUF\nWSPlGQQywsZpyVq5kHQSvhc9TselVwHDn3b4tky19z6tl05aTywCEaL4TZh8+JzzUoVXhEkcn7IB\n/zYA7w1+fi+AH1A9iTF2GMD3AnhPyc8rDKtE0lYt6XgwC97RR9kygWqCSxLC5mkcfccd0nZlhh9n\nLfQ3mqsKIGIBlHFytYvzmwP0HFd8ZtylM1AkzWSXTThKkuHVzzqI17/wqpHfry0Yvh88s2j4Ho8e\nZ9v18Od3n8R9py6J4rCqJR0VaKB8WtJ2NMP3/x6/IU/C571VSLNlJlU2U7+dUSTieVct4Y/e8Lyh\n/EXT1MC5//5OJRr+9DP8A5zz0wAQ/L8/4Xn/E8B/ADDSy8cYu50xdowxdmxlZaXk5oWQl23Zffij\nXDrFsvKjAj5j47Vohe2RPfRsbygQyAE4zvAbUjEaBfokhn92vQ8AOLfRH/LQyww/vqSWGb7ow6Np\neOnT9uPnX379yO9HSdvVjAyf/k4Vj7Rdb/2r+/C+Lz9R6U04ZPhqSWctQw4n1PCTffgAhiS3nczw\nWcyWmSVpK8jEiEDNGMNLn7Z/qHutTAhdb/QgFRX0abNlMsY+xRj7huLfbVk+gDH2fQDOcs7vzvJ8\nzvm7OedHOedHl5eXs7wkE8wiGr6VruFnSSDGMTLg9/0BLUXYQp5tAPykbV/Rh5sxJoLGUMCXggkx\np6SAf2bNH4h+dq0vLoZ4P/y+48GKnejtwC++OXAjbRmyggKi0PAzjrCTb+w0WHqj5wiZrZqAP4Lh\nU8BPcek0R7p0opIOBf5JjNDbKuiMQU6NDaTWCklJW9kBVgQh+XFLa/iWro31mhefN+oJnPOXJ/2N\nMXaGMXaQc36aMXYQwFnF024B8BrG2KsBNAHMM8b+lHP+Y4W3ugCqtmVm6cGhgj6itUJV9r80MMZg\n6gyO68sye2aGv0cjaAGQKunYyS4d1+M4t+Ez/LPrfdF+Wc4fAP5+jK8w6IbcHThC+snjcdY1hqap\nZU7aUuCUGX7P9m82m31HknTKJ21nLQOMjU7apks66QVotD8HQsPf+ZKOxpAo6ST10gmL+ooFWjJ1\n9IOq8HjNShaQS2dSN+Oyn/IxAK8Pfn49gI/Gn8A5/yXO+WHO+VUAXgfg05MO9kA04Gc98VspAT9L\nDw4VdE0Twz9U6A7czCuQMtCDQSY921WWdNNj8ZhCskDflhi+IsdxfrMvXBOXurbYV0aM4Q9cb4ip\n0n7vSAw/72pqxjJE0jbrRCO5YRsx8I2+Izmnyt+INY1h1jKEdBNH2rQrAu2fpPNYHCOJ4ZPtdaci\nbneWK8GTGD4lc4sQNyBKCB2PR+SZrKDrYVJzgssG/LcBeAVj7CEArwh+B2PscsbYHWU3rkpQlWfT\nzL50omZfqqStU9Clo2tIZfibfWfsDB/wrZl2wPBVgSNR0pEsf/0Ul87ZtX7080TSllw64TSieNKW\nGLqs4ee9KFuWnkPSCRi+1LCNGLgc8KtyTs01jURJZ73vgLF0W+5sw4TGkr+XJZhnoOEr8jQ7DZoW\nlXSi3TLTNfwi0iwQ1/CLuXTosydlmS1FJTnn5wG8TPH4KQCvVjz+WQCfLfOZZZBWAZuEpqENJW05\n537JfsFCi7TWwl27mgKfUTB0f9B1z/aU7IICRKKkY3uSC2R4BXR2vTf0ecDwPF0Vwwf8gCe7dPJe\nTIeXWjj2mF8SklXD7/SHGf5m30HXJg2/mpXXXNNMlHTWezZmLfW0K8KPPP8Ibrx8PlEzFpKOlGOZ\nFIPcKmgsWh2dpbWC6OJaoCUCEAbpnuPC5TxSRJUVguFPKKG+s2/7MVhSg66saFn6kKTjCqtgMYaf\nNh6wM3DHWnRFMHRNFE+pGb6/n4aTtmGiKq3w6kwCw1dp+KqA37J0dPqyDz/fvn7DLVeLm0VScpNA\nK4yNviP2hYrhV7XySmP4o/roAMD++SZeceOBxL+Hsltom93pDL+ILdMpKBcSmpL0yPlw36ks2G4a\n/raCqWu5l04NqZqOEC4FiwT8dIa/2XcmwvBNzR907S/3VRp+IOnEGb5K0lFIXiTp7Al6Ag378KWA\nr9iPPsMPe+nkzZe84ukHcP3+2chnJ8GSEtFUZLMmafhV+vCBIOD3k5O2ZdoYA9HvQ//v9IA/NADF\nDauLEzX8gnIhgVh5J0i0F7lx1Ax/jCgyoq4p9csghCdKgTs6o1406qDfnYBLB/BvVgPHC1oIJGv4\ncdbSlBKCab10zqz3sGfGEq2Ow6RttNK273pKF03L0rFZ0KUD+Deqn3uZ79nfO6IRnalwcBED79me\nCP5JHVDzwpd01Az/Une4t1FehJIOrcDcHe3BB/zzNNpawf9lxjJSJJ1iZIJA1w05q4rYMvUJJ213\nTfM0IOhTn7MfikrSCU+UApqd1C3SUpwgnQm5dAydCX+5kuGTpBP7iqbOwJgvE4S2TDXD3z/XEH39\njbwMv6GjW8KlAwCvuelyPP+qPbhsoZn6PPk4Us94WWM/t9GHpWdr65AFaZLOuY0+rt43U+r9xSrM\nljX8nc3tkmyZLUtPtGUWJRMEukbIzlsoaSsCfi3pVA7L0EQv8axoGvpQ0lZUfxYIQqSJJw0B70zQ\npUNBJ43hxzV8KsrqB6sDQB3wV9Z72D/fxNKMX1lKQT2stA1aKyTkEFqmgc2BK12UxVjYqGAPRAeJ\nkNdetk2eXetXKrNR0pYrzoGV9b6YC1AUtK/p+PTsnc/wGRvulunPUEgeGl+GTAChxEcMP36tZAER\noElMuwJ2GcO/5bp92D83OgDIaFl6pCAH8CtUgWLZ/bQh4JzziRReAf5JvpnG8MmHrziJqd96aPtT\nSDprfdxwYG6opcIQw09y6TR0dIOJVUBxnTUL5Pcm2WZDYvgrG/1Kj8lc0wj6GEXdMwPHw2rHxvJs\nvnM0DlEBKjH8mZmdfanrcVumS4Pv9SEN//jZDXzrqTUxynPUAJQk0DmxXkbD1yer4e/ssyCG//z9\nz8j9moah4/xGtLc9FWwUa60Q1bBl9B0PnFdn/0uDoWtYC3zqqQxfwawbweCHJIbveRwrG33sn2+A\nwX+9GQv8rpsu6bQt3Wf4JVlYFqglnfAmf269WoY/36RVhB0J+Oc3/UR3WYY/1EtnN/jw47bMoBLe\n0tmQhv+nX3ocH777JN71Y88FULy1QjzfU0zD9z+7lnSmBKqkreMVz+5T3FIlbWklMRlJh4kTVcXw\nrQQfPuBrxNHWCtEL6kJnANfj2D/XFKMazQSGb7tcyfDbloHuwBXST1GdNQsiSVsrDMaElfWqGb66\nRfLKejUB39D8PItcJ7HjffgKW6ala2JAvYzNvoPNgSNaKxQlE1pQICgCfgFJhwjQpCS3OuCPQCsY\nVPzVJ1bxb/7kGBzXK5XdD4eADwf8qis602DoTNxg0iptkyUdmeFHb4i0clhomSJpS0GVMRZpIJfk\nw28HLp2yTooskFcY8rQswsCtZvgJIamBWlUBX86zAFB2RN1p0GK2TOpma+rDtsyu7fvm6fwvWngF\n+MSE5L9yLp1tUGm7G+APOfDwuQdX8In7zmC1Y4fFQEU0/JSkLSWHJ1F4ZephBbG60tZ/TEVaGsGQ\nbFkykCHfuESyVgqq1McHSAv4RuSirMoho4IpJW1JTosH46qTtkDYN4dQVcAHonNtd6ct04Np+ENz\nOt0oIaG6irVgXoJ8/POiZeriXCmyUjBFa4Vaw58KtCzfHkgXo2wVHNWFUYV48zAZk5R0ZNeLqsqP\nGIdS0iGXToIPn24kbUsXRURyAzN/CIwnWlQkafhA2OK4qEsnCyJJ25jzIv54FUgac0jn2L7Z8gPs\nLYnh74bCq7gt0299ool5xTLo/CTZroxc2LJ0ScMvVogJ1Ax/atA0NPQcV7T63Rw4YUOvAkGIkqAq\nDb/qis40yIxZ5RC47eZDWGpbyjwFSTpJlbaC4Zv6kA8fCBm+PMA8DgqwdFFOyqUj7/uWGVpyq2X4\nCZLORh+LbbMSNu7flP3xez1752v4LOiHT4PbbTdI2hrDSVs6P9fFuVWcTLQtHeeCG3UZDb9m+FOC\nhqmDc+DURb8ZWGfglmqtkMbwJzHAnCCf5CqGf/W+mcQCoKap4fymk5i0lW9ce2YtMBadQUBjHsUA\ncyXD9/fBpa4Nxorpo1kRb51tBDek2aYBl/vbOY6k7ZqC4S/PlpdzgHAV5ngcHt/ZvfCB8PzwuG+M\nsF0O02C+hh8L+GTCIEmnjFzYMnVhyyyl4de2zOkABaqTqx0AgaRTYnACMXyVLXNzAgPMCfIyNu/J\n1jB0v1umG86l9aSZnnJ3yfmmiff8+FE8+4ol8XrqJyQCvorhB/bIta5TKqmWBfJxNHXN7yTqcbRM\nHZ7Hcd4ZVGqVJZlLlbStQr8HIPznYrzhLqi0BSAmTwmGr5B0iFiJ1WMJMtG2dCH/lam0rZunTQlo\nqbXa8U+OzsCRGnoVZ/iqgN+tuCtj6naMYPhpaJgaNgcOXI+LbZVZVLy75MuefkA0UQMChu+OkHSk\nMYXj9OADPsui1Tg5OwB/JUPN1PJ2WR31ebON4fYKKxvVBXxi+P2UxPxOgpBKOdl9/YBvGhoGsdYK\nQsPPOC8hDWQuAMox/NqWOSWIJ1Mig7VLtFZQBfyJSjpaVMbIg4YReo/nA3lC1vFH5SKEhp8i6ewL\nAt+JC52xJmwBX/+lbTB1JgX8MOlc9U14rmmMX9KxXfTEAPOdfanHW5bYrj+RzlL48LtCwy/uriHI\n53iRgH/t/ll81/X7cNORhcLbkAelzgLG2B7G2N8yxh4K/l9KeN4iY+zDjLFvMcbuZ4y9sMznThJx\nZtcZhP7zqhl+Z4KSjjyOLS/7axi6SHhRAlJ26giGn/C+hu67dNIknWv2zeCy+SbW+85YE7YECviW\noUWscuMK+AstUzBMwHdodQZuhZKOr10Tw9/ptkyKtXRZCYavs4gPn3M+5NIpx/Cjuam8mG+a+JOf\n/A4cXGgV3oY8KHslvQXAnZzz6wHcGfyuwv8C8HHO+bcBuAnA/SU/d2KIB8POwEllpqNALEA15rAz\ncGFobOTAjiog65Z5v0fD0MSFNd8KGL4TlXTSuktmcekwxvCSG5YBjLetAiFs/aBFGD61WqhigLmM\nhZaJi91oNS9QjQcfCPMs/V3K8EVrBSPK8AeuJ8iWSNqWWEGWZfiTRtmz4DYA7w1+fi+AH4g/gTE2\nD+DFAH4fADjnA875xZKfOzHEA3534IqlYJG+5SLge97Q3/zWyBPK1kuMNuuMX4Ks+asYfneQPsRl\nyKWTEIxeTAF/zElbIEzcRiQdQ8NsIFlVfVyW2pYYsg74+j0A0dCrLPz2F6F1dsdr+LE5E47HRWsF\nx+Pi8d4gvO7WeuUdYHIF9m4I+Ac456cBIPh/v+I51wBYAfCHjLGvMsbewxhLbPjNGLudMXaMMXZs\nZWWl5OaVR1zD35QCfpHJRGHAH/5bZ+BMpHEaELLmIsxPlgfIYihPBRt14xpy6SSsBF503b5gWPcE\nGD5p+JKk07J0zAqGX23AXGybuNgJGT416NtbQdEVADQCO2JPSDo7m+HLtkyAJJ3w5k3Ouo4dJso7\nAxempoEV8M8T2juN4TPGPsUY+4bi320ZP8MA8BwAv8s5fzaATSRLP+Ccv5tzfpRzfnR5eTnjR4wP\nMjNqW37L3o2+jZapF/LvEhNxtpjhm1ooW+SFHDzmBcOXAv6IQeyC4adIOgCw0Dbx7CuWJqI/Cw1f\ndukYkoZfMUNeaPuSDvXEXw3Y/p4R07myomFqUUlnF9kyAb+jrRHYMoGwkRwlbAll5cJWRMOf/n08\nkk5yzl+e9DfG2BnG2EHO+WnG2EEAZxVPOwngJOf8y8HvH0ZKwJ82UNJ2vmlgpuHPWe07XuExdHSC\nKeK9H/Abk5J0yjB8WdIhDV+WdNxUG2MWlw7hv/3gM3Gpo57/WiUEw5dyDy1LF7bMqldeiy0LA8dD\nz/bQsnRc2PQDPlUml0V8ZsGOT9oGEZ9uoAPRPM1/nNqhdOIBvyQrlwnaNoj3pSWdjwF4ffDz6wF8\nNP4EzvlTAE4wxp4WPPQyAN8s+bkTAzHgfXMNtC0dHduXdIoGfGHLVCZtnUq7MqaBAlyhgC8F8/mW\nguEP0qd2US+dURo+AHzbZfP4jmv25t7GvKAGWr6VLyyGIYY/DkkHAC52/UB/YXOAGUuvTGu3DC1S\neLXzRxxGryu/PbI/AIV+BzDU6rysQaK9zRh+2S18G4BXMMYeAvCK4Hcwxi5njN0hPe/nALyPMXYv\ngJsB/D8lP3dioAtl32wDbctAp+9grWcLZpsX8RF/MrqTZPgleng0TQXDj/nw01wtusbgjCi8mjQi\nDF8LJZ1Diy1YujZyEHpeLAbuJtLxVzcHWKrwM6iXTm+3MPyYLdORbJlAKOkMM/xy5558nm8HDb8U\nneScn4fP2OOPnwLwaun3ewAcLfNZWwUKiMuzDaxs9EtLOmlJ282Bi0NLk3XplE3azqtcOraLgyk3\nEkNnEX256Ii5KiEHfLJotiwd3/OMy/B3b/7uSoMx4Gv4QBjwL3QGlen3QGidTZt5sJMQd+n4vXQ0\nQSaIXJAHnzGA8/Iaflkf/qSxs8+CCtAwNDDmt6xtW373xPWeLSpM8yLNlnmxY2OhVW1gSUKZPtyR\npG2CDz+PS2cagpFcaUuSTjOwrB6YLzdjVoXF4DhfCiSd1c1BZfo9EK6a0qaa7STIPnxqu21qkkvH\njSZtaYVVtqhPzlVtB4a/9VfalIMxhje+5Fp8302XY8byk7brPaeQJRNIZviex7HaGWDPTLEbSV7Q\nUrY6hh+XdMr78CeJ0IcvSTpj9K6Thr86NoYfbS+90106si2TOtGakkvHdvzHiOHTvq4yaVsH/B2C\nN7/q2/C8q/agZeno9J1SSdtwpms04q/1bLgex56ZagpvRsEow/Cl4BH20om2Vkhn+L5Lxy7RoqJq\n0DZYRlTSGRcW45LORrUMn27kVE06DauocYKs9K58XknHcuD65ydp+HuD66zsuSe7t2pJZ4ehHUy3\n6dpu4aRt0ohDsuVNiuGbldsy/YvM8/xeJWlJ2zwunUmBAoOc6BunDNIy/fGPF7sD9GwXmwO3sqIr\nINynaz0bllGuuGg7QJdsmcTmo0nboNI2xvDLFvXtttYKuwotKxx2UJrhu0kBf0IMX0g6RTR8udI2\nKun0nNEtnuVeOoxNBzNqiNm7TCpKG9/lwRjDYtvEpY4tWH61DD+UdHY6uweitkyqqrX0sAsqsf7O\nwIGuMWEnLjsruZZ0djDktsVlA34Sw6/a/peEMGlbjuE3AicEuXTivfBVkDV8S58O9ikkHV0Tnvwq\ne+CrQO0VxrG6kyWdnd5HB4AokFvvOSK4G3ro0gmTth7api6kmLJkQ15F1AF/h0EOYoUrbRNGHIpK\nywkFfMHwS2j4usZg6FrQez3qgkgLMrqmwXE5+o43FXIOIBdeRbtljhOLLQsXuwPRVqFKhk/n5xMX\nOruC4V++4DupTl/qRSQdOr+o11PXdtCUCtyqOP+IGOyGwqtdhVYk4BdjY0lDzM8Ty6vwok+DIVkP\n84LkAgokVMYP5GT4rjc1wcjUNWhB50QK+OOeS7AQMHxx7Cu82T/3yiUc2dPCpe7ukHQuo4B/sSvN\nq2DYP+c/fmbNn0ndDQwFdH5WISfSamEbxPs64OfBOBn+6uYALVOfyPATQGqtUMKHb4mAL0s6NM82\nheHrDE6QtJ2GoivA70+/ILzZkxksvdjyA/7qGFZ3hq7h9u+6BsDO9+ADPgGbbRg+w3fDgr6ltom2\npeNEMJO6E/R5Eqy8gvMvvHlMx7mchunfwilCO6Lhl2P48YlXFzar9WGPghieXMKlI/43NcHwxXjD\nlJ5AhtQ8bVoknZ980dX40Bu/EwAkH/54t22xbeJidyDkPCoGqgo/9Nwj2DNjTYxEbDUOLjTx1KVe\nZOY0YwxHlto4udoFgMBBFhKrKlpv03ttAwm/XGuF3YYqGL6eMNP2/KQDfgmGb+haZDIXTVcCwsKW\nUS4d1+ViKtE0YK5pips4fa/mmAPlYttCz/Zw+lIXi22zErYpo2Xp+J0ffQ4Uffp2JC5baOL0pVDS\nIdny8FILJy74DL8bY/hVnH9tS4ehsakwH4xCHfBzoJKAnzDicLXiSstRKMPw6XWylp/XpUOFV9PC\n8GXcct0+PHZuE7NjHkZDEtJj5zpjy928YAKdRqcFBxeaeOCpdeG1p3PryJ42/vHRC2Ke7WLbFKy8\nChmmZRm5p8ZtFeqAnwMkU1i6VlgX1ZOSthsDXLs8W24Dc6BMpS3grwwaEQ0/JumkBXxdE0nbaQz4\nNx9ZxM1HFsf+OYeX/MHVdz1+Ac+5Ymnsn7fTcXChhZWNPr7+5CUAwHXB9XR4qYX1voO1roPuwEXT\nrFbSaZv6VNSSZMH0XW1TDBpoXZTdA6GkM5S0nTDDv3Z5Fv/sOYfxHVfvKfR68t8D/lL60XOb4JxL\nSdtRGr7fLXNakrZbgZfcsIxf+2fPwjX7ZvDcK+uAXxYHF5rgHPjkfU/h8oUm9gdN7+jGemK142v4\nkaRtFS4dfVt48IGa4ecCsYIyAV/TGJqmhnPB0GrAL/fuDNyJBvymqeM3X3tT4df7ko4frG+5dh8+\nes8pPHR2A52MGr7H/erc+RL7cruDMYYfft4V+OHnXbHVm7IjcHDRD+xfeeIibn3mZeLxw0ttAMDJ\n1Y7o81Sls2auaWwbJ9TupVcFQKy1qEOH8NIb9uMT950Ridtx+LDHjYahi2lCt1y/DwDw9w+dQ3fg\ngrH03AAtf7sDZ1d4xGtMBgcXwjbWsiR3JAj4Jy500bVdNK2Q4VchKf7rF1+D33rdzaXfZxIo9W0Z\nY3sYY3/LGHso+F+5LmWM/QJj7L5g+PmfMcaqbzA+AdBJUobhA8Brbr4cK+t9fPmR8wAgfNjbKeC/\n8hkH8N1P84fMH1ps4ep9M/iH4+eEzznNsaAHrKozcKdSw6+xPXGZFPBvkgL+QtvEXNPA4xc2MXA8\ntE1DStqWl2IOL7XxndftK/0+k0DZq+0tAO7knF8P4E4ohpMzxg4B+L8BHOWcPxOADuB1JT93S6AH\nckzRXviEf/Jt+zFj6fjY104B2J4M/xdf+TS84Zarxe/fee1efOmR81jr2qlyDhBeZJ2Bu6s1/BrV\nYj4ovtIY8KxDC5G/HV5q48EzGwCAlqVVWni1nVBWQL0NwEuDn98L4LMA3pzwOS3GmA2gDeBUyc/d\nMsxYhpjyVBRNU8crn3EZPnz3SXzivqeEw2U7Bfw4XnTdPrzvy0/gr+49heW59I6f1IvnwuZg1xQF\n1ZgMLltowtCYaKZGOLLUwie/eQYAMNswxd93m6RYNuAf4JyfBgDO+WnG2P74EzjnTzLG/juAJwB0\nAXySc/7JpDdkjN0O4HYAuOKK6UtmvfU1z8DV+2ZKv89PvfRaaIyhbenQmO/Jvnpv+ffdKrz0afvx\no99xBdZ6Dl44wvt9202H4AW2zO95xmWpz61RIw9+/mXXK4P4T730Wly5t43luQa+91kH0TR1vP21\nN+GF1+6eOgUAYHxEGR5j7FMAVFflLwN4L+d8UXruKuc8ouMHuv6fA/hhABcBfAjAhznnfzpq444e\nPcqPHTs26mk1atSoUSMAY+xuzvlR1d9GMnzO+ctT3vgMY+xgwO4PAjireNrLATzKOV8JXvMRAN8J\nYGTAr1GjRo0a1aGsgPUxAK8Pfn49gI8qnvMEgBcwxtrMt268DMD9JT+3Ro0aNWrkRNmA/zYAr2CM\nPQTgFcHvYIxdzhi7AwA4518G8GEAXwHw9eAz313yc2vUqFGjRk6M1PC3ErWGX6NGjRr5kKbh7y5P\nUo0aNWrsYtQBv0aNGjV2CeqAX6NGjRq7BHXAr1GjRo1dgqlO2jLGVgA8XvDl+wCcq3BzqsK0bhcw\nvds2rdsFTO+21duVH9O6bXm360rO+bLqD1Md8MuAMXYsKVO9lZjW7QKmd9umdbuA6d22ervyY1q3\nrcrtqiWdGjVq1NglqAN+jRo1auwS7OSAP63VvNO6XcD0btu0bhcwvdtWb1d+TOu2VbZdO1bDr1Gj\nRo0aUexkhl+jRo0aNSTUAb9GjRo1dgl2XMBnjL2KMfYAY+w4Y2xoxu6Et+UIY+wzjLH7gyHuPx88\n/lbG2JOMsXuCf6/egm17jDH29eDzjwWPZRpKP+btepq0X+5hjK0xxt60FfuMMfYHjLGzjLFvSI8l\n7iPG2C8F590DjLHv2YJt+w3G2LcYY/cyxv6CMbYYPH4VY6wr7bt3TXi7Eo/dpPZZwnZ9QNqmxxhj\n9wSPT3J/JcWI8ZxnnPMd8w/+gPSHAVwDwALwNQA3buH2HATwnODnOQAPArgRwFsB/Lst3lePAdgX\ne+zXAbwl+PktAH5tCo7nUwCu3Ip9BuDFAJ4D4Buj9lFwXL8GoAHg6uA81Ce8ba8EYAQ//5q0bVfJ\nz9uCfaY8dpPcZ6rtiv39NwH8py3YX0kxYizn2U5j+M8HcJxz/gjnfADg/fAHrW8JOOenOedfCX5e\nhz/45dBWbU8G3AZ/GD2C/39g6zYFgD8s52HOedFq61LgnH8ewIXYw0n76DYA7+ec9znnjwI4Dv98\nnNi2cc4/yTl3gl+/BODwuD4/z3alYGL7LG27gsFMrwXwZ+P47DSkxIixnGc7LeAfAnBC+v0kpiTA\nMsauAvBsAF8OHvrZYOn9B1shnQDgAD7JGLub+YPjgdhQegBDQ+knjNchehFu9T4DkvfRtJ17PwHg\n/0i/X80Y+ypj7HOMse/agu1RHbtp2WffBeAM5/wh6bGJ769YjBjLebbTAj5TPLblvlPG2Cz8Qe5v\n4pyvAfhdANcCuBnAafjLyUnjFs75cwDcCuBnGGMv3oJtSARjzALwGvhD74Hp2GdpmJpzjzH2ywAc\nAO8LHjoN4ArO+bMB/FsA/x9jbH6Cm5R07KZln/0IosRi4vtLESMSn6p4LPM+22kB/ySAI9LvhwGc\n2qJtAQAwxkz4B/J9nPOPAADn/Azn3OWcewD+N8a49E8C5/xU8P9ZAH8RbMMZ5g+jB0seSj8p3Arg\nK5zzM8B07LMASftoKs49xtjrAXwfgB/lgegbLP/PBz/fDV/3vWFS25Ry7LZ8nzHGDAD/FMAH6LFJ\n7y9VjMCYzrOdFvDvAnA9Y+zqgCG+Dv6g9S1BoA3+PoD7Oedvlx4/KD3tBwF8I/7aMW/XDGNsjn6G\nn+z7BrINpZ8UIqxrq/eZhKR99DEAr2OMNRhjVwO4HsA/TnLDGGOvAvBmAK/hnHekx5cZY3rw8zXB\ntj0ywe1KOnZbvs8AvBzAtzjnJ+mBSe6vpBiBcZ1nk8hET/IfgFfDz3Q/DOCXt3hbXgR/uXUvgHuC\nf68G8CfwB7rfGxzAgxPermvgZ/q/BuA+2k8A9gK4E8BDwf97tmi/tQGcB7AgPTbxfQb/hnMagA2f\nWf1k2j4C8MvBefcAgFu3YNuOw9d36Vx7V/DcfxYc568B+AqA75/wdiUeu0ntM9V2BY//EYA3xp47\nyf2VFCPGcp7VrRVq1KhRY5dgp0k6NWrUqFEjAXXAr1GjRo1dgjrg16hRo8YuQR3wa9SoUWOXoA74\nNWrUqLFLUAf8GjVq1NglqAN+jRo1auwS/P9lPdmRKYgFiwAAAABJRU5ErkJggg==\n"
          }
        }
      ],
      "source": [
        "plt.plot(fhat_fiveVTStwo_linearinterpolation[:,2].data)"
      ],
      "id": "9b516386-07ae-46ac-88ca-879d846ac4f9"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "## 2.3. 원래 f"
      ],
      "id": "a00069be-f2f3-4d6c-af5e-986f71ae25bb"
    },
    {
      "cell_type": "code",
      "execution_count": 314,
      "metadata": {},
      "outputs": [],
      "source": [
        "f = torch.tensor(fiveVTS).reshape(200,5,1).float()"
      ],
      "id": "7fe5dc56-d325-4b27-b7c7-d45449b9d9ab"
    },
    {
      "cell_type": "code",
      "execution_count": 315,
      "metadata": {},
      "outputs": [],
      "source": [
        "X = f[:199,:,:]\n",
        "y = f[1:,:,:]"
      ],
      "id": "f6997e8f-37cf-459f-bb96-309ebe2ccc60"
    },
    {
      "cell_type": "code",
      "execution_count": 316,
      "metadata": {},
      "outputs": [
        {
          "output_type": "stream",
          "name": "stderr",
          "text": [
            "100%|██████████| 50/50 [00:32<00:00,  1.55it/s]"
          ]
        }
      ],
      "source": [
        "model = RecurrentGCN(node_features=1, filters=4)\n",
        "\n",
        "optimizer = torch.optim.Adam(model.parameters(), lr=0.01)\n",
        "\n",
        "model.train()\n",
        "\n",
        "for epoch in tqdm(range(50)):\n",
        "    for time, (xt,yt) in enumerate(zip(X,y)):\n",
        "        y_hat = model(xt, edge_index, edge_attr)\n",
        "        cost = torch.mean((y_hat-yt)**2)\n",
        "        cost.backward()\n",
        "        optimizer.step()\n",
        "        optimizer.zero_grad()"
      ],
      "id": "d1abce18-e0a1-4665-8d7b-deb22742495b"
    },
    {
      "cell_type": "code",
      "execution_count": 317,
      "metadata": {},
      "outputs": [],
      "source": [
        "fhat_fiveVTS = torch.stack([model(xt, edge_index, edge_attr) for xt in X]).detach().numpy()"
      ],
      "id": "8d90ae8f-8904-439c-894d-a1e8352130b2"
    },
    {
      "cell_type": "code",
      "execution_count": 318,
      "metadata": {},
      "outputs": [
        {
          "output_type": "display_data",
          "metadata": {},
          "data": {
            "image/png": "iVBORw0KGgoAAAANSUhEUgAAAXwAAAD4CAYAAADvsV2wAAAAOXRFWHRTb2Z0d2FyZQBNYXRwbG90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\nTkSuQmCC\n"
          }
        }
      ],
      "source": [
        "plt.plot(fhat_fiveVTS[:,2].data)"
      ],
      "id": "2459f666-b8ad-4bed-ba44-3e898aa88efd"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "# 3. 2에서 얻은 fhat을 이용하여 그래프퓨리에변환+Ebayesthresh (스무딩2)\n",
        "\n",
        "-   그래프퓨리에변환을 하는 가중치\n",
        "-   년도끼리 이어주어서 하나의 큰 그래프로 만든뒤에 GFT\n",
        "-   Ebayesthresh\n",
        "\n",
        "## 3.1. Mean\n",
        "\n",
        "### 3.1.1. Temporal\n",
        "\n",
        "#### 1) Block"
      ],
      "id": "aee35fa1-8461-415f-a789-0e93ce5ae3f1"
    },
    {
      "cell_type": "code",
      "execution_count": 117,
      "metadata": {},
      "outputs": [],
      "source": [
        "w=np.zeros((5,199,199))"
      ],
      "id": "2feafadc-8eb7-43d5-b105-c64f18a4aac0"
    },
    {
      "cell_type": "code",
      "execution_count": 118,
      "metadata": {},
      "outputs": [],
      "source": [
        "for k in range(5):\n",
        "    for i in range(199):\n",
        "        for j in range(199):\n",
        "            if i==j :\n",
        "                w[k,i,j] = 0\n",
        "            elif np.abs(i-j) <= 1 : \n",
        "                w[k,i,j] = 1"
      ],
      "id": "55dccf28-a04a-4ee9-88ff-df2c643456d5"
    },
    {
      "cell_type": "code",
      "execution_count": 119,
      "metadata": {},
      "outputs": [],
      "source": [
        "d = np.array([w[i].sum(axis=1) for i in range(5)])\n",
        "D= np.array([np.diag(d[i]) for i in range(5)])\n",
        "L = np.array([np.diag(1/np.sqrt(d[i])) @ (D[i]-w[i]) @ np.diag(1/np.sqrt(d[i])) for i in range(5)])\n",
        "lamb, Psi  = np.linalg.eigh(L)[0],np.linalg.eigh(L)[1]\n",
        "Lamb = np.array([np.diag(lamb[i]) for i in range(5)])    \n",
        "fhatbar = np.hstack([Psi[i] @ fhat_mean[:,i] for i in range(5)])\n",
        "_fhatbar = fhatbar.reshape(5,199)\n",
        "power = _fhatbar**2 \n",
        "ebayesthresh = importr('EbayesThresh').ebayesthresh\n",
        "power_threshed=np.array([np.array(ebayesthresh(FloatVector(_fhatbar[i]**2))) for i in range(5)])\n",
        "fhatbar_threshed = np.where(power_threshed>0,_fhatbar,0)\n",
        "fhatbarhat = np.array([Psi[i] @ fhatbar_threshed[i] for i in range(5)])    \n",
        "fhatbarhat_mean_temporal = fhatbarhat.reshape(199,-1)"
      ],
      "id": "7bb60443-3540-4bf1-951f-357a0562e5b8"
    },
    {
      "cell_type": "code",
      "execution_count": 120,
      "metadata": {},
      "outputs": [
        {
          "output_type": "display_data",
          "metadata": {},
          "data": {
            "image/png": "iVBORw0KGgoAAAANSUhEUgAAAXwAAAD8CAYAAAB0IB+mAAAAOXRFWHRTb2Z0d2FyZQBNYXRwbG90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\nwQQTTPA8wYTwJ5hgggmeJ/h/AclVyifTB7I9AAAAAElFTkSuQmCC\n"
          }
        }
      ],
      "source": [
        "plt.plot(fhatbarhat_mean_temporal[:,0])\n",
        "plt.plot(fhatbarhat_mean_temporal[:,1])\n",
        "plt.plot(fhatbarhat_mean_temporal[:,2])\n",
        "plt.plot(fhatbarhat_mean_temporal[:,3])\n",
        "plt.plot(fhatbarhat_mean_temporal[:,4])"
      ],
      "id": "427291ad-5e9c-4539-b1c6-8c122307dff7"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "#### 2) Random missing values"
      ],
      "id": "6dbc5b59-5bd0-420a-9b58-0a813dfd5e94"
    },
    {
      "cell_type": "code",
      "execution_count": 121,
      "metadata": {},
      "outputs": [],
      "source": [
        "w=np.zeros((5,199,199))"
      ],
      "id": "634b9b93-fd71-4c48-9387-488c33dc64c1"
    },
    {
      "cell_type": "code",
      "execution_count": 122,
      "metadata": {},
      "outputs": [],
      "source": [
        "for k in range(5):\n",
        "    for i in range(199):\n",
        "        for j in range(199):\n",
        "            if i==j :\n",
        "                w[k,i,j] = 0\n",
        "            elif np.abs(i-j) <= 1 : \n",
        "                w[k,i,j] = 1"
      ],
      "id": "39003b94-ac38-4d6d-9fb5-80171605a7b1"
    },
    {
      "cell_type": "code",
      "execution_count": 123,
      "metadata": {},
      "outputs": [],
      "source": [
        "d = np.array([w[i].sum(axis=1) for i in range(5)])\n",
        "D= np.array([np.diag(d[i]) for i in range(5)])\n",
        "L = np.array([np.diag(1/np.sqrt(d[i])) @ (D[i]-w[i]) @ np.diag(1/np.sqrt(d[i])) for i in range(5)])\n",
        "lamb, Psi  = np.linalg.eigh(L)[0],np.linalg.eigh(L)[1]\n",
        "Lamb = np.array([np.diag(lamb[i]) for i in range(5)])    \n",
        "fhatbar = np.hstack([Psi[i] @ fhat_fiveVTSrandom_mean[:,i] for i in range(5)])\n",
        "_fhatbar = fhatbar.reshape(5,199)\n",
        "power = _fhatbar**2 \n",
        "ebayesthresh = importr('EbayesThresh').ebayesthresh\n",
        "power_threshed=np.array([np.array(ebayesthresh(FloatVector(_fhatbar[i]**2))) for i in range(5)])\n",
        "fhatbar_threshed = np.where(power_threshed>0,_fhatbar,0)\n",
        "fhatbarhat = np.array([Psi[i] @ fhatbar_threshed[i] for i in range(5)])    \n",
        "fhatbarhat_random_mean_temporal = fhatbarhat.reshape(199,-1)"
      ],
      "id": "e9c66b3a-d5ad-48e1-9b56-da6cb60bd54a"
    },
    {
      "cell_type": "code",
      "execution_count": 124,
      "metadata": {},
      "outputs": [
        {
          "output_type": "display_data",
          "metadata": {},
          "data": {
            "image/png": "iVBORw0KGgoAAAANSUhEUgAAAXwAAAD4CAYAAADvsV2wAAAAOXRFWHRTb2Z0d2FyZQBNYXRwbG90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\n"
          }
        }
      ],
      "source": [
        "plt.plot(fhatbarhat_random_mean_temporal[:,0])\n",
        "plt.plot(fhatbarhat_random_mean_temporal[:,1])\n",
        "plt.plot(fhatbarhat_random_mean_temporal[:,2])\n",
        "plt.plot(fhatbarhat_random_mean_temporal[:,3])\n",
        "plt.plot(fhatbarhat_random_mean_temporal[:,4])"
      ],
      "id": "52a9953c-41b0-44cd-9253-3b19e4f2a560"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "#### 3) By 2"
      ],
      "id": "8f88b7fe-fbc3-4af6-a060-ae67fea7a773"
    },
    {
      "cell_type": "code",
      "execution_count": 125,
      "metadata": {},
      "outputs": [],
      "source": [
        "w=np.zeros((5,199,199))"
      ],
      "id": "dac80c6c-4e79-4bdd-bca9-44156f81e9d8"
    },
    {
      "cell_type": "code",
      "execution_count": 126,
      "metadata": {},
      "outputs": [],
      "source": [
        "for k in range(5):\n",
        "    for i in range(199):\n",
        "        for j in range(199):\n",
        "            if i==j :\n",
        "                w[k,i,j] = 0\n",
        "            elif np.abs(i-j) <= 1 : \n",
        "                w[k,i,j] = 1"
      ],
      "id": "eaed954f-8e23-43c9-a42c-08727712b610"
    },
    {
      "cell_type": "code",
      "execution_count": 127,
      "metadata": {},
      "outputs": [],
      "source": [
        "d = np.array([w[i].sum(axis=1) for i in range(5)])\n",
        "D= np.array([np.diag(d[i]) for i in range(5)])\n",
        "L = np.array([np.diag(1/np.sqrt(d[i])) @ (D[i]-w[i]) @ np.diag(1/np.sqrt(d[i])) for i in range(5)])\n",
        "lamb, Psi  = np.linalg.eigh(L)[0],np.linalg.eigh(L)[1]\n",
        "Lamb = np.array([np.diag(lamb[i]) for i in range(5)])    \n",
        "fhatbar = np.hstack([Psi[i] @ fhat_fiveVTStwo_mean[:,i] for i in range(5)])\n",
        "_fhatbar = fhatbar.reshape(5,199)\n",
        "power = _fhatbar**2 \n",
        "ebayesthresh = importr('EbayesThresh').ebayesthresh\n",
        "power_threshed=np.array([np.array(ebayesthresh(FloatVector(_fhatbar[i]**2))) for i in range(5)])\n",
        "fhatbar_threshed = np.where(power_threshed>0,_fhatbar,0)\n",
        "fhatbarhat = np.array([Psi[i] @ fhatbar_threshed[i] for i in range(5)])    \n",
        "fhatbarhat_twomean_temporal = fhatbarhat.reshape(199,-1)"
      ],
      "id": "061959b5-1284-4e61-965e-44d20bd4294b"
    },
    {
      "cell_type": "code",
      "execution_count": 128,
      "metadata": {},
      "outputs": [
        {
          "output_type": "display_data",
          "metadata": {},
          "data": {
            "image/png": "iVBORw0KGgoAAAANSUhEUgAAAXwAAAD4CAYAAADvsV2wAAAAOXRFWHRTb2Z0d2FyZQBNYXRwbG90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\no0aNGs8R1IRfo0aNGs8R/P/9ePZgy5YY9wAAAABJRU5ErkJggg==\n"
          }
        }
      ],
      "source": [
        "plt.plot(fhatbarhat_twomean_temporal[:,0])\n",
        "plt.plot(fhatbarhat_twomean_temporal[:,1])\n",
        "plt.plot(fhatbarhat_twomean_temporal[:,2])\n",
        "plt.plot(fhatbarhat_twomean_temporal[:,3])\n",
        "plt.plot(fhatbarhat_twomean_temporal[:,4])"
      ],
      "id": "1aa82525-59fd-4925-8380-fccf0a008fec"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "### 3.1.2. Spatio\n",
        "\n",
        "#### 1) Block"
      ],
      "id": "5d32ba0b-cb24-4a5f-9db3-e5221072b8c0"
    },
    {
      "cell_type": "code",
      "execution_count": 129,
      "metadata": {},
      "outputs": [],
      "source": [
        "w=np.zeros((5,5))"
      ],
      "id": "b48bc50e-c44c-46ec-892d-66861ece0c0d"
    },
    {
      "cell_type": "code",
      "execution_count": 130,
      "metadata": {},
      "outputs": [],
      "source": [
        "for i in range(5):\n",
        "    for j in range(5):\n",
        "        if i==j :\n",
        "            w[i,j] = 0\n",
        "        elif np.abs(i-j) <= 1 : \n",
        "            w[i,j] = 1"
      ],
      "id": "83cb2f1b-80c5-41a3-bfb6-6b040b4e7e72"
    },
    {
      "cell_type": "code",
      "execution_count": 131,
      "metadata": {},
      "outputs": [],
      "source": [
        "d = np.array(w.sum(axis=1))\n",
        "D = np.diag(d)\n",
        "L = np.array(np.diag(1/np.sqrt(d)) @ (D-w) @ np.diag(1/np.sqrt(d)))\n",
        "lamb, Psi = np.linalg.eigh(L)\n",
        "Lamb = np.diag(lamb)\n",
        "fhatbar = Psi @ fhat_mean.reshape(5,199)\n",
        "power = fhatbar**2 \n",
        "ebayesthresh = importr('EbayesThresh').ebayesthresh\n",
        "power_threshed=np.array([np.array(ebayesthresh(FloatVector(fhatbar[i]**2))) for i in range(5)])\n",
        "fhatbar_threshed = np.where(power_threshed>0,fhatbar,0)\n",
        "fhatbarhat = Psi @ fhatbar_threshed\n",
        "fhatbarhat_mean_spatio = fhatbarhat.reshape(199,-1)"
      ],
      "id": "5a2eae6f-ae5d-46c3-8e0e-399dfec106ef"
    },
    {
      "cell_type": "code",
      "execution_count": 132,
      "metadata": {},
      "outputs": [
        {
          "output_type": "display_data",
          "metadata": {},
          "data": {
            "image/png": "iVBORw0KGgoAAAANSUhEUgAAAXwAAAD6CAYAAACiefy7AAAAOXRFWHRTb2Z0d2FyZQBNYXRwbG90\nbGliIHZlcnNpb24zLjUuMSwgaHR0cHM6Ly9tYXRwbG90bGliLm9yZy/YYfK9AAAACXBIWXMAAAsT\nAAALEwEAmpwYAADOG0lEQVR4nOz9ebxl213WC3/HGLNb3W6rTp2+yUkfICQkITQijShgg9iC8ILK\nKyKiL1e96tULykVevVcBBWkEQQ2CEDVgICEJSUgDSUh7Ts5JcvqmTvW1m7VXN7vR3D/GmHOtXbWr\nTrXJSZ31fD712bv2XnutueYa45nPfH6dcM6xxBJLLLHEjQ/5uT6AJZZYYoklPjtYEv4SSyyxxPME\nS8JfYokllnieYEn4SyyxxBLPEywJf4kllljieYIl4S+xxBJLPE9wTQhfCPFLQogzQogHL/D7rxZC\n7Akh7gv/fuhavO4SSyyxxBKXjugaPc9/Bv498IaLPOb9zrk/dTlPeujQIXf33XdfxWEtscQSSzy/\n8LGPfWzLOXf4oN9dE8J3zr1PCHH3tXiuRdx999189KMfvdZPu8QSSyxxw0II8fSFfvfZ9PC/TAhx\nvxDid4QQr/gsvu4SSyyxxBJcO0vn2fBx4C7n3EQI8U3AbwIvOuiBQojvAb4H4M477/wsHd4SSyyx\nxI2Pz4rCd86NnHOT8P1bgVgIcegCj/1559xrnHOvOXz4QBtqiSWWWGKJK8BnhfCFEDcLIUT4/nXh\ndbc/G6+9xBJLLLGExzWxdIQQ/w34auCQEOIY8M+AGMA593PAXwD+lhBCAznwrW7ZpnOJJZZY4rOK\na5Wl823P8vt/j0/bXGKJJZZY4nOEZaXtEkssscTzBEvCX+KGxMdOf4zHdh/7XB/GEks8p7Ak/CVu\nSPzIB3+En7n/Zz7Xh7HEEs8pLAl/iRsSMz1jVI0+14exxBLPKSwJf4kbEqUpmVSTz/VhLLHEcwpL\nwl/ihkRpSqb19HN9GEss8ZzCkvCXuCFRmpJxNf5cH8YSSzynsCT8JW44GGvQVi8V/hJLnIMl4S9x\nw6E0JQCFKaht/Tk+miWWeO5gSfhL3HBoCB9gWi1V/hJLNFgS/hI3HBYJf1wvffwllmiwJPwlbjhU\npmq/X/r4Sywxx5Lwl7jhUJii/X6Zi7/EEnMsCX+JGw6LCn9SLwl/iSUaLAl/iRsOhV5Q+EvCX2KJ\nFkvCX+KGwz6Fv7R0lliixZLwl7jhsM/DXyr8JZ7DMJMJz3z/91OfOfNZeb0l4S9xw2Gp8Jf4fEH1\n2GNM3vkuigce+Ky83pLwl7jhsFT4S3y+wNV1+Ko/K6+3JPwlbjg0Cr8TdZaEv8RzGi3h6yXhL7HE\nFaHJ0tnINpatFZZ4TmNO+J+dnk9Lwl/ihkNlvcLfzDaXCn+J5zQawmep8JdY4srQKPz1bH1J+Es8\np7G0dJZY4ipRmYpUpQySwTJLZ4nnNJZB2yWWuEoUpiBVKb24t1T4SzynsVT4SyxxlWgUfj/uM6kn\nOOc+14e0xBIHYhm0XWKJq0Sj8PtJH231vv74SyzxXIKrPg+DtkKIXxJCnBFCPHiB3wshxE8KIR4T\nQnxSCPHqa/G6SyxxEBYVPiyLr5Z47uLz1cP/z8A3XOT33wi8KPz7HuBnr9HrLrHEeSh0QRp5Dx+W\n7RWWeO7i89LDd869D9i5yEO+GXiD8/gQsCaEuOVavPYSS5yLcxX+VC+Lr5Z4bmKu8Gucc3zid49S\nTK+fn//Z8vBvA55Z+P+x8LMllrjmaDz8SEYAaPvZUU9LLHG5WFT4e2dyPvA/H+PJ+89et9f7bBG+\nOOBnB6ZOCCG+RwjxUSHER8+evX5vfIkbF43CbwjfWPM5PqIlljgYi1k6denXqa7sdXu9zxbhHwPu\nWPj/7cCJgx7onPt559xrnHOvOXz48Gfl4Ja4sXCuwjduSfhLPDex2FpBV4Hw689/wn8z8J0hW+f1\nwJ5z7uRn6bWXuIGhK4O1+28WG4WvhPKPWVo6nzOUjz/OmR/78WUtxAWwmKVTB8I39fUTKNcqLfO/\nAR8EXiKEOCaE+G4hxPcKIb43POStwBPAY8AvAN93LV53iSV+5Z99iAffe3zfz5osHSU94S8V/ucO\n43e9m+1f+AXsaPS5PpTnJBY9fF16ZX89FX50LZ7EOfdtz/J7B/zta/FaSxyMWT3j6PgoL9146ef6\nUD5rsMYy2S0Zb+f7ft56+GIZtP1cw5W+6M0WJWr1c3wwz0EsEn59A1k6S1xnvOnRN/Htb/l2avPZ\nKdF+LsBobxOYczZI4+G3Cn8ZtP2cwVWe8F1ZPMsjn5+wVc3O+kuwdd16+Oeu52uJJeHfIBhXYypb\nUdvnEeGHjaH1fINYZ6ltvV/hu6XC/1zBtgp/SfgHYa/uct8r/y5n9eY8S2dJ+Es8Gxqifz4RfrMx\nikLzgce2ANq+OUuF/9yAq/wwmsbaWWI/Su0puDTxUuEvcelo5rg+XwKUW/kWHzvxcQCePjvlO37x\nD5mWuj0Piwr/+XJOnotwZSD8pcI/ELXxJUraSuomaFs9x7N0lvjco1H2zxc1+2sP/Ro/8vv/AoC6\nslgHRW3aaVeLWTrLoO3nDm5p6VwU2ngKrq1cKvwbGk9/AH71W8EanDGUTz55VU/XEv7zRM1O6ykm\nePfN18rYfQq/zcNfevifM7jafx5Lwj8YtfUUrJ1aZunc0Dj6IXjkd6DYY/y7v8sTf+pPo7e3r/jp\nnm8efmUqIhsDYAPh19pRmKDwlx7+cwJN0NYVSw//IGjbiJIIvQza3sBoSKieUZ86BcZghsMrfrrn\nm6VT2QrlPOG7kJ55rsKPpf/98+Wu57mI1sMvC4bFkDd86g3LqtsFaBe1X+vQQ2dp6Xye4cH3HeeD\nv/H4xR/UKPE6x058+96rue1t8u+fL+RWmhJl/WZxJhC+tvsV/rK1wrXB+/413PerV/Sni4VX73z6\nd/nXH/3XHJscu5ZH93kN7fwarUW00EtnGbT9vMLTD2zx8IeepVVQQ0LVFDvxAzquJnWtUfjPF3Kr\nTIUKlg6B8GtjD07LfJ5cBK8b7v91+MxvXdGftmmZRc70xEcByCenrtmhfb6jxq9hTdzm4S8V/ucZ\njLZMRxXGXOSDMwsKfxoI/2oU/vMsaOs9fK/whZ0TfmvpRAtpmc8Tm+u6wZSgr0yM2Gqu8GdT3+48\nn5y5Zof2+Q7dEL6IqQLhl+VS4X9ewWgHDmZ71YUf1CjxeooJCt9eRWDr+azwZbiu7rN05DItcxFX\n5ZvrCsKFlLrw/y71dRc8/GntrctiOWO4hREhziQSytyv03qZh//5hSZNcDq8CIG3hD/38F2RX/jx\nz4LnpYcfAl7SHRy0lUIihXzep2We2it46Q++jQeP713ZEywq/N/4m/7fJWLRw5/pGQD5csZwCy2T\n9mubnWOuX1B7SfjXAc0HN9m9COE3lk41az38j9wneOBdTzN629svW5E1Kvb5omYru6Dww6mq9NzD\nT5TfSEqo572lc3Ivp9SWR8+Mr+wJdOVJH2DvGOxees2Ibgg/z5mForiinl3ZcdyA0KIh/BTTKHvH\nxe3gq8CS8K8Dmrzwye5Fbn1bhT/DTvxGPHZW8cQfPM7xH/gBykceuazXbCydTx7b4fjwyu8UPl+w\n6OErBMJBbdw+hQ8QyeiGu+vRW1tM3ve+S358HRTjcHaFNRqm9KTffF9eukI3waYspjOm4aKR11c2\nVL7K9XnDbi4XT95/lqp4bogi5xxaZQAYmWJqi+bgDrDXCkvCvw4w+hIU/gLhl6Oh/5FxVMHHs9PL\n2xQN4f+7dz/Mf3z/E5d3wJ+H8GmZcft/xf6g7aLCv9HuenZ//dd55m9933w83rOgDmrxigjfWr9W\nG4WvS7gMS0aESttqmpNb/32uL1/hO+v45R/8IA+858pTOmejirf+7AM89tFrFzR+4OwDV96S3BhM\nECZOKnCQh+nf12uu7ZLwrwMuydJZIPwmaKuNo6r8Ff5yUzQbwp9VFaP8YIJzzpHff/8NUfiyLy0T\niNwFLB2pbjiFb0djMAabX9qdXEP4e/kVEFM4n65R+PrSFb7TGmlD24tZzjSs0by+/DvQujIUk5pT\nj19hHAKoyxAUvUZZMFv5Ft/+1m/n7U+//Yr+3pYVJsqIF4LYuQgKXy8J/zkDffYsZ/7Nv8GZgxfO\nPGh7EUsnqAJXzZAz/zjnoApXdjs8fVnH1ChbsOT1wYRfPPggT/3lbyW/777Leu7nIhYtHfAKvwna\nSiHbAebXUuEb6/jg41fe/uJawc5m+74+GxpL54oIPwRrp7Pp/P/1dF4pfhE0OfgAJi+YheB5Ya6A\n8ANJb5+4MjsI5kLsWhU2jasxDsewGF7R31fTUDOi57GVPASkrlfHzCXhXwEm730v2//xF6mOHj3w\n980kpktR+G4yJlzUsU5Qa39P53ZPXNYxtT10hGV6AQVjhl4dmavo2fNcgc/SWVT4orV0Gv8erq2H\n/95HzvBtv/AhHj41ZlpqfvA3H2RcfPZ7F10O4d/3zqNsfdhbGFem8D1pS7Pg4cMl2Tp24S7V5Dkz\nPOHm+vLrTerCf4Z7p2dXrH4bX/xa+eONyGpSgS/77yf+/GRmfhErgqWzVPjPITQWDPpg5dgsqOle\ndeEgUyB8M54Pd3ZOULsIB+wNL+/WtTYVkXYgDLPqApZO07nwMuMDz0UsZumAH85caUtlq7aHDkAk\nomum8Lcn/vyd3Mv5yFM7/PKHnua+Z4bzB4xOwKkHr8lrXQzN52enz074T96/xfgJryCHs4vUhVwI\nQeFHrt73/0uxdRYVvi0KpiEgWVyI8K31/w5Ao/CtdQzPXFmWT0v414hMG/twdoVZR2VQ+BnzO57G\n0ll6+M8htHnzBwTNrHU46+iuJjjryEcX2GTB0mmqbAEcApAYlXL6zO5lHdNrPzHjZ3/aoKy+oMJ3\nVcjVn3x+50Eba9BWt710AJSD+mM78ORgn8K/lh7+NHjAO9OqJX+9mDP9nn8Fb/zOa/JaF8PlKHxd\nW5y+cg/fNYRP7T1HfekKf5HwKcs2IJlfSBG/9R/Ar33bgb9a9N13DrB1Htp5iK9549ewle+ffLaI\nZhTmtepG2bzGFSv8qT8/mZwfa0v416mfzvOO8OszZzj6178bvXt5hLoIe+IhANz4fGukUQ+rhzvA\nRWydoDrtxG9aBzhCZWjUYW94eTnT63ua1RlkproEhf/5nQddhWyPaJ/CF/DEhOiZtTZgC9c2D38a\nfNWdacV2UGd68Q6uGEJx5UHFS8Wc8J/9Ts1oi9WOe8RJ9q5A4ZehGFASyL65eF6Kwg+WzixKEVWJ\nFp7xc3OB4zj7MGwf3HTw2Qj/qb2n2Mq3ODo6yhPDJ3j9r7yeJ4b7s9UahX9qJ+dn3/MszQ0vAY2l\nk+srS4OuwufRUfPz0RD+ZHZ9Msued4RfPPgg0w98gPKRR6/4OeyO90Td6Pz0rmZRzQn/Qrev+9Mv\nnZh/FFp1mIwuXYU75yAEkP8yv8dXFe8++HHVjWHpNButqbQFn6WDdljj9ls619DDnwSFvz2t2J42\nCn9BLdYFXIE/fbm4HIVvtUXUNb+X/n1eUn7ysjO08sXq73JBhJQj+Mgvwrt+5MKvHQh/HHdQ9YKK\ntQuE/+g74fHfC8+5BxewRxrCl1Kwc/L89dvEsEbViCdHT6Kd5vjk+L7HNGLsyTMTfvJdV77/G7QK\n/wo/8yrccXWSObnngQbG0yuw3y4B0bM/5MZCo25ddeV9a8zMbwJXnL/wmkXVXfG2QlVcgGwaD3/q\nF0ueqPlzRBn5ZIpzDhFU0cWgnW77ydxrT+DsZw58XGNB2c9zS6clfBtjlUUaSReBwLdK3mfpCHXN\nhsK0ls6kwgTi3KfwdQ5XkHJ4ubgcwjfa4sJFacPuMqsMvfTSt32ez1hv/lPO401UE99Bc+8Z+Lof\n3Pc3eneX+uhRXPDjXSKIJnMCKxYJ//f+BUQduPdr2PvkLmZasnHAcTQplZu39w9U+M1nPK7Gbczm\nXFunEWN1Zcm1wVqHlM++vy6ENmh7pYQf6iJO5o9C96uARYV/fZIBnncKv9kkV9OK2DaEX56/uZtF\nlXRCa94LBYgaDz/3i2XYmxN+HXURdcWJvUtbSLWpUeFlImuIbXGgkrtRFH6zkb2H77/fUP78OSP2\nWTqRjK6ZpbNP4U8aS+cche8MmOtb6NWu4Ush/NriwqDsTFQML9PHLxZz/csRP76+xr9bX/WWzmz7\nwEZqO7/0n3j6r/61do/dk5wiNtrHAIB88QJc7EExxEwmnHq/YftBdd7zwVzhH7l7hb0zs/NaDzTF\nT6NqxKjyF6ZzvXV9TpZOoa9uXTTr8IotnVAv80zxWPuzhvCnS8K/NmgzHK6K8JuxbedvuIbgk8yr\nKHuhnhi2IXz/XHsLhK+jjMTUfPrE6MA/PRe1nRO+1YKUiuKAwFSr8K8X4Q+faTf19cCkmnBqemrB\nw4/oj3wsph+WsjPs9/CvS9C2bC2dejFo2yi9KySAS4Fzrv38zCV8jkY7XFgKKTV7l0kkxeIaL0a8\nN93gY9G6V/iz7QPfa33iBC7Pef+7x+ysvwSV+AOINXStpVjMmipGkO8yfOMbsbWgmskDmwg2hL9y\nqOPrVc7xuFtLpxyxV/o4SqkPVvjNHp1dZa771RJ+856qKEc1fYaawPYFiievFteE8IUQ3yCEeFgI\n8ZgQ4h8f8PuvFkLsCSHuC/9+6Fq87pVgrvCv3CNrSPpAhd8SflD49YXSMsOwg5DHvUj4JuqQWH1Z\nhN9YOhhBRsX0gMDtXOFfB0tn50n4t18IT//BtX/ugJ+9/2f562//6/P2CTomDput50L9goVELih8\nce0UfpP9tJilY+wBhH8Z7YMvF66q2njNJSl8bcEJjFNkVAzzy1v35QL51vmQlzz9V3nB0e/y9s5s\n+0ALS589i0Pw+FHF6cNfgkr8OUo0bBpD0XQvdQ6KPdx0yM4b3oCRDukE9TPnN2erC4OUgs6Kj8+U\n+QUI/yIKv9mbTa+r/CoJ/6qDtoVBWEOZaFQ41kbhz65Tv5+rJnwhhAJ+GvhG4OXAtwkhXn7AQ9/v\nnPvi8O//utrXvVK0QdKr8fDzpsf3QZaO/8DioPCbRfb2p96+vyKvtXRqqlhQLnj4WnXoS8unTlxa\nxodPUWyeV9ChYnZAaqYNhH8pyvCyMd0CHIyeZdLXVeDU9BRnZ2dbZRWbiCj0Zek279+K89Iyr1V7\n5P1B22DpnBu0heuq8Bd9+0vy8BtV62IyKkaXaelU5Zw0T46foV9sEtdrMDnjL3B1ft5dnT57Fhsq\nnWfdI63C94RvyZs7Ll2ArclPGfSp03z8i8Igm6cPIPzSEGeqvXOuz4mNLRJ+q/DP8fAbS6cZiZkv\npD5+5y99mDd9/NL79JSPPkr6SW/FXGlaZl0alCkoYkFkShCOKij84rlK+MDrgMecc0845yrg14Bv\nvgbPe11wTTz88GG48vwP2gRfMG4UvrFs5Vv8g/f+A97y5FsWniRk6ZSGPBXU8TyQpqMOXSxHdy61\ndL5GhT3njPdqD1L4XE9Lp9lc17H17agaUZiiVVTKxkTh+6zZu0YQq4WmatcyLTMQ/rjQrWW239IJ\nRH+F06EuBYsptc+WXuusawv/tEu9h3+Zlk5dzS9eT06Ok5ouwiWw+3TzKvPhKAEXIvy0PofwQwpr\nNfF75cEX+h9XR586/zhKQ5wq0o5/3ktR+BeydJp22o2lU9SG9z1ylk8cHV70XCzi7E/9e+796d8B\nrsbSsUSmoIxB6QIhwQmwuOs29epaEP5twDML/z8WfnYuvkwIcb8Q4neEEK+4Bq97RWgzHK7Q0nHO\nYcPGd9UBhB8UvookMhJYbdtikH3R/IbwK+sJX+338FNneWZndklpdIuWjtPe0jkoF79R+E3h2DVF\ns7muY5ZKs5F3C+/bK3cA4R+k8K9RpW1D+IvYb+lc/3OwmHv/bAp/MWHAENOhuuziq0WF//T0FKnu\nomwCw6fnD1p4vzbPsZMJLgyQr5MBOvEtgBMNGzKmwPp1XfjPs55GIODRWwVaQn3smH/OfF4r0xB+\nEgi/Opfwzfke/oUsnaglfP8cZ8dN2+ZLJ1l9+jTpzgScu+IsnWlRonRB0hugTIEIm1hDO+7wWuNa\nEP5BeU3nstTHgbucc68Efgr4zQs+mRDfI4T4qBDio2fPnr0Gh7cfraVzKQpflzDe38TMzWbtuztY\n4YdFFUtUJDHacXbm30e1mI7WpGXWklniqKNFwu8QW8O0MpekyHybAf+9aDz8AxbMdQ3a6s+Cwg9p\ngTvFDgCCqCX8NPQvElbuC9rGIsZUYzj1wFW//qTUHFlJ9/2s3pel0yj86+fhL352l0P42iV0riBL\nxyyImmemQ2KbIO2iwmcf4euwZxuFDzBJbgEgqWFTZTiC3RIUfj1TRKsdJqng7CpUx0/Au/8F/Jc/\nPX+JlvD9PjmP8A9S+BdIy2x2WuPhnxkX+/5/KdBbW0hjGeRXrvBnZY0yJffc/FIineNE4AQJ1XO4\nedox4I6F/98O7Ov85ZwbOecm4fu3ArEQ4tBBT+ac+3nn3Gucc685fPjwNTi8/WgtnUvx8D/8C/Az\nrw9tLKdw9EOYBXU8nZy/4RqfUEUN4c8V/r6+2aYGBLYWTBOHS+ZEolWHKNgQx3affTEtpmUKI8hE\ndWAGwmJa5jVvkWw+uwpfOAlCIW2NtDUqBG2FFfuCtirfQW8/Bm//J1f12s45ppXhzo3uvp+3rRWs\naTOvrq/C92tOpOklEP78MzYuYSXSl63wzULB1MmiyY5KsItDTPRBhD+31SaxJ/ysdqwpX5CY69wX\nWgH1VBGvKAohOLMqKE+cgt2nfJwg4DyFX1yY8FuFf86FdxYEWoT/24d2H2RcjTk9ujyF75xDb/k9\nvTbxFxbr7LP81fkoSkesp7zklldy99G3ozd89a+T4jndS+cjwIuEEPcIIRLgW4E3Lz5ACHGzCBVE\nQojXhdf9nLRsvNS0zGPjY8xGxyDf8eR836/Cf/pG7M48KFkd0I+8UVUqkijlLZ3twr/VfQVAtsal\nA3QtyVOI0377Kx112j7ix3afXTHvz9LhgpZO00vHOjDXur1C0y/9Giv87Xyb45PjWGeZhL7hu8Vu\n20eniBxy4bzuU/g7T6Ce+QgGWvvgSlFqi7GOO84l/MbSWST56+nhB5KPDh26bIXfV/qy0zIXFf5W\n6d9rZBLyxRv7hayklvDFXOGP1M0ADGrohqHdhS7mCn+qiHvaE/461Ke2fFXvQmygJfzsApbOQlrm\nuPIVwYsK34zHTHf8PowQIDQ//+g/4E2PvonTI3/8F2pJci7sZNI6BBuTZ2kIdxForYjrKbcffiEr\n46PkUcjHV+K5O/HKOaeB7wfeDnwGeKNz7lNCiO8VQnxveNhfAB4UQtwP/CTwre5zNIXjUtIyC13w\nLf/rW/gTZ97Br6z0/S16MQRn27YKMJ/XuYiW8GOJir2l0yj8ajG4ZQ02GWC0ZJZCnA3835nSE34I\n/j5ziYTfKnzdpGVe2NL5zEu/k7f9wqef9XkvC9cpaPvjH/txfuD3foBpPW1V1G65S2z8xt/qRYgF\nj15aNffwn/kIympMlFz1cU1KDQ7uOqc4vc3SWdzw1zMP/3IIf4E0jIvpyfqy0zIbhW+AvTrMEEaS\ni7mC32fpnAltRxYsnZG4FYB+BVkIqOc6h2KEs8HSSaYUUnJmVeDGM8x4OJ/7zJzwVeT3VZmfk6UT\nHluYAmEtX/9xSzWeW8KnfuRHMO/7KACRFSAqLJpZPVtQ+JdGsvrsVvv9eshwvhJbx5qEuJ6yvu4v\niGW9SyQFIgjF64FrkofvnHurc+7Fzrl7nXM/Gn72c865nwvf/3vn3Cucc690zr3eOfeBa/G6V4JL\n8fBznVOYAgn8q80N3n/sva2KsXs78+c64KJhFiwdqfZbOvs8fFNTRX1cLShiSFNP+HE9QUcdnLas\nZNGlWTq2bjMPhMGnZR7Qp91VFUbGnD30Sva2/Pv5yKmP8KZH3/Ssr3ExbOVbPLJ7CoDt4fCqnutc\n7Ba7HJ8cb+0c8Kp/beqJ49QgQi4SvlPzLJ3JKSIHWsXekrsKTEvNPVoSvfsMh6yglyiyWM6DtouE\nf43z8MuFitBW4d90+PIUPik9eflB26Zb5ulIoUyn/fmUbP6gcy2dOEavrwIgTcme84Tf1dCR/mKc\nmxyKPXSuwAlE6lX56TX/PPWZ0X6FX2ji1LvvSSe6oKUD8LJnHH/j7ZbNz/heOs45ph/8ILrbAyBy\nCkHd/t3cw780ha+35heS9dBe6HIJf2cyROAJP+r5u/uqHhIpgYgkVl8fPfz8q7S9BA+/UeJ/M7md\ne6qaH/3EvyMPdsJvPPRb8+eqDiD81tIR53n4+xW+Jpc9nBGUyX7CN1GG04bb17tX5OFL4SgOCCi7\nqmK49iKsSqjDHcCvP/zr/JuP/psr8vRHWzn/9Qc/yI++6//hu4//d84qSTGbeGX2m98HW489+5M8\nC0pTMq7GbeAbvMI/tOcV5HZXIBcqafcp/PFpn6Uj5GXNYT0Ik1LTt97GuCmJ2eynxFLO0zLr66Pw\njw9zXv1//S7v/LRPHmgEi7pMS8fn4ddMLjO/uyH8Z6KIVM/trCkZj+ZfwX3TP7Pf0jlzlujQIarM\nXxA6+UlG7haskHRqQRbstrzOoRxRz/zF2fb8sZ5Z8+e43p76dRTWpVf4/jNPO9EFLR2AbjgcGfpU\n1UePYs5uURzZ9L8Qgi8/7ftNaVNz5jI9fLM1V/hXaul84uj9gN/vsuMvpHW9RyQl/W7EenZ92pw9\nrwjfOXdJaZmNEu9Zyw9u73B8dpo3jh/DAR878cn589U101Lz7975aDs3tNlkwhnMyWPoyYzt/BwP\n3zlwhrHrgBGUkUAmgfCrCVplWO24fb1z2R6+DPugys9XtK6u2d7wGbF1Gebu1hPG1Zjd8vLbRe+e\nnrF3Nqc6C0NX8I8OH0LXMxgehft+BT7zvy77Oc9F48M+uTcvxtnNtzk08Rti2BEIOb9YKRfNg7aT\nU0RRx3v41dVZOtPSkIbA8EYSs9FLiJSY99LR18fDf9PHjjGtDE9th9jTbAZCEG1s4vL8gmM2Yb+l\no11CSkV1uVaBKbEItpUiNXPCn5Hy6eKP8fHpt5yn8KPDhykyT+Sd2RNYIsaDO+nUkk64GBfGe/hV\n5dWt7ls2p7fh1AsAqIYl4MAanHNt4RX4KvaLEX6n2dohyDz7qLdyynhOd3/tgff71z11f+vhX2qW\nThOnmKzErF2hpfPAMX/BifUMES6OWo/o2JpbN7rctda92J9fMZ5fhF9V7ZSqi1k6jR+YWMNri5JD\nySpP1HtMhCBuKvyEA13zzs+c5ife+QifPDYE5pvMnjqO292m3h2dn6UTLIi9yn/QZQxO+oUf11MQ\nEm0Tbl/v8sxOzr/8nc/ww7/1qQsfr92v8AHq8nyCs1XF9uEvBObDuqbB6jg6Onhc48XQ+Ix1aegS\n8ZFOxn1ub95V8RopfNhP+HvlHhuB8Hc7DqHmAUTp1DxoOzmDirsYnM+g0ZfnXy9iWmrScF153R3r\nfNMX3oySciFou2jpXBuF75zjf4TqzybN1k5nyE4H2ffrpWm+dxDODdomrqS8XMLXFTPRZU9K0npO\nQgUZYzsgt2uUk/1B2+jwYWaxJ+fOxMeKdtZfSqoFWRQsneDhf0CHPTCwfPlTf5ZXn/zzuExRj8J5\nNZVvAOfYb+mc6+HbOvRLhSx8zDLYmrOPfgzVjakWun0ezqdE2qHLEWeaPPxLJfytLYhjzhzJ2AyE\nf7nVto+f8us5cQUi8mt5MCn5hTf9ExgPMcsBKFePxVvgixF+o/DjQMyHk1XO2IKtSLXqQSUWtObp\nbf+czYY02iGVgLJEWo3Wps0uaT38QPw7RagajMHgN1MSHluTcsdGh7w2/If3PsFvfOL4BW2XRYWv\nApGb8nyFPzVd8nSTtNjBWn9xao7tqdFTFzwfF4INdoYuLbfi/dGZK+fDMbavXc/xJ4bzgRVOCFaL\nYA2kFhnNl7FyEXGj8MeniOIuuimcqK/cx5+Umiwo/K974SG+56vuJVbiAkHba+Phf+Sp3fn6Cv6y\nnc0QvS6y69fLxWoqzk3LjF112YQvTUUluwyV3Kfwc5dhhL/o7G7N1bYn/ENMo3ARtnvQ2WJ3/SWk\ntaQb+edosnR2JzDu+7vcjdktRDZBr8W+GAvAVG2TsYt5+Npo1tI1YK7wVXjM7GMfo3NnF+vmtS5W\nRqxPoNYle3lNrASz2lyStanPbhFtbjJcUWxMw1CXAxT+0e0ZP/67j5z3nKUpObHtg9sJZUv4N+86\nUlMjiuk1m8p1Lp5XhP/0yXmfeHsJHn4S2tzelKywZUu2lKJTOsoIiBxigfCblC6jLSqW2LJEWE29\nsMHOVfg7+ZzwC+OVTtxcHESH29f95oikYDir24rAc+EVvl9UMgxB19X5C3Dq/POt7XnyrEvTzuN8\n+kM/ednFSU2LWlsJVsJmMraaD8rYvgYKP9gjT277zy4L+d1Z7c+dlhqZ7Pc7b/4Pb8FpDZPTqKTn\nFT5cVeB2UeE3BKSkmOfh6wID1IC7Rgr/t+4/QTdRDLKIcTEnfNXtzQn/IlOv9gdtYxJb7AsAPxu0\nsUhXo6Mue1LRr+dB24KMOoiUvR1/DmxVYYZDosOHGYdbTi00+cpx9lbuodarZPvy8EesDh07q4Kx\nXaWjBygXUa24tt0CVh9M+AdYOpsd79FnVah2Lw367Fnqo0fp3t7Bunl9hpXejinDndkd612c45Iu\niHpri+jwYYYDwerYIpw7kPDf8sBJfvJdj3J2XPLE2Ql/9T99mOojb+CBj/8iUeXvdBJqiPyabuwh\naernblrm5xP+3R/83zhg3LvtommZDeHHgfAPRz3OuJqzStGtIE/BKBDG8nTwVucK36IiiSsrpNP7\nmmu1Ct82TbhC1WAM24X/KDq59wdnyWG+5K51/tjLbuKf/xnvuz98+uCxh4tBWxn2sz3As66tf720\nHPrXLXSr8J8ePQ1Pvu+C5+QgNJkErhb0jT9+46p5gDTfhenVlVs0t8rHirMo5zjcPQJAJ6QIGlmh\nQjCvxp+EwVs/TPXYw1COUEm/HVZyNYQ/KXXr4bcEpOS+PPyfXF/lr91yBHPAxfZKcHIv5+7NHpu9\npG3rYKdTr/B7DeFfODaxPy0zIbIltZn313k2TEtDQo1TCTtS0a+6iBAgr3SKsZ60dkLiWv7xjwOg\n7r2HaViQRmmOrj6KkzGWL6QTzwnfDHe5+7jj0TsVe/p2/7c2ouwb6qny8dqDFH6mDuyls5l5wu9X\nfi1GpaE+4WtAkzVwLqaSIdtOxmxMHFWw+e7a9OfzUmwdvbVFdOgQO31QFvoXqLZtUmAnpebDT+7w\nnofPwu//BO966NfpGZ/FlMgaEfporc7859IXEzZu7Z/3fNcCzyvCn4122Fu9l4+89p8wdGsXfFwT\nAEqCIr8p6rKD4aRSdEqYJVArgbSWT4UWxq3CrwPhVyXSmjZtbyPbmCv88HVS+QVcRvD4tv/ZYHIM\ncEx6t7GeSv7jd72Wb/wCn6f78KkLEP4Blo49oJNnHYqV0io0rSo002BzPBVHl12c1Fg6kU7aDBbj\n9P5ReFdp6zQXXwsMREw/BLcT3Sj8qs3ekMJfaKxU2DO+9D9KV9BNFeRVKXxD1lw3QhwnkotB24Kn\n4pin4uiSCP9tP/8AH3/H0xd9zKjQDLKIXhrNCX82Q3bnls7FWiSf6+FH1gdCqwvNaDgH47ImQSOi\nlF2l6NYdkqY61mSYsJ52hv7r+B3vQGQZo1fdSxlsCiE0H1j9MFhN4u4iC5ZOXs8YPzxGWfjASyWj\nhvBdxLRX4ozEFPKClk5dGNzChau2NZ24QyfqsBJaTsaVw4z9mlCRQdiIKvKfjZUR62Oow/q6+1Av\nHNdlEH7ILNoYH5yl0xS5TUrddlp11Zh32D3uSe8lQqMi2Vo66xN/3C9KHudP/51XPutxXAmeV4Rv\npzNmHd+uYcqFr6DnEv5h1eG1D0te+Bsv4cjQkadQK5DWtgukKXQ619Jp9tatvVvnmQRB4btgv5Qx\nZOF3ThT05YhJ/zZc4RfRZj/lUD/lkQspfDvvltkQvjug0KgOM2Az4Z93MpthnCESkqNRhM2HFzwn\nB6Ht/W9SBs2FBrOf8LeujvAXg2EryYBe7DdmQ/hG1i3h94WXmk5EmLM+BztKBhisN3Uuk/CP/8N/\nyN5v+TTcaaXJQlCwDvbKPkunzhlLyVhKzAEB8/Oe+5Ehpx6/ePvrcaFZ6cT00ojxBQj/ogr/HMKX\nWGIMZW1hchZOXzgRADxRJdTIOGUoFYnutneHte7jrKeP4SilLmq2fu9D9P/IH+GE2UYH1apkTRmV\nKLOHchlRnBE7R1FPGT5ac2YVPnVEM6vnCn/S9zZeNVVg6rYVckP4TcfMxQZjtamJZcwgGdCvFwh/\n5M+xjCqEiymVJ/w6Srmj/iEGZ14DwN2bIQb1LArfGYPZ2SE6fIit0JN7fXJwA7Xd2VzhN5bcg+Sc\nwXB7fDeJqBBxjFAKhGAQFP51aW4Y8Lwh/NrWiKKgSvytVE7ngre2jaoUwee/SSS8eOt1fOpl/4h7\nTqeUCeRB4TeYlQsefiRxRYl0GmsFUkiO9I7M8/ADuYtAFlUsWJOhv3rkWIv3mPRuxS7MzH3JzX0e\nPn1wLvm+EYchS8cdUPyjiRE4hPPH8T3/yde/vahzhFJKTheX16yuUfixzeiH7w2Nwhegkqvy8Y01\n+zpdrsTdlvAjs0D4He/NRs5faKxU2O2TOAeyPBKOi8uqtnXOMf6dtzH9wAeBELQNhN8o/EVLp648\n4VshmDzLhcU5RznTlOdMbToXo7xmkEUMzlP4vcskfIfBn6OMyvv47/8x+KVvvOg4xkmhSYRGxRkj\nJYlMryV8feRrAFBUjKdd3vJjH+Qjd3wHgz/+9ZyYnKBW/vOJRdhL1EgiUCmZdeidLfKTig++TOCE\naAlfuojRin/9ehLtV/htWub57RUqWxELxUqyQi9ss6yCOhC+UxXSxq3Cnw7WUOIwh05+PakU3LLq\nY2jFsyh8vb0N1qIOHeJs1+/jtekFLJ1G4Rde4Udo3tmJSBysu01iKkTirUkRRS0ZX8+Z088bwp9U\nEzolVIlfTVPX4e/+2icOfGxLzMEWWTWKrO7iZISVCS52FJFELFwwWoVfW1QkgqWjcU6ylq6RqnTB\nw/ePFcED1xGsS/9aVWxZ74zJO4cpt4c8/IenMMby4iMDHj093neRmpaao9uzfWmZKtw1HDh6TsRE\n0jBtNnl4ny9P/V3PU8XWeX9zHp75MPzsV0I+bAklNil90wTp8P2H0gGs33NVhH9ut8OVuN8SvjJz\nDz/r+c3aEr6IMDunOVm/HPPmL2F9dgQjuKziK5fnuLrG7HnCmJaa1O738CMl2vqLupgxln47jfXF\nCb8uvR1xEOEff2SXpz/l4x7jomYli8+3dHqXqPCbVt2iQLuG8ENqZrHnm5eduv/Av33HL36KB97w\nCNv5axBRykgIhOuSNYQ/9e91NT6KsYrjz2iqeIX+V381J6cn0SEQmYkgbqRDiBiilI6zDD7zDDjB\nR1/kn0dXvhpXOcVw4M/z9iz2Cj+890VLB/YTfl2OiB/8Df7s7V/LkRDQ71SOam+XafdmJrImcjFl\nIPxZb80/Z73Ga2RGNwT+n03hm23/2ajNTUaRf2/dWvnK4XMwXLR0Ck2fnA9nGa+1EfXMkrgC4lAV\n3nzF9/25XnjeEP6oGpHVUKZe4VfxoC1mORcNMWeBGJPckmi/2KyMULFjFgmkdUhr+PpT9zMr/Ydr\ntCUKlk5D+BvZBolKuOfhESd/6J+1Hn4qQofHyHJ35hdMGRnWuzkIyQfedpZ3/qdPc+KRIS85MmBW\nGY4P5wvr5977OH/yp95PqStUICMV1qs84BazFgmxNMzC6ybCP/hlsT8nz1SXMGHr9/7/cPoBGD49\nV/gmpacNsQsTeyZnPOEfetFVWTpttlRoxLWP8G2o0FQVcTcNP/OE7qTCHHuImdsAoF+uYxCXVXxl\nRqPwNRB+URO3WTp+XURStDGaupgxagj/gM2/iIboywPaHHzkt5/kQ7/5ONY6xqVmJXj4kyYP/1yF\nf5EmeG2rbpFjXEPAQeE36+PpDx74t0c/tc3s5IzHxn+RsT5M5TJAkYQ1YnP/Xleief2GVTFqMPCZ\nX3EKzrJJxd3qLmQc4VSKc4qudcidIQB3jf8yf+ZT34/Q6xRRSICIY/Ku492uT15NFjx8vw7Oa5Fs\nLXUxIrGa77rp9WwEnZBVsLdT8Iev+0EeLV4KgA7Cquj4WJDD8IUTQRZLNo3g0d9++qJBbbPrCxTd\n2oBaRTzw8u+mV93qK4fPQRO0nQYPfyBm7CjFS05o9h49ihqeRsRzhd+gGg8v+PpXi+cN4Y+rMVk1\nV/h1vEJ+wEALmBNN1/mVI6c1SbAQjr4IRndqZgpw8Ef3HuPvfeiX6T/+EOBzn5ssHeE0DsVqukoi\nE77gMzM/rDlUwa6E/HGhHPfiu3DmqmZj4F//kc/4r1WhefHNfoEu+vjHhznjQrM9m7UKPw5vKbLl\nvgwh5xxGpsz0LkX6FABZSFe8I6RU7uqLE+LpJ9/D+Mn3+P/URZuWGZuUjtEkzlEJ4Qk/6cPKbTA+\nddHnvBga//7WdB3A+7NxH2UcNE3Mopo4KHylQ9BWRNjjD2MS34E70z1/53EZHn6j7G34Wiyo8boN\n2srWwy+LKRPpL6SjZ8nDbwn/AIWfT2qKSc200jgHgyymnyomZd0OML9cDz+Siwq/9tO6mmrgpw9u\na1VXhmjTX0h37QqJ9a8X11OkqbClJ6pB/CSbvRMcyh/ByhjnnN8/UYq0mluc4bsG341MI+qoSzWt\nWbEWNxqxN7ibFwy/gpvGdwFwpu+D2CUJu6uOtT34nZMfaL36cxV+m6nzmTdTO03s4A/eMeaRta/z\n77WCaWibsF35u1gRsnTK1PPA7trHGBQOWVheUSmGn9pltnfhlG0TekWZQZeOPsTZm15Nx9x7XuGV\nc47doPDHpWZcavrMGCrJq9+n0TIjmuygSt8yY5Hw6/HVdXa9GJ43hD8qR2SVowwefpmuUhcXzmsH\nSHWNMzCdTkkD4Z94rcXdXVJGoK3gBal/rNrzV37dZOmURWjqJVlL1ohVTHfqF6gOt4UrqlH4ztcF\nOEsRW9KBRi3YGbo0bPb8hl1sfrU79ReEs5MZMij8KOyBjIrZgh/p6hodZVRuzCzxz90Lo3/WtaZn\nLUMbgrnV5MCxgN/7+/+Qn1pfCydp1qZlJiajpz3h10LA5LRX+En3qvrKNBfeW8NntpKs0o27DGYJ\nOxsvx1IilCFqFL5ZUPi1xCT+QpHqHhpxWZZOQ/hmz2++xcrONktHiXYAyria4MKd09RevLVCGYig\nLgz2nIyZYlKTT+o2yDfIIvppTFFb9t7+DjAGtb6GSBKI432E/66n38XX/4+vb2cnNxljigqNP0fe\nw7dzhX/0g2D3H4M1FqsdZccf59B02z46sZ6hTIkLVeJCTfmqe36VjVEQPGXtyU+lSKcRyuHiDnRi\ndNSl2itZtxYxynniBX+SPJrwX7/kn/O+L/7vPLXqn6NyMdurcHgP/tvxd/sLrPBDhYDz59p+8Kep\nhSTGcfxpy+mVLwB8AVY98etvrP0aQvo1VUdeQI36PnBdncm5OaQW1xeZNqVbwu+QaZ/4oXR0nodf\n1LZtYzEpNJOipifH3HsMDj0jMVGH7osMt3yZ/xzEgqXjlkHbq8eoHpFVC5ZOuoa5QFl6QzT1IymP\n/fYR8smI2Hh1sV5LNo1BKzBW8LKViEfv/XPIYbAAFrN0nAEhWUvWSWRCdxpymM94r7wfLAAVSywR\nwllfhJVGDMZP0+/6x9eVJQ0TsRYLQ3YCcWxPZ21aZhT6TXVEyRs/Mp886aoKrToYUbCX+tvtblCk\n/TpnzVh2bU1tar7hTd/Amx47v4Pmtp6xFbxP6nyfwu/bOlg6Ajc9C2kfoo6PE1zhTNlGNd0W+825\nkq3Ri/p87RN/g72Ve9hJ34mQlsFGhtI5Ueio6YTC6gidhEIc3cNIdVlB2znhhzTEoCY7g7jN0lm0\ndPYWyvYn7uItHBaV/WI+uXOOYuqLbnZDfxefpaN49emHOfn3/z6dV76StT//5wFQ3W5L+Kenp/mh\nD/wQp6an2qppn0AgiERF5Xz+exu0bRR+vgNbD+87vmb4xnHlfz7WXTIdguX1FGlrXCgU1MIidI4I\nlet6NqUyFUKlCBsIP+oieylWJUx3S9aMQZQ3sbv+cu679V0U8ZTHOp/EiHC3RMxWX7A2hYcmxzi+\ne5I4UYiwXs+ba7vzOLUUxM5hakvRfO4V6CCQZtpf/E2o1dAq8IB4BARMTs64yTTxhAunrTYKv+wl\nc8I3MZNz7MLdWUXs4HYt2yydTA35lg9Y8kGwJZMRsQrT2xYUvpjl135AUcDzh/DLEZ26g5MxUZRj\nZYy6QPFVQ/hmGKFzhdvbaQdurBlB6hxagrOCF64c5pk7vo4kXODtYuFVyDBZjbzCb9Kudo95m6Mn\nBUYK0qyPcQqB5cQm5LHkCz71H/kTr/OPq0tDEuyfckG1Nwp/e5bPK20BK1JedijhX7zlM7ztQW8V\neYXfwYicvWSAMiWZ88fXrXLWrWGIYTvfYq/c44nhE/tPinMUOPJQOEM92+fhD0xN5ASVEIh65hV+\n+9grU/mtwldeXa5kG3R0n5tmL+Hup9/GTuchpDC86HU38/pHfoKoaopqIsyhV2Hu+WMAZHUXE/cu\ny9JprBxXltiioJh64uitpQtB23m3zPFC24aJu3j2TbkwhKSc7reKmnO6u+sJdJBF3DO9n685/nFE\nf8Adv/iLqIG/AIrenPB/9A9/tG0h3YyAbDLGlKjRoZ2x9/Ctv/Pa8I3KOLrfx286qY6TIQLDpOrQ\nrUL9Qz1GmQrwitQTfoEIe0nPppSmJCIh6kSs3j1DxBlyxZPcdLdi3ViE9tlTT276oHHlxoQEM2pi\nzvYliYbDJuOxE0/SWZlXye4L2lqDy3fRQOx89beOu1RxRqpBT0OKp/YXgdKFAkHW/HOVeySrcOLB\nHTquqVK/SEO64RDZ61FLN78I2pjt2f67x+Gs5gsqxV+eJMwmlU9xVWPu3HLMbvN3W7Eb4mY+66ch\n/EqB1LadTnet8bwgfFtViI9/ijTc1sWdIQBZYQ4M0DRBWxuqX9XeLiIQ/sBIEgdagbOQB9Ueh+6T\nc0un3Ef4iUxawh+d9OmPPQF1IsnSFSwK0Yn4r18jmUaCpJ7Sxfv1ujKkgfAXi2Yawt+azBU+ACLj\n6160wk2DlLc+4C8arqrQUYaWBaN4ncgUdIJt1C8nrBnLUAq2Rv6uoGn41sAVIwohKKKw8XTRNk+L\nbUrPzgkfgOTqCb/JbX55vMb37Q75mju+hk4o58+KHYpYIIRDSkGcOlTYqFYorEkxXV+wluoeOulc\npoc/V+yz7V1MIPn+euazbJwLCj/cti8Eaqc8G+EfrPCbiwrA3jDUYJgtvu5Df5WXlM/gbr4Z1e+1\nj5HdbttL5yOnPsJX3/HVAO2ENaN9n6FYlK2l06H0VoMu4dBLQMb759MyJ7xC5HTkHnmV0a+8Qk70\nsE3rBT9/NZ4NEaEbn8lnC4SvSFcMLu6gNrwazoeaNWuIrL+AzOIQkxKOwMXkIuFM36+jPxe/jOFw\nStybN8iLEomQwhN+sdcW1nmFH9oVr64BYEOve6t9AH8i/PoVdFA6pzt1rB+yjM8udPx8FoWv1tYo\nTUmnDgrfRuwV+xX+cFbRswKJoJj6LJ1YjXz7hNTvi57cQ1jNaHcLQt3C1mpIDrlOqZk3JuE7t89G\nmLzrXXzBD7+Re0/7QI3NPJmtWigO6C1S25pExujCn/xsbwyiIfyIGIdWgBXM8qba1P9tY+m4yufh\nA6yoVWIZMQhranbab8iOcNSxIFu9E3vki5GRL8CYNukg1QwZiX2EXxaGclZTacu41Kx1Y5zQKOtz\n+AGc6BCZgrVu3KYN2qrCRB20zLGDm1GmJKkNOEVS7LFuLEOp2B777owNaTSoJqdwQpAHG8pbOiHt\nz0XEDhSSlrLS/gLhX1lr4iYts2Mtf2s4YnNwG1mwJpQpKWPhJ74AopMSz/x7dTLCTsZtA6pM9zBJ\n94qCtgDbp7batgqD9RTnPClEah60ndi5PTgRF7ew9hH+gtrPJ/PvxyNPqquVv2D3ixlmbWPf88hu\nDzubMatnTOoJr9j0LTh28kbhO1QsiSnRzIO2rYcfd2Bws4+5LKAhvEJM6cohZZXRL9eJzQQhNdLN\nj9NFku50GxXiXjrPKU2JchEynAcZ90hWQyXr2LBuLJFbQdgC4jm5xqHD5q7I2At92r5J3UOn6rMt\n5scohKC/lnL00zuY8baPGxEIP5z6YuDPlW0uqMZfYIakvjgQiHRObyo4cmR/tlT9LAq/IfysDtaM\ni5ieY+kM87q9Y5jNaiaVpmPGRBbI/IViIP3n9C3/5jcpQhHb9pq/MC8J/3LwozfDu37Yf3/6U+hj\nwZ5QnvDLzG+igT24d0ZtPOHvyHt44u4/SXdUYoVfjF7hO4wELOSl/3kU7gCa22hblO3ovUG0QlaC\nsooq7lFtDwFIrKWKBVm2jr31tUgV0vpC3yhXzIgTRV16cpECzCeH/OZPfKJN+fqyF2wihEE50CHu\nY0UKdU6s5DxPfFrihKKWJcn6bShTEtUOZ1NEMWLNwa6SbE1875FzFX4x9ecsb4RWPdsXcJROEaHm\nCn/R0rnC7pEN4adWg5CgYpKG8G3lm9g1pNJJyCbh4halmNG47SWT6R4m7lyehz+aE/7w9HZL+P0N\nb41UhSaW86DtdCHIPuXirQv2E/6Cwl8g/Gkg/H7lP4dOWVKvrO97Hhk8/LOh/9Jt/dsYJIN9Cl8o\nQSxKTMjSSUXlbUFdQpRB/wiMT+573iL0kS/FhK4cUpee8Lt6GxMrECGGkUhclCIK084V1kVBZSoi\nGyOFwTiBUDFZ47tPNGvWIsQKwo1YSVZIpP9Mk6ByxyJhFBT94SmsmA2eqH1676Sa8Mmzn+TL//wL\nOXt0zMfeeWpO+CrGBl8o7/kMLReEmghUNyXFhKERkZ4ymMKdN4WU6BBDuLils4daW6My1dzDJz4v\naDuc1W0rjvGkwjnohQp0F3mn4XDiP7cNxtTCH9/Oqr/SNS0hrjVuTMJX6bz3+a99O+aTbwVg0vUn\nei/1Zfc9Kw8stKhMRSIUJ1Zey1N3fxPRWLczOi0RkaVV+IVu+rj4DdUWXpW+lw5AXw7oTGueuf1r\n+PBr/ikuBHipNGUMnaiD1Y4oBGbHoQOay3PiVLWKI40ULtdMhyW74fb/y194CDAo69DhzsCRtYRf\nNWmDE09ItaxZuekOlC6JdYQzGa4csZ4MmEnJibE/N+cR/sS3cy3aVsPF/jFsLkaJaMHS6UMcZNpV\nKvzMaB8AFoLENhk5pZ8jQEP4MXGIb8iNTex43LYHznSXOsquWOGPzmz7TpkCOr15JoeSor3LmRJS\neXXs0zMvEqguZzUqZJzsI/wFS6f5vluexllIi5riAoR/ZuY/m0OdQ2xmm3MPv7bIlvBDW43FLJ0o\n9Qr/nNTZPPfnvZQTumoXV3VYKdfp1Du4OGrv4+IswkQZppTIUFtiiqJV+EpoclKiSJL1vRqpcsu6\nNli1ghZj+nGfCE/4adMTyUUMg3NV7Y6IqpRdcZaffc/j/NzHf5Xvett3cecXr/HiLz3CR3+/Ymy9\nkItlgmlUdeYJ38i59w+gkWjZDCKa0Z8IblsfE8WSM2FQ2qVbOsHDR1G7/ZlZu7OqVfjjsV8bnTCF\nzkTraOFYlUMANsUIK/3eH64HF+KXv+2Cx3A1uDEJP0rmqrLYw+yNKToR933hClaU7Mpd4mpM18kD\nS6krWzGoVLtY7FhiA+EbF4NTnvANFCZ4giqj0ra9jXbl3NLpqwHZuKLINqjSVUTjKxYlZeTIogxr\nbEv4I9UMaSmIEtUqjjT2sy6NduwE//7ewz1ecFPmLZ2wti3+/SdKtu2Zq/D4UtbcdPsLUKYkNinO\nplCMWM08mTw+9n7uuBrvG8lYhBGDua39BbWe7evVIqzvQ79P4Udh7ukVevgN4Se6bu8WYtMQfoVW\ntiV81YkQgWTluh//p0NDu7QOCv8y0jLt3gh1yJPGdGuXzAniGLb+6T/2b6kwPmgbYkCzYHN0deYr\nbi9yV1PmmpXNMPhjwdJZVPjltCaJJPH0NKaUCGDWX9v3PJ7wp+3F+abuTWxkG+2EtUbhJ6LE2nMJ\nvwyWzi3nEX5ZNgp/SlfuIcoO/WqdrNzBJFHbkjXJFEQdTCVRIe6li9ITvo2QQlOQEElJLxC+Lhxr\nhaOOVyjliF7cQ7rQGrzpv2MjRkErTHb9OZlGe/zfb/s0H376BNpqClPwsi+7BecE2/Xd/u+jFBOs\nkVni8+6tXBi2TojvhDsUI2YMphCZKd/8917Fpw7vr6Q+CA3hLyp8SYQT5b7Mmr28phtacdhwp9kJ\naeCF2qBSFhHSdzfFyGeRAaN1H1w2xcVtwSvFDUr42TztzFSYScGsK5FyBZOMGDIlrfboEl1Q4W/O\nBCaMYysnHaxoCD/CuRitQDhBESwGG/WY5DXO+sIrW80tna7skU7K9vlkCPDasmYWGVaSFaxxSCXp\nxT2GQYG4oiBKJDoswERJnLFYbdvGTBu9hLVO6FTZKvzEK/xoXvpfNoQvNLfcfguRKYhcirQxwhnW\nuzcB8Nj0eHseGuIAKGaeVGYNUdR5m1HikRDLpL299pZOo/CvkPDDZ5jpqiX8JJADoiQSbk74WdRe\nYEXwunWwvRKbUavu5VXa7u2R3HEHAMX2LqmDRFlkGCxTl3rfAJSp0GRWkJjUV9xeZJB5OdX01lJk\nJM5T+EKEbpAzX2XL+CQ6JA9Muiv7nudchX+4e5jNzua+LB0hQYmqHf7RYaHSNkphcASK4b7PqLV0\n1ISOHCKcIjYd0nIXlySIkCGQZBEiDgo/rHUdFL50CilqT/hK0A2EX9eClcIXQBbRiH7Sx1r/mSah\nvYFyEUYJRGKZhclXs2TEn3nifSTH/XutTc36LV5hD01ovCYzHP59FioofLVf4SsZoYOlU8sZqxOg\nHHPzPavYbujAeoF+Ok5r7Gh0nocvnEKIqu2YCz6hohsUfhK+ZmECVy7WsfH8sZuMsMof93TDZy/N\n7MKQ+GuIG5TwU2g8VV1gZiWTjiCrVxDRHkM3JalGpKgD26HWtmZjQkvQxiS4cAU2xFgXoZXAIShD\nuptOBox2vFXTNk8Lm6AjuiTjOeFHRuIsmLKgiHwFqTF+UtZKssIwNJyyZbHf0oklzjiMtq3C3+gm\n2DqkkQYx41x8nofflKGXynBkvYcTFdKlbexhbcWT2zMLs20XA7fFzJNIaUts8MOtsbhg8dQuI40y\nqsbjTwcQXyOFb8qW8JWZd/zMnMGG/uxRJlsLTaz6u5XPPDU//tKtXralE992GyhFvbdHX0oSaYhC\nbUA1HPKtT/5T+tZbPzNh6FhF7BLGUly04Kyc1aTdiLQb7yP8fFKT9WM6/RhTGFayGMan2uSBUbAk\nt49P+NjbnkJ2u7jpjLOzs6QqZRAPvMJvPPzaIpQjEhXOSYxIfVpmpX19RJR5hQ/7VH4V2oTUqiCR\n8/WQFbvYNEFEDeErRNxBlxIZFL4paypTIa1CUZO7lEgKOmmMtRpjFNEsRsddpsmIftxHh1vTNPFf\nmxToKLXMwkSpSo74W5/8bV73Yd+bqbY13ZWENKkZal+pG6l5BlMlQ9D2HIUv4hgTBFUZNYQ/Cq8v\ncVzY0mnabbSEHxS+cAIEbC1MHxvmddt7qbnkZIVBK8fUbiLjuQW0ERS+FYJq3WeWTcx8Ote1xI1J\n+Cr1Ct8asBoz04xTS1yvEEV7jMWMSBdEQh5I+JWpWJu6OeHLuLV07ILCr5IBCElSjajjPuPj3vY4\n19IRVhKPZvPnU/42WBcFVUyr8JUSDJIBQ+fJwpVFG7QF7+FjHM7Bbph+tdZNMNovYBsUvnUR6GKf\nh18F66CQlm6icEojyIjDUJT1Vb9pLI7b+14xLfr4eTHf+EWc+QupdtRRIEDXIYsSyhB82u/hXx3h\nZ3XZ2kPNZkxUSYrGon2KZCYR4XzbgSfGs7vzDVjYwWWNODSjEWp1FTUYYPb26ElJLGpUIPz66P28\nfPgeXmY8Ac2EJXOKiMbSuXC1bTnTpJ2ItBOdY+lUZL3Y+92lZdAo/NC3ZjfzCv/B9x7nQ7/5BGWy\ngs1zzk7PcLhzGCEEm9kme+Ueta0x2iGEQ4UGZiZaoStqTKhXaD182JepUwbC17KCaJ6emsx2cWnS\nJKwRpwqRdDGVJBKh8KqsKXSBtD5nqyAmUpI0khg0OuoynnjbYpJ6D7+qziF8F9FVGVFmyIvQJM/5\n4zhyNlQ+mwohBBu9PXbrO/3bkWFMaDnEiYw66pyv8FXUBm1nSU6nAjvya7ubxhh54SydpuhKra1R\nFhWx9c/thD/GMws9cPYmJSFpbq7wZ45JVzC1G8TJ/A7wkBihhWKSdFE9b0XNloR/GYhSf8saNp0p\nDMPUIM2ARAyplEOZHIU6MEunMhWrEzv38GU0t3SIcSRoOe/L0x/73PW9Y14FN5ZOo/CNtsTjHB0I\nX0cZOveZPGXsFb41tlX4YzNFSIerqn0evrd0/CramVT004gkkucRfqPwkwWF3+R759LRiZVPh5Mp\naeiu2Sh8gJdu+EZTi4Q/zeeEP4uyYOlYyjiMeJz06MQJ5YFZOldO+F/x5J/ndz75J9uLR9tIK6ro\nhHx34wxRQqvwd4U/zysLs24re+mFV84Yf+u+uopaXYXxmI4TxK5qW17UWz6bKXV+404F3LEjedFx\nw1hK3EXsozLXpN2YtBudZ+lkfU/4orLe0hmdbBX+TupTC7eO+WyPEavgHMPRaf7Exx3TD/1hO+Zv\nt9gNlo4jIuwDNaAna0xzAd6n8OeZOlXoMaVlhYvmwetktovLMhrRHGWSKOlgSkkcLApTeYUvrG/p\nkOMVfhYrCuHQUYfhrie1vc6IVHWpar/Putlc4a93NolSSx5+J0In1Dt2/Hlt4kvr2Vny+jZwEEmv\nuLszf/Eqsk3f32chayqKk1bhT1L/XHrbr+0sVhhBa6Gei0XCLxYK5pyIwTl2xmfany2m2CaB+Lsz\nx3TQxxLRSebrY1OMqNIOO9kqSXqIWkFxfl+9a4IblPCDhx8CZ6ZwjDOBMH26YkgVQaQLlLgA4duK\nlYltFbmTES54bMbFINKg8APha38LPQkTqdrmaQ3hG0c0mlLFDeF30YXCFb4nz0o69/BXkhVG1Qih\nfLFUlMp9QVtCkHA0rVjvhY6RwdJpCN8YGSyduYdfhbuEmYROohBpSDMMKmW1f0v7/l+8/mJgv4c/\nyxfSFEXSVtrmygdCt49ukKmUqlH46cBn1sBVKfx7dr+I43u3U4rQ9C6cC5W4tlLYOEOUulbhnwni\n6dZeShHSNkvT8zaGefadZEN7WrW6glxdRc1mdEtH141bwq92wxDqhvAlfPPvlXzLO49hhWAW2gif\nC10bTG1Je+dbOsWkJuvFdHoxkXYcTiqop+hC4mLByCmsdWwd9xeuYfCQR8MzfNXbTzJ80/9kI/NW\nxk6xEwjfEgWFr1WfrqzmsxKiFPpB4e+zdBrC19RRSCXEkszGiE4HGdaOiB0qDQo/uHdVVaOdRhiJ\nciWFS4ikII0kY+UbqO2NvL++0x2DzSC0aehl/qu0EWvpGqojKGwHkTjiIGrW85r+zLX9rtaiY1jb\nY2PSR4WK7E6wtMp4gJEJxcJFK44SdAja7nVCPGbH/76bKLS4iKWzQPjVdM4bVkZEBvZG83kS+cIF\nYcXVZJT0ZjAN9QG9puAMwSEx4oFv+g7+n9d/J/1ojTyBckn4l4EoCYRf+hqsSjDt+M2xKobULeFH\n7eCSRdSmZjA22KhR+HGblmlchJCe8MtA+IPUE1q+47+qOKRlunmPfLm1jY72K3xXVlStwg8efrrC\nqPSEb8sqWDpNWqZEhLW4N6nY6IZU0Fbh+98Zq0AHD7/J0imMb84mFZ1YoTpNXYH/o7i7ySAokZt7\nN7OSrLQK3wyHpA/s+oI2YMcpqHO0ttRhrGBNhyxOqPd5+FdJ+ENLv1zDITk9u4vikUeYPfQYytaI\nVNENCl9bTZwYRKi4PBUKsCLnKOLQjyg0/7oUld+kZMqg8K1YRTjYNKfmCj80y+tQYoxh5gR3HatJ\nQkbGOBQ/nfeeAsHPFf7+LJ2sH5P2Y2LjuC2k7elcQSYYl5q9M7NWgQ5zT5DT4VmyaY3L81bhb+fb\n3sMXFhViQkYO6Ioa2xJ+Bt0NX227QPh1pallCcJxOikwwuCSGQIHnQ4qdK0UsibOel7hh8SBsglc\nBoXfBG3TWDKVkqqzSh7aGmwPRhgdMsWAfreZaxCxlq0RdQSF6BF1fV+cBndszavh18STAHzne4+g\ngsJPQhO9Is2wKsGk8888ibNW4Q97fl3qEHvrxIpauAvm4Ztd/3mo9TXqsMYyO8SKiLSG8cxfaEZF\nTb3wuX6teJB/Ev0yK1MoOp7wB3G4CA1uYVOM2Ouv80zvML1ohVlKW9l9rXFNCF8I8Q1CiIeFEI8J\nIf7xAb8XQoifDL//pBDi1dfidS+IKAuWToGtBCDIM387/EK7jYhTVCiFz2fnX0prW9OfGEx0gIdP\njGgVfujiuO5PYzEOBR2RavvhQyhx39lu7xh01EXnClFWlK2H7y2dQTIICl/g6pooVdSNbx2pdujK\naFazHjpo2kD4Lih8bQXUBXG04OGXlsgU1DKjkyjivj+WjaZgLBmwHmrbNzubbHY22+Df3m+/hTve\nXvMSX4TLdriD0LWmW5YIW1Pjg7b1Yh7+VaZlcrrTfntycju7v/xf2Xv/B5GmwGUJnZAPrq0mig0C\nEFZzchraXGiLDHnzVd1I0Esg/CY4t7qK6/dxmVfBa8UzSGdRwlKV/rx2KdDVjM0zgqR2ROF8j8qD\nZws0vXPSTrTP0nHOkU9rOiFoGzvBEYb+fZQJsuOYlpqtY57MVg5l7E5CAHuvQDiHneXnKXyEIQqE\nr1WPjlhU+BkIcV5qZl2aNlf9ZKwoojEyWHei10NlTaOvsiV80UsQWMqGLI0gogiWjiSNFKVwVEm/\nvTOeJROqOsGFjJReGtpc24j1dJ2oJ6mSAXFm6VTzjLDbt1xr6WwY32Hz1uHNqJCym1ivnsu0g5Ex\nQllSMcbi6CZZ6+FP10KNyp5/b51EUTnX7rdzsajw69Ampeu2sTImrWESEht+76EzJA1fC4iQfKm6\nj8EM8tRfkNfiIAhWb2eVCWVVoa0jUQllAra8tLnDl4urJnwhhAJ+GvhG4OXAtwkhXn7Ow74ReFH4\n9z3Az17t614UURpu3ytMmGBfhY6LAznirs7LiYLdUxzQk7wyFb2JaT18J6O20ta4CKc6WCWpkhUi\nPWPlcJiHmYcsnNQHbRuLwdQGMRzjZCib7nSpxhHCQRl7397auaWT6xwRgas0cfDwnXP7FP54WrcK\n34ZBLS5qLB0BpiSVbu7hlwalC2oyskiRhVL3I6U/P6//8Y/SD8U5hzqHONQ5NM/nDgv9a+/3z7Wl\nhSd8Y1mZ+FbOmoxEpdQCP2wk6YGUnlSusPBKnupTq5L1+BlOjm7G5jlGJihdYrKEXsh9r22Nanpb\nYJiEuITRjt4gRouaWRGCd5dwLGboyVqtrlJ1+lT9O4g2U9TEn4dI1NQhHbcrSmbTMfeGOSCRadol\nDw987iaW4rN0Iqpc46yjLg1WO9JeTByqUtfr0IG1Sog6fpDG1jMTpBK8+HU3M5oItEo5vBeC9fmc\n8LfzbW/pMFf4WvbJRI1b9PDBp2YuePi6smjl72SOxxFPr3+KzsBbWKrXI+o26WAFaeYtHXo9lKip\nwh0ORrSWjpICJQW1AiMzv2/qMVZaijJuLZ0sPcfS6fo9lsaGbEGX3XHWUZsarKVXHCWqZ5TZLain\n/PtMbQjsJhlaJSgsmRxjJXSjTqvw9YqgjKDe81zQSRQVF660NcMhRBGy18OEZdRjpyX8PLSlftuD\np7gpDQNnVhKsS4j0BAmU8SYSzZoKdunq7SgsIsyTTtDoxMFzWOG/DnjMOfeEc64Cfg345nMe883A\nG5zHh4A1IcQt5z7RNYNKW4XfEH4d+9u9jtzjReqlELzXoum1sVA0UdmKztgPKQDv0TWWTkmGURnE\nEVWy4tM7Bx1UPaWwA1YOZdzywlVcWfr5roApKtykhBBMtN0exTBUHkbQj/tzSyeoHxdJr/ATCc7b\nQmkkkeEwp/mCwq/Dboh9eKop8uyIuiX8onJEOsdGXaQUrB7ygbObi4jSRZwtBN0wFWkz22Qz22wt\nHTv0i/PLHnJkpeNMIHyrLesTQ2RKtMxIQrXxRPiqWH9MnfOKkPb+1//imb/5vTh98SZjyZlVzvRP\ncFP8aU4PNzFFiVEJylaYNKMXmnhpq1Eq3PM7g0Tgul2MgfVBQhlNGc9C1sMlFF81lo5aXWWS9Jj2\n72T1jl7r7UeupHYZVig6lJwZnuUVgfCVseAc44V2yYtoLBxv6cQ454dxN0VXnX6MS/ya7Yecf507\n4o5hXGq2jo1Zv6XHTXeHUZ29WzkcbiZsntOP+yQyCQrfIdBE4U7IiC4ZFa7JIAp3sOdW2+rKUjcK\nP4p4371v5KbDviAvGgyIg/Xi7Iw06WBrien1iaT2FqIDDESuICchDi1DfCqzokxXiY0/l5Nc0Ym8\n+OjEGQaHcp7wo15MlQzIVEUnHPJeV3HXGYd663upHnkAWxKy5HrwqD8RqQs2Y9LBRDFSGzI5RgO9\nJMMEDz/uSnb7UIc7826sqHAXLLxqiq6EENiZwGLoiCFWektnVo0oasN7Hj7LFxzyArO3FlO7DuPQ\ngqVSm3TlDj3COlwNNQThbjpjhk0c8joVXkXP/pBnxW3AMwv/PwZ86SU85jbgJNcDUUpexHzqvWOe\nsN/GC7oPEoc+Oh25x932Npz7KBDy09/xg/Dx/8J/jL6Nb/rWv0ldl6S59P1b8B5+k6UzdX2suoXD\nxQsYDe4kK3dIe12knmLiHl/xJSeITAXOUYbMhTMfeQs31QszK9OMyWyV3UMvhs7DKKn2efgAZ2NY\nOz2l+vhHgE3qyrdIbgi/rAwbvQTnHLftfDFP3rXBHjX1PTHJiR4n04jOq8p50Lb2zaJepZ4Bazh8\n5Dag5kVHNVuDAazBWnUTt09Sdn/737EqH+d0foKfefMb+Mozu0TCkdWCv/E2SzaYYF7uK1k3CsNu\nVlEmq8iH1vmS3W/g4fIz/P4P/10+/eJ1XtnrkI4f4ltmZzncPczWz/8CZ3/8xwE/CCY+EgpNfvuX\n2D37AL+yu0rvjx7idYe+jGRvhdO3P8itk0/z8OxPsKu7uP4acZpQHdmkx5NAwunZad7szvK60Grh\nrvUO8coK1sJqP+HJeIaYKt57cp1bfu7NqFdP+fnOo7yoOMTX1n/IY70hX/ql/xurG/fCw2/DnPFL\n9e2f/DQndgdYlXDCvoVyKyxhPWant0EVDWBb8gf/9i0clt/IE/fA6t5TxOZhTo53ec/DZ3jVI3/I\n8PGHOD09xT2rL+DUThe4i/tO7/HQU9tEwH/48f9OvxgDL+SpD/xXTnTvATbZeXyN95z5a8xuVqSr\nhjtP1DxZncXdNeJ3RvcD9zLu386h0P/ezWYIIXhh+YXsnShJrQOhkaHtQ+FSUleRnsn43d2/wqn/\n8igv+7J7ucvdzmD4Hv7pb/83vv1Vr8fUlrguObLjON5XfMFTlpsf9155tLJCHO4Mdt//Djr3jTkE\nPGVSRFQznBqkk4AgcjkFKSr0sTdRmAi2chex9lv/0ZOajc4K20BHdbCy9pZOtg7dFD3qk7qtVuE/\neVvKFz86gx97A898/CFujXwNQJ7EmCd24AshVjVGWnTcwciExGgyNcFY6CQRI2WwWLJOws4A7ggW\noFQ5Jt7j9G7KZ47tIY/NuK/7GKtZj2948avZOfoguZzws2/+TnaHr2EjWifSlSd8DWU95v2PbpHX\nhhesdtiNcnp9wV7VpXpqk5N3fh1O3EFfnaBrGsL32XHftP1feEp+OV37RxCxI3oOE7444Gfn9hy+\nlMf4BwrxPXjbhzvvvPPKjijKeHT0Sv7wPRXwLYi77+Q10222MWRiQlrVENRhXRg4/Sk+U69SPvUn\neOMb/wfxeoUT8/xdtSKwIdf2PfqLednaEW5+eEzRgSNnPobqvgw1O0Hf7nDPff8H9q7/DEARjLyV\n4x9r/XsAE2ccv/mP8MQL/gxR8i/8z7T38F+49kJSlfLxIzO+7v6a2Tt+B176HdSlIVUS5XxTlwjB\nSidm69gZXn3q/8OT9/jn3vHp9DzOV9Pf2qI2CucctRakOuev8E44+kE6Nx8CThI/UzCaduHr4Y7T\n38ALTr+Al+z8ZV7V7/LfD29Sve0wnyhfzEvX38qJjuCPfNoBQ/KNClMZpNVUypBvvAwegNfyEj4q\nv5RvfPcPcvQbJT//xREUT6EefzN//RV/jbM/9VOotTXMcOg7AgbCf/xf/Rj3HXkZvcN/mt9IfoL7\n1x7llXwzW9k2txZ+EMeo7mOSDr2XvZBR9xZ6ocHYbzz6G/xPOeIf3yGwSvBl92yiPj7AOEmcRJRq\nRjbNuOkPO3xiusLs2HHe+kd/nD976jDr5Sf4+3fdzv/xYcdf+eM/Bb/2V7CzbwDgsXcJUv1S4mrM\nb8/+F187nZEiKGzOKdXHqA5q+KXk3VdwNJz3rNgm0j/Mp06e5l/+wYf59Tf9I3COAbAFjG/7o/Ci\nu/jZt7yHU/km30ZK9MwRco6gTMkXP/YGNjc3+H3xzzgxfhEnOi+C8Nm+dgoWy++JN/PYYx/n/yv+\nNXnnMLcO55YOwKse+UaiJ0JgFc0zwcF5+ETFi7MevVNHeIS/CGfhD9/8BE/ddhdf66a8fetfcuwD\n38zX51/BrdsVf/as5Ze/IeZH327o7XwGIsehV72ejlA89u7Hufe+++nlZ0A6ftveyRdQMy0dMliD\nEQUzlxKHyW6TTOJGPvaV2Adw9TpHT/f4c19yM5+0N/OC1RfwMfEIie3zis1XoDu+gC7TeRu0ve8L\netx6ZsZGZek89AfoF0qUrTm1HnPvSb/HVu8YYSXoQQ8rYiJRcyR5jHe7V7EaK44NznBy9hi9pMdu\nX2CHAj71m+zKbWzvLOOdVf7bmx7myKcn/M8v/EWqvuMbXvyrHDv1CNPE8DO7n+DrZ69Eq5LIVFgZ\nk9SOqp7y0ad3SJRkM47IexGd1HK66jIev44nXvpnUcAtybvIwh0Ot7+Gh+KX8+riD/nn0aPc716D\niB1x/dwdgHIMuGPh/7cDJ67gMQA4537eOfca59xrDh8+fGVHFKXUoalZIR5i1j1CXyRkcowQDldN\nscHXrEsD+S6n+i8CoMwhXaiKBVh9xdx6+KK7jvD6e7wb9RUf+D+498k3Iztdulu/z4uPvREhwO15\nvzOPvSz5Nf0n9j2fVglF8Frj0MOmSct86cZL+ci3f4Sn/+Q6P/J90bxHSWlJlUSEa6dy0E8Vn/6D\nJ3FYvvyD/5QXv/4D/NyX/l1ee7ufU5rMmqCmo9IRcT2ih4VqRv8lfvhFdDhCNpWN6lVIl/Cy/Fco\n1v4OH3/yOLFNmUQvZNrt8kPfEfF3/6YnknrHgHEIZ1hbr0nKIYdeex8P3PxehFoD4FXuK/lvj/tF\nNtMzb4nUNdkrfBvfxRawQ23Jan938yXypYzH3iQtZUVP+YyY0vj+RnGi2NUpKU1WzikyB9/2Xa9h\n7fBhnHHIfh/rJFEkqVWJCoUsVW9AJUPTq6TkIelbSszqqbeenMEVMxy+b89s7VN85Qf+Ma+cTIhD\nGbFAA3101MHJjM7sUb73pm/hlu5RjEpJDBT1jKr0d3oP/KUv5i/9Y8XaR9/Nia/8Ar8uix2+4avu\n4u/8zNfwO6/9/7G1+b/zVe//e/RuuZfXHhnzAz/9Nfypp/93vunhH+Bv/YUP8H1H/hx/5ce/mJ9/\n/f9GufkSPvnqH6JHiZURr9wJBWeB8JWJSYer7bHq2vshuU5R2p+Hm8/+DF/znr9NlErGZY8/6GQI\n4ZhWM9xoTKIrVmYwk4KVHNa+9Vt56QOf4eYvfg33vvJVfPcv/jne+tNfy/f+88O85MFP8xM//y/p\np4I0itpKWUXNDoNW4e8NJB99bY9/vZpT/fXv4IHvfi9P/Iu/zI/9ua/md//C73LHyh04KVg3X8or\nDr0CHWzYuM7JKocVgvu/pMP3f19EfpPBzsAUCmk10yxG/cBfAqC/mWMUHLn1VqRKUKLkFWu/y2/1\nKzqx4ujtn+S3XvHT9OM+u30wRYR7yz/gtkGBVhWpELhg9QqjqUIQWJWWTgKffPIoX919GR0tUbLC\nyYisEtR2yolhwc2rGdVMk/Zi0kijVcaJu/1+f9faJ/jywS+ThvnLrNzKDx/+Cd4a/zE2xYjM5fzx\nl5/htb/6b7keuBaE/xHgRUKIe4QQCfCtwJvPecybge8M2TqvB/acc9fHzgGIUrRRntzNSWadm4AO\nHel9VVHPsK4pBTeQ77ATbYT/K9JphZFzgq7CAGeAm3rpPBc8pOjJToaNE2TYWG7s/bhZGiZC1fUC\n4Ru0yCjCYO4ojFy0xqKaGbdCcCgZ8GTPokLgV9eGVM5vlBQ+jezJ+yfsZI+RlUNkHIEUpJ3QRCws\n2qo2VDZB6TE963xjtZCWaTsJttCkClwz5MNJTuh+21IXodhefw2J6HF6zXux1Z7COUmeGF7+gof4\nig/+n6wNRhTRFFtLrJCslYaKhMwJcp2jd3xmQnynv/Y3LWCdcwgDqQ19wsuUfBY6NoqaWFREylLZ\nCCNiolSxrVPiEHfZzrdZtyCTHkoJrLGIXg8rFHGiqFSBDDmrdZyhoy7SKqyqORHIPw8xHwBXFbg4\nRTpFmflL7C27trXThM4RWmGjDk6kCFeiJKg4XJA01PWMKARTJq4EIdir9iicQDiDK0YMsggpJbmw\nOO1vg61JEMUIKSV2VqO6CTLtIISjrqcg4MyeQTz+bpQwWBFRh/hES/hOIUMFdVqdwYZ1WZsM0ZT7\nFzkCUIllWnf4g24nnIcZblYjbcUgB+EcvcKnIgoxX39SStaydfaqEUIIhBBEyiKIUEHhK1Gz4wat\nh59EkmPDAgQcGiTt3+2DFG0X1lr4zyappnQqKOOIKuTfVz1Hnat5WweRoEO2jxI1NhKUrod2CbGo\nqERCbRxZrMhUyAqKe+wOBNS+2rZ46vfRsvYVsiFTR1Kj8bGUuHSQKgRQlQ4hKqIQ6xhUisoWnBzm\n3LKa+SK6XkxMgVEpo/QIRTzmEbxrEeug8KOUNJZs2T5rYkrHjEkkyM7+vknXCldN+M45DXw/8Hbg\nM8AbnXOfEkJ8rxDie8PD3go8ATwG/ALwfVf7uhdFlFHbGBU5ouo0ViVs63tIlf/gZD3FhQ/KVhby\nXXbD4nJ1Qjat9ynyZh4o+MyPpjBDhdQwkWW4JEGG4KmdeGIrUpC2JjWmrbIlGlKLDmVQ9knWEL5r\n++EDbCZrTCJJPPCLsx6P+PZP/+3298qB3K2Z7kpOdz/mfxZ5Uot6/vhESB2cjmtAosyYrrNgKl8W\nj8UkK+Acq05DSAXrW8HRottmogAMB19KJgc4Kdhaiyn2IhCKcWYYDBIEjqSGIgrVi1GXQanJXUqG\noNBFm8ec3H5HOE+e8CezLZQBnP8M+qVqu2LWIRMnzSyVSzAiIk4UZ6uEKBD+2dlZ1qyFOENG0jd1\n6/kNE8XKK/xw8dKh1L5b9jGyZjt0OilMuUD4FTYNF4JwYbx5Z6EzqMlROsJEXZzIkKE1bpRGWJUQ\n11CbnDik5U5CpeteuUdpBUqXpHZGP43AOXLA1k3Nhmp7u5hco3ppW2VchhGGezOLfeydECmfUNDM\nBtQaV1Ut2QP08mPY0Ja31ikm5LwnRXivoqCsEj7QCR0r6y2cVihT0p8JugVIB9HaGudiNV3FOMM0\ntKxQkcNYtaDwNTustAo/jRXHdv36ONy/QHMwKXBN3MkFhT+bkFVQJFHbbqPoW2wl+djsFTinkS6m\ndqE5IRobSfLar98VNaEICQmdWJGGYHUv7rHTD6cuuo0i30bLCmUFIuwF5QQ6BFjTEmSoQagrkLJC\nqTD6sorQruTkXsGtax2KqSbrx6h6CkJi48OUWc6EDsYJ4roh/A5pJDkTxiWuFEEHJ/O+QNcS18LD\nxzn3VjypL/7s5xa+d8DfPvfvrhtUgnYpUhnS4jQ2g7G9iY3Yn0ypZxjpC5Eoa9B7jDopKSB0xkq5\nv8te7eYK32iLLg1WaF+IAshOFxcnyJB14ibegpilPi88tXpetRvvUplbMGlQPXHofx2Ctg0OZRsw\nBtkQ/tYxDk2Pzt8igtlTExCOrc59/jjiGApQXYmwNZShH/deuBMxjcIvEdaQyBw9uA2AVVsiqjnh\nP5F32w3UmZ0k776AvjlEGe9yal1w6wn/u1FXk3Z6FEBSCco4VC/GPfpFyYiEzE3IdY6Z7Vf4e9tD\nokpzZvdxYgM68ruvXwqSJPTOEQ3hO0qRYoiIUsWpMiFc39gpdniJMRB3UUpgtMN1+1D6lru1KpEk\nVAp0yJRaywdUyR67oVgnN9UC4Zct4ReZxCDY2Jl7qpEuUDrBRl2sTFvCj7NQQFRF0KlahT8OvZGG\n5ZDKCbqmJLUF/SyCakouRasorZY+pbguMKVF9bpt+mQVLgS3uSFyeoZaxWh1TvvfPEcsEH5HbzOp\nJSrOMSqhtCEjJtwNGDumNl12QyV5arZwLkWZmkFOO6VNXYDwm/fVT/pEkbdH5LkKP0xJyyJJEdI2\nDw2S854v/BGhXpEqjLOMZmM6FVRJ1FbY5r0wynDLYe6wRDamNhlgUKLGxIrZ1J+bdbHHLNzhZYki\nVXPC320I321QVmNqVSEQ7cjSyMY4mTOrZ3QqGHf8cdcVKFGilD+Ofh1TU3FqVHDLakY5nZB1I6K9\nMTDA2U1MZw8qQUVMpxkTGaWkkeK07kIM/SI43Un/4PNzlbhBK20zT/hS05/N+1tEiZ+cpPQUE0UI\nWxAFVT4NqkTqDoOc/QrfzpWu1dbnxau5ry87GTJNFwh/CHjCl1aT2nmbBhPvUbkeJrQdSJJFhb9A\n+D0fzLSDMFh5OvFtHZr3AojKouIKrxFBhs3vsoS0GmFD2eskEL4wY3o2DL/YeoSEKbrrX2fVlMiG\n8J3g0WmGDq2IV/eeAmC9PkQn6nByI6EOee17XUMa2tpGldun8LNpTkFCZl1Q+P5CqG/xpfVv+N0H\n+bF3PMKZ0VFi4y8SAN1SkBh/flxIbU0yqEWGcYookZwsolbhOxxroWe+imSwdHxaXBwUPiSMOwIX\nhm+vzQYU0rAXuqAWtmpbGruqxqRh8pASjNMeq8Pw2UhJpEsik1CrFCczRMiCiYNK7tYJQtQt4Y+s\nPyd75R7aSJQp6JicfhpR5ztoIRDNPN4QJ3D5EFuCHPRahV+FlNKX4yvgpiI9rzmYJ/z5tu7WZ3Gl\n8Cm5JqEKd1G9qT8mW++hjEQ4x7rt41yBI0Hakn5hGYR88wMJP6zdvcqnQ0YRWLvg4YuaXTcgUnOF\n3+BwP+UgSCXa9iHNvosmQ9IKqnSu8GeBD+8ZncQoi7IRZZhNYQQQSfLQdG5N7DAJXVY78Zzw+0mf\n3TA7V5sBRTX1DeOApLmLD3vumd0nSTREWQxxl1r7hnFNX6FMe8I31nFzY+n0Y6JwkVa2jwgXqZK2\nGREI33Zi2/n12s9De/Il4V8GohTtUpAVg8kQGeaNqqiGpE9kcvJuijIFSZiMNWsCl7rHYObQ8Xwj\nVeco/Loy2AXCF1mHpJshmvmxU/8hz1KQTpMsEL6Oh/sONYn8B91U2jY41POB4Toskno6wyzckCkH\nwjiQNTJsEBWHzoJJQlLuoSv/+FmYuIMd03UuKMicRE6pQ4fBNVsRJrzRt4KRSamU39D9mb8zWtOb\ndKIOpw4nbeXxsGfJwm1uXFrKQPh13COeTilIyawNHr4n/HdU9/njnO1ydGfGmdEzRBqqEKTr1pCY\njEoVxGGJxhmUqo9FYqVgaDptN0KAdWMg7iAjgdEWl3lii+OIWpYIIRn3Ej8rAFgpBuTCMmoJv54r\n/LpqCV8rGHf6dIchRXdtQKwLJJJt0cfJGOlKjBOk/VCMpROE0ETufMI3VhIFhT/IIvKpFyRpyMow\nwYazZ48DArWy0raZLqvQQExNmKoVRhrMuQp/lu+zdLpmF0pJpHOMTSltF3B0wpATm2+TmZRba8sh\nMoQpsTLBUaEc3BSKui6m8PeKULcQC0/4bm7p7NKfWzqhmZ2SgvXuwQpfLBJ+2HdytB0UvsKG9hmT\nfoiPWYOJHJFNKEObEI2E2KeGAnSZtO2Gs1i2Hn4TtAXQVUap85bwO2HLNBevE6d8V9QkSwLhKyJR\ntITf0bF3DYCbOwnW+CI6Wc3rMdKVUHuzSPj4Hlm7gfC7s6Dw0yXhXzqiFE2Ckz7w1Kn9phKxhrhL\nYnJGawOSOicOqrw0wWLRPQY51J25qt9P+N7Dd2qeJyvTmLTX8QQMuJnfmFUCwhoiN2+1XCX7C3KS\naAVnfcvjRQ//UOheOev7lVftjedBVHzQVliHExUq2MsyeBwmTUirPXQYcjsbNUVJvtqvaSyXiBl1\nIMDVen4B64fAXhn5LKlumGe7Wq+RRRknDyW4UHm8MzCkzfotLUUULJ2ohxyNKFxMJxC+2d1FdDrs\nqoIihqQaszOtODs+gWSu8BMtyGyXSuU089xVKimDoixxjOkQLWT2rlkDUQepvIfvwqDoyNmg8GGv\nt9LONu2VA2bCMQl2Q76P8HV7B6aFZZZ1UcEnr9a6JCEIejoEmaUrmdAhDSSWVSkI3Sr8MhDBsBxi\njQoKv6SfxuRhsEyTdmhD4Nyc8DNc1erqgsL35/aOuORYvUJhLCI05HNJ+OxnU4SVbYdIJWpkUPjO\npVSuh6KY25H5DhLJi4qELpbNXQFCstvz6+HWnQsT/lrqfzZX+BLrElS44NQyQhO1QduG8Dd7CVKK\n854PfONBYcFaRxWCsGL3LFkFZTr/m/HqfC/YxBHZmDxk5mkhkMl8L0Wiogh7Z9HD78ZdilTgOhl1\nriixbUuJ4NQQBSvo5JnHAci6KTbuYWxELApUHILgOuHI9usZWMFmuOPNejFqoelgf82vqbK5Uw+9\nptJIsdMS/jEQal4FfY1x4xK+S7GiJKsh076LnY0sJD1iM2O8vkqsC5JA+LVp0h0jBnmGTsMtp5xn\n6ahYtgrfRQuEHwuyXgfhfFigIXwdC6TVxG5uEVXpmEXE8aCdHLWo8NdX70Q6x7Dr7Zpqd7+lo5wA\n7XCiXCD8cEubJqTlHlUYLJGPa39gIdugIfxUzqjDgh6Y8H6Et3QAZsr3/UirPTQzeuUKnajD2UPz\n7qFl7Iikb8OrCr2g8LvY8ZiKlI41LeGr9TWm1ZRZClk1ZXdacTa0lW2qoZ2NGbg1r/DDxpOJaIfQ\n5NYycZ3W0gFYN9ZbOioo/NRvJmlrahU6WoYBIgDdesBECqaBeAqn9xN+0hA+5N35BX8yiEkqT/hb\noSGbcgVjunRC5XOsE5w0bdA2ZEL6SVQ2RpmSzJT0UkUe2lekobDI5KEq9pQvdFKr6+3mL2tv6RwR\nU864NW7d6CKaO9E1Txhm6tfLpOMvJErUqAXCL22PhHl7iSzEVe6s1+g6x5Fdf7Bn1vx6uCW0fFGr\n83PXoCkS3At9g6JY4WzSevh5yHRruD0Lls6hC9g5ADKSKODTJ0dszyKUq3CjIZ0SyoU/K7sdZh2/\nXmzm920Z+u1USMQ+wi9bG2XR0umFCl93aA09MRRCtC0lGjQK/+xZHz/rdjrokNGXiBkqXMQSu8rL\njv1FvqBSrCn/N2kqULM54W9uroXjC3fq4cKTRpJd/OeXljvezjk3e+ka4QYl/IzapVhREBlItV/8\nWjlIeiS2YLa+htIFSbBhjFn0PfvoJKyuVLZZOkmmsMYHbYkWsjaUpdv3m98Zgc2Dj51IpNNE+D7g\nRmjKeH+bgVR0Maap9FtIu+wdZt1Yznb9Ji/3cvSihy/8rEwjSuJA0E2Wjk4SkmoP42IiB8W4Qtkp\n7Vs0vpNoLGZU4Va3Fy46yVrSKvyJWPPPayrKaJdO2SdTGXUM8WrDxL5vj4wdMq+oVIHDerXuvPLq\nWkNhCvTuDtHaOlPtCb+rc7anFTvTHayQ6KDwa9ehZ3tEuuAv/sExdh/tIhb8m5mxTOjsyzhYC0Hb\nJkvHZoGMdYWOQqAvm6e6deo+EymYhXNSONPOT3C1QcdN0Biq7kK2Uh+y4PXv6eAxu4IpHZJu2MAm\nxQnLIBB9Q/jPjJ8hsqnP0tEVgzQmD101G8K3YSyjPeN9erm+MVf4oQ/QrWLMrXfcw9039dqJTm4t\nnLtA+McOPcAru/+Lm+LHiAtBZHIcGZXrkoaskzKCQbjg3GoO0cewEhqynV3za/KWHYeTArlyfprg\nYtAWQCXSD7MPJDkVCbGap142Cv/w4MKEr2KJcvB//uaDnNgD5XIwhvWpo1j4szrKqNZ9LKiZBliG\n6tQSgUrmtlYkfNdOOD9oC2A219CjklKI+YDz5m+DINre9p9Hr9ullv59pyJHxc3g9dA5F0ncNCx8\nzzuQs/kd/S1HNsPxhYt0NFf4JQlT13DO9bFz4EYlfJWiXYYWBZGFjj6FwFAlFpI+mcspDm0SmZyo\n8TsXKpkz3cfGCWAQsWwtnThVmNpSV7btTAn44PDAP8ZagStCBkSsEFYjnaBOutSyogyjzaIwSSgy\nSavw1YKlQ2edQ8ZwopsjTUU1rTDMCb8jpe+tLgp6IUjXeviZV/jg7ZlqWqPMBNtcUHQJOicVM+oQ\n2M3CMcSbKT0HwsE4LGJlSmbxDsmsQyfu4KThptd60hBSgK6QMchZAcLh3BQd1FNiIzrOktczzO4Q\ntbHBtJ6SJ9DVBXt5zW6+h47mKrqyXXp5wt2nc77y01tsP9zHRfOL4UQbKmKUmFP+ekjLbBV+yPKR\ndYEJqXNlOlepiVlhIiVFSK4vnGm7ejpt2juyWoLuzpnmTFaRlv4znAbJmbgpM9El7oS0WJ1ghWU1\nHJ5Wgl7c4+nR08QmQ7iCjq7oZ1E7SaxpHWBnYYbDlo+bqI2bWg+/CumPndk2995zr5+70BD+Sog5\nTPzfz6IxX7nyn4lERVL6thpWZJS2RxxiCscPwVroD3QTR+iZEhXmI4w7c4Vv+12EPJ8qYhnTi3tz\nhZ/4aXBpIK7xQlsFCBPbuDjhR5EkAu4/NiSOesT495NqKOK5yKriDBWqtJsyGV0YwFK6qG3hDEHh\nB7GURZ7wIxG11o7dXEEPx17hy4U+zIAKhD/a8bbmoNenDrGtTE59rytA4n+2ESmKafgwjz+FXFD4\nd916KwC1OEfhx2GiWVD51ysl0x/njYgoRbuEWuREBjrlI3z7ob9NHoGNO3Qo0IcOEekC6WIcIBYU\nfmwGmMhnWqDmhJ90ouDhGxY6LyCkoR/yigu53uZF6zRGOoMC6rhDLeuW8FW6Ry1LIpscaOmgYg45\nwdOdHGUrqsLts3RSJakrgxYFnXAhkCFjow4KH6DnBOVEE5kxTi4SfkkiZ1SlwylFElS9Wk+RCLoO\nxsYrDWVKxukOaprRjboYYZAhrVQ0Cj8JhA84N5v78U7ScSFLZ2cHtb7OrJ4xSwXd4IUPi1lr5+AM\nlesS6ZhIF2yvJFgtcGJ+gR1pgxAQLWyMNWPnCl87CJaMqAuiYK3YeM2/H50TuwEzKSmCv55j5wrf\nztNya8AGwi9i2GJKEqyfsgpZOUwoRJe4E7qlGj/bdzNUWhsJd6/czbAcEpsE50oyXXlLJ5Bla+mE\n7BmzE8ZlHrqp9XrLcEFKbQ2Dm1GxbIPnLqTv6pl/TB3SWZ2FrLF0ZEbpekSB8E8eytgYecJfE0fo\nlyMImS7jbmj/W4FYHXAhrCarLeGrJEYgycJ+2XVpm5IJc2K7mKUTxRLlBM5BGnVJxNx+miVzVVZF\nCbe/yPezMN3Qq6c0KGEoRLKP8BXV3NJJFINkwCAZEIVzpzdW0Fu7lAhqtZ/wpQl3V2N/Ye72ulRB\n4WdiShQUvgsDegZCUo5CGvT2iVbh16rk5nVfe6Mb8mg9/ED4oe7gemXowA1L+N7SqURJZKCSMavR\nafZshol6dCmRK2s4VwAJ02yFyMZtFz1JHxsIXyrRBkvjVGGMT8skdljh7Zwnh4+z0vWnchjdgrUN\n4WdIq3EyolYdKlVTBhJwyQgtK6SOsAdYOgCbIuYsBcpp6lLsI/wOoIuaWlZ0g2KI4sbDj0mrucKv\nZ5qoHrfWAmYetLUWGKwT2RDGC5kEa0IyNp5Qpa0YdnYRlaJjehhRY4OhoqKg8BOJCIQv3Iw6KPbE\nSDrWMa1nzM5uo9bXmNQT8hR6dQUYprpqM3TickjlOggdo0zOtBtja4FdGFO3V2vWuwnxAuGvWzP3\n8I3FBvUkypwsFMgp5TdcJz+LCkGyIlhshXNzD9+KNr+9AFzPP9cshR2mbYW1KUO2h5uQqx5xeFxs\n/KjHw9I/n1Zw9+rdCCeJXIKjIDOaNFLkpSfcNPjPduJVvB2GcZmbt7S3/pX25Jc45wk/kjjREH74\n7EOFckP4pvbrMtI5CMXUbrRZa7s3r5NVUxwWxyZdXSBDYdY0nQ8GlAf49w1W09V50Db1x9IN62bH\npG31OHh1DRdX+HHiPXwAQbaP8KfxPLGgUjHJLX5OQd4J2XGVQUnD2HWIsznhx6JsLZ1OrPiuV3wX\n//7r/j1ROHf1xsAPLNLqfIVvOjiT0Q3Wvhr0qYVfOx0xJQ7v2crQHVMb8jBvWpw6ipgG+yybEivf\nJrppu95m6YTz0mTqLC2dy0XkC68qUSAdFCF4NDS+rL4rSnpJlzLKcTLhbLrhN2nIoNFxH6sSEBqx\nYCUkWeSDtqVBxn4j2wi++cM/xHblb8G3OdQqfJN2kFb78vcoo5Y1ReQXw066i1Y1UquDFT5wSGVs\nuRolLbVW+yydr3j4A9TjGZWq6IpgXwRLR0eKNPRj71vQM01cjdtuhegKdEkqPbm4lQ3fRkCB6fgl\ncUcnZawzpKuRzrLb9QTUK9fQ1JimQVYUBYUvIahLYaetwk+1o+Msrq6IyxxW15jVM/IUunWNiCYo\nPc/QyYptKtvF2YRIF+QdhTMSbefqbrfQbPYSoniuPNdC0Lb18OM54XdDrYWSawDE1RaSHsJJ6hBk\nLsSc8K0FIyMsBm0FoheCkClUMe0gc1F6Iu4wo5Rzwpc2oRaCNREeF8Xc2ru1rR52lHTCDIM8pFo2\nCt9VFVYNfNsJ6RBrc4VfhTuQxDnoe8K3oaOrC8eoA+FXwYs2ofhOhYtFYVdRJqdWoG++FekstSzI\n7QqZc62lUytHHuIg3UNHuBBW09XWw4/SQKqhhmLXdYgOVPgXKLoCklgRObhtrYOxCYmaE/4knvvr\ntYrpvPpLiO+6k8lKc+4sMu3wo/o7iM61dMLeyWLJoc4hvujwF7UKv14PAdPpfsJ3OJRJcabbtmeW\n3Q41oV5ETkhCsZ0Ld8NpUfuYmS6wp09iZxXClriuH7qeRRLdtG1pCd+fl53W0lkS/mXBKZ+lUzaj\n3cLm39UJtczoUbDBlDzxn+KZaJPIxlhVokVJHfd9LrLQiIVB2HGmsNpPxJGxQCsI9RycKL3Hd8Zs\ntITvsgHCaZxUaJlSC00dOb5o9T/z9iO/T7ebYWsWCH//x3Eo7lPjUMqhTbxP4UtA15ZS1XTCAoqa\nLB0ksZsinWbNSlxtScoRbXp26BsTixBrGGwgXEQpoQ5pZremMeM6JXJ+7u5eZwhAmg+oXdkq/CiW\noAtUKnHBjpBmSh0WbWogc66t2NSDVab1lFkCnapGRCPfeyaQd392GkOKc97SMVl4z/m80dpOVbHZ\nT4jCUO+Byvx2jjooJbHa+gs2IIppS/jSeaUq9VkQkqzu4YKlU+Dmg0GsQIuYWpUYJ1GBTMtMUUbz\nHkpRGQiRGVXUI+qFEX02pRSCNeEf1+0OWE1XW8K3UpPpYCWFzJvFAR9WDjClQ8UWka3OLZ0wDD51\ntArfNnq457/q3L+mFhoD2DAPoozmyQKizplk0LvZ93VxoiTXPTLniIL/roWlCFPi4rUNLoS1dI1R\nKC6KAvll2p+HoegS7fPwnz1oG6cKBbzung0qHZHJBcKPFghfSnpf+jpe+Pa3U6YmvC+HiGOedLeQ\ndObxnUhUbaA0Wyj+agi/2ggEPtsftC2TGZHJPOFXDq0cMsvaHj89MSEOOcl1U0/jYvJxSaynuLKk\n2tMIO0Gt+ruQTqLauEsTm2k9fLck/CuCFakftCCaWa9BcZiMSnbpUvDKh36WSeo3wbZcI7IpUjlq\nOaGKBzgR49D7VHcSVIMuDSoRaAk6BG/P1j7b4US9gjGCKgKRrniFLyO0Sqilphbwh7e9l53uSQ4N\nNqhLc2CWDsChkHcuhUaLOeFXWKyI0VZSSE0mQwpisHS0cCgJHTfmBTrkQJcjbLMHTFD44XbZ9tZw\nxBTSUYfK1nu3TzOtE5QtyVMYpyGbZNajsiVlUIJxHHlLJ41awlcmWDpRRFJpOtaxEvZt1V3xhJ9C\npzaoaLi/yjYMXfHPkzPIQobMaBcVFPhWXrPZT4kSv0HWVHhMU3hl3ALhz+gXfh0IOwhf/Wt06/kd\ngjJdzoSXtkagRYSWFVpLkgyQjjqLg8L3pNqpwowFcuqo32bpbGQ9KgErIeDY766zmq6SNIQvDFlI\nB85D5k1aQx0ubpa+H9yTwtOzk6ASEJLKLCj8wc2oSOCQPoOpKxBpii6C3SQNOltrBwCVC1cUVedM\nOnDk9pf40yYss6pD5mwbpKyFo+iGGM4BOfgNVtMFDz+kMqfaf91x3bbKFuZke6EqW4BeFqEQvD4Q\nftP/CvwdFkBiHZWYU1cVLqxSO1+4BaTZnPCVqJBxhhDziw7MCb9cCxfu8bxmIxeOShUok4DO6BZQ\nx4BKqEPLh54co8JdTTO2EQSj7ZI4BNjNDOz0P7D2laFFSKTmVfznWDo7bhm0vSLosGjLcLUuOhsY\nFEfrVUrZIRWaQ8NHGHX9hhzWPWKTECmJZUKd9LEiwQqD3KfwFxZRUPjNXJNT2gd1jucDausJP0rW\nENZ3NLQyoZKaGYb/Mejzx8Wqz+ktzcFZOsD/2957R9mS3fW9nx0qndT55nwnjyaPNJJGOaDwJA1C\nQggkkMF4MDY2LC1sy+bZBmds81i2n20hY54xYMPCtoz8bGMBAmOeBQjlOBqlkWbmhrmh00mV9vtj\n76o6p/v07e7bN/Tcqe9ad3X3ueec2qdO1be+9f2l+dCmcRls987C0knJyZVHjmagEiLleo4UHn6e\nITTcHP8B0y6DJxqsV/i+dndAjSlyGdAXhugbj6OTLu1ej0HqofIhgwD63ipCGXTPkuuys5FCX0M6\nQIaavNtFColOu+QqhNkFZCwd4dvP2G+2bZZOYEugInMRnRkbtDUJflzVKeh0gOeUq1hcxHNq+Gwv\nZqEV4DmFP1OcQF7Dqt40J3fzeemv0hrmyCxGOH86MzYgGjnCbxnN3U+/gt/4iG3bbHLInMJPM0Ek\nE3SQkzZ9hh5Ik5OJGJ37CJPhyZhUt0oPW5qAWAiaubswRB2mg2m8rOoPFLieMj2n2qME+tP2/zOa\n5LHkTEPxY7/7YzYnW0cMsyEeAhlMVW0kjGTuLasIlSGjiMxd3HKRkkTT9F1gOW5XQW8VD1iJYN41\nsWsKQX/oWYXv9lEscpKG3T9qenMPf5gNSdzpESSO8GmNKfxX3LrAoy87wYmFjRXsbMe+9pG79hMn\nikB1iR0xD9y51jI58UieeuIIX2UV4fuRBAFSGJTI0H5E5Kmx7pyFhz9whN9eNeQiw5DTF4ZExNx+\nesCjHzlHI8aOHpRe2fJhSiyWF7lspFBq8VyMTqoLVdd7muP77b4OPWkv4LDO0imzdGoPf3soCd8p\n/Ivtk/zTe/8L30w6DB1RRSbnoiP83mqAzn187YFZJfFaZATkIi8LK4CxQJAKJKmyucwATxurcp7s\nBcS5JNbgh3MoUlLdwMiARKY8ma7QlZI3qRm8QNk2DRt4+Pd0jrMvTeknF0llSIq73TYZqSsP7+mE\n0Clc5SydNE8RCg4OPs2XXKAr6i9jSsK3fWN8z1V1Rm0yGdLD0Pny5yyxGoUxns3BDyQIQ7Ag4Mkm\nGFjBZRh4HgyXkY0I0+8T4KGdav3CsXfwWfUmjv9ai+/6fTfrNYgYZINSrTXzRXzXVsGQorMR68HE\nBKHbN0sXS9V0fmg9fOUIf9oNp8FvIJXN8Ehd90nRW6Xdr1R5KhJiZS2IMLEn1hQhUdomSTw7szgX\nZEKTqJg0k0TE7H1gic+85jhDZ3kZd2ypdIiUkPptpBTIPEHkHkMhaLgxmk2zl/hLEV5epHpmBG59\n/XRIYMBPYHXKKfwsJIsFvUjYYi0ALyLOYnyEHUmILVLKc0OsfWQ2RDQi0kGRGZTSVz6LrgujmR4p\n2hv26YaCvfNWUMxHOf2+JMwN0h1jQ5ORNAvCn2YjTPlT5Cbnr/2vv8Y/fOzn7FJjexyeo4UeETH7\npyL+2htvH0vVXIvifMuGOcYIfNFj4IroBr59XTvPSUbeolD4OqdS+FrjB6pssOcFzTE7ByqFn/gS\n0Wwy1TUgIFUJfWFI5RA/U9x2ukc0hNwHlEfiekx5YoDy18cj4mGOl1aEvxoKjnZsRtGfevExjuxx\nFtmaLJ1K4W+cFbVT3HCEn+WGP37CKsGBOylbrQamuUAvzlhyaWeeirjQsidkvOKhc5/ADxH5KkO/\nQ05IIgxyNGgbrFH4EgaOAJ50QxJWh5IEn0RDGM6xZ+kLpF4DoQISN4Hczw3P9xzhDzYmfL+5wKOL\nSwzyZRLd4EPNGezMo5zUFeMMZELo/MnSwzcZUglEkvI/GgnhQ7NMrTyJWJul4/Ka86BFqhqsYpj5\n6ufxki4mV2gjUCal76yGPQ/6ZM947F8+Sdd1ndSegsESsmmJpZ1pfKfETzduYaCnMMMpbnEtQo7+\n7x8EbMaLff4iM7Et1EpFjnKKFyCgywFpYyN6eQkv7SIlGAF7p8JylsB0lkI4DUG73Idx3wV5uyu0\n+qbMTMnUoBxMU/R8aZuw9Ndj07BZOs7SSVJBIGI6RzK6txwkLg4BF9xTme0fbFyWkcwTpPGIhSBw\nCp/HbuHx/9ilObTrjWVe9s7p50OmXPrUkqvUykxAFksGoSxbDxeEb/17G0RV7tgc0EBkQ2TUIBsW\n82tTvnh+yLm+HROj5ivVqAdDViNohG2E79PRCcMB+LlC0EbkMStZjj9rs5o2s3QAPvzEh3nKdXr0\nkybSDT/RlyD3SSgIv7/qmpjJPpmrdC7m0DdziM1ITr4YEQlue76W+JFGOX/cDyNCPU53ZVpmniKn\nOjTd26QypidTMpEihGbf0oDG0NjaG+WR5AGKIVLYIHHRJkJkVcDXG1H4vRAOt63C/94XHePYXkf4\nZR6+y9Kp8/C3DwH8zd/4sv3DtSCdn27SdJV3pweu0dehF7LYcH1fBr61dAKfqPc4cTBNP5+jS3XA\nwLjC9wLFcgMWXbe9s44AvCwlzjWJgkZjgfne12i7maOJCxA+fzAgUj6eL53Cn+zhE83y7StdlByS\nqganpQcixZisLFRKVUxQpEh6IwpfC0gyYgHigLK9U4pq1XRg8/B9u92+amOkomcy5r7+JbykS240\nHgJhBEvuFvPAfU1kZLj71Cvp4VSOp6G/iGrZ53RiDz+uDnaA5RNzfOEwxEpisqfwsgDNTQBMs8RM\nkpN4LWJpxhR+wCqzwtov3soSXrJaZk0dmW2gwg7SGGYGqzB7wu4Dd1LHg9QOGumt0OjnCNfCOJdD\nYndnU1SEtogqwlcLmAwyCktHEhKDF9EJOsROMYpC4WdDhATj7jYUKTjC99xn0Yt238z2bUO8gchK\nS6efx0wl7oR3x1KeemSJpB9Ja5XkthPoME/wTQ6tfWOfdWgiZDZERhFpXCn8gdAstu6iF0JjqiIR\nv2+DtqEOEVGE7/LyVdoB2UZkK2AUh4+57VyC8It+OkCZ4RIODrHHf9xWQ689pjdBSfgr9nP4osdM\nYI+nviP8lgrKNskAwxHCL/o4eErgRxov9OGW13P/w6/jx15zy9i2CsLPTAatJs0BRHnOqc5XeDLo\nkskEhAbVZnXhR8nClvXwcw+v2KYXIR1HBHHVmddLqmCz32wQjvbGKYbH63GFX6dlXgakFBydcbex\nrm3t/GyLhlPnT67aA6J58hUsNqwqz+IInQdE58/x8o99DJFZP35Z+OOWzkiql+drfuZtiv/8Kkcw\nTvn5eUqSKQY+TIdTSN/n+BP/HYBE2pP8Jf0BSA8v0GMe/tosHRozeMBJT2OkJkgjhEgQJiMpmnvJ\nmMBZGp5XeNQZQkuMa4iWDFxV7Kilkw7wfbvdi260YKd3Bn/Yx0u7pPh4BlTcox+4CUFRxPwDimMX\n72Q1tyrT155V+B2r9NqpJhi6fHFHiv3j8/zSt93N77/yz9NVktvOvpA7F3+UXrRAO+syneRkOmSg\nJDqtTt4lIn7x9n9i32t1kT1nP4F/wn7uw7MNCDr89fMXeNvZJ2Hu5Ng+jAcpkoy826XZyzGO8I0c\nELtAu+9SrBqmURF+uA+TC3I8EqfwQzO0hO93SguvIHydDe1ktYLwTQbGIxMC2T+HAeaGdv/O9Fze\nuMgJEsizlH6e0XFdHs+3XJuPVJPHgp5Lke0lPdAhwzwhyNLS0ikJn4rw86LNMinmnGBfnrEaQmdq\nxs5IALx4wEokiHSEDEOCrBgM5Ag/X6Hhh+w/vDnhFwp/Kpgik1We/GN7jgACNaFC91Io7lpKhS96\ntFzAuVD4Lb9FklWEH5v1hO9riR8qG1f5nl/j/nvu4R3PH52yOmLp5Am0mzQHhtks58O3/Bs+2T5F\nKlMQmpX2YVY7t7DSug2kJkk9PFdjgY7Q7nvQ8TPle49aOu21dQxl0LbqpQPwNbOfwa2PwLGXbn2H\nbRM3HOED7G+7A88p/L2zrVLh/2HvIJ+VtxHe+VaWoxiZxZC2UEbR/szHeeJQwkePfQSARcLypJJK\n2BREBy9QLDUFp5qKEIkTaXhZQhZD3xdMBW2E5zF3/nM81f0CX5+2t7wv7fVBaXQgSYYbWzrMWhKb\nGp4BbFaIEQnCpKXCz0VMULSj1SNBW0+CS/1LXUqjLFoAul460gvwAsXZVUuix85+GoBYGFIR4BmQ\ncY+eSx8LVcjc8QiBJBFWrfoSMBmy7Qg/UTQG1iN/3osX0Mow1Pu56cKLkOltLNGhM7A9UM7P3kmU\n9phKDZn06UllC4QczuOTzR6y215dZuH8Zzl3ooGnBPs6IQRt3r7S5XhvaUTh232YDDIkhny1y9RS\nQl4QtBhQlDO0XTfR0DTLDJqhnAUjyPBI1ZA4FQTEoEPafpuhe61yRXoqGyCkzcgCq/CN+z7ylacY\nBtNoV/u/MLCfpS/By6C/coa+FLTdheeca2eQLqeAoOsIv5t0bUve4RKeyWH2uN2WOx5jEaHyGNGI\nyOLUfZcpRz7cI/zYJ1mJoNGeLfetl/bphlSEX0xfOvBaW0CUr3B4uk3zhQ/RevnL8Y8dYyPMRTYO\n8J473oMcaW505qBtI+Bt09IpkiT6y07hyx5K2XWXhB9ME+eVfdI1VcpuMfzLV5LGVEDYHG8fPYoi\naJvmKXmrQXPoCvgA4S2TyQQjVBkvGwQHQXnEqcJ3Kc14Yfk9iGwV5e6WdNJFhfa9Zmb2rNlwkWRQ\nxMHcvGU8+m/5+VK8XA3ccIS/HC/z2PAXARBuPN7cVJOGa1n6sYsNfmrhZxFTBxFhgJesIs00ACod\n8Il7cj63/6McCj7F46qydKSWY2rfd+1oLwq4RYTlrX5oUgZxQD+A2UYH4fsI4FR+AWNu4/uP/R8c\nTVOQGi9QGOMGqTOJ8I/Dvrvw3a1iK+lgRGrn3IqigjLBd7nYhYefmhSpJSbJkAJSp/CVu8MoumWi\nA9suIheE/XO87Jt/yLnpvQx8SS48IiPQSZ+ua1MQ6pC269kicB0DnU0lp+zfzVjQ6i1yb/uPeP47\n72H2UIeevIP9y/YgvpAfoDW03vD5uTvR8ZB2kpMpn4EQ5MVFCegjCDquqrG7DELwxErCwenIBv5G\nmqEVhF9clPsrCUrkZBcvMn9myCCwRHg873JHMuP2p/3S/LxdZqf8ZkHWhcLPJL4Zgteg41eWjnbp\nqyodIKRBRoWlk2FcdDxOhix2DpVLbAymEAL67i6kd/5J+kLQdgr/ohogGw3iRdfdc4zwQ4bpgMAY\nOPEKu63CviJC5dbDT51V1HRdN1fe9hp++VUKv9kpCV9lfZaaEKgAEUV4rmd7fvKdZLqNYYVjcx2C\nEyc4/HPvR4Ybt+o93D7M+1/zft5z53s4MGVFQLqwTNC2n+lSAdpJWOfhiz5ad0l8Q+7eqxHNEY/4\n5YvujhwgdW2ffS152Ttv4TXff8eG25LuHLKEH9IcuAI+QPrnLOFLr8zAybwD1tJJ1Yil06gI3/TQ\nmT3XvKSLaNlzY2HuEGMoLZ3xLB1grDL5auCGI/yO3+G21v2AzfIAkIFP09kxy4OUvZ1iR4fodBXF\nNAAqS5C+QciY1x78eb7pVQSitBgn/LDovQ0HjSB0vV7mfYEZ5vR9mG90EK76ta8DmtzEe5/3Z+wb\nSK+0iIY9Vxi01tIBuOPb8YU9iBpJh1ymSFPdzgZJbAlf67EglPAUeZrjKUnmCF+XHn5B+CG+i0tM\nLX+dPf1FPnHifowLLnsIZB7TE4fYp17MfDTPtGvDO4xdKwTXdU65zoXtocRPYd90H+0pZvc3Ob96\nlNCV2z+h76HtCP/i9M1EQ492ArnyGWBbOwtyMDkDJWl2muRCoLMEEQQ8ebFv7RyAYCSbwd0NzR6w\n63rmWysoaUiefBKVG1LXGjnUKYHMEHlKwxGtylulwv9tF+vNnYdv8oLwQ6aD6dK6KwhfOw9fudnE\nSuQYF1MZGMlK+xBg6LrjQ/mKgVOM/QtP0ZeCpkskWFIxst2m/7it2r4wZb+bQuHHQthOj2viFQkh\nOo9tWqa7qwud0l9684v44hFB1JqyhG9SVJ7SbWuEEMgwxB8s2sNiBUv4ZoUjM1sfov3wwYfxlc/h\n+QPEckB+82IpsLxJx/QlUJBnf7Xy8OduW+Wzb7YXKz83BI350sNP8oRutloes6mpCL85FdCe3fhi\nJYRAS01mMtKmJfxZ1yZcBmfIyMilVyr8ZX3IpmUmoixaRFcugDF9tBtO7qVd+q7Y6sD+m8c3fAnC\n97ZpgW0XNxzhA7z20GsBykCd8LzyAISq0i9QASrvIqVVpyofIgJb2NINrUdd+HNKyfGMnZH3a8V9\nDmYpmYIFH6IkoRfAbMNmQQAMdGB7iRQReKnRfkH4rofPpKv7nW8lcP3Lw6RFJlPUKOHHCZ5RCKVQ\nUiEQ1sP3FCbN8ZUkH7jbzGJoSzG/1Sl8sIQP8P8dvo9sRGWrbMiq2MsLmj+ClppZl5OduSrT0GWi\nqAWr7to929nQbzjfen+TkYQKVpI9tIYz9Bs9jPToxLcQpIJcevQEZFETjwSVDRlon1boETtLSQYB\n37zQ24DwLQnOHmzauQVJjhrJwlNTVmV5Okd7KTJPidy8AJm1Sw8/TEIMdhRiKmOMUaXCf/nhl/N/\nvuQnwdN4pgraGgFeofBlRfixEaw2DxFES5xXhXKUDJyH2188w/QzkqYrYht6QKtBttwjmEp47IQb\nYFN4+ELgR1XVa2lfidAp/IjcKXzfefk9F6cJHeGr3NkjHbtGEYWIQY+goemeS0EoMlaIvI2LozbC\n8blj/PIDP4m6c7kUWJet8JerLB0VGNI5+3kCY/CbC6WHv+LqNow7ZoduWtZWLzSe9EjzlLQZECYw\n6/afDE5jjCSTHqkj5r6aY5BohkPGgraFKBT00am9W/KSLk8+v8PPPiI5cuzuNR+ysHTGC69g+/tr\nu7ghCX+PI4LA3fYJzysPQIA9nYrwBT2QdserLKbhSzp5zopnfbeClNUaSycMq/zbVn+JuSwj1YJ5\nz9CIU/qephMEJeH3lU/kq7K3OUqPKPxLEP7cSfx2MVlJk4kENZKhEA6HeEYiVHGCKVd4ZQnf05K8\nCKKWlo7N0sGLCArCX/oa32zv4bFoz1grYpUNWZRheVB2mi0SOQRXTVl05VR7rGc7vexOTFelObPf\nXuCWgnPEMiEdLBBmTRb3rSKzIQ1zK93ETtbqG0EWNdEmRmcD+jpkuuGRuKAxQcDFXsLhmYLwnQoN\npqDhLtpKsnDYka/bn7LRgCl3R+IZfDVE5glB5iGMR5xWWTpBGlatkdUQjMLLh6BDAhXw9lvejgxC\nPFN5+APpExVzfaUp207EuaDbPES7+QzLTuFLT5YKP/nIH/GjvyTY/7Q9Tgc+mKa1zxbuWimLi1aT\nVafwwW8sVN+NOx5TQjwTIxsRmYsHRU7hr7qMpEZ7liBeLu2b2J0DMozIB30aHZ+lp12zN7mCv2ZW\n7lZwcvokse4T6GBE4V8e4Q+cwvdcNXjxuX3AC6dITUpu8rKtQ5G91XcK3d8i4WuhSfOUxE0rm++7\n78k/R54pcqnJikpu4MJ5TRybMcIv43xigHLxEC/pceHYrXz0Dsls58iajY4rfDszwD1UE/72UfiY\nf+MZe2ssPI+GVynyPa6VrE2VqqLpMhvyjlzz/tNnWXSE75Ue/rilEwbVCdHMM1sMogWzxs4C7Xma\nZqDGLJ3QkyMKv7J0em7IuDcytGEUwf2PlL9nMkWPKPxoGNu5r9oRjjuApe9hUoOnBGboerAUc3jz\nFOJuqfC1J2h2n+J/HryX1Tgj80cJP2ZR+nbtWEU09FzTNXICVxgkmrPIqSmmllxwNLKkPLPP/jwz\n/XW6QQ+vay8MIjToZAmdt1jK7MmcCEPWaKGyITrt85K7DvOSmxZIiulTLkZxZK3Cnz0+NiFo73EX\nQHUkENx2W9Wr3jME3hBpUhqxh0eHOIkoejQGaTRC+LEj/EEZYAOriv28Uvh96RO5vuhqhPATo4nD\nBabDZ+i7eg08wcC1wsgf+5Zd7zft9zP0ID+8n+juO2gdiilc6m7SBb9JLCRBe3/13ayxdEQUlZ1a\nwzghU4Keu8tttGa46asf5O7PfoB+ZAiKeQFRiOkPaHR8Fs/YdaRyBU9uHOzcCCem7F1WqEMa/uUp\n/EIt91ZitAYlHIHvuR2AQGo8dzGKs5hldwErRg2uuII2X2+R8KUmyRNiR/hzPcsdQhhEZucNpFFk\nkzuA8+clydDgy8LSicptCxkTDM/hmR467dE7eA8CQejSaKuNjhO+cIPMpWDD0Y9XCjcm4buJ8013\n2yc8j8aowh+xdDJRlfIrk9KKmpxIUi4o60lrr1L4o5ZOGFW3vK08p5PndoLQwL5fz/dp+rpS+IWl\nIxW86WfhnneWBH/mG8v4kaYxNVlV+XsrhZDIFG2qgFVrkCIzxhR+alKEr8lTY29tHeH7asRbGS6D\nDrn7lYd4xbtvZ+mn/jH/4eZXkuWGfLTALItZUuHYbWfsu6ZrIiPsnXc7ZBo9Pc3URXdX5QJ9U/MR\ntz+8n28c/CT9sIfv+s8olSDMAGkCLqYF4UPebOIPl/DiFW47vhdfS1LXTydxZZOHZx35FoS/Jquh\nInx7eIe3307gvn8ZeBztnEGSMncq5+GL302cVmTuZ2HZC9/mlUt0PhwjfBlG+O7Y0umAvgjKKk6t\nIBdFpbcbai565JH9f6MEfZdhJb9pm/dMP2lJa+BB/y99P0d/5VcR7/0CqTv5e2kPHvohhu29+CNF\nOUVGSyYCq/CjBrlUILDNvjxbuKWFxm+28ZMVWr1zrE5HhM0F9z1F5ANL+KYYHi6WL0vhH+0c5Ttu\n/g5euP+FNIs7nu16+O4zLT/TxxuZYevvvcv+lD6+ay8c53Fp6Xhu/6/G21P4SirSPGXQcLGsuDr2\nZdH1NmoSDc7hs8q5s4YsyZG4ojovRLlzQ+qUhbO/xxtX3ofA0NU5kY7G2jkA4OI95U+sraOvsn8P\nNyrhDzOUSCgaegvPKw9AGLd0hnK5fFyHGuNOqPPSEr5XKLcRS0dKQeCNWDq5oSM8hsoQda3F0fdC\npBTjCr9Q8A/+AMzfXLZwvXi6x9zB5voDo1yXh3StARKZokcsndkEyDLLNO4z9dM+wvcwGfhSgBvJ\nF8kEXJMyBsugA/bfNM2tD+1DPPACYtcD3kQjZfj5kFUvKhU+QBq4MXwiI1h1ucdBBzU7S2fRBcod\n4QspeNX33k5/9gK9sLq4+qoLJkYR0HcFJwkG02xx8xd+hdu+/O/L6t3cWTpDpzpLha9DaO+Hgw+M\n7a+9xxzhu/0d3n4bQcO1OD5wL/NqhSAakCufd/3ar+AtVnNMLeG7JmfKpkfqNQpfhiFeVvRvGfKb\nPJ+oFAaQFel+oVV2EX2MI5RMCfrSjV90mSiB658+9GBoEnvMdPaTuBbK3aQLcycZKl2O57PbcoVa\nIsQzCbIRkUuNVBANbcuAXtqj4TVQI3N5z3ckkTsOZBhi+n0anep9Y71akup2oKXmp178U9w6e2sp\nsLabljm9r8GDbzzGrS/azwte5qw8qfH32j5HvhfhueM0yZJS4ReNDZedlbUdhZ+ZjIG7IHeS6tgv\nppgmYYthJ2TB+zpPP5FiMgMuLRevUd6VaC9HpymRyxpaZUjDq/Z7iaMvgXf/J9h/T/lQoOVV9+/h\nRiX8OMNTaRksFFoTerK86987Yul05WL5Or8ZYNyJcFrY/OLS0lGVpaMDVR50YBV+O5gm1gZzwVoc\nsSOIKmjrlwMgCowWcs0d3Li6Tvg+nutnnsiUIK8KTaZjMFmKcIOTZ4IZloZLSN8DA4EAObTPD1RW\nqeI8KW8poWrRCmAajbIfjsqGdL1oLJPAhI7wZUawcsb2/lAaNTND05GnCKr3Bruv+5El/FykNEyX\nnAGCEO0anSUCaLZodM/Q6D9jvXcgc33Z+0LRDjRTxQVJCPgLn4CH/uzYttpzIVHbw29HoDXR/fcT\nudestI/we9k9aBkT3HSYYNDjLb///5av9UYJ3w2qV9mwrIoEEFFEmBaFVwN+w7yk9Ky1ws6ZNdWc\n5EbexXNpigNjSNT60nmjbG+mNK+Kl4pMlKK9QpIlY1aLGlX42CwdIzRKQRRD4iu6SdeSjudhnIJ8\nOugTujiCiEKr8N3dpTAZQ9UbO74vB4XA2m7hlZSCh95ygld/3+087yF3rLb2Ebh4TdA+UF6Mkjwp\nPXy/aFNsthe0LSzQositmVYXOt99FUPRJo0kt0a/x+J5V9hWFJnpKg9fBQKZiZJ3umZIQ08gfCnh\npleP2ZCBJ7ddlXw5uCEJP0lytMoweeGbegghaPoaX0mmG/bgCFRAX1cK32+GGNeL+pSxQUBvQtBW\n+3JMAbXynHZjjkRBVhC+ex/heRjtkUo9ppJh64Qvfb/MoR7KlEZuCUDkMdMDBWlWWjoz4QwXBxfL\nC01DpAin8D1pxjNbdKXqxm6Bo0ZVKWgyYqnHG0+5gpJMpHbcX5GSODNt7zYAGY5neUQ6oh/afT30\nFplJLmIYggjQjBB+q9oPsukGw0eWbLtoDs82xu+E/Ia1yUYghOC1338nL/iue7j1j/6Q4MQJGq4A\np5vn/Ez6ndYbbs3wkR/6m0RJNVxlVOFnugjM9scVfhDQcvaHyoZkQpYKX2sJQqKMppjZ4pseQcd+\nH6tZRnuqyrRJi90ehiDEeAWpKy4qCH+YDdcofPviHB+JQTYbVuFLQxQbEl/ST/s0tb17FJEl+Yst\n+33Y7ynCDAZE7oLkxask2lyWwh9F4eFvN2g7huKi0zlQWky+DsvfRz38oi6mKLza6na1HCf8Rlx9\n7jB1mT90QCTcEv0+UctZc8UQbB2Wd1qeL9CZba+NEHRNv9zPm8FaOjXhXxbSOBsj/MJWafiKhXZQ\nEkaoQnp+VaXnt0LwWyRGcTq1xFjcKto8/OKLVWMeZys3tJt7bVGOG7Yxv9d5pL4PTqlGa7r1jQZp\n5w9dWuEXhB/LjIax6luYhHYfzIilMxPOsDhcRPguzdBkSDc71pf5GsKvDsZRBU+jUbYizqQ9eEfv\nAETkxvGJjNAYiKbt27mZnWC94VFEOqIX2lvdxD/P0f5jGDHEiACF3a8pBtGq1ldYOrgA8FIuK/9+\nExy+Y5aFI+3yPaZcPvaqNHzWnGBx9k4yf5rB0ZtYdftkoLvoPCxH0BmVI8mRrpdN9dlCpvrf4s4T\nMdOLXyGRmtAvxID9LHY4vXssX2Gq7fN0YDilcuZm58v3+sIRd4xGRSdUe5HJ8ozcScWC8OMsHid8\n953krpGdajlLh9wq/EDTS3qlraAabvRgW5S9XaS7CLgf+MkKiWbHCr9RKvwrQfj7ywuQL/1ybQXh\nByoo06RzrHjZyB5di4Lwuy591XO1GRhN6Cy1XHggYpRIuetF0wCkIsPoEKTE8xVBQ+OFoSX8XCA8\nTT8dTLZ0JsBaOrvcwxdCzAohfksI8bj7ObPB874hhPisEOJTQog/2ck2t4I0ztE6rywd57c3Az02\nbSfQAatBRfhep8Hw6Cv4j9lL6bpuhn5ZeCXLIJleQ/jNPKfdPkQyoiruv+0YAJ03vAH5ju8BWNee\ndVThzx7YuEOe8KqWw5lMCbKi/UBMo5+PWTrTwTQXBheQxbg5k6GSmFxAIC6h8EcIXzaaZbe/gVP+\no3ZUcZeai8wO4ygVfqVc1yr8UIesRjbAm3kXOBl/iYg+uQzwRKXwZXuE8Avf2RHVYiarlMxt4sjx\nKf5Ve8Bp10dH+D5Zagi1ZCm0h23XX7KEP+Lhh0WuzJiHHyAHXe492UXlMZmsFH7ZnTH1MG4Wgc5W\nmYo8/kM75uMqYc+eufK9PnHSEX4RmM6qgqIC3aRLlmekJh077iqF7wrIWhG5cIQ/hDhQ9NJepebd\nndKowi+2GwaO8OIV29p7pwq/8PC3GbQdQ/FZOwfLC12ggtLWSvKElXiFjt8pffRUmC3791ARfl9l\nxBryRBEZgcxmiUasU+mG2dz10gUGB0Ki4BTCXTTvftVhXvP9d+CFDXQKw1wgPJ9+2p9s6UxAoOXO\n7oa2iJ1eUt4H/I4x5mbgd9zfG+GVxph7jTEP7nCbm8J6+KYcNSjc7d7RuQa3768qCAMV0A1TVNpH\n5BneVIf49rfyvvRRuq7dQaHCR1sreMF6S6czdaQcAAHQ6NiTuvXSl9D607Yl8FpLR2qBkILOfFhW\n7k7CqMLPZFo2wcqJiboJZHlp6UwH03YCkV8QfgzDoT2JWUv4lc8+epKIZqXwB051jCp8v+m8Y5nZ\nUv9wGgA1pvDHPfyGbjDUK5xqfouk9TiHs29xOFslUwGes2QSQLVHLB1H+MJZO0PpcWTu8gh/vhWw\nqAxPL7r2AlqSpTmBp1hy6+96SyhTZekYnVWEP+rhByH5cFA1pxuxvIrjJUw8pHFtq7NlpiLNMM05\ntTTg4FzL2n8SPnO8UPhuOIpT+KOE30t6pb0zTvj2taZU+AFGKpRJnYev6af9CYQvSiIqFb7L1/dj\nO+z+crJ0RtG8Egq/OD5HLR01nqWzHC/T8Tsov7j4bT1gC87DNynDbEgvlGSxJAJUPjcWK5PY4yZs\nRzx1WwO8tBQB03sbHLtrHi9sIIHYn0UEQRkw3woCrZ4VQdtHgF90v/8i8O07fL8rgjTOnMJ3J5PL\nUf9X3/cgf/uRO8vnBSqgF4CfrKLyIarTKdMPuy7aX4xKU1rarBsp0L4q2xgAtPbcQfvgg4xkdNGa\nrRomtV1AqRmMk7oQAs+Xl/TvYTxom4nU5tEDmYjxV4eYNC3z8GfCGZt14IinaYYwjIm1rVIsi5Vg\nQw9/VOGvivUKP2y5QR0idYQ/4uEX77GG8EMVkjHkg7d/gGzhE/ZzSdsTqGhilQiD6lTrK+wY4X7G\nSl+2wg89RSvQJeFrV40baMmq6/jY8y3hp44gjUqIyvS7UUsnwPQHdr8DQqtSyRaFekHiId2cAk8M\nmAmq6uVD0xGxLzkzA6dmwUiBaFxa4Re9YyZ5+MbtPxV61tLJU8IY4kgxSAcTFX5h6RQXZl8mCAlB\nvGzFwQ4Jv1D4OwpENufhkX8O93xPuZ5ABeMe/nCZTtAp06dTthc3KBT+IB0wiCR5DC9LoJneTWCq\nFse6qNeRHsv9lKFqrZs96wf2OE32PIDwPHpJb+sevid3dje0Rex0C3uNMacA3M89GzzPAB8WQnxc\nCPHoDre5KZI4R3tgDKAUwqlUT8mxvGBL+AIvXkFmMWqqU3rZhcIvLR13ECllCV8IgSc9tNAEP/QH\ndGZOlAo/lTDVrG7bpxoe//Jd9/Pt9x5ct9b7vu0od7380LrHR2EVfmHpWEVvtxMjk4x8dXUsaAvQ\nc+tu5kNUEhN7TuGPNhzbQOGrVpP2yhM0uqdZdup7VOE32vaEy0U+Rvj6Ego/0hGDrItQfQJRZMG4\nfUsxixe8znpLR5WE71VtFS4Dcy2fp1xjMu1ZhR96ip47cXveIhKPbvMAmVzEyJxQTLB0gpB8OMS4\neI03MvWoIPww9RHOatEiZs6vAsMHZyJ0q81Ts4JMCdi3B+niFEWWzmhzsNVklWExz3aEiAuL0bj9\nJ0gwXojIEsLEefgjlo6IQoyApeZo0NZ9T8MBr351xKGnftd6+JdReDWKRhHE3qlqve/d0JwrL3S+\n8itLx6Vltv32SDxjmwrfEf4wGzJoaLKh4W8vDZnLXzlinYJfEL7yWB4k/Jepd8Fb/unYewWRPU7T\n1RWE74/t+80QeeqaWDob+wgOQojfBvZN+K+f2MZ2HjbGPC2E2AP8lhDiS8aY399ge48CjwIcOXJk\n0lM2RRpn6BCMC55shFCH9EIbqEq9JrLdKYmtO3QKvyjYKYjfk2VufnHwCSFo+a1S4fcCmHI2QYE3\n3LWfSXjwjcc2/TxrLR1cMCl1M3vT8+fLASQzgSXdFc+WobezHjOZ82UNW/LwvTBg38XPsO/sx/nv\nRx+y+2FE4Tfa1ujIZWo9fBe0HbV0ZLDew+9lKyAEL8QGLTNntSFdZSvgj/QOX0v4Q+lxaGZrJ9Ak\nzDV9nji/CNhsmkGS0/IUfb9J2+TgppYtdY6R+KfQSOQED1+EAWYwwLjUTG+kzYZ208GCxEcUk8jE\nkGmvSrc8OB0x91N/n8Xf/WEe0LPMvfdHoRHBtz451hQMLCH1kt5EhV/ccZb9ntMhxgsQsZvkFmj6\n6dJIgLaBme6Qqd46hW8GAw7uy/nWcJFEqx0TvlaSv/S6W3nFrQubP3kLGLN01EhaZrzMyemTlYeP\n2ZZSVlIxTIcMsgHDSJOt5BB3CdqSMB9Q5PAFuBoS6bHcT1iZPQlHx93pMGpjgLzbRfg+/fTCli2d\nP//Km1jsJZs/cYfYlPCNMa/Z6P+EEGeEEPuNMaeEEPuBs5OeZ4x52v08K4T4IPACYCLhG2M+AHwA\n4MEHHzSTnrMZ0mGG17bDqIsMnUkoLJ1jT/wmsddGTf1gaW30kwzl7BugHDDuBapsOOZLv/xCPelh\nfA0kDHw4PDIJaKcYU/giRTjCT5QbQn7uXDmkYtpdaFa0YQ64bfWThPl5+lrbXJhRwh8hsVFLJ/AU\nqtEgW1qiW/TCH1H47VaT8yIlE5kduVdYOrNV0Hatwi8GZQxOvY3b934VwFbQDiDVTWtTCfCmOrZe\nTgiEsyA85+v7zXBd4Hs7mG9VZOn5kiw1BFoS6wY6GxC49NVBtMAg+CzSMOLhV59HBiFmOMTEzlcf\nabNRTEWLsgDGCN8q/Jboc/DM7+C96i284qNLvGL+bfC6t9oGaf+OdYQ/E8zQTStLZ20wVWlRWjqk\nA4wOkEMbf1lr6TRf/GKyPbNE+n9wqGXvKgubJ+8Pys8TXwEPHyyJXSmMWjrFxSjOnaUzErTNxdar\nbMFdUE2PYTokbnjkz8SQdAm0JMgrhR+KFYywbsHKIKUTrueVMGrTB0y3C8E0w2y4ZYX/vIMbD4q/\nktiU8DfBh4D3AP/A/fyNtU8QQjQBaYxZcb9/G/C3drjdSyJNcrQvncLfmPBDFdILoLPyTQBUp4NW\nEi0FaW5QUpREX7RVeO0P3ElrxhKHpzxaXuXj2VRI2ymzILgrAeF5eGMK35JHrN04u6WlytJxCn9Z\nwRwwFZ8jTgVJ0RZiA4UvhMBXkjizHTZls+kIvxjDVhFty28y0EvrPHzZatlYQpoi1ij8d972Tm5q\n3ccPfOAsvf1WF8SNDgwg8dsY1x/IbzYYaI0MqvRZr2UVfqO1s1mfc2OEr0pLJ9EhajgkGlQneC86\nhTSCqLR0KqVWXMzynmvs5VfHWKH2oywCUVk6HWU/359u/AHer/8/cOAzkPTKmMpoa2uovPypYIpz\n/XP0s6I9xlrCl2V3ziwZkGsfveI6YkaKJE9K0pl997uYBX4v+avrLB0z6JcxifQKePhXGqOWTrG2\nQTpgNVm1Hr5fefjNbVg6nvBKSydpBmT9LpicpsoIRwi/KVfKrKHlQUJ7QpJFFHXoA6I3wLTcNLUt\nZulcK+zUw/8HwGuFEI8Dr3V/I4Q4IIT4b+45e4E/EEJ8Gvhj4L8aY35zh9u9JIKGJpzfgwkXypTM\nic/TgU3FKroqujF9hY/vuVvm9mxIZ86eGAdunqYz75Sn9GiNBG6kqy4d+OKKftHrFL47MQe68nmF\nrrJ0AJZc0VArWUZmVBlEwWQPH6rP7WtZBkxXy6k81aHS8lp0/SVSFdu7BndXIYRAzUwjwnBdHnTH\n7/DggXsBWBaup37HWjux1wbjumx6CtVqVSmZVAq/PbUzwp9vjShxT5ElOaEnyVWASofM9aog3Up0\nBs2IwvdGFL5LOc1XVjHa4/tefLz8P+2acEV5CPhgciQpbXdxvsM7bZ94zs1ddhfgsXF7Iz+ng2kM\nxmZeMW7pgAvcuqEtWdzHKI1I7ZqL1shrVWbDq4rXirTMvD/ADG2cIFY7T8u80vClz0P7H+Ku+btK\nhX9xcBGDoe1VHr5UYluWTtE8rZ/2SZsBeT/GGOioIeHI9LWWWAapyXPD6jClE01S+K7YsjfAuDvR\nrVo61wo7UvjGmPPAqyc8/jTwRvf714B71j7nauJ7/86LAXjq069GLH1qw+eFylU3Rj7B6hA15cq3\nPUU3zso0qXf91Asnti4OVDCm8JVTS0nkbbnwYysQnjfm4Stn6Qz8ivBxefiRjghUwJLrMtiIl1lK\nBVlxzm+g8MH5+ENL/AXhFwp/1Epp+k0+cvMvEWoNTwLtvdVbTs+Ug7TXokjV+4Z3koNmlsHMQfgG\nJH6LPF0FFIGW9DqdMtAOEOxZIBGS5r6NcgK2hrnmSNm8L8lza+kIoVH5kDedu8j/crH2s83TyHy+\nytJZk5YJkK+uIn2P73moijVZhZ8S5iEIHykShLDpsVLAMWnHVXLucffh7PchhUQJVSn8wtJxQfiL\nA1u0Nknh5063pXGfXDSR7uK5Etjg/qVshSItMx/0XZaDFQe7TeELIfj5b/t5AM727B3i+YGt67BZ\nOnYftBv+ZQVtc5OTtyIwkCeCtojH0jLbYgkjPVaGqb0gTFD4RdxK9+MyIeFGU/i7GiZJypTMSSjU\nUt5wecwuJbBU+KoK1IoJ2QY/fM8P8+473l3+rZxayhrbHx5xKQghaMXnONE5x+nOV5CpPZGTkVS/\nwtIRQjATznDBBXTDeAWZQVbw9QZ5+FAFbv0xwl8/laepmyxGZ0naQ/jBj4w1L1Ozs+v8+/L/pGC6\n4fF7PMCLhv83YtqSmREKY6q2tmsV/tyRA/zwa/8ys69Zpy22hVFLx3cpsj4S34BmSNB1GTzJKotB\nF20YydJZr/Cz7uo6y9B3dxFB1gDhI1wJvsz6vPLWPRzOn7JPPP8V+3Pk+/CkVyn8EUsHLkH4nqTQ\nbVncJxcK6S4ay4Hd9qUIvwza9gcYd6H+cy/4sStqSV5pFHcf5/q22+ioh39wNrLzjreIolvmMBsS\nT1vxlvYVLTUYy9KZkhfJlQ3YAhMVvvSLgTqGzJ0vW/XwrxV26uHvapgkuXTQ1incvBmBWCmrPAty\n26wQ4vXHXz/2t+fSskxj6wfcVqE8xf0zX4VWhnYl+zJUyGaTvNstWyuA9fHPpy6NL+6i0gZ5Md5w\nC4QfaDWm8MWaQFhhY4U6hEPjnSr13j1kFy+yEY7MNvjKWTdycapFMY8gHyF8/+TJMk4BNtj6q3/r\nHRyY2tl+HQ3aBi7TyhN2lKMSCfQsuUe906wqwawxdKQj/BHrrlT4K6vrBIXfDBF5gp+FGKGQbuYv\nSZ9//T13wN9zCv/8uMKHSm3CuKUDcMHNHVhv6QhwzefyeEAuZEn4S759j0srfGfpDAalaPjO5333\nhs/fDShaK5zvO4XvdwjdhfZvvO15TO/ZuqrWwnbLjLOYeI+9yCVdRVPE+FnsMj8k02IRI+ZYKgh/\nQtBWjKTnFoR/Q1k6ux2bEr47eUSriWy3SxuhCFBuN4fYC4tWAFf+Sxa+j0kSWl4T5YqifF+jpqdt\nGpiqvsrpYJrzPTv8RaYpKqUi/NFikbWWjprk4YfO9qj2RdN1FJ1027/nx3+cfLW77vECh2cbfPjz\n1sf2pytPPne9rH0lOfDT/2Dd6w5O71wpFR6+FFX/dA+Bb0CIGFy74nBwmq6UqNzQke62fpTwCw9/\ndT3h23jLAC8LyZVAiaLHbh8ufK164rlC4VcxlTGFv4bwLw43tnSKDmx5MiA3EuGqdS+4GE+oN75Q\nFsF1M+iDO1dGiWs3olD4o5bOkTtmedtfeYB9B9uXeuk6lIVX2YBsr80yi7uKJkO8PEPmCVIbmnLA\nUHqcXbHHw57O+rv40USF4o66tnSuJTYh/MIf1Z2psQrPQulud3iD74I2snV1CD+PYzqyiU4HQI5u\niDIdU4wMcJ0Opzmf2wBknglUWs38RIdVj5I1yq9S+OMe/tpUyFCFKKHWqU0Ab88eghPH1z1e4Ohs\ng8SN4QsjH+FaSmbkZdMrIeWYh3+lUFg6gVboEYXvG0FGQt4zhPFnmLnwx6RCoI2hLYcg9djFschs\nyVZX1h1fIgjQaR8vDcmljyr2e9KrbBwdwsrT9veRQrhRhV+kYZaE7yydyUFb1xc/GZAbUSr8C8pa\nEpe0dFz6a94fkA+HtnXvJWzQ3YAiwP3E8hMAzIazCCnYd3z7NpSWmnP9c3STLvsP347wNElX0xQD\nVJahTIrvxixmaE4tWcLfP+Fuc/RCWWTF1ZbONYSJL034J6ZO8Otv/nUO37ZMeu6Z8vHC0tmuwg8b\nLuOi1dnkmduH8DxMHNMWIV7apx++n/ymE6g/mrZPUGssnbwLwmBy27LVFN+0DuwQ5SyeHLRlnPBX\nvYipNUEwIQRNrzmR8DfDkZFK2dBTqHxIKhtkmPGOnVcB05GHkrbzZ9GWoKk1oRA0IiAXHFz8HYL+\nVwGNNjltMbBjKUfucAoll6+soufmxrYh/ACd9dFZQKay6mtJ+hXhH3wQnvgD+/tGHv5GQds12TNS\ny8rSSQbkOcg8JVWGFTd3dTPSkWFIPugjhUCMpMPuVggh8KVtTvYdN38H89H85i/aAJ70MNiL8osO\nPUyydw9Jd4WIITrPkCbBF641OYrTSwOUFOWY1LF1jWQEpoXCry2daweTJFWL3Q1w2+xt8ND4Y0UK\n4nb7gIQNS/Re+yoQvu9j4oQp7Mm7LJ9gKroHNe1mcI4SfjjDStpFKEOeCnQmyIvxhsoD7UPMeg9/\nxNJpvfQlPPHlJxgon70Tip1aXuvyCH+k+VngSTQpKZCSbyu74nIgpWC26SNF1YdGGoPKYWbaCoPp\n5S4993F1ntOSQzvgZfR9ijz81VXEvvEidNWyd2Aya9r5w0X9Qzqwlk7nIMwem0j4RYogVIS/r7kP\nLTRfvmjTONdbOgJyiFFkwyHGgDCpbdXtsBnhCzfX1khVBh53OwIdsMffw19+/l/e0fsoYb/sg62D\nHG4f5lv795J89Rs0TA+RG6TJ8ArCzySnlgbsaQcT43tjCl/ai8hus3RueMK/lMLfCIWHv93+1AXh\nB53pbW9zM1jCj2ljyWaZPieCKdR0Me5+XOEDoCCP3WcoPHwVWKIXqkzlLDAatG08+CC9zlH4hT+e\nqLybfvOyUvfWKnyNK/Zhe21tLxdzTZ9enJWEP1i1xBrMWOJtXlhkqZigmGc0GUAw3iSrnOZlDKxp\n3SEaDXQ+QOQz5FLYiWnKryyduZNQDrUW1chJrNqcFLR9/r7n89FTH7XrnGTpZIah8skSN14yTxmZ\n47EFhW/n2gpPryuY2634Ow//HU5MnSjjSZeLwh564f4X2v5Yhw4x+Myf0E4vYDKBJC0Hlvdzyeml\nAfs2SB4QIwV4PbF5wPx64MYm/DQd+xK2isu2dI4e5UIL9M0nN3/yNlEQ/ryyFkKsDLPhLGrarnU0\naDsX2ecYZcgS9xkKL1l5loAmBPJGC6+gGtgyqZ3BX7zvL17WybZ/KsJTgiSzFo529QLJyHavJuZb\nAWeWB2WhTn/Fpa/eZm/zdK+Pm32DZ3Ka9K2lM4LRXv9Cr/HwhcCTOZiATAk8LW2spLB07vh2aDvC\nD9rWM3cYVfiFh+9Jj1cfeXVJ+BMrbXPDUHlkQzdA3mQk2yJ8O9c2971dH7At8Kojr7oi71MQ/osO\nvAgA79ARsqGi0XsGkwk6yRn2erYVSC+VnFrqc+u+yYHh0buj8+kSUsjLugu+mrihg7aXr/Avz9I5\nedPz+cd//TZuueeV297mZhC+9fD/1M12mMrrb3kzbzj+holB28LTTD1IC39CYYleCOvd6/UHYnFn\ns5bwJyn8Vxx+Bc/f9/xtfw4lBYdci+PQU2h3IUrF1ffwAd79wiP8qYePlQq/t+xSMfdUjd8K/9XL\nMxoM1rXBHa0zmHR8eZ4hJyCXvp3E5EWwchr6F2H2OLRcAVkwThyjHn6h9D3p8coj9njSUiPF+D4q\nFH7XhNC3rb6EMiTbsnSswjfD+Fmj8K8U2n4bLTUP7bMXfO/QYQAaF86Q54K7+7/Fi2b/AwDdVHBq\nacC+zuT9OXqxPJtepKEbuy4ecmMr/B1aOttV+PPRPB985IPb3t5WIH2fvD/Ad0NdXnnT62hHcyw5\nwh+1dAqF392ToR93qXbKWDsHLNl76w/a0aAtQOQyWXbSsGwSjsw2+Po526BKawMpxNtsa3u5eP3z\nbNfSM1+35NhbtvUK0WyTbhRh+v2S8P08o8FwHTGPdgKdVNjn+4JchWSIivCfecz+5/TRytJZ875a\natJs3NLxlU/Lb3H3wt18dfGr67altMBkhk+Zm3j43Ofdg3mp8JXYvPOlDEOy1RVk3EAEzw6Ff6Xw\nnbd8Jy8+8OKy6aB3yDaV66ws8kwmCBqRPV+SHquppJdkEzN0YJzwL2QrNPSkJsPXFze8wudyCL8I\n2l6DGZNbhfCspVP0OylIp1L4FfEUCv/MoRzcvFipjA3WgvPx1ys5mxZZXejCSyj8naDw8QOtSgs8\ndc3brhWUZz9jb8m1HW546Hm734pRlb7JaJj1ls5mCt93HTMzFdgJWF6jytCZOVa1olir8NX6StvC\ncvihu3+Id9z6jvWfQ0tMZvjf+Z3ogb2IDY62+PQDLvVVr+9rtBZl0HY4RPrPLYXf8BrcPHNz+bd3\n0M6sSE+fsTVXQVgKpRT7vW7o4WtdWnSpgmiCqLre2D2MdhVwrS2dq4nC0skd4RdqoiT8EYUf6YiW\n1+Ibh0feYK3Cn+Dh+1qOFVmVls4VVvi37GvjKUEr1OVsATx5TRR+gbWWTtDw0Au2d3up8E1KaCZY\nOkpVRUqTFH6jOua0L21bhmKC1czGCn80aBvnMVpUFs7LDr2M9z7w3nXbkp4kz3I+mt9BZux203nN\nmUNbL+0vgrZ5PHzOWTproRcWQAqSCz0btA2jUhzFzhDZSOFDdV4mavdl6MBzwdLRO8nS2UWEXyh8\n17O8ODHLsYJqnJTno3menDmH185JVqQtAHIl6YRTkK1vcHbP4WmeWqz6h0T+1VH43/XgYR46Pksr\n0NUgd0+PtWC+2igIv1sSvq4I350VYZ4Smt66LB2wd1h5kkwcsBO2ArDdI2zb3uLED6cgmql+n2Dp\njCr8ooXAZp8jzwzfNHvo+vZCYrIhmm0QfmSDtmYYI6d3H0ldSwil8A4cJAn3kWdPIhrtkvA3U/jg\nkisGA1K9+zJ04LlA+DtR+LvJ0vF98iTGFJkY/saWDlgf/xmlCQ9Jki/mztJx6u11f3ci4b/9gUO8\n/YFq3GIxx/ZKe/i+ltyy15JdMTBENzxalxjkfqVRZOkUCt+P9IilY58TmRjPJOsUPjhbZ3V98zSA\noB2B64LsBQqkO/Gnj1ZPuvddsPd5Y69bW3g1Ojd5w8/hLB2M4FznLjgFZD28chbx5v2HRFgEbYfP\nOQ9/EvTevaRSYvxVRHuuPG8yNELA3ks0ZysUfip3p6VTE/4EVB7+LlL4rvDKxIWH7/rCNJtMvfWt\nNB56wdjz56N5HlMS/5YO+RcXIcorS2fm2Ja2KaUg9OTYAPMrDT+yn+O7Hz7BgYdvu2rbWYsyD38l\nxo80Uop1lk67GIAxgfBlENg+mJMsnalKJetAgyuWY2aE8F//99e9bm3ztK30pFeusEsBZ5t3AnCT\n/CafEwrItmjphOT9Pnmv95zz8CdB71lg+IUv2kp9v0ph1n7AQhhcst9+kQaeaGjuQktn90jYKwRj\nDF993et55l/8C8iynWXp7CoP3x/38J2lI4TgwN//ezRfsJ7wz0mBfN4+fuTPKWhTWTrbwE+/7W7e\n9cLLmy28FTRvtTULJ+4+saMB5dtFofCNsXYOUBJ+XtzZuIZukyydInA76fiKZqvn60BXPYs2udCu\nVfhbtXTAEv6p1l0A7BEX8EbmI2yG6L77IE1JnnzyOe/hA3h79pKcPVvd8Tih1IzCTY9R6dUe/jWF\nEIKs2yV5wjZW2pmls8sIP0kqD3+TApn5aJ5VKVjZfyfn8q8QLFXBp+3gkXsPXtZ6t4r5W/ah/dO0\n53ZWMbldqJG4REX41tIx2qpjTdFhdP3aiiypSTGiaL5D0fbZCz2IJ1g6E7C2edpWBokXo/08AwMi\nYBUlEjvch63NVG297KXofftIT59+1hReXU3ovXsxfXt3J4Mqo+2hm/Zx80svPcuptHTU7vTwbziF\nD6BnZ0lO277jO7F0ttta4WqiyNIpPfxNlNhcaHPxT93+RgA8v1l1ydxFOHDzNI/+k5cTtrb/Pe0E\n0o2vhAkK36tIFFjXSwdGFP4ESyeYny5/16Gu5uFuV+FvgfCjtn1OwwjSxN6RKFKCQuGrzUlHaM30\n299uf689fPSearKa8CpLp92IOLqJMCkIv92c5XD78CWfez2wexjtCkLPz5GetlGznVg63m6ydDwP\nsoy8b1u1btbkqsjFf6prJywFMydgzx1Xd5GXietVjVj434FLoywIv/DltbmEwnftFSYGbednEI64\nvcivitw2Ify1Hv7WCN8eB00jSGPbpsKIFN8FfLcaOJx++9tA2XnCz3V4e0cIPwhG6lc2vxgWhP93\nX/nTY9PwdgtuOEsHQM3O0fvEJ4GdWTq7Ki3THUj5yqptj7DJ51poWPJ6etX2Xfdf/Bfg8Cuu6hqf\nbVCeJI1zgsieBmpmBr2wwPIcQA+vIPxJHn5QePjrTyE9PY1OByS+Zy0dcQCCKZi6tOJbq/C30pyu\n4Qi/jSTvWcL/rdlH8PYN4enf3rKt4O3bx7Ff+WW8o5e2nZ4LGFP4wUjfqS3EVIo77yBsrmuDsRuw\n+1Z0BaDnZjED2wt8Zwp/9+yeQtHn3dUt9SwvFf6qVfi7bSj1bkDh4xeWjlCKk7/z23zqhfZiWVL5\nxLTMjRW+8H20G4CtGz7c/33wFz4+Nhd3EsYUfrY9S6eNxPQzYmH40sl3o92c4e34yNG996JnZjZ/\n4g2OUcKXvl/FvraQJltk6ezWWMjuYbQrCDVXDUS4rG6Z3u5V+NnK6pYOpplgBikkp1btqMOtpPg9\n11ARfnWMSN8nKNLwSktnUlqmI+8NpkN5OEunEVhl2FrYdD2FwjfGbNnS8SONVIIWgqSbsCoMh2cb\n5Wtt8LbGdiCjCOkm4IkgqNKZt2HpXI7QvBa4IQlfz82Wv99IWToA+crKlgJrSipmgpmy4dZua9O6\nG6C9cYVfoLgbKoO2kyydqAjaTj6+PDe83Gtsfb8XhVaZyUiyBK22oCiFIGr7NI2gvxyzKgxHZhtl\nSuduzBR5NqDw8cWowt+CpVPcidcK/xpCjYydu5Hy8AGSJ59ET2/ttvsHnvcDpSfcnpBp8lyH1JMJ\nv7g42rRMUWXZjL422DgPH8BzA2e8aOsnfqHKkzzZcuEVWFvnRDvCTwxdaTix0CrfazdWez4boBcK\nwg+25+F7u5vwb8igrd4x4e/CtEz3OeInnmDqkUe29Jrvu/P7eOSmR/jyxS9zbOrYVVzdsxOTLB0Y\nVfjG2jkT4iWlh7+RpeMBaY7yt16lXCj8gvC3YumADdzu6wp8z+PW581w054Wj3e3XnhVYz30XtvR\nVAY+5I68t/B91JbOdYCeHbF0NjghL4XCw/d2oaUDEN5555ZfNxVMXdagkucCqrTMDRS+YaKdA9Vc\n241O7EYk8NLetlJOC4JP89QWXm2xMjpq+yyfG5AOM04emRp7r63k4ddYjyJwO9paYVse/i5V+Dsi\nfCHEdwohPi+EyIUQD17iea8XQjwmhPiKEOJ9O9nmVnClLB21mywdb4Twn/e8SzyzxlaxmYevMRMD\ntnDptEyA53/vQ7zupen21lMo/Gx7Cj9qewy61rprTrm7E1l7+DuBLjz8saDtNhT+LiX8nVo6nwO+\nA/i5jZ4ghFDAPwdeCzwJfEwI8SFjzBd2uO0NIcMQ2WySd7uXRfgNX9EKNPOt3RPoLA8gKQlvv3ZN\nxm5kbM3SmVxZKTexdKbuuY2pe7b3PZUK36TbJPyKXBodu64iZlNMcqqxPTQeeJDgttvwDhyA7jbS\nMoPdbensiPCNMV+ETSslXwB8xRjzNffcXwUeAa4a4QOo+TnybveyJl6FnuJ3f/wVzDR2z5dWpJcG\nJ08go1q1XQmUhB9dytKZHOwWmwRtLweFhVMo/K3WTowRvlP49+25j3/7hn/LHXO7s7p6tyO89RZO\n/Gc3rnQbls7Um96EnplB7KL43yiuRdD2IPCtkb+fBB662hvVs3MkT3zzsk/IhfbuUfdQKfzwjq37\n9zUuDakl2pNl58wC64K2k14bFtPDrtwpVFg6aZ5uufAKquIrgOZU1UX1vj33XbG1PadRtlbY/PsI\nbrqJ4KabrvKCLh+bHq1CiN8GJk3j/QljzG9sYRuT5L+Z8FixvUeBRwGOHLn8trzK5eLv1lur7aLo\nzridgG2NSyNqe7Rm1xcmlQpfqg0tnUu1R75crE3L3HKWTsfNRlCCoHlDJt5dX2wjLXO3Y9Ojwxjz\nmh1u40lgtInIIeDpS2zvA8AHAB588MENLwybQbtq29Fg57MZ/okTLLz3vUw98pbrvZQbBi948wnu\nfc16UVFUp3o62jBLR1yiPfLloiD4YTYkM9m2PfxGx79ujehuaBS2nndtW3hfDVwLOfAx4GYhxHHg\nKeCdwPdc7Y3qG0zhCymZf/TPXO9l3FAIIr3Ovwd4y8m3sLe5l8bpb4DrSbPutceOoebn8Y9eueEw\nhaXTT20v9i2nZbrW0o2p3WVD3jA48mL4rl+GQxsmIj5rsCPCF0K8FfhnwALwX4UQnzLGvE4IcQD4\neWPMG40xqRDiR4D/gR3M8wvGmM/veOWbwD95EtlooFrP/qtyjWuLhcYCbzrxJjix8XO8gwe55Q/+\n1xXdbqHoS8LfosLXvsILVJmSWeMKQ0q4/c3XexVXBDvN0vkg8MEJjz8NvHHk7/8G/LedbGu76Lzh\nDbRe+lJksyb8Gs8OFATfS3tjf28FR++aY//Jqauyrho3Dm7YCI+QEuU63tWo8WxAYen0Ekf42wgS\nvu4H62K8GptjdyaL1qjxHMTlWjo1amwVNeHXqLFLsFbh1zMMalxp1IRfo8YuwToP/wbI+66xu1AT\nfo0auwSFwj/fPw9Ax69jUDWuLGrCr1Fjl6BQ+Gf7ZwGYDqav42pq3IioCb9GjV2CQuE/03sGgNlw\n9lJPr1Fj26gJv0aNXYJC4ReEXyv8GlcaNeHXqLFLUCj8lWSFtteug7Y1rjhqwq9RY5dgNO++HlxS\n42qgJvwaNXYJlFRIYU/JmXDmOq+mxo2ImvBr1NhF0MLaOjNBTfg1rjxqwq9RYxeh8O1rhV/jaqAm\n/Bo1dhGKwG2t8GtcDdSEX6PGLkIRuK0Vfo2rgZrwa9TYRSgUfp2DX+NqoCb8GjV2EQqFX1fZ1rga\nqAm/Ro1dhFLh13n4Na4CasKvUWMXoVT4Qa3wa1x51IRfo8YuQq3wa1xN1IRfo8Yugic9tNS0vNb1\nXkqNGxA14deosYugpWYmmEEIcb2XUuMGRE34NWrsInjSq+2cGlcN+novoEaNGhW+947vpZ/2r/cy\natygqAm/Ro1dhJcdetn1XkKNGxi1pVOjRo0azxHsiPCFEN8phPi8ECIXQjx4ied9QwjxWSHEp4QQ\nf7KTbdaoUaNGjcvDTi2dzwHfAfzcFp77SmPMuR1ur0aNGjVqXCZ2RPjGmC8CdQpZjRo1ajwLcK08\nfAN8WAjxcSHEo9domzVq1KhRYwSbKnwhxG8D+yb8108YY35ji9t52BjztBBiD/BbQogvGWN+f4Pt\nPQo8CnDkyJEtvn2NGjVq1NgMmxK+MeY1O92IMeZp9/OsEOKDwAuAiYRvjPkA8AGABx980Ox02zVq\n1KhRw+KqWzpCiKYQol38DnwbNthbo0aNGjWuIYQxly+ihRBvBf4ZsAAsAp8yxrxOCHEA+HljzBuF\nECeAD7qXaODfGWP+7hbf/xngictc3jywG7OCduu6YPeubbeuC3bv2up1bR+7dW3bXddRY8zCpP/Y\nEeHvZggh/sQYs2FtwPXCbl0X7N617dZ1we5dW72u7WO3ru1KrquutK1Ro0aN5whqwq9Ro0aN5whu\nZML/wPVewAbYreuC3bu23bou2L1rq9e1fezWtV2xdd2wHn6NGjVq1BjHjazwa9SoUaPGCG44whdC\nvF4I8ZgQ4itCiPdd57UcFkL8rhDii66r6I+6x39SCPGU6x76KSHEG6/D2tZ1MBVCzAohfksI8bj7\nOXMd1nXryH75lBBiWQjxY9djnwkhfkEIcVYI8bmRxzbcR0KIv+qOu8eEEK+7Dmv7R0KILwkhPiOE\n+KAQYto9fkwI0R/Zd++/xuva8Lu7Vvtsg3X92siaviGE+JR7/Frur4044uocZ8aYG+YfoICvAicA\nH/g0cMd1XM9+4H73exv4MnAH8JPAj1/nffUNYH7NY/8QeJ/7/X3AT++C7/M0cPR67DPgZcD9wOc2\n20fue/00EADH3XGorvHavg3Q7vefHlnbsdHnXYd9NvG7u5b7bNK61vz/zwB/4zrsr4044qocZzea\nwn8B8BVjzNeMMTHwq8Aj12sxxphTxphPuN9XgC8CB6/XeraAR4BfdL//IvDt128pALwa+Kox5nKL\n73YEY/s9XVjz8Eb76BHgV40xQ2PM14GvYI/Ha7Y2Y8yHjTGp+/MPgUNXa/vbWdclcM322aXWJWy7\n33cA//5qbPtSuARHXJXj7EYj/IPAt0b+fpJdQrBCiGPAfcAfuYd+xN16/8L1sE6Y3MF0rzHmFNgD\nEdhzHdY1incyfhJe730GG++j3Xbs/QDw30f+Pi6E+KQQ4n8KIV56HdYz6bvbLfvspcAZY8zjI49d\n8/21hiOuynF2oxH+pMb81z0NSQjRAv4j8GPGmGXgXwIngXuBU9jbyWuNh40x9wNvAP68EGJXDVMV\nQvjAW4Bfdw/thn12KeyaY08I8RNACvyKe+gUcMQYcx/wXuDfCSE613BJG313u2WffTfjwuKa768J\nHLHhUyc8tuV9dqMR/pPA4ZG/DwFPX6e1ACCE8LBf5K8YY/4TgDHmjDEmM8bkwL/iKt76bwQz0sEU\n2+voBcAZIcR+t+79wNlrva4RvAH4hDHmDOyOfeaw0T7aFceeEOI9wJuAdxln+rrb//Pu949jfd9b\nrtWaLvHdXfd9JoTQ2Kl9v1Y8dq331ySO4CodZzca4X8MuFkIcdwpxHcCH7pei3He4L8GvmiM+b9G\nHt8/8rS3co27h4qNO5h+CHiPe9p7gK3OO7gaGFNd13ufjWCjffQh4J1CiEAIcRy4Gfjja7kwIcTr\ngb8CvMUY0xt5fEEIodzvJ9zavnYN17XRd3fd9xnwGuBLxpgniweu5f7aiCO4WsfZtYhEX8t/wBux\nke6vYoe0XM+1vAR7u/UZ4FPu3xuBXwI+6x7/ELD/Gq/rBDbS/2ng88V+AuaA3wEedz9nr9N+awDn\ngamRx675PsNecE4BCVZZ/elL7SPgJ9xx9xjwhuuwtq9g/d3iWHu/e+7b3Pf8aeATwJuv8bo2/O6u\n1T6btC73+L8B/uya517L/bURR1yV46yutK1Ro0aN5whuNEunRo0aNWpsgJrwa9SoUeM5gprwa9So\nUeM5gprwa9SoUeM5gprwa9SoUeM5gprwa9SoUeM5gprwa9SoUeM5gprwa9SoUeM5gv8f0z0b1e/c\netMAAAAASUVORK5CYII=\n"
          }
        }
      ],
      "source": [
        "plt.plot(fhatbarhat_mean_spatio[:,0])\n",
        "plt.plot(fhatbarhat_mean_spatio[:,1])\n",
        "plt.plot(fhatbarhat_mean_spatio[:,2])\n",
        "plt.plot(fhatbarhat_mean_spatio[:,3])\n",
        "plt.plot(fhatbarhat_mean_spatio[:,4])"
      ],
      "id": "e71f56c7-466e-4e0d-bd58-29258a81cd65"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "#### 2) Random missing values"
      ],
      "id": "ab343680-1920-456d-8c1c-d94ee39b9228"
    },
    {
      "cell_type": "code",
      "execution_count": 133,
      "metadata": {},
      "outputs": [],
      "source": [
        "w=np.zeros((5,5))"
      ],
      "id": "1a4c9cfd-13a7-4c85-9776-301f8de58948"
    },
    {
      "cell_type": "code",
      "execution_count": 134,
      "metadata": {},
      "outputs": [],
      "source": [
        "for i in range(5):\n",
        "    for j in range(5):\n",
        "        if i==j :\n",
        "            w[i,j] = 0\n",
        "        elif np.abs(i-j) <= 1 : \n",
        "            w[i,j] = 1"
      ],
      "id": "9e5bb134-bef9-40ff-b7b2-c4314ac36120"
    },
    {
      "cell_type": "code",
      "execution_count": 135,
      "metadata": {},
      "outputs": [],
      "source": [
        "d = np.array(w.sum(axis=1))\n",
        "D = np.diag(d)\n",
        "L = np.array(np.diag(1/np.sqrt(d)) @ (D-w) @ np.diag(1/np.sqrt(d)))\n",
        "lamb, Psi = np.linalg.eigh(L)\n",
        "Lamb = np.diag(lamb)\n",
        "fhatbar = Psi @ fhat_fiveVTSrandom_mean.reshape(5,199)\n",
        "power = fhatbar**2 \n",
        "ebayesthresh = importr('EbayesThresh').ebayesthresh\n",
        "power_threshed=np.array([np.array(ebayesthresh(FloatVector(fhatbar[i]**2))) for i in range(5)])\n",
        "fhatbar_threshed = np.where(power_threshed>0,fhatbar,0)\n",
        "fhatbarhat = Psi @ fhatbar_threshed\n",
        "fhatbarhat_random_mean_spatio = fhatbarhat.reshape(199,-1)"
      ],
      "id": "2fb7810f-e058-43fd-9432-aa58e1397ff6"
    },
    {
      "cell_type": "code",
      "execution_count": 136,
      "metadata": {},
      "outputs": [
        {
          "output_type": "display_data",
          "metadata": {},
          "data": {
            "image/png": "iVBORw0KGgoAAAANSUhEUgAAAXwAAAD4CAYAAADvsV2wAAAAOXRFWHRTb2Z0d2FyZQBNYXRwbG90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\n"
          }
        }
      ],
      "source": [
        "plt.plot(fhatbarhat_random_mean_spatio[:,0])\n",
        "plt.plot(fhatbarhat_random_mean_spatio[:,1])\n",
        "plt.plot(fhatbarhat_random_mean_spatio[:,2])\n",
        "plt.plot(fhatbarhat_random_mean_spatio[:,3])\n",
        "plt.plot(fhatbarhat_random_mean_spatio[:,4])"
      ],
      "id": "9e87dd22-aa5e-46fd-bf04-527b005692b8"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "#### 3) By 2"
      ],
      "id": "71721d39-dcbc-457d-92e6-1b726438ac9b"
    },
    {
      "cell_type": "code",
      "execution_count": 137,
      "metadata": {},
      "outputs": [],
      "source": [
        "w=np.zeros((5,5))"
      ],
      "id": "65abae4b-9c4c-494f-b888-8b9a57137126"
    },
    {
      "cell_type": "code",
      "execution_count": 138,
      "metadata": {},
      "outputs": [],
      "source": [
        "for i in range(5):\n",
        "    for j in range(5):\n",
        "        if i==j :\n",
        "            w[i,j] = 0\n",
        "        elif np.abs(i-j) <= 1 : \n",
        "            w[i,j] = 1"
      ],
      "id": "7c0eb15a-9402-40f8-9541-51197d6b49a9"
    },
    {
      "cell_type": "code",
      "execution_count": 139,
      "metadata": {},
      "outputs": [],
      "source": [
        "d = np.array(w.sum(axis=1))\n",
        "D = np.diag(d)\n",
        "L = np.array(np.diag(1/np.sqrt(d)) @ (D-w) @ np.diag(1/np.sqrt(d)))\n",
        "lamb, Psi = np.linalg.eigh(L)\n",
        "Lamb = np.diag(lamb)\n",
        "fhatbar = Psi @ fhat_fiveVTStwo_mean.reshape(5,199)\n",
        "power = fhatbar**2 \n",
        "ebayesthresh = importr('EbayesThresh').ebayesthresh\n",
        "power_threshed=np.array([np.array(ebayesthresh(FloatVector(fhatbar[i]**2))) for i in range(5)])\n",
        "fhatbar_threshed = np.where(power_threshed>0,fhatbar,0)\n",
        "fhatbarhat = Psi @ fhatbar_threshed\n",
        "fhatbarhat_two_mean_spatio = fhatbarhat.reshape(199,-1)"
      ],
      "id": "d61b0314-5214-4065-9d69-03ea8ccd0015"
    },
    {
      "cell_type": "code",
      "execution_count": 140,
      "metadata": {},
      "outputs": [
        {
          "output_type": "display_data",
          "metadata": {},
          "data": {
            "image/png": "iVBORw0KGgoAAAANSUhEUgAAAXwAAAD4CAYAAADvsV2wAAAAOXRFWHRTb2Z0d2FyZQBNYXRwbG90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\nYJCGTikAAAAASUVORK5CYII=\n"
          }
        }
      ],
      "source": [
        "plt.plot(fhatbarhat_two_mean_spatio[:,0])\n",
        "plt.plot(fhatbarhat_two_mean_spatio[:,1])\n",
        "plt.plot(fhatbarhat_two_mean_spatio[:,2])\n",
        "plt.plot(fhatbarhat_two_mean_spatio[:,3])\n",
        "plt.plot(fhatbarhat_two_mean_spatio[:,4])"
      ],
      "id": "bf5ab8d8-1f17-4877-92c5-2be0a5477894"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "### 3.1.3. Spatio-Temporal\n",
        "\n",
        "#### 1) Block"
      ],
      "id": "d87112bf-dea1-4856-8006-0fc3731dbcfb"
    },
    {
      "cell_type": "code",
      "execution_count": 141,
      "metadata": {},
      "outputs": [],
      "source": [
        "w=np.zeros((995,995))"
      ],
      "id": "481f9dc6-36de-43c2-a5c8-0f2325882185"
    },
    {
      "cell_type": "code",
      "execution_count": 142,
      "metadata": {},
      "outputs": [],
      "source": [
        "for i in range(995):\n",
        "    for j in range(995):\n",
        "        if i==j :\n",
        "            w[i,j] = 0\n",
        "        elif np.abs(i-j) <= 1 : \n",
        "            w[i,j] = 1"
      ],
      "id": "6297b71f-1a02-4e67-a64c-5c6a6ab85ec5"
    },
    {
      "cell_type": "code",
      "execution_count": 143,
      "metadata": {},
      "outputs": [],
      "source": [
        "d = np.array(w.sum(axis=1))\n",
        "D = np.diag(d)\n",
        "L = np.array(np.diag(1/np.sqrt(d)) @ (D-w) @ np.diag(1/np.sqrt(d)))\n",
        "lamb, Psi = np.linalg.eigh(L)\n",
        "Lamb = np.diag(lamb)\n",
        "fhatbar = Psi @ fhat_mean.reshape(995,1)\n",
        "power = fhatbar**2 \n",
        "ebayesthresh = importr('EbayesThresh').ebayesthresh\n",
        "power_threshed=np.array([np.array(ebayesthresh(FloatVector(fhatbar[i]**2))) for i in range(995)])\n",
        "fhatbar_threshed = np.where(power_threshed>0,fhatbar,0)\n",
        "fhatbarhat = Psi @ fhatbar_threshed\n",
        "fhatbarhat_mean_spatio_temporal = fhatbarhat.reshape(199,5,1)"
      ],
      "id": "66064009-7a62-46d0-a3cc-2f32a318fe80"
    },
    {
      "cell_type": "code",
      "execution_count": 144,
      "metadata": {},
      "outputs": [
        {
          "output_type": "display_data",
          "metadata": {},
          "data": {
            "image/png": "iVBORw0KGgoAAAANSUhEUgAAAXIAAAD4CAYAAADxeG0DAAAAOXRFWHRTb2Z0d2FyZQBNYXRwbG90\nbGliIHZlcnNpb24zLjUuMSwgaHR0cHM6Ly9tYXRwbG90bGliLm9yZy/YYfK9AAAACXBIWXMAAAsT\nAAALEwEAmpwYAAC4P0lEQVR4nOz9d7xk2VnfC3/XWjtVOqFzTw4a5SwhMGBjkk3mOr3Gr3nte+37\n2q+zcb62sX1tjAw2xoCNecFkECYIIRBCSAIJZY1GEzSa3DMdpvPJFXdY4f6x1t5Vp7vPTPf0mZk+\nuJ75zOecrlO1a9eutX77t37P73mWcM4xj3nMYx7z2LshX+4TmMc85jGPeVxfzIF8HvOYxzz2eMyB\nfB7zmMc89njMgXwe85jHPPZ4zIF8HvOYxzz2eEQvx5seOHDA3XHHHS/HW89jHvOYx56Nz3/+86vO\nuYOXPv6yAPkdd9zBfffd93K89TzmMY957NkQQpy80uNzaWUe85jHPPZ4zIF8HvOYxzz2eMyBfB7z\nmMc89njMgXwe85jHPPZ4zIF8HvOYxzz2eMyBfB7zmMc89njMgXwe85jHPPZ4zIF8HvOYxzXF5oUx\npx9ff7lPYx4zMQfyecxjHtcUD3zwJL//c4+/3Kcxj5mYA/k85jGPawqjHUbbl/s05jETcyCfxzzm\ncU1hrcPa+c5iN1LMgXwe85jHNYU1DjcH8hsq5kA+j3nM45rCuTkjv9FiDuTzmMc8rimscTgzB/Ib\nKeZAPo95zOOaws018hsu5kA+j3nM45piDuQ3Xlw3kAshbhVCfEQI8ZgQ4hEhxN/bjRObxzzmcWOG\ntQ4c84TnDRS7sUOQBv6hc+5+IUQP+LwQ4kPOuUd34djzmMc8brCoAdw6h0K8zGczD9gFRu6cO+ec\nuz/8PgAeA26+3uPOYx7zuDGjllXmCc8bJ3ZVIxdC3AG8BfjsFf7214QQ9wkh7ltZWdnNt53HPObx\nEoYNAD7XyW+c2DUgF0J0gXcDf98517/07865H3fOvd059/aDBy/bBHoe85jHHolaWplr5DdO7AqQ\nCyFiPIj/onPu13fjmPOYxzxuzKiZ+JyR3zixG64VAfwk8Jhz7j9f/ynNYx7zuJGjSXbONfIbJnaD\nkX8F8P8BvkYI8WD4/5t24bjzmMc8bsCwofGhmzdAvGHiuu2HzrlPwNyDNI95/K8SDSO3cyS/UWJe\n2TmPeczjmsIaD+DzZOeNE3Mgn8c85nFNUUsqc438xok5kM9jHvO4pmgKgubKyg0TcyCfxzzmcU0x\ntx/eeDEH8nnMYx7XFPOCoBsv5kA+jxc3qgmc/+LLfRbz2MVwc0Z+w8UcyOfx4sZD/xN+/I9DOXq5\nz2QeuxR1knPOyG+cmAP5PF7cyDfBVqCLl/tM5rFLMa/svPFiDuTzeHHDav/TVC/vecxj12Ke7Lzx\nYg7k83hxwwQgrwF9Hns+7DzZecPFHMjn8eJGDeB2zsj/MIQL27zBnJHfSDEH8nm8uNEAuXl5z+N/\nwXDO8a7H3sXg0ffCR//DrhzTuil4z3cIunFiDuTzeHHDzqWVlytOD07zznvfyUcf+QW49yd25Ziz\ncsqckd84MQfyeby4MU92vmxR2hKAyupdk7ZmnSpzjfzGiTmQz+PFjRrA54z8JQ8drrl2Zpp0vs6Y\nM/IbM/YUkH/u/Of49afmO8ntqZhr5C9bNEBuDZhyV4452yhr7iO/cWJPAfnvnvhdfvDzP/hyn8Y8\nriXmrpWXLapwzY0L0oq7fuCdZeFuF443j92JPQXksYwbljGPPRLzZOfLFsb5VZAOP3djVTTLwueM\n/MaJPQXkSqhmcM5jj8RcI3/ZYptGDrsir8yy8Hmy88aJPQXkkYya5eI89kg0rpU5kL/UMQXyekuf\n6587c9fKjRl7DsiNNb6j3uD8y30687iaCGDyuw+f5lNPr77MJ/O/VlzOyK//Zjp3rdyYsaeAXEmF\nw2He89fhC7/ycp/OPK4mAph86Iunee8DZ1/mk/lfK2ogN7vJyO1cI78RY08BeSxjAAzM26LulQga\nubOays43eXwpQ7sZ+yHsjkY+Z+Q3ZOwpIFdCAaCF2DVf7Dxe5AisUFiDnjO4lzQuY+S7UF0718hv\nzNhTQB7JCAAtmAP5XonABqXT6Dkjf0mjBvKKWlrZBY18D7hWPnb6Y/zS47/0cp/GSxp7CsgbRo6Y\n9+7YKxF0WWE11ZyRv6QxZeThuu8C+dkLPvL3HnsvP//oz7/cp/GSxp4C8pqRmzkjf8lj/eyIH/97\nf0B/bXJtLwxgIjGkW+tc+P7/iDPzWoCXIpqCIHZRWtlW2Xndh3tRorTl/3KFg3sSyD0jnwP59cTx\n1RG/99iFq37+6vkhVWHYXL1GIA+WtwjD7U9/gfWf+inKEyeu7RgzkVeGZ1aGL/j1LyQKU/CjD/4o\nhdlbCfa65mLqI99l++ENysgrU3mbMrA1rl7y8fJyxN4EcjGXVq43fvZTJ/hHv/rQVT//sbN9AJ46\nN7i2N7JTIEf778yORtd2jJn4tc+f5ht/6OPk1UvH6h+8+CD//aH/zkMXr/563QjRSCvsorTyErpW\nbFlSnTt3za8rbdk4dn70D47xnf/js7t9ajdc7C0gF/Nk527FpDTk1dUnH8vCP7e4htcAjUausFD5\nyXU9QL4xKim0vfbzuI5omO3JT8AXfvUle9/rjWlBUA3k109+ZncFerF3CNr8lV/lmW/9tmuW4koz\nlVa2xhVbkz/8pC96uU/gWkLJ2WTnHMivJypjKc3Vg6HWfjJV5TUy4TChev2vxFq/xDXDF77UrQIL\nvJZzv96oAgDqJ34H8hLe+Odesve+nmiAfBddK9sY+Ysskuu1VexwiCsKRLt91a+bBfJS22bM/GGO\nvcXItyU7//DfZV/MKI3FWIe5ykFeBQZc6msE8qCRK72MdC3g+hi5GZS8uVBULyGQ18v0ypk91fxr\nmuzcPWllViN/0ffsrIIUV1xbbqKyVfPZS2PRL+FYeblibwG5mEl2zptnXVfUQHi1gKhrIC+vVVoJ\nwOcUot59/TqAXJwa8/WThHz80gHqdIMGvadWgpdr5LsgrcxuLPEiM10XgNyV13belzJy6/7wV6Hu\nLSCfFwTtWtSe7quVKIwOwK+vXSP3K3AFTviHhi8cyK32550XLx2QT90fu7fTzksRU408PLDL0sqL\nXRDUAHl1bde8tCXGGZxzzfj+w94eYk8BeaORz10r1x2lttt+Pl/oGsiv1S1iNZYIEf6D62PkLqwM\nimvV6q8jGmZr9Z4ad80NaBcZuZ0BxJeMkV+jtFKGm612ullx/mFvD7GngLyWVgzsKWZ0I0Z5jdJK\nzcj1tTJyozHONzur8cReR7Kz1mXL4qUD8ibZuccY+VQjrx/YDY18+vtu+cjNcIheWbn8vcpaWrm2\n866/L2NNQ1TmQH4DxXYf+d6ZUDdi1AB+tYzcVDWQX+OEsBrtEgBEGG7XxcjrlUT5EmrkdRfBPQbk\njbTSJCd2r2mWiuWuSSsrP/hfOPXX/vplj0818muXVgD0uQcwQZaZSys3UEwrO9lTS9wbMa412VlP\n4BcirRgCIw/SihldR6VdzcivNel6HdE0n7JmT427abLTX/fd3FhCRbsH5Hp1FbO2dvl7BRC+FteK\n18X968zPfDNfmn/cv8eckd84MWfkuxdVYNbF1TLyMBHMNTDyE1vHGWMxDSO/fo28ztyVL6FGPt2N\n3u2pcTdl5OGBXazsVJHYNY3clWXDvrc/fu2uFe00Lmh4lXN09Kb/3VisdZT53rGPXkvsCpALIX5K\nCHFRCPHF3TjeTjHtfsieYkY3YlyrtGIbrfHqmfD/+/1/kXct9NC1Rl5LK9fhWhHhhqJfjspOgo98\njyzTL2PkuyCtzDLyXQPyoriifDKVVq6ekVczuGCEQNkiPG555GNn+IXv/vS2Vrx/WGK3GPnPAN+w\nS8faMaYFQXNGfr1RM/GrbS3rGkZ+lS4XqxmUA7akbBg5u8HIA3hUL4O00ux9uUdqGJpCJrF70kqj\nkUdy1wqCXFk+D5Bf/VwvZ3BBC4hDozNtHYP1nMmgavI9f5hiV4DcOfcxYH03jvVcMe21Mgfy640r\nMfIL3/f9jD5z5QZD9hqllcYCJmg0chFWVNfjWhEvVKu/jrisi+AeWQ02jHwXpZWazap49xi5DdLK\npUz5BQG5nQFyBJGbMvImYT8H8hceQoi/JoS4Twhx38oVrEZXEw0jhz0zmW7UuFKyc/3nf57hRz96\nxee78DzzPNLKbz10lrVh0QB5JcRUWhHX71qR4e1fysk4ZeQ1kL90JKKyFVvF1gt67bTXyu5JK9sY\n+S5q5EBTkt88foUS/aowz7kqnGXkRkAcpBVtXDNm9Eu4mnup4iUDcufcjzvn3u6ce/vBgwdf0DHq\ngqBqjzHyD5z4AH/y1/5kw+xuhKgllVpicdaC1juznzBpn8s7vDWp+Du/9ADveeBM07tbCzGVVmaA\n3L1AnVnaWiN/6QuCdrOw5mrjV574Fb7tN77tBem6lzPy3avsjHaRkdcFP7a8MpDPjsnf+MEH+Ox7\nn9nxWLOMvEIQu7AytLYZMy/l2HmpYk+6VhpGvgeSFuXpMzxz4XHOjs6ymW9e8+udc3z+AycYbe6Q\n8Nk4AR/6V9sScD9w3w/wkw//5HOf1yWMvJ4sV3IPADTy8HMw8mEomx+XpplQFcwwctU8146vcYOK\nEA0jv1Y/+3XE5dLKS0ciLowusJ6vbwOoq41pQdDuJzvli8DILy3Fv1KvlcF6zmA93/FY25OdEDfS\nimuklblG/jJH41oRAnDNxr43ajhrOf7t386h370fgM1i85qPMdos+MxvPMMzD+4gRz35QfjkD8Fg\n2oD/E2c+wb3n7935vJy7rES/ZkXPy8h3mrzlmHzT7ziUV2ZGIxcYakY+A+QvUF5RjUz9Mkgr9QMv\nIZDXK5tc7wxeO8WLbj/cpWSnLeuxtwMjn5FWTGmeU1abXfVqIcgI43AurTx/CCF+Cfg08CohxGkh\nxF/djeNeGrH0zK6B7xtcXnF5jh2NiFa9xvlCgLwedDvqgvX2YzMTvTDFc25LpmfA+GoZeQ3kOzoV\nPvYfufk9fwqAvLLN+1dCNCX6bhuQX3vC01mHqtWNa20VcB3R+MgbQHzppJWaiU/0ta9gpkC+iwVB\nxiGkQKqrl1YeWXuEL3vXl7E6Wb3yMYsdGHk9JmfIhdb26jVyaIC8srPJzhubAL6Q2C3Xyl9wzh11\nzsXOuVucc8+9rn+Bsa0gCG54IG+SNBMPsv2if83HqAfdjoNXh/eoxs1DhS62LTEvjdkEZ3kZkO/E\nyMOPnYB8cJ5odDG8/wwjh6ZEHyFxSeqP8wIY+WyfF/siA/nj5/t8zX/6KJvj8gqA+NKNu/o6vhBG\nPvW/h9gNacU5pBRIKa5aWjmxdYJRNeL86PyVj3kFwIbLux9a67DaPedqbJtrRQgywjUwriFFc9fK\nyxy1tFK9DMzohUS9JBQT//N6GPmOg68GlWrK2HKTPycjr2b05Vpasc1kuvI1FSEf4XaaAzpHmgng\ntjFyPcPIAezSfv/zBVgQ9Uw1525LK7/8+C/z8MrDzb8fPdvnmdURpzcmV5BWXvi4u/d9x3n4o6ev\n+vk1kL8gRh585E4Ifx/eDWnFOIT0eeurzVfXY+FKY9I5N5X1nse10jRue46q3m0+ciATgZGbKZM3\nc2nl5Q0lFYLZ3hE3NiN3uWdRcuLP8wUBeQCsHRnolRi5KZ4zOVY+JyPfAcjrl+zEwnSOdIYYQz7D\nyCvBVCMH3MKSP8wLYeQzE9Dscu+M/3jff+Sff+KfN6A9DmBRPfpFeqc3/O+7wMifvv8ix79wZYnh\nStFo5ObaGbmZySHtVjW0tdfOyOub0JWAfOX4ZuNZ2JGRh8fN88mMbE92zmrklbHNDeBqtyvMRxXv\n+YH76a+9sMT8Sxl7CsgBFGJXkzcvZtig/UUByF+IH7gefKbaYdI0jNxPdOs8Gy6f49rMAnnNznda\n3tYxZeQ7Azl4TbKYTXYiqFw6Pd3esv95nYzc7aK0UucUTvRP8FtP/xbgN6cGiH7kB/gj7zkG7E5u\nRpcG/TwteN//zPv57k9+N7A7GjkEWWgXNpZwFoQSCCWe08E0G7UsdOmY3FqZ8Kvf/wBr+17rj70j\nkAd55CoKemYJjEGQzEor1+haWT834uxTm6ycGlzV8y+N1dMD+qsvzU1gzwF5jJhh5De6tOIHcBRs\neS+EkTeWqatk5DXreS4gr7QldtC1UIYdyp+Pkctml5mdgNy/b0bhd7mfkVYqWtPP01vyh3khjHxm\nAh587EE2f/09V/3aZzaf4VOnPsazf+NvMvniI9v+NijriSr40Yd+lGrrDNV40z80HpGMq+az+A/x\nwsedqezzMsJPnf0UHz75YWDKMK/HtQK7t6tWw8iF2FlmuyR2klbykf9sVdwFto89Z0yj3dTSS5Mv\nei4gv6REv5ZW9AtIdlbhhvtCXS4f+qlH+fRvPP2CXnutseeAfC8x8noAxrkfENcjrey4oUM9OYJG\nXuid9cg6KmP50jziLwzTpjCoKcrYIdlZ+7fFTvsfhvdviZK8MjOuFdBk08/TWfDv8wIaZ81OqNbW\nJuN7d7ZYXho/9cWf4r988F8z/MhHmNz/+W1/W5/4ldI+9WrOj86z+kt/ji9/+gf9H4uCuJgmO3Pb\n4xd/CtbOvrA2A7qyzwsMYz2+DPyul5Ebrn5XLVdV9N///isWITnrXStCXX33w50YuamBWXnpbZaR\nbwP1Wlq5Rka+XVq5dvthlddA/sJcLpNBSTF6acjmngPySIgd3QOrP/4TDD/+iZfhrK4cNveTMA13\n9uuTVnZi5P4ajPsFZa4bLfW5qkhLY+k6QceKy5Kdl5ZJ1yFnfl5xn09dYFzEN2/dRG9Nb5dWmEor\nOmlDHG9j5NW5czz9zd9CefLkjucMUG3bp1NgBle/5J3oCWbkVy2X9rc+N/AaeOL2+eeOVzkwesr/\nsSyIa2YGbJnDbG5IVp994UBePY+0MqpGfid4a67LtVInOwF01LpqaWX48Y9z5h/8Q4rHHrvsb7Ma\n+VUDeRiTl5KLGlCtvDogvxpp5LJkZ+Mjv/ZeK/V4Ky6uMXnkked59vZwzlGM9PN+17sVew7IFWJH\n98D6z/4s/fe97yU/p52illbS0g/4Sxn52c0Jf/3n72P0HBsJP2+yM0yO3/zAYT773mee0yFQR2Uc\nkYMIKPV2aaXKJ7zrsXdd9ppaWpEOiitNBJ2T2x5dm5BNzIy0wjYgNzJCtdvbXCujT36S8umnyR9/\nYsdzhu09yK2MsP2rt3OWpsROPJC7pz8J/+1Lm7+d63sgl3YJgIkp2Jd7Z4koSpLAzMxMu4HqBfS1\nds5b556P4Q0rf21mcx0vJNmprSYLtRc6Tq96BavDJg9Xkr8aH7kUV939sL4JXQbkNTCrUGcwC94z\nv9cFQ+YqpJVL29h6IHfbXSvXKK1sffTjnPtn/+yqXjP7WmvdHMh3iojQxhYuG5iuLLHj62iRustR\nM79W6ZOFlwL5506s87uPXODplZ3Z3fNr5IGRjyNGW0Uzaayz25bWs1EZS+T8ZshlVbtW/ASYTAa8\n8953spFvTJ+vDVH4XSEo9BUGp84pXMcfS7tpib4Q6Jlkp5YxstvdBhKTL3jbnx08NzCX9VIXh5XR\nNTHywhQkgQG6rYuw+mTT4uH8KDTuNF72mZiCth2wxABZ5qRFaGcgaBK39blcS9Tf4fNN7nHId5Sm\nvO5kZwPkUXbV0ord8itHm19+86gZuZDiqvu/7CytPAcj3/b79mSntW7HROv27oeghCPGbGt7fNXS\nSr0SyzV6c3Pb34aFfs4VSTHW247xYsfeA3Induwd4arq+npdP08458gfffSqnvsHT67w7k9PEx3L\ntk2/6G8b/LXFbfIcDK1mb8/nI6+0RJd2G+vZKeFZatsAswnHbzzvVb2t2fTaFpVtdveR7LCrkM4p\nbdsfy7ht0oqesR8aESHbbex4apecPOyB3PSfG5jzsHIpMVgZY/pXL1UVpiANH8kWhbdfBIBZGwXg\nqjyQ52GPy7vcWYS1RMahjEMzw8hfwARtgMu47V0k9fbvaVT5MTxbD/BCk51p3fo5zq5aWjHPAeTb\nNPKrZeQ7SSuXaOR2J2mlTnbOgvEO82F7stOP2YxyGwu/WmmlIQ7aYUfT8ZpXhj/yzt/jvQ+d2fG1\nNZC/kBv+C4m9B+TM9o64HMjNiwjk4898huN/+s9QPD0F6M18k5Xx5X1Qfv+xC3z+qQvNv2+PD6Od\nbpbNQCOp5M9hpdPPx8hNiXOgjUKX5uqA3HjXyuzxm4rOwLZngTyfkX6k8wP58hMtKF1wpxi7TVqZ\nLQjSMkJkGTbITnYyoXjySf+y52HkVc2MMVgRYZ8H+GejNCVZ+EhN747ST871fCt8hMDIAwDcbc82\nr8/KIBM1jPzapZVZAGksiFun4Z03w8lPNX+rgbww0wrdF1oQ1KrbWlwDIzdb/ntw+eXynLUOqa5R\nI38eRm5qRr6DtNIkO2fmwE7zYXuy0//MKKlm7LtXm7xsGLl2uPHYO2mA9VHJINecXBvv+NoiOJ3m\njHyHiAAd2tnOSivOGDBmyshPfhouXB17vtrQa34JbjamssM7730n/+gP/tFlzx0UmmRm4twifUXj\nrLwyKp6fkddWtfFOwKGLhvFWpd3G3HbSySttiQLDrllOPVlkAPJZWSafYRU7MvJqQhmkFSxs70ee\nEOGByKAQadL018gfewzCBHk+YC7DDcU67TXy4bCZXM8XhZ0y8vq913/xFylPnGAz7+NsRFF5d00u\n/bW5000bkbVK7/yYauTXPkFnGWV9U6J/zo/jJz/gz825RlqZ7ZlzrYzcOot1dsrIo+SqNfKakdc5\nntloGPk1FATtlLdppJLncq1E0TTZeRXyyLaCoDDGU1FusxxefbIzrBjqzp8BWwZhLo7yEnTByqC4\nTG6sGbmp7FX77a8n9hyQKxw69FzZBuR1OW+9ZP/tfwAf+fe7+t51ssxOpgP84vgiF8cXL3vuqNCk\nM4PqJuULYWadK+MyZMWvpDmHGAT7Un/kd1D5vZ99lHPHNqdPMEWjQV/GyHeo7qyTnTC1NT4XkE9m\nGfns+a48Aac+65sxOdNIK8K4KSNHYFxEIvy100Ih06ypep184Qv+uJ0Odvh8QB4A31a4MAauttS/\nNCVZuBy2rLAGLvzn/87mu3+dfjnA2Yyi8ARhEvqm326nK6rWLjDy2SRdwwprgD7xScCDXe02KfS0\nQvdak53GGnBw57N/hLRqY6Lk2qWVyc4a+bUw8p0qO5uGcGHVMNseov5ddTqXJTv97ztLK63IrwzN\nDCM3M2Tp6u2HAYzDgeqx1s/9ub3h7K/hfujN/Mkf/AN+5pMntr22ZuTw0mxLuOeAPHJgGkZ++fKr\n0bLyPozXdvW9XRjYs0xlWA0Z68uXWOm5nIOLb2/+fRi/bN/GyAOQPxcjL2oWqr3/+PFPn+fUo+vT\nJ+hyG5DPTvidpJXKTDVyW7OiIDdI4xDOXaKRX8LI60n0+98Dv/l3IEzU0nkg31eMee0v3effK0gr\ncWDkGoVI00YPzb/wMNHRo8S33fa8GnlVGgwOrMbWksFVOldmNXJXaVyYnHplhZEe4EyLcV4Duf/b\nLcaX0hsZ87oL34a1yfUx8pnr2BQF1QVd5x7ETfpc+OEfZmnoAXKip31erlVaqWzFYn6QO459Na9Y\neytVlD6ntDL6zGd44h1fitncbHIPV2TkTfdDAe6SSt8nPgA//tWXdVmsx+Rl0op+fkYuO53Lkp2z\nr700SjsF8irAm9fIp+d5ra4V7bbvbDUIQL40Po4YnMWN1zi7uf37qRk5vDCH07XGngTyK0orNSMf\njXxCsRzCZHNX39tOJuHndIAPygHD8nJW2N7UpOnhek8ZDroesB3Ix2GgXFFzDlEnS6x2DYur2eBn\nzn2G8zancl4SqCYlN/3dH6Sdh91/dpBWSm2JXWAZDSOfTvLIbGfkRThPJ0E5MZVWxmtQ9BswKgIj\nP1AMeN0Hn/IJQuEZeSr8JDAi8tJKYOTV2bMkd9yO6vWuQiM3VIAI0gpcPZB7Rh6KnyqNDQKqXl1l\noodgWkxKPx0mUnDWHeCo9URgc/Fu7hh8HQuju6/PtXKJRv6zj/wsP3Hqd/wDVlN97ncY//hP8yVP\n+vOcVpxeO5Brp4mNP9eF/ABGPbf9sDx+HNvvU548id2sk507aORBWqn/3cTZB+Ds/TDe3kumLlLr\nPn2e/PHHp+dY10hcQSPfWi0wweF0qY/80t+3fY4ZRl6GG0RbVpiwihRSXLO0YgNM1m0l+hM/N5LK\nj70jYoNhcWVpZfY4L2bsPSDHYcLSdxuQ13fzeruycgSTjSscYRrVhQuNY+JqwuZ+Ms0ylVE1orTl\nZQU4rrIIIRvA2R8SgbPSSsPIK1+scN/7T1xWPlwvy5yZlnbXA+O7PvJd/GysmzaxujC0jp3lSPjY\nz5XsrKUVe4m0ApcDeePfjiSSmRvPZMMnDOtkVmDkUbhJtAvvHLAuahi5QXpppa4kzXNkq41c6D2v\nRl5VFi1A2QobtF97lRbEba6Vymxj5IUd4WwGKGKhyIXgMXsrXes/lwnAgE2bBmDVc3j/dzz/cjsj\n/+1nfpvfWXuwecwc+wzgrxtAv5zepK5VI9dWkxh/g1/ID6Cj+DmllZqcVBcuXIVGDjIA+TZGHpK0\nDLdLjTUj/9J3fYGLP/Cfm8cbF0/tI5+p4PzN9445e/QrPJDX3Q9nGfkO5KeyFalKfVJe+s+/FBts\n6CmUtqOrllbqm3V9o6mrkWtGnmg/9r66fwvxs9tNFrMVnXMgv0Io56hkDeQ7FBBsbXhr4vNsrbby\nwz/M6b/1t6/6vd14OyN3zjVsfFxtl1dkWMppFSaTSRGIKyY788pw9tgmn/3NZzj71PZzboDdTrW9\nKjcYaxhWQzaFQQdGXkvXrcA8r0ZacZc0zQIP5LM3phrIZSS2JzsnG37lU20H8npQtQMOWKtmgDxI\nK3Xr0jxHZimqt/C8vnBdGrRwRLOMfGs7IzeDAWam/N9Zy+pP/ARqlE9dK5WdMvKVFTRjnPFgncqY\niZA85W6ePkd5ZitN1shYL4SRTyYzlZaF5cL4Aus1+LX3Y08+BEAnv5yRXyuQG2uIrD/XxfwAWiXP\nKa3UJKU6e7aREHbUyNUOjDy4gBhtd3HV554My232YD3rWhGiGYOTYYk2vgeLl1ZKnHNXxcgrU5Go\nhAhHERj5YqSx1QyQX6O0Ut9o6s1Q+mFF3NJ9jFN0TJd48xI5aYaRvxQWxD0H5JF7HkYO2M0wkHTe\ngMyVojxxEr22dtWFDbWvth70s4mp2jJWhwoe23HPSyppYegm3W2bS9SMPK/MtIDgki+9HrDCzkor\nUy18gGuW+84JrJC0anfdJcnO+y/cz+8c/x3KyqBCRr/2Artyuoy+HMj9OahEotxMsnOyAc5AsO/V\nyU4Zvp9OOKR1isSFZCcSmaXbGLnIWqiF3vOya11aKiBxU4380iKiM3//uzj33f+y+XfxxBOs/MB/\n5k1PVKThcjgDNjBys76OMCMy5R03mYjJpWDLdRvWbsLNWLq0Wf1UkwKe+ehznu+lMes8muQF6/k6\nG3rse4Ufei1m00sSNSMfVDNAfo3JTm01sfHn2iv2o2X8nNJKnf8pjh2bPrYDI6+TnXDJRiM1mRlN\npRXnXHPu6aRq5g5sd63ITqchY5NhkElljOx0fOGW1pcw8p018kQmRA4K4cdIR+nGOZJ14qvuftgA\nec3Iw02oTna27ai5sbtLWP5kVGGDsDpn5FeIyLkr9lrZzshnNLrnYOXVs89utyw+TzQl3kE7nPWE\nz/5urWv2lhy2PUDISUmmsm269axGXk6uXEBgGiCfYeSFbjTTvnDbKietTBogv1Qj/7lHf44feeBH\nti0td2Lk2zTycANRiZoy8moydVyEpPKUkQcgzx04wE0ZuUUikssZuez2ntdOaIK0EttyRiPfDv7F\nk0+iz013oqmtot2cKSO3ogFpgMViQi/xyegUxUQI+rSbLWF1FIDcplNGPtHwvu/a8VyvFLOMfGMY\ndGgcW1JC2sOG774TLmvNyJVQ166R26lGHtuEie7Cc+xzW5OU4qmncAg2Fl9xZY3cTO2HwHYSVIZ5\nNMPItdVYZ8E50olubhiw3UdeM2+AfFADeYTs+vlji6uzEJamJFYxCkcRbvZtUTbjPG3HlP0R4/vv\nv+LrZ6NxrdSk4RKNvOOGVEEyVZecTz6qGIbCsnmy8wqhnJsp0X8OaaWOySZ8+kf9/zNh8xx90Wt5\nZvPqKgTrQVizitkk56y0Mq4Mafheizglj8GNxiQq2SZ3TDVyQzGpS3q3f+m1q0QyTXKWuWneb3BJ\nCbxRCe26/9UlS+nNYtN7k2cYgjOXNM0C4ksYefsXfso/XgN5Zbcnkmsgr+2HYSendgHSSUAQuSCt\nOInIUqgqnDHYomgYOTy3ndBUlgpHYisI+YfZBKktS/TKyvblewPkbqqRa9HIJgDLI8tyth3It1xn\nhpHX0kradHK0TmF22qh6h5gtrFofbPIVx/80f+zpP8+6CkAe/t4w8gDki+nitbtWXNVo5ADFZMn/\nsoO84sKYLp86xvryq3jgLd/F1iS+7HmN/VA9FyOfauQT44+blb6DZm0YgKlsaFWCzLKptDIKWrmM\nUZ3Q9qEq0aVlOvXDBNMFfOq/gqmw4zHf8AtPsjyA2DmKkEdpiarpX5+2FLq0rP/Mz+5w5aafs2nq\nFSSaOtnpNXLHghs2RoPokv0C8nFFPzQoGo13lrR2K/YckMfO+aZZlywVt0kr/Vkg34AH3wVffPe2\n41Snp9ttma3Nq3rvehBeiZHPSivDXJMG6aKIEopUYkcjEpVsY8lNZWdld2Tks42JpvLLDCOXl2zc\nIJPGL10Mpz5o8InW0mxnNqKRVnZ2raiTxwFIMoVEkJd6WyJ5/IVHcGbKyAnSSrsAFao6I+fL4n2y\nMyxH8xw3mXhG3vNA+lw6ec3IkyAZycUl7IxGrs/5Ap7Z8n+zsQlAd8LUtWLZxsiXh45DnSX/GZ1k\nImVg5DWQB9ZlU/RMb/WdtjfdKWYLqzaGA44M7uLI4E7WlYKkgwlFQrVGXstwC8nCzhr5p/8bPPxr\nlz3sNfJpa4R87G+UO+3bWevhdjxGR/57LAvHqND801/7AmvDsIKyNE2z/L9ngTyA9Iy0Up93LbO5\nWSCf9ZEnyVRaGVwirQDFZIDRlqQdCpxqIH/yA/DBfwGnPs3ki1/kjfetc8exAco58lkgD+M8iS1W\nJYzuu8+vJn7trzL+zH/jN479xrbVxbZtBRtGPi0IyihJhG6APL5koVOONYMA5MPhHMgvC+WsB/I6\neVMMwOjtjLy/6Tf9BS+tDM9Pl30hymefnT5/6+oYec3EG0a+A5AP8ookjIkiTihTiR2PSVV6CSOf\nSitTRn4JkM/4ZWfLfmsgH0iJpjM9R5XQKz0jLj/4f8GFafvNBshn9bxL+pEDxHpm5/jBABFAPkn9\nxChK2wB5NZac/N53MziTTZtmhQnUyUFZ/7tyJdIZjBOI1A/+muFsY+TPAeS2BvJwDd3C8jbgr876\nkvpZRm5Cs6NOztRHbrYz8qURHO76gq3UCXIh6M8w8jxsGO2BfMpyyypipxhuFJeVgs8y8sFoRFZ1\nyXSXtSiBKMMGIG8XPs9Qu1YW00Vyk185l3PfT1F84Zf5hUd/YftGErW0IgwWSznuhguyA5DPaNeN\nR7/UfOH0Fr9837O8/+Fwk7zEfqjHMzeYK0grtfWwSXzP9G9pvOBC4pLWVFoZTqUVEYD8Vx7+RXRp\nSdvh3GogvxjsjHkffcETl+5YEwEFNZCXzTxKRJhnm33KZ56BZz7Ke555H9/9ye/m0bVpJXidq0pi\nd0WNfAFPFnIbcit2mvh1zlFNTAPko5egJ/meA/LIWTQOVGDk//UdcO//fzsjH2zxN44c5J37l/2g\nGq1MrVFGgy6pnp1l5FcprYwvYeTllYF8a1AiAyMvVUyVRpcx8srYphf4ZEYjv6zQxDjKkDQZDcvm\nObW0MpGSIlqcPl0mLGg/2EshYPOUP+fQfbE026vcRD34ZjVyC1Xpu7tVp083Vr8k9TeIotJN7sEE\n77WpZOMjr6suFwuBsv5cpK0QVmOdRKRhqRokrVojh+dunGW1l1biwPJEb3FbK9sGyLcxcn/DmQVy\na7Zr5EtDuHXR9yJPnL+mY9IG7IukZl3ptpa8pb7y9HHO8Svfey8PfOjUtsfrm3SOYzzJaVVdsqrN\nepSBjDCF/y66hSBVaZPsXEgWsM5euVK3HPEpvc73fe77eGjloebhGshFVDJKN6jGYbW0k7Qyo13X\nLg2tLXlIbD/y5JOwcdLbD5WA3F/j/gc/NPMBL3et1NLKQe1XMq4ocGHnn1lCYZNW0+9nNtk5CYuK\njf5FjDZkgZGv/Py7/E18JfRMLwYNkLdHBuUcpZBYfCvbmpHHrmiOPf7cfaBzHqr8GHl8fepxr7+r\nLLE4qXBJ1sh+g1yzGOoiVqOb/XER9EfTVgLOOiayosKRT+ZAflko5wKQJzBeh8FZ2Dy1nZGPBhyL\nEx7IUt+uFKZs4QP/DP0Lf4Zfe99ncUFwu1ogn7pW/M8dGflgym4rFaNbfiOFVKUNkI9nwLSo7DbZ\npA7nHNJOu/EN+9PCiHE5ZVAj1Wt+NyphoQqMXIjGUTLREypboZ2mmq3UDEzClSVEfpJE2nHxXW3u\n/a1nKE+fxoUCrAF+wJfVlJE3fmyrsMFjXSciFwpBFIBcuQppNcYJZBYY+X/7OgBEljWMfGXlxKWX\nvYmGkdfVkL2l7Yz8jAdyV5Z87MRHsM7OJDtdk+zECUwA4VIqloeO25cPAJBax0RISiKcERgpfFUk\nHsi1S0lUfTNOrpg8zIcVk0HFaGs78JalQeN8O9yhJXIxEsWG7IFKsEH6aeeOTGXbNHK4sgXRFWM2\n6tbFP/LTnP+3/xaYFgTJSLOVrlGN6j44O0krlzPyjeEGv3H8fwDwDce/D/fu/7Nh5C4k/qsgXfkP\nGIB8eDkjP2CmklRdDDYr8dmk1ch7+SBUacuIDRWsrfkYXVqSVlgVnr9Iefz4lJEXA6rzHshbY03k\noAIKEjJRIoxDxRJZ720rE0afuxd0zoPWn/cTG094zf3TP0o1DpvCKD8f5aGjmNp+OKk4mvjjnHU3\nNZ9hYyMkjMPK2e7/FJXKtyW5X6zYU0Def//7eevH8WXaKoF+6E5XjbcxSjMYsKkkp6IIeyHcsWsg\nX38ad/EJkgtnyQ/7u6nZ3IJjH4bf+FvP+f5NQdDk8mTnNiDvz3RgUzEmixtGXksWdZ8VuISRz0gr\n9dKzCORxNKO1jWbbwIrt0konAHkxA+SzhUh6RtxVTlBZ6/tZdDxri7VCryj6qznV6TMNI//I+d/1\nxy1NA+SN1zro46kc4mSMQ9ArRCOtSFshnME6gQhShQmTRWYZcmGBMu7ws5/4uZ3toEVFZAriICvZ\nTm9bK9uakQP8kw/8He49fy+TzRGf/ZJ/ScTNDSMHqIw/38nBRZZGcOuSb2qWWMdECkoXY43AKNkU\nBMU2pXIJ7dh/16VrTUvsZ2KwHoprgpTymWfWOLE6oir9jagSDjGcJhI33WIAcn8tEw1tG18G5Jcl\nPJ3j2Q9FLP2ef1503yNs/MqvotfXPSO3KUpVDNJ1zLjuTHllYd/mE0Q7rKgyP57KsuLJvnd3vMKd\noBqsNiX61P1PBtNxqIuSDX2zZ+ThO6yth/tmEq81ETKVRRASinELW5V86OSHePS032DEypiVwHyr\nfIzRlihRSOF8G+P1NVgLdsliC33Bu5Vao4oIRwWUIiWjAuuIYokIK4njh2POfOJDnBRwLkggT6w/\nAcc/Dr/7f1Ge8j2A0rDnpzh0dJtGflvbD6bT+lDzuaZAHvJd6QqVKpu5/WLGngLy8X33cdcjYiqt\nDMLELcfbGHk+7KOFoJCSc+th1xmde/ZUDFH5OkfG6/QP3YJotz0jf/KD8OAvYHTVAMl7fuB+Hvq9\nqZbeFAQV25OdkYwY6SmQz2piWsWYVuoZuZwy8tldgWY18nIGyOulZ83IJzNAPp5MASQXM5sby4RW\n6VCIwMi99DBbiNSZTPsox/iSfVeWuI6fbO1qCZxAl8ZLK4FhVzJs7DzDyBv5AQ8CLeFBxcqIbu6a\nZKd0Gmk1zgnvWgFM4YefyDJUr8cT93wHvc0/xYn+CS4Nm+c47bhr4xRJzapa26tBZ4E8K+FU/xRb\nQ8GocxSnbiOtYJT58/0cCU5CeaDH0tBx/L19XlUqMmuZCEFVM3IlMdKfb2QSjItpRf57r1wLrtAG\noQZyHTTv7/rlB/mR3z9GVRo0vv9MOuk2zx+6BVARppqRe3TckIPFxAP5E+tP8EP3/1AzPl05YXwx\nIb0QWOPmALSm/77fhnsf4mA/QamKKspxum5rMbPiqyrKkPR3k5zkttv8721/bsIIxmZIm5xbxCpV\n7ttfSCkgkBoz06f7kc0v55dX/7PfLbDw30t981kqpzeumgjpypIQpI4oxZUVnzzzSUbDqfxx3oZc\nTD5Cl5YolihpPZCfPTZdYcww8nRceUbuoBIJKSUERm6C22rlVbewsFXxH7peUnvtvtfyxMaT6LB/\nazXwP9P6/BaWOHPxGM9snmRSGW4JHt/T5b7mc/W3QquKwMiLZJNKltvm9IsVewrIRRwjLWh3KSOf\nbLPPTUZTpnwin6kyK0dQDBCm4shojc3Fg6jFRQ/k+SYO+Ib3fCO/+uSvokvD2ac2OX98yvhqJjHL\nyFtRi4VkgdFMMnU8A+RGxbhWelmys67qXGzFl2jkMxvmhoROINjoL06TMZPBhH/+Pw1f+UVL7jJk\n2ADPqoQsdyRCBiDfBGCrnH6OP3Hx55rfI+e7IbqywrVqIPeDsyo8kLtgJ9QByKsy2A9V2kgrtWMl\nw7+fldG2ZKe0FdJprBO856Tfjs8GfV1mGbLbZdS5icjt45NnPsmlkT97FicV3aJPVIS+LVkHMxhw\n+vF11s4Mqc6eba5Vt1KcG51r2FFsM6SDYZCKN0qHUJAvZSwNBc/ev8GdRpEaSy4ERQByHUmcnGrk\n2sS0ZV0AdTkjf7b/LP/zc78OwLlNzxDXRiXrowJdWrRwVDiyqt28Zmy6npFXktDdgMVymkhdSL2j\n55fv+y/8j4f/R9Ntszr+FKXoIPIE4RxR34Pq2s/8NJ1//l+4eS0l1gValmCUJ8kz0srGL/1Pnvnm\nb2Ft4yx2MpkCeWDk0kXkZsjdIkhW1cT7yJVoioVMvSOXNWxV+zEkHH/gDvq/6a9BTVwWZxLDtpFW\nLIkNQBlnuKqkX/ZpVf5GYlXM+dJbW02RoytDFEskM0BeRzGgunCBlf1vJBka3yUVx/nqlWxuvQpp\nIIolZrQJwNE73gTAEzIls5aHH7uLUTXkxz71eX9tBx5DEuvn+ihWVIMt/uCUH5tHU3/ea3a5OYVa\n+sxHgZRFQypVTHvPv4ixp4AcpTyQ19JKvUysRg0jF+025YzscDye8cKWIyiH6FySWs1Kb/8UyCeb\nDIXg/PgCJ/sn6a+FNqtBr3PWNtreLCPvxB3aUXvKyI3mFU/9YvOWViWYzDPyWMVTRh6klf3dZJv9\ncFZaqTVEkahw6Cljyx48zpuPO1592lG6lEx65m1kTFIYEmQjrVRnztD6K/+Cm1dDgQLhmiiBYsrI\nTctr3JnxQK5LSznDyHH1bkRBWlm4qWHkVWDkmQ1STjuhVbipRm4rhDU4J/j9C34ymCAliCzDCcmk\ntR9Jm0+c/gSD9ZwLJ6aJzPGzHhSXJ2tEVVjWt7u4yYQP/8yjfPo9x6jOn+fsPj+kb1L7ODM8Q5HX\nXmC/aumHFX47B5SjWMroFhnOQVsIWsb49qdKYo1AK9EAeWJTjI1o4e111RWkld965rc4dc4D32A8\n8sVe2rI58Y2bNFDJ7UvtQndAxphK0O+F/MIskMc+f/DFgd+cej333S+LJx7joTf8Dc4c+rN0JyCt\nI779NvTZc5jD+ynjlOT8FkaU4CSWaJu0MnnoIVxR8I9/7F9yvlLI/cu+MCetC7sicjPiFcKvSiOb\ne41cTJOdehjknnLEJOx5urZ6mOHHPg5Mdf1uMR27tdXRVJbYhTkVGPmgGJDqUAQkI85Wnojp0Sam\nv4pSFoXx/egvngIE9I7ixltsjWMefsNfZyzv9M31gKdHf5xTK38MYR0qVtgA5FHL3xxbJbyuKMkm\nHpAf3PDXuAoOlcT4zzlOFK0C1gJjPxT7zz120/zUKGBFU+8RTahUjpm3sd0eQkmEBYMFNWP9qiaN\nRq6WFilnMvAn4pnnBUZuK/+xL0hD3o68jzzfZFP5x8d6TH/Vf1G1p/WRj55idd/rADiVvIZHP3mW\nYTWkG3fpxJ2pRt4/w4HNIOc4i5MROmt5Ri6mrpW6qnN/JyEvr1zZWUsrceaBvIqmLG7fJ723Oyuh\ncjGZDJKGSkhyQ4rf1GG4WXHqx99Fcvwsd54PXRGD80KmksgJD+RFga6BXO8P72+ozpzx24QBImT8\nq1pa6RzAhpL1gm54rV8Kry1EZLm7nJFby7rz57qlD/q/ZRmjzQInY4SIefDcF/jMbx3jN3/owcbS\nNT7jJ/SB0QoytEUwSRsjY0abJetnvKxwyh+Sm+U+VtZPU9UNxUJ1Zr8NDkEnB6EcwyNdkP7cWwiy\nYOFTqcJqgVYSIfz1SnQbh6TlPCMe2yV+/cee5SP3fYYfe+jHAJ8rWSx94tRWsBUcC1vjClM5tAAt\ntycctemAirGVYH3Jj8FZ4Fusk4/Ov24t9yw1f+oYw96tmKjHgbDg2v9//BWWv/M7Wfl3f52tbkY0\nGnHLSkiSu2SbtDJ87BHKuMNbT/4Fzh/6au7feoT0Fa/Adb2UI12EcxV3Ki+/ZJTY4FqpC4jMeIJz\njn/z2e/hgvMEII+X0Kv+Zldr5J2Zz+PyCcZ4Z4fJPfM1KsWVJeNR0VQGW5VwpghFe0WONopPPnGK\nqio9I185B8t34LoH0Wsb0/lRRQ0jH5n9OBSd0jNyO9gEIAqrnG9dH/PnB0PujhYRCMZJbav1ny8O\nzqGxErQL2JgMQGj+sfo93tteJHKSSPjn1rbJet5qWVGpvCnqezFjzwG5dAJtrWfkdcxo5NHSMib3\nA3fJKE5sY+RDKAa4cF3Pywd4MD/mfeSTTbaCO2NcjdlaqYHcH+u+DzzLs7d8NQAnF9/Owx89zbCc\nAnlT2TlZb/zUSTXEyQQTfNNto6bSSs3IOymmMnVuaJv9sC56yDr1BrpTIG+f9+/XKkGbmFbDyBOS\nXJM4n+z8/S++g0897YGlLsqowU2migjfDdGVJVXLv09qg7QyKXF5zqS3D5xFButasrXOUz/8FMWg\nhQs3hTwkXFPjz2NjISEpZjRyq4NrpaKMYGPxFXzw5h9g1D6MyDLWL0y1blFEnLu4QjnRrJ3xE31y\nwYNXosfIIA/opMUk859tsFFiZMzpAOSHxSL91bNUcTtcuwDkLXj2lq/h7F3/EhFZzt+9TBWHmxCC\ndgC6NLE4IygTf62ENaTBeZEwQlFyqngz506W3PvAw/zUF33160RP6NW6aSUbIN+cVL6nPI5KhoKm\nBBAVoupQGoczkpUFD3jdcgp8C2J7hWXNyDePncfKGCsibl8JBS933MGRf/kvKI4uY2WKciUHgnZb\nuayRVmxRYE6cZOXAmxAoqniJ+7ceIfuRd5K8/o3+OTIi1nBLPM09GG09I69bOo8nHO8f590nfoe+\nWwKgTBfR6x4Qa0bensxYDSdTlmomUwLiqopiGFahdoQVEas6tDKoNMbFjMYDnKk8kG9tcmz/bbw9\n3eT06ho6rLqkFiTGS7C58Uy7V/lkJwHI49CS4TvXh3zjaMyrFyS39m5F98LG1xP/HcUhxzRUgshC\nf7SOlEPe9tR38KR+NTGQyjGIoul4WEuiWlZoNcHNgXx7iFAWLKxrvK6/tf7dPHrx9Q2Qq6UlbFja\n3F62OR5HEHuQ+f73fArctIXpWIzZSo13reSbbFyJkQ8rjLaMBxV56wBicYlJskR/ZcKrP/wMi6Ld\nMHJnLW6wQmnbCAxxOcCJFJcExqflTLIzMPJuwp968hOA78y2zbUSpJV2AHKrEpLUn6NWGWcPKdql\nwxjfy0TaCqMSokKTGksJrPcXGLaO4hBNUUZRlxW3FJGbSitV8InHNZCH5kDjzhLSGaLQB+XA6ln0\n0FJsRdggnZShKCkNrT03uhFJ4Yh0YORGB2lFU0Ywbh/255IuI7OMi+c3m8+d6jb5wH+H5475iZyv\n+J9K58jAmnWcMWkdqEcH4/ZhzvjFBPtsh2ptDR11wvXyk3zYgkHvVor0EESweiCmHzzsiYVWALo0\ntVgjm9VI3XsaIBIFsZiwqu/212nsmOgJxhrGekwnX/JP1DNAPg5FKUqgg7SSdhQyGpHpLuvBzndh\nwV/j7ozTcOGSabo+8UC+cT7kbKTi9oseyKP9QRYLTbOizHBoM+zW5KY9ycunn0ZYx8WDb/X/Tpco\nY8GaHE93xJERSQX71bR3jTU2+Mj9ClRPCh648ED4vJ7JF8kSesOPg3q8pxPNOHAvm08akhKHTVmM\nSnBlyWRQ9xbaxMqYWlq3lcUSI90YtL9pm1HBI3FEKWBlc9jcrK2I6Ewc1kGuPWArBFtmExF63MRp\nKEAL0uAruhV3Ld3FMPXXdDwqUJFETQKQB8NB2d+kK0peufp29PhNxM6PBykmVCEf02wqLTRlNAF9\ndU35rif2GJD7042M14KNizhVvpVPXvhW8rEBKZELC1AYMgtLZY+LUcRo/50AXDjj9S9ng9NC5mym\nGrO5iRtvshna406qCf3VMJMcrJ8b4Rzk6T70/luwMqbMDV/z22u8+qm8AfIL3/tOjv/d76W0bWIm\nKFOASLDhRtLSgsp6V8y4YeQJX3bRe927yylG22aH9SKw87qaDaDVCsnFtMVwIaJdgjWRH0ymJA8M\nslc6SiRjFrEqYdg7QKeoNfIEgUElighBpY1nQ5n//DG1tBIKllqLCKuJQ3HIQmiBYFyKdTWQB4ue\n9gO/3/Hn0apm7YdhS7gIimCp01ELkWWszTDyrOpQb7r05GPPUpqSybo/bqQnUyCPZoEcRu0jU0ar\nM7oTO8PI/fkNWoIiWQAh0UlCocecP7Lkz91CN6w6stRsB/IZ+2YkShI5tQKaelMqk5NPStKQyJRa\nsRkcDE5tkusVZCwajTztRkRqRKY7PHHWSxHne/6at8INIEHSvsSrvjJexWlNfxh6souI20J7E7Xo\nx1qlNZFLiDuWQxu1tJI20kr+xJOUcZeN5VchhKNIFyli2Cg2GturExGJho7cwHWP+Mec70XuxtNt\nD+8//3mkVYhQ5Viki5hhjtO+lYQUknhUshGMOi7PG7CLg0nAyBhXlsjgZEJvYGTUAHkcitxSMUHU\njHyiORvInekXTZdKKyM6BcRVG4dqrtvQ9olqaSWQqxrIb2vl3LlwJ+cZY4CqsMQJiNP+JjUUYbeg\nQZ+2CMzbLpA4QSQrlJygw3ydtuetqGSBNHMg3x6hLFhZb+vLrb+rlrbFIxcPIpIE2W6jSkfHCNLC\ng8Uv9jo44JDYBGiklSIqGbYErqpwZcmmCtKK9tJK3U9i9VkPMk4qtva/qjmdSbaffQNHJ/buic13\nv5vi5AUmRZdEjFGmQIi0WbqnIYFS2rJh5Ps6Ce2gA3eXw04/YUCMwmRO29PBGJx7FFkLnSrahQOj\niFyBsiV56gd8d2KwZrEpl99aurnpqqddghIlUSI9Iw9J3DyTWCGRBJANcmqRZMhZIB/662hNjDP+\n+CVtEJYoWAPH4TxawXYmjPeRC2uIWx3KYKnTKmOlFHz4c2d8f1kg0x3cxF/7Zx4/x3uP/SbFlgeO\nyEwQAcirKGXSOoghxznLuH2E1VDk2i5iehOoAiM3ga0N2n7pD1AmGYUes3HAs9jYODqBsSaRwRpB\nFfsbUlpezsibyKeSnBn48x4lI6SJGkauOsdwruQV64/z1pWn/bXpxaRyQFZ1OBcKaza6YCNJO1QJ\nJkKS1XKPtbhqgVP9i5SnTjFO/U3MSS+tGAHyg3/PX5swvpKeIQurVe3SRlopHn+c1f1vACG5tbuJ\njtqUUcJGvjFtZiUj0gqGUiCOepdHvbFEXRDkEDx6+n5a1TTpVySL4ECvr5PrnFSlqFHORi8w/cmk\nkR+SYOG1Achb9U3QbIJQmECuUhPGE35eWRljCseZALCur9HpNEnankCrnFo8AQpREG8Fz30YFzWQ\nH01y7ly8kwrH2SjCVI5Y6aY9xbD2u48GdMI4dabrGbmqiOUElxu+6yPfxaMXHsMICwK0KpCOHbem\n263YU0BeSyvKwpaG3PovqqtWeKZ/kCpbRHY6qMrRNor24Ga+fjTmR/Q5fmxpgUMiVCMGRm7igmFw\nMZhCXMLIJ+y/xR9/5dmpnXGtc2fze946wGLf0I7bvPn+rcaWOM67JGHACRIqFTTYB3zjrsIUjEtN\nGkk6kSANnrPfP+l14CrX8ND/ZDz0kyWbYeRpbABHkWTYVNEqAaNQBEYee6Tv5gaqKVvtd4+wWAWt\n3aVEokRFgojQWxvIYyjSJQQK08mxob95KROEM8RBWlkaB93SRFhbV5G2kJFFVCFpG5LMWaBUwhoE\nFuEcB5du2sbIT40MnVJinPe3LxQHwEja+2I65RKrK5sUoT3BUEVNsrOSMZPsAJW4CG6FYfcowxZY\nIMkVvTHoeLu00m8FoAGquEVejRmF8nzpBO3wGeO48vbDmpHP2DcjShIx1T5E4T/j+GPfh9vwr1+N\n+0in2AznLWRBZGN6oy3uDHp/u5fSkgNauss4MNxxCrbTojXy30mCIAurhLsqjdItzg9WKZ58knHb\nJwSsUCyMfSJ3ePITYKrG8pYtWGS4OVVuum/n+sOPsrXfF7McsMFeKBfZyDfI617x0jPyvpJw8FU4\nB4LQMGvi54QTko2107QDkFtXUaRLAJjVVQpT0IpaiNHkEkYeuhGGZKIRMTjXWA9VSJp/491/yl/z\nAORtOSKyBVZG5KXirK17/hrMwnJz3p0JdEr/PacqVCTbMXHdUyZ0tLSV5NnijXzio29l/aeXed25\nP8rxOMKaiFgWDZAPAniLyZB2SGgJ0yVBEElNqkbYsuTDpz7Mma2zWOmfX6lw7V9kC+IeA/KptPLJ\nU32KYP15dfYRHIL+0p3ITpukhExHrOsu/+niKm9s38wnWi0OXsLIdZwzbAreJFvh+GYkMJXlyJ1e\nX1s9NV32r8qjze+TbD+9rZJO1OaPfT4nfe1ryW5dJC+7xG6MsiXCJZQ1kNeMvMq5+/z7+VrxLOu/\nfIJRxx/zXGBO5bmn4D1/HY55C1e7OwVy5TSRqyjjFJsqkgqkjlG2RNmKMiR3OxODaoDcMWwfbrzJ\nlUuIKUikJnKCKvSOyaVh2PaySrkwZUqVVEirWQyJzV6doKpEA+RaZMgIhK7ZclgKB4eQsBbpDMI5\njize0oCpjloUTrCoY3Lppa9DY1/2fPC1YVPppx2V9cdZb3ebZOcXB19k0jqIc6sIfcEX/ghBHsXI\nsWNhPHX61PrpOE2bSs0yziiqMTqdMrd2WGHEsQkFQf4c0uLKjHx5n0GV/jmT+38GEfB+LVR/boV2\nDULlKBshTUkSHFadhYyO2CKrOhSjQAJSQZ5mZGP/nBRBWhUI53hFWZGZhLV8jdEnP8kk5Bl0cHBt\ndWDLlXDhi+ggo/UZ4tiukW+OSzYfeYzVhQ7SlKT9C+Eclzk3XGNUd0IMQD6QApZuwwW4EFLgwlh2\nQtLOYTnUHli9SZkuMujeyu/+6jkmRUFLpIjRmPVwme0k5zcef28YH2NwBhNWju2ygxElKhQS/Z23\n/H3/fYTvpcOI2HjXCqXgrB5xeMOxcCpChzYLTijaObRLjw/7U1/drfUIFW5qxgoQvlXDJwf/B5E0\ndLoZX37yf+NpdysDc5DYbmECMRkFIFf5hAVR41CH2EEceSCXleXWFUc5GDd5kFLVVb5zIG9CzEgr\nAyMbaeXW9EEEln73DmSng3TQKWIecbfjlu/mwMKtjKXgYJhl2ig2F+/GRmLKyEvJRmDkauAner7k\nwejUM1sI4RDWMLEZab6BNDl5doD2Vs6Bs31uX4HW176V7j09StcmsjnKlEhSSulvCHEtVRz7EH/m\n1L/nW8pH0GPLygG/bB3UjehDKbC44G2Mnd7UoSOdJrIlVZTiUkVUSqRTRFRIU6KjsOFsYYm0H9hL\nYpM8PcRC0B81npEnwveH0zWQmwHjlgfyceoTXDZuUQmQznBAenbbqfdQLB029CwxIkXFAsrtQJ7U\njaWMQWCQTnDLwq2NvKGTjMlQk7qIcXwBpScsjzxTbN8WWqVeqHwrWWFZ6+1vNPKTg2fIs/0IvUJU\nniPP9iOtZBIlmNGE3iShqhl5vbN6vNBcyyJukW+dIh5MZZI0lJIf6AoGydHmem5j5KIkkSMSMeLo\nkZJW3uLr77eMhUTmHRwOGXvRuh9WVTUjl7ZChgRgdyFjkU1S0266CI5TqLIWybjinpW30S26iHLI\nX+wP+LbhkJ6LGJTr9D/6cSaZ/65MkAS32mFV+ey9TVVpWY24uDQrrWj+4PHzLBVDJkmGtAXxul8J\nteLDvOehJ1kLhUVWxCTa0ZcSlu/ABr15UGrcqGbkiqUy4ubKk5HY+STlydu+ntPnBG49pmdjhHX0\nOwInBTaf8MULvrgtNiUOgwmdCmMTg9AcKcOuQtrh4sg/DvTkkFh7aUUaweZoi7/5PoOVULziDn/e\nMqI1EXTLBZQqWYif8d99OUTg/PtVFpklnIy/nDV9B19x97186996C1YYhs/+C1b03XTT30OG8ayD\nBTTJJ7zC+XxGrDskThArQyZHxCbin/2K4NCzOVrUrwuOoZXTsDmtEt/t2GNA7n8qA51Oa0ZaWWVB\n9Nlq34oMO/K84uy3cWByK+f+0idotw8wEZJDoenTCftq7n/LP+DQ6C0MQ/LQM3I/UJPQYOj7P/sM\nFkfsfB/jtPBugVa+SlSsM2ntJ10fs3gidN3rbdK7U6KjFm6sUaZAuoRx2EUkqauJP/yvURiWQ9VY\nf+EOAIaxnxzlyA9i1fetQ3udGUZuS5QpKKMUkSoI5eMKi7Ilpt45vIS4OkCkR+yL1tHRYVqhz3Xu\nOihRkIgc5UDXGvn64+TZkv8s1YP+Z3sBjUVYzb7QCkCEL+Kh4i18evkv++snElQiG2llCuRB37cO\nMCinuCk9ShmKXHSUMd7w12ErXSOuRnRzLxnE738fhRpjNxw6amGlY3XhYAPk8SjDSUVSrpJNLuBE\nxEJxgDxKMMMhnWHsvwssVqVYIUlmGoxVUUZRDolnqixVsBi+zizy2bf9S8rEfzcx01VZJAre0vkN\nvnbxh5HxhNR0+CsfdIytQJVtTFLxpcpv6t0fDchiSSb7RDZBGt2wwqyl6NZyX8gJjFOo2l3URPK1\nx/4Srzv+bbhyyF86f5g3jxNuimKOnttiOLSh4rZqmlz1O/haiGfvbex9iZhwfl9ofxyklY998Wz4\nzmKkLYgunAAglYfYLDamG3JLRaeUbMgEWvuwzn+X6+MSOw5AjuA2sZ9W7udM2/jPs3LAWxj3PTrh\n1cc9Gx1m4NIEN55QFP4aRKbEOYsJN4nIRkhp6emQoB0PoduhHXIti/SJTYkOrrW3P2Z4zWl45CtK\n6robK2OyHLrVAkmS04r8PDIhseqkRpcWmcU80fkmFuNneUXvATqLKedv+n2kWeR1rd+lar+fyFmc\n07hgAU0LzUIwIyS6TeIgji1laNvQm6REWqFlgaLTSCvlu/8u/Obf4cWKvQXkQSOPLLTbWcPIMzFg\n2V1kMztK3dJhefQG7iodg+/5t3R1xERKDgdp5Qy+sKdlDmxj5LVG3h3vQ0g4PinQUSgQkTmtib8T\nZ/kanfEKk2w/yXqf3tlQoJENSLojdJQhRp6RK5cwCGyjBvKq2ORvHj7M5+OQmRMSYSu4w3ea29gM\nlqzgCOmmIMLSTmq/7NQqhUQ1wK0wKFM2vZPbBaTlPrJ8nY7cBNlChIq5wrWIRUnChBhBFYB8oqxn\nynZIqcJEbXfBWYTTLAVpxQmJBVZNj2HkWb8RKXGqIHR1NGG5n2iJxYIVCDTSKo7Yfc1duYpbmJCA\nGrbHxHpEFDbKaP/+RxjHA0xfoKOMltjiT9z1aaI/fSdGGJbH3kmxNLlIN+xKs5AfoIxiDl74HMvj\nFITExP4GbJIO3706XeKWqkUhBJHpktqwCgqteNMtf35F/GoA4myaJ4lEyYHoOHdl92Ljkd+tSLXQ\nGxFR1UanJT3hn781GnLbvjYH5EWUi5BGU4bNQ80Dn/bfDSAKD2STFHSriww+8sPrb+KT98X8+vr3\n8r6Nf8HNUvLWp02jjxfZeaysGTl+DJ++t3EctZlw9qAfw0WeYXTBpx/3wOaIkZSwdoFIj4nsPoQa\nIxpAjOiW+Da7cauRVs71CxgGA4BQHGWBtGhTqgmdyq9cXLi5vPoTI77pPSWfe9s/oYjb2DTG5jlV\nvX2gLTHknAx9k2ITo4RpahbMeIg4cpCFsT/eEgOkrRr78etPenJy4q5pdbRLErJC0C0XidOSNArS\nUfC0O2XQpUGmEblaYrF1DhG8+cmh3+Nj9/wYr3jsV9n/4aD7i8pvZIMvwJuEsnzpFAmCJLacS8Oq\nTiYoF6PVhJY4wMHNsNI6N4Ktaevs3Y49BeS1ayUy0O6kFK6HEJZY5Czr8xiZcnGkqaIOyrVYqnL4\n7fdy8zN9JkLQFn6Zsy5fAUCml9nqgFOCaqgaH/ny+CjZvgQjIDFh38TRRVqhoq41WaU3vuCX9aOC\n9slVNjvw3uIJftxtYKIWUT4JyU5JP1Q3NtKKENyf9rjIUvPRIj3BElpjrng91u8+Yui4qnFqSJ2j\nqjFGJMg0mm4CIEDaEheAPCshK5bI8nXSyA/SUuwH56hsyzNyghc4WOTGkaBMFlFmi0qFwpFWD2cN\nDsNi8IxboTi3z3f/MyL0FhcpSRZDaAZW76qSGIkVzu/Kg0G5iKV8qklXUQvT9+eRLzrimS6S2WCD\nIhoQVxlV1GJZXOBVyTOIzmexQnNodDvYikPDsyyG1qkL+QHS2NHON9k/CTmBxN+AbXeJ0k2bHJVR\ni4kUKN2jg79GBEZerXuAsHIfFkPSmSY3I1GwFXzzRvnxUcVd3GgfSdVFxxXLp/x1uLg54EA3pVUX\nAdmKjQMniMdfxP3MDyKD1izLBBM5jBLobAEZEqgCyUOPvpJUDLlQvYpbL76JtzxtOXvESxmnOxeb\nXjhbHcFWe5n7JxcwQXPvxiUXDnvQnIzbnF7tk4e/OZEgqPx+msUWUi8gohEq5COsiFioHJsqgThr\nrHzPrg0g9FpxQnLIdEnKNpN4QKfcbK6TsBod7aO/8FoGvdsR6iZsEuHyCVVYuUmrsaJgswiuJBsR\nCY0MTh0zGREdOcJC+C57Zgtpq8aN9ZpnHReWumy2ZZMXsHFMlkt6xRKpHBOtrVPJAhWKi4gtVWmR\niUKLFBsnzdaFd5qKzvojDE6kLJ9V4TqUQIwTeJeYnq7qANLEUYTWxkYlSBthhKYjD/LKZ/21Xj+9\nvK1P+27HngLyRlqx0AqMXEYGIWCp9Drf2U0athKFj9dbcTjTJh/4xkFj5ZsDtfQSRgnKIx0m6wlb\nUtETMfvGR3GL/qbRDkmubOs8We4BoZWv0pqs4WREkS6SPHGRs/vgp+0q74pjnFAoM0GFjQCGQV6I\nQuKv+Lp/zVhCaad6baQniNBAaD20w9xq3UksCtqT9SbBZydDVDXByowokU0ybmhAmQrBlDm0iiWy\nfAMRqj511CatwLoEJSoS61mjDpWw40hQxktI02cQ3C8u6xLZEtD0THCoRIrzywIt22iZ4gAjU+93\nr5mWiyECZRUWG5xCBukixFaoQiz76KiFCeXQep9sgFzpMdJpDAOUbVPGHRIx5nPJlzCQkn66xqiz\nRe/if+XAsM/iYAguZzE/QJI4TClp1UnIxN+AbavH2C1P7YuqRYFCmA4951mbMW0kArM5tXyWKidZ\nmJbVR6JkPSTaK0K3vLiDWJe0qi46Kug97MfPJJ+w2IqJRb2iqtBqyLu+5D2kiWP8pKe/yqRUiUNY\nyeZNdyHD0rKI1wDNnzj0g9zdewh35h3cuppxdmmRSpb00w0IK75Jto/3J7fxl286zOMXngKgG+Vs\nHAmtGfIWv/vgcTo15RYJIrQLSIpNZNVDqDHKBSCXEb3S0lcRxG1sePzCah/h6hqD/WSj24mrNuN4\nwEIgO53yIt3hGSatA5y/xTu9jFrEpBF2kje7J0lbYkSFC59B2YhYaEQAcj0Zkxy9iW4RXCtm4KU1\nobBCktnbeeRN78TktzS9e4gSVJmRmTbtC6eJP5Lxy2/6d9jqM/7vsTczkCq/gk3ippvnncOCv/xh\ni13SPHZPsByKisgmuHZGq4RIdxnH0+R3kky1cCsTJDFGVvSiA9x9zs/lwfoCK+sTBhf7092NdjF2\nBciFEN8ghHhCCHFMCPHPduOYV3yfMLeUAZe2GdsFKlU3479IbHNWNiPGLZ8sU2GXnsGZt/FNj34n\nx3/7MGdXbsKoJf+ayi+RhjelTDYSCgG3uC6LxQFGbY10lk7fD8zexnk6pf+yW5OVBtQn2QHkoOTc\nPv9eeWgeFemiSWqNTMhyC/+3/OibcKIkrbr09Knw/BwZrFT90MZztXUPkSjoPf3BRhd2WxtNoZFK\nFSYw8LWxRtoS6RJIIqKyRWJaZMU6VtbVcym9iQMbIRQkoZxeh77gw1hSxos4M2JQb66bZCy5IQ5N\nEvzFWx3FOJVo2cYJ5RsYyYSsnfpyZOd7rMgIIiOxwnpPIBrlFOWWB4/26DxatbCjAi00YrnbAHkS\nenEL10eILibOSOWYp+JX05eSd7/xPyG+uc3b43XSXNEtwLo1FvJDZLGm7EeYkOjcyDzbvvDm1zEy\n+0jLLZSeUMkMbBuBZMF4x0xRdslkghtOE8yVKkgXZ3ZQEgWbobeMDvtTlnGX9KLxfmo3IarbGWC4\n9UzJTRtvDt9zSaUcW+2M9C1vQm2FVsimTZlCbGM27ryzWdEsDn+VL/vcv+amhXVeefgYuIgqPUSZ\nHmCSrGOEBzUHHDR/ntuOfRsAmyGB3YkLRCwRtiQvWrTsiO//Fl8LIUgQwSaXFpvEZdsDeXAiORmx\nWBo/FqKskVZsWTRAfuKOb+bs5tfQzm9iHA/IJpuIcpOj1WO08jWGnQNcOHAHAOP2AiaJMJMJwUHq\nZRJRIsKmJMomgZH769ffGtK6+dZmpyllKlRNamTM1sIdnuGVNzU9lFwUobT/fhI9QRjB4rDPkQ1D\nvwUy9S2aTUhkyyTx7Tt0yd0nCg5twaNf6vjJb5C89y1HKOOKlk2h0yYroFV1ObR2rhkPcSKoVOg9\noxIECVpW7Bf7uOtscAyplN8++2Z+7l/dx7OPr7Pbcd1ALvyW6f8N+EbgtcBfEEK89nqPe+X3CmXI\nFiav/Faeit9MHoz6VCXLbpVhv8Ok5Rm5agZexsLEL6nPVf7UFvrHaZdL4ODk0tdy7xv+GX/uob/P\n7aNbAFhPxtwzPEcWup1lxSaHJk9z4B2Ghf4JssKDeu2Z1QuGrx2Nm25/0pZNUqsofVlzFPZ7rHuD\nZ7pDmp+jMzpHXA1RusJhaZ9d4ytvu5kVFwOG+PHfbYBcrZwg0gVCZCSxaDTywlivydsEWgkydDDM\n8nV0kFCMSlnMHdJFoASxCX7wIhQ9RAoT94h1n7Gss+4RAoETBtH3S8N+RyGSdrNEMirDyIR2FiOc\nACrv0IhAORWkFQGBlU42NDhLe3IRo1rY3DCJxix0FolVKGQJhSJSD3CqjY46VMKwFR+gryRWGlLV\nYzmVyFFdqbvKQnGAdlzirGish+da/ru6IPuM7DKJHhLpnCLdTxTyBgtBR51UXTqiDXnKwlZwO6iC\nZMH6FgM4FBUjWhgRYTe9Nn/6YJf2KqSmjaqG/mYLxEKzcDrnrgtfHcaFpowczsbobgcxyrEYYtth\n2PY2O9dxVD0Ppnc9U9IebeJ0h6Xl0ECsdRjkPrpiAysNAolREiFbpDpsDmJCPUFUEAkJQlOWLb7j\njYu8+Ujd3TBBRMHPXW6S6hTlBDJIKFZGLFSGkXCekYfHk7BJCIDSQ1K2kC5hEveJx0OqM7/FK5IH\nyPJVymQfrVHoNFgtoBOFnoxmtgDUaFk1QB7ZhEiUELaDW1/vkx29qZEQZVU1IG9lzLgdKk71Ei7U\nLFhAmnBjCI3Gbr/ouOu845kjAhVLqtJgglVXtUKV3WSdXrCLfvpwyqluxM++/W2kQrOvjBCtjFaV\nErmEpf4skEvKsAGFkTGICCsq7j6fk4VOnacOtTh8NrSxaO281+sLjd1g5O8AjjnnnnHOlcD/BL59\nF457WUzthw7Z7iBEh34oX3ZlxbJYx056DHpeOpGBwjujSEISa028CpzhwOoXSGzGwdFtbFZfRRW1\n2T+5i5vOfhkAZ+SALxs+23Q/S4tNVCvl8YUHEUAaSrZrG91fdZt803CEckHbbKXNZKYokDHIAOR1\n06Os6iLLIa979Ce559ivkRp/A2hvVmwpRT4pGElwpx9qimDUcIAyOdKlxLHEBiAvjUXaksgliDSG\n0FI0KbaoZNDCA5ArF0EkibU/Dxt07VIsgFAkus+wtk9hcbYF5LDiWeugFbMsp5tZ6KiFkwlNo0mh\nUS5GKoeyCsd2IB9vOTK9RVyNMLKFzS2TeMhiskCW1LJLuO7hp1Ft+sQYmXpfMyDpoKKqSc6N4xUW\n8mWywI7qYqDVAOR3ss7Q7CcyIyKTU2UHyQKQd5INlJ5Q6A77qsMIBIcvht7UUUG6ZFG2AFchBOHG\nksCmZ+SnjnRxwrPAqOg3N/GeM4jKkVWLYexWFAqsjZlkGa4SlNEY5Xr0O5DYmHZ+geqgn5pZ6BtU\nTVIW92cIZxm3D5HYAxxljTQQmY3/bT9CRiQu4etHY2KbokVFJisiIbFKo0lwF1ZwYXcf6VJkHIC8\n2EIi6RXTHIIVMS0NY6FBxY38sRw54mpI745T3HT8h7ht+Ps4kbPZuogajxlECXppvzcHiAgZ3C6d\ncgGdSMx41BAeF0nWOxoZgFzamIgSGaqIB4MR8cGlpvxemrKRGY2KGAUgV3oZaWc2rwgJ8zgQoHvO\nOm5dgWeOQpRIdGkxwVkVtYJrqX+m2YP202GF/cbDd7EsE+4uQbUz0qCPd8ZTIF9/3xc4dCpIKyr1\nNx2nufPkKiKMg7P7UtplKC67QYH8ZmDWIHk6PLYthBB/TQhxnxDivpWVFyj6hy2ZDo3eBrkl1o7a\nS+Cqin2RB9f15df4pwcgty5CBsljrG5mMR6Rhg0n7lzzHu7XPv7TODchWX09WpSc1hu8cf04Mh7j\nnKWVryGV4Ysj33tBmRzlcorWEgDnO/vYZ+2UaRw93Gjet5enENIgw+C6OFpD2YjEZkT5iKhapTO5\nSFoSLIsRwjlkAauqjdWiYeSi0h7ISUgi0UgrCtdIOaLVQpha4plQyByLDozc69ZEEVGwU9raKys8\nc0qqAaPQT8JajdRdpBuhL4QloVokiaYJyzJ0kouCzCXQKJMgIpBOYoQNyc5QXLElyMwmykxARJhC\nkUdDFtIF0tRPoPoGun9rqkWuihY2yryvGZCuhZTTfuCDZM07QwLTKkOflUHqz3s/OUO7D1MMUXqC\nsRFZFYD8YNezdNNmqfAruoXBSZy8QBnlJJFB2AIRGB5Jh5IYsb6FNCWbCz3KJDTfmmwhQ35k2Wyf\ntDIAuTOKceiK6dQE5AJrXUFiFJ38AnZ/sMWGJFo5UqiF/bTNKpuLt5PYFgvqIl8X+pvsE2MOVJKD\n6gBvqqzfKFqVRMISIdGxxqqUrRMXubD+LA5QLiUYo4hCi+K6GhLAqohW5SjQVE5jQ1n7bV2BAC7c\n/CCIC3TWTpLe+k4eO/gxVFEwTNqMj9xEu5zO80hM6FQ9qkRhxkNaZYywmtEf+yOUcYl0dd/6iEiU\nzXgfDSdE+xcYtw/j3IRYj5q/kaWMOx7Ik+LI9LylguZ4/vv6ikcdkYVnjgiSNArSStijthPG8uaz\nmEJi1bS+5Jte83pcFGNdRJQI4mB5zvJ1CNfMnFvjwPlwc5EJRvp6gZuOn+HCQTCyYG0xaYrS6rbU\nuxm7AeTiCo9d1iXGOffjzrm3O+fefvDgwRf2RsKhVcor+/87a/eWUFrCqtoz8mTo2V+wY4mQEDEi\nBuEvcEGPTBniUAJ8x8YbcKKC5CytoQfpjfYFVsd9brtwHA6d49n0P5EVGzgz4Bn9aPOhI4YUrUXA\n8YXO3ewzpmEa4k2v5thR/+W+yT6NVIYnkm/gto3XsTJebwAkmwyxHX++qXYok2NlRm8MURkxjFLc\nDJCrGckmklEjrSylEhmWd6QpLjSxisyECQVaFhiV0p0IIqcgjojC7uFR6AkdOw/IWdVnEpJgzlmU\nbYMqsWGThkgsET0HkDtRoWyMVBblJE5YnBMQ9NiNjZiWXiPS9ca6GXnSZyFdIAtVrEk5oIodt1yc\nAvkFuljZoi8l0kQYI1BiuonIVsvnM7bSO3j8ld9Bf/lOCjWmiPyKZGSWMa5F4iZEJsdaRRa01M63\n/1MiM6GwHXoByFuTVaruT/H5Oz6IshpHgQrLepktMDYKLk6QZoSJukxCR73WeLP5jhardHYII01F\noQTOKEYBSGKRY6IFzvQkmVF0yxXEkh8Tz7xhDDiqoYDFW2gXF+gvvtJ/5+o8+4IldJkJkY2pSsVr\nREZkEipZIq1BCUmZGIyK+ezaKt/3ie/ByhiBgqRe5frr2K6mCXgnY1rhvjUsh+jQt/3tRzwgfeT8\ns5hMcmTzMY6qQdMmeRRnrL7qtfS+1jeDc1iOxo/TKRco3QQ3HnL7SoS0FeqbvgQjC0SzJWBMRNHU\nI+STgqiXMuwcAXMRVwmyQEA29r2yGXudfLp3phUx2Dp56j/AUjBDTYHcYsKGKWknuFA2T6ELCb0M\nwsbs3/Sa1+GSBO1SFAVxSHIn5QBp/LxRpqAzqFcJMVb6z7Zw/iLnDzkqVVLFGZvdUE+S3ZiM/DRw\n68y/bwHO7vDc6wohXWM7GpzSOOMYBp3WaU2aSsapX+q2o6BZqbRxduioTe46JLJCmU0A9k0OU7XO\ncOFgxJ2n7gVgvX2O0bhPt79O/3CL4we9/3Mr0pRK48J9qtfW6HSBuGN4OrqdnosaRm6+5NX85J/w\ng/FL5VMQOU7Fb+GutTexOllrAKQ9GdIK1ra08oNCq5T9W5BUCS6LsbQap4UyUyBPZYytS8ilwRF2\nM4pjHFNGPpEVlfJA3isjJNLvfRi800nYXzG2no1lVb8pZCiUv+GIeKqLVklCJKdAXtRALutsvEbZ\nBKEcwimsqF0roax9Ycxrt95DFMqwnY3I4yELcZesF1rsVkNWDjhuXp0W4pxiqWHkkY2ptEGKqV1x\nreO/+wfa38nZm/4o64uvo4zGaFnhMJyvfJLv1m5FpHOsjWmFG2rr1e8gdgUlXTr5fpwoiasBZesE\n/c46kTVM4pK0Kij6ijfffQtEKZ0tDQxJdZe1RT/Ju6M1BA5pShbqbcuCBCJtxSQWCKuauoWOHlEm\nC6x0BfsmB8mqLYj8NT1/z4SoZam2LNz6pbRGK41evD86SxGcJF1RoImpKniV6hHbFKMqsJpISHSk\nMTJhXFXoYtzMCZuERLwLQF4GIFfON80KLVj7ZZ9c+krS5TA2VuN1bCxwJbxSn26asg2TNqs6I882\nsVh0tElPrZBVC+Smj5vkHNry2yNHt6Rolc/s7aqIKRBBW67yEqEnjDqHicsLWC1Y6B9HyxGnbv46\n/xyh6RbTvkKVzPxNClB66jbqtwWrC5ClKboymMg/J+v4McCWZ+TpQg+BIFUtDrT2IVotSttG6i0k\n/juOqwFRNQXypc2AN1Hmb5KDm0k2t5h0LYXKiW3KxX2Bke8+ju8KkH8OuEcIcacQIgG+A/jNXTju\nZSGka4ofRmdC4kcqHAJXaYyKWG950F1M/ASv4u5M8UmHCS1G+QWE6eMIybfWSVZ6EUdWjnG08wWe\n3v8A+0NjqP5y2vS4PhsZFG1k5N97aVlRtXscfusWg/gAWh0iCUtpG+XoMOBjJ3BRjBMRrarLer7R\nNAdKqiFmYRJ+h7iaYFTK4X6GcoqoE2Flp9EFpS29Vot3hOjAyBNTQWDkNk6wtL1v2xQMmaDjCqNS\nOmVg6rEkcoGJF/5najyQt4o+TmoPOpH/8DIuG6eCjRVSzDDysNtKFDRwROmTncoinWyAvFV9kfe+\n5r/z7V/xcTruYgPkAJNoyMLnfpqFTk6aryP0SVYXBMlM18GzoouJEgZSktgYV01QauomWe2u47CM\n5X72rz1MW18kT9ZAePnibOkLwfapIOuYmG6xD5k5kiwijqBMD9OeLGGjLQRgIhAoIl2x3i0QtmT9\nyS5LS0sc3rfIvr4F4YF8s+evw9LQM0ZlCtpBGz+/4DseKlsxUV7eWgnNl7qTPmXcZZLt5x3H/09G\n/ZuaFVUiSuKOptqqcMt3k21N5YpD6jR5WBA7pzAuAQsL6SJtnWCUDkCuMKry2w6WhljTALlJAysN\nuzbVjLztNrBCNUVsg3JAjnd5RWXYfLrXx0W+8VTH2QbIZW+B06OIfuTYbF1ExOfJ4jGZ7lG6CRQV\n7SLGSM14eBajptKKJCJy057zttKMt4boeJH26BzGJkhnGfe+wFh58D6bbTQ6vJHejVRLjlGVY8N8\nPXOTZ9pZllCVFhuk13Y7aOSbz2IKRby0yJ2Ld3Lbwi0IIZC9HrnrEZtVhKgZ+bBJyCtTsNQPXSV7\n+7EypjO2CGfJO5ZKFkQmRXczpCnoP3w/ux3XDeTOOQ38beB3gceAX3HOPXK9x71SCOGwou4073+o\nlqKUGU4bBkaw3n0GnGVfXFcLTu/URbKAJWNzeIJKOWy8CcCgdZLVlkTg+KrOT3Bq+VEOhobyW4ux\n7yqXwVoCC/oeZJAQOge6jFmme1PBJN3PujrCQugJUYhxs+v8xHUwYR/ETHfolxtkAcjjasipZT8Z\nOwUk5Ygq6XFgEJbpPQ/KTbJzhpEn4wITpzhniU2BC4zXRAlWtjDCT/ORG2Mjg1UJrZBwiRLl3QFA\nXNUrgn0ol5NYQ2Q10pSMlU9+qVQj8BWmEoGRC033sUkaJnjdUjRIK0LabYzcSMvZ3klksYVREZGZ\nFtnk8ZCFjWdpnfsQX/GZ76YQJ7jYEyhboYIEwy3v4mn5IH0pSa0iKjdRydSTO2hZdLqFcIZ7jr2b\nrxt/D0/e9aN+uMgcS0xvUdBKTbB7Jr6AaNlPgyQWVEaRDRcx0oOxltaDi604se8JCk6ydbyFLiNs\nFZEVYNWQVHcYtrsIW7E02QKcz3eEBOHT+x7y11FPyJUgcoIzwUvd3VoDIUnFa70DRadQ93enJO4Y\nyvUJ1blztMLGy2k7oie3GNWbQBBhXEwEbJg2Pe1zFFhDJBRaVdgoxVaW2Pj2wTAF8o7zxKVbLfnv\nUuY4oRChV06/6LN5PlQGf/B9kGXoqITUes9+AZ3QAuLmWw9y77mKDSV5/2t+jMXF36PXCjJa0kOW\n1lc/yor1wRm0rJB4GVQ4hSymCc3IOS6c9oC5vHUOS9v3s1980I81CefS6c3eRQMKkTWrFlEV5Af8\ndb54mx+nrSzzGnloydFRQLbYMPJoaZF/8LZ/wN95sy+pTxc6aJchlMPKHtb5GocsnwK577VvmXT3\ng5As56G+oOO868mkxGkHK3KOV9NE6W7FrvjInXPvd8690jl3t3Pu3+/GMa8UQkz17zqiVkwhPJCv\nl44zyw/whof/LT3nv9z1panqM257HU2aIaVyiFDxuNk5xblOSHyMCpSIODgahL9VtGWHX/9yySde\nJ+gOb/OSQRzRPbIfQ0rhuhTZQR6M30wnVAaO3IAqJKqeMnc0zZtaVY9+udm4JeJqyMP7wlJ5pGjl\n6+TpMvtGQbtdiHC0GoYibYUJ3ezU+jlMnCJcgcwLTNCLtUoxwgM5wDACpwpMlJDoWqdTKALdCr01\nsmo/MTmRdqSVQdmSsfKMXLTCzi3BhFaIhcaCOQ5AfiLsVeoLKGKkMggUFuOBXHnm6PIBJoovYeQj\n9t/yDhRhq7ie4HzoX61CdW2VrrEmTtNXkpaLiIrNxnVRKahiAYuf4nXxB2lPVuhlGyyHm5sNlZVH\n715CJimRzolsylJ+kNa+YKtrScayRzrsodUxf9wIcIrIaB645UPcf/cjOCMZPX6BauTHjIu3SPUC\nebZEUg7obZXEPdcUhEmZ89jhT/LYrT9LO19lHAsiJ1kbT5CRpbvqJ/ZC6bVvjMA5f+P3jNygNycU\nx56mPQmtCJb8tRkGIDcuxpAgEJwcZxwpFbct3Q22QgmJlr4Pj9OQzDDyeiu7NIydhWBbHcVtv+l2\nsPS5X3sfK0+E3NOpY9ig93Z6oe/Nhmx2NXrl3Tfx2LpjQyqG6QZ3J2PaWUheRovh+4gpopL18QWM\nnNoJFQo7sUhn/S5bwMoFf+BD6+ewrVvIE3CdL4KwVB3FSE3bLqxJgSZuSvhlOaHoWv79/0vy6Ne8\nHoGg02r5fulhL9bMldA+AJunMIVELS/xVbd+FV9921eHz+ivUZW0qZIuMhTStYoayEtE+DnO/Odb\nDgVGtmOpVEHLdWixgM5yll77RnY79lRlJ9JOGXmIrB0xIcUZy1rhsEoTmxVk5SfwKPi8AUZdD+SR\nHqIVRNEaVmjW2hc53fZflpuURCLjUGgKtG5OcVAt8IF3CO57laC3uYyMHGqhQ+eIbyM6MvvQrYP8\nSvztlNIbdgZ2CysMQgk+b17PeMlXt2VVl8KOg7TiiKsxH7vJD6ibx4osX8OqhF7pj5MuVlgSJFNG\nroMWHZnI93VxJSIv0KHwp5IJWmTYAGKDBBATTJSShAZRWSdqGDkGtIRWteT7lBtLS/veLVXYizO0\n8/baLzARi03vmVoj/62nfhXwJc3KKWTkECHZaSsoE8ApKAaUajuQ5/GQW5JlojhUt3ZhvRtkA+vB\nvYwmDFljICVtK1H5BirYFUchgZTsfzdf/rbTyHsO0zk4Zl/oL26DBHP0VQcRaeqlFXzv887+IE+1\nY983JdLk0ie+CwUSibAa6eDCIT+eqi1NNQptXduPEdmElNeTVANU4Uj2y2blpNQmVlriRX+9tILY\nSpYSg0ot2dgTikOjAORWgsuwWL4sH5F0NTjH4MMfJss3UJQsRD6xu16Gjplh+z6AJ7YShItY7rW9\ntCIVlSy93KCFB/LgoMiDc0ZFmigRHHK+hfCKWvSl/3m4rh+7H7u4SCwL7vyFn+HY3/5GAO5aCAUv\nWzELuf++3vDqWxmRsaEksZXcnFR02qGYLPaJZKNSJknFer7ebEY9vueV/sY/ssQHFlDSEDnHxooB\nKrrjNYr1iDyBRE5Qh9bYOBgzFNNV2UhqQDQFVaKYYCJ46G7JO+768/zHr/qPJGHTEy2CpbHKob0f\nN+ljSoFanlowAXqLfn5WcYcy7hEFR9XRc5/msP0IIuTMpC3JQ05pXwBy1/ZAnroWQixwyI24a/Eu\ndjv2FJBfiZG3egljG+OMY2ViccpgYpCh01kRT/si1PtEpiZHK+gtfoTNI7/CZpyw1fMD0o0NipRb\nRluo1JCLCS0BN2vNW/OCQ+WW90cvLtA55JnoyB1EtZfp55rIhGrCap1YxSSdiKFdZmXxDQAkNkXZ\niKzqkYiKohNxOhR6HNoYk4US58TdAUC0MMaaGMtUI8/D5snOZWiVIm2JyCu0DL2PtfE9t13orhgp\nhBthVEoUCkba7RhVA3np2OxCp+oSywqpLZkxzYYEAKoXLH/SIRHkLJIWm0hbocM1NtpfcysrYhsF\nCUpihQkbGbspkF/CyIuoZH+6jAqrmPWeaDYi0NJPnFLlDN1F+lLSRRKVW6jAyMt2cIf8kX9C/J0/\nxav+xZ8nbln2ByAfJf7vR+5eRGRp45gB6B0ICeNe6LNy2wVcmKxlJBBOgq2QCAbtHmppgSrPGA7C\nJhTLX8DIksi1SIJ+nByIGzsoyi+z94UEplYQO/i6e5aIMtvkAdJgGXVWoV2GRvB6FxN3Agi+5z10\nv/LLefvSe3lN68Nh7IUdmoINEWClbOOIabeiRiPXssSqBKnZppGvBOmHSJK2Y7Kwq84gbHYyKXq8\n9fSfgLURprNApsa0N9/P/ePfZDld5s5WHxNJitbbOTKMsFJwy+09WolgVca0jOJoSxOakjIK16CI\nMybJhI2y76tTAf22P+634Bs42q+5HSmM32tzQ0B8HoEjf+o4kwRa1rF104iTByJGcmqSGyvjx1zQ\nyGUxJnSWYCE6zJ+8408SJ/6Bqu7mmQ+ZbLWDh1yg9u1nNhZqII+6VEmPVjAHdMfnOHr6I6jlHkVE\nID7+fWNTImJJ0s6oZEFiMpzs0BJDRnnJbsceA/IpI5cdP4F7vYSxTcHBxdxSKYuJBTJsDltG0wE+\nyTwjPxwl7Osd5mv2j9D7f4++jBmG3bNt4VCkHBmNidqGUhe0cHz/xVX+79U1bharRC1LcvNROuEL\nHsW302slDPIKGYDy0a1HeNXyq0h7CW0nGLhpyXdWdT2Q6xH5bQdxQlBEsDRyTWMuk9yOwyLaAyba\noYUBfNuAPLgdKpehoxRpC2RRkscFDkMZddBRCxna5K4lEUpMMCpD6dBZsJcShyZiWks2OoKWyYiV\nRmrbSCsApcyJwlJaSod0MHELJOUApXNcqKC0YfNKIysiGyEiB6jG7VIkQVoph5QyRpkCF5IdRmWI\ntEMU2oGuLNJsDZZHQVpROaUbMJaSBSeIyy2EgkLFmK5nV4eXDkPcgtCOd19oOWqymCRT7Lupi0zS\nph0CwNJBf/6dXhhbt51FhIKUIiIAuUY6iZKO6NbbePjh3+fnt1YpI+gkOcN9vpSi9r8n+9pIVyef\n/WP71EL4HII/ftdBvuLOHioz2xK6AM5FlC6lEkDaa4Ac5zj4t/82b3/bhNu3fsGfXwDi0k0LtIa2\ni3YJUZAcIqGoZOHb1mpBrB1VAPJH+96DZVs90nZMHnaCH4YbYNW5jXc8+80M3a1USY9MDeHcgzyl\n+9yzeBcJFa1b91Pk+3jDccvFV+zjOz78Fzl658dZVTFLKFp2TDtUqrrAWIsko1QF63rcMPLha94O\ngNCG9uvvQSmLdIJhP0FkZzgW9nSZJJA6x1mzyLDQDINV0GHJhcUDeeznTzFBR3VCODh0glOn3jB8\n8Gu/zImfeJLxSkiQHphaGQH21VswRp6Rd8YDqDulnttCLna5sBQ6OdZJW1sR9yLa2QKVKlAmwdEi\nFWOOndr9vuR7DMhNw8jbb8l5+zfdwWP8OJ+O/Re1UTlKYXGxbIBcqymQF4lfMrWrnJuXb+fITW9F\nWcWYgnGrxAgwuUTamOVhRdw2lLYkw/LasuJWbbhFrHDTl21w9F/9UzpL/osfdd/IopD0Jxqp/Zf+\n4PoDvPXwW2kHIB/aqZ+4VXVpVT2i8SbR3X6ZVcTQGQlfaACU2WHyaIyLtjibDxFmg1boXV0F21Tl\nvLUy1iXd1TFrSxKrxmzEN6OjVsN41xOFEjlGZijrz6+3mKGExgiLti02er5ZVBRZZGVIKtcw8jwe\nUb36Dro3T5CxQLgEQ0pcDULfl5BwM+Gay8pLK8p3x5MByBtGXuUUMkbgMMKXqIuoB3GbpKeJv+8f\n8enXeKtYvphwaukRnjj4WZyYMq8FJ1DBNTCMW+huWGmEIiCCVllLK8PXbPJNf/ONSClIbr+Nqjct\nf1g+5FnoHbc43vG5f0+rN4GwW1MhBfXbCgRKWk61J8gLa7x5kFJ1LF8/GVMd8dq1C7mZeLnbNKQK\nizQWZb3tHLztpkViWxJlFmU1ot7BGW/H1C5B4zyQtw1Eis4f/aO03vxmeM23UpdqjEUN5NOe6kPX\nRbuUOOQFlqIWQzvACUUSpJUy8ePg6fUKmTjkwj7S9lS2HIVEdu3TrqJFqqhLJgfY/lmOxRH3ZN5I\n0L7jJiYPP8wt5yoevjvi/Og8KjvJhlQcVhGUQ1TWhtQgxbQPfaVy1m0xBfJO2HLPatpveg2RcggX\nM5mkxPEFPvuqsBVjIvhY99t5xhxmkFeMAoyVqsBJ6ZPxKsYKjShKqji06gjOlqhm5HT8ZjGf/pT/\nzOdCb/8D2+tclgOQF2qBKu6QFQPio/6ukkw0LHa5uCTCfJn616O2oZ0tUakCqRXOJSRiTKtYY7dj\njwH51DLUGR3npk/8d04WH+ehoJMWQvk7ciKRIaNs651hZOFtiM6Smdxv1Px1/zcfcl+FEwaEYJJF\n3kdqLL2hI15uU+LIqqkEcLNYRSUOdeAmoliRdiKO5V9O94MXuCkHVyUYoalcyVsPvZXOQkLbwmim\nfDjTXTplhzjfZOnVXnLRsSQZC5Qtp5qwGpDbDVZHfQ5ufJA/G/9D//rAPrXLMDIlK3KkdTxyZ4RT\nI07aw2jVIgnyQT8WxGKCFgky3FA6QUZwSqNpsdX1IBNFDuEc7WKarMujEergQW79oxsoBYRlfGLG\nU+eJs8TBs6uV9oxc+c0Ponrn9sSBixA6Jw/FGEbk5PGYljwMiT9u9413+a6UseCRf/UOPv66R/nI\nK97li4pCLABRkHI+c+S1bLze3xA7Iak8BXIPSLfd0eXmV3opbPkv/SU+/9feHt5fs7Q/lNa3Erqj\ns6Qu8oxcCEolkOF9pRPk4hyf5RkODyT3DGIOZSUHjKV164T11jkcJwCIl3qI0K9m3PPn1Q4yiFaQ\nOQG6IMrCJg7B/idEhXUxlfNtlEW2gJBw67/7Lo7+++/xn+2eP9HsOTkODLC0U0Y+dh2/L6vz383B\nqEsZZLfIpMQaitDdMrcRB75kyKGve922HiBFuNT1BiB5tkwp22Siz5nROSZSck947/Su25v9aj90\n1IPU0D3LMJYclgKKAaQLJL3pxt5OZlhVsY5rkp2bW36FmLZz4ttvR0UwNgcBQRKtcO8rwwotgTK7\nmWGhGeQa6xIm0ZBK5WRxihB+i75ajtQ1kIfE8Cwjl7ZsdhkfXaiBfFolCtNk50AeASFJqiHxbVMT\nhVvscHEpFOuFm4W0FXFWNUCOFZSFIpFjXtmZsNuxp4AcLC4AQOvYswx/833ElWMzaGRaSnIBJBFy\n5MFQhCxd3goTxY6JtUXEMXT2U0bTZdQ4TdCF5PBoi6wQxK98GxWCLN8iD4P27iSUqYcqvs5iytqZ\nEcJBzwpMGTcM4y2H30JvKaXtBLmdSivtqkev9L3CD73+7UQiQqcRImwKnauwEQJjPnDyt3BFxT5Z\nksWetR0+sgRAaT2QK1NglOCJ2yPoJhw8eLPfiKEssQLyyBCL3O9RqHpoUREH76xTGiM7jIKIGUwM\ntAuaZF0eD8kCQEphsca/f0tOmn4yypSktQlGVSgXISKBExIV+uHkgZELUzAJ32MlJ+TRkLY8BIFN\n124AgLZ1dILf+s7eK5vHl5wlMSN01OG/vvnPsvrNX+WfH2QeQuuEw+Em8tojU5YlhCAO7LOfrtGO\ng1YaPnxmJZEBESm/zZ0NrQecYMueYGVBEFWW4vyIKMgeB5YW+ZU3/wcq9aC/HvuWkLF/3bl0SCfu\nkNoZIMeBzpsksmaEFYZ2soK1CdrGWCmacdb9I+8gPhTGatqDV3wtAJMrMPLcdXAoIvx4ORD3mgKv\nxCTefhilGKGxROy7dUh22xGS9iyQ+3Ov2w4U6T4KlzGWm3whuKbuCave9JX3ADBcSDhxyL9uUPW5\noBzLxvjOgmmXrBvjZIdKCiQpRN6iWAN5PwD5oddsIJIOcQRbxidfW2qdc/sF5dtey9NHBa0oY5Br\nhrkmi1qM4z6lyum06uK/FoQCuSqSKAfhnk409i2vC9drxjjQuJDU/qllGTyD18Jxv/U3/7gckNx6\nW/N3vdDmqZsEwumm46q0FVEyppMuNTZkrSG55bXQ236j2I3YU0AunMYGbUoE73M3h1HIWte7iok0\napoZSRn0rbYf1MoMUcZ5IAda8XQClK0WppDcvhlai77mHRRSEFcTzkg/oG4Rq5D0IEg83eWsaeaV\nON91zciKOxfvZF+2j85CQoQA2SYJXQ8PDm9FEtMen6fzyldzx+IduHTK2DdDqfnBjQFbG+dYMDEH\nhG6A4RV3HMJJ+Ih5O4Vso0zB6dvabIoJqhvjbARC0i5zz0akoAgrmSJd8i03o8A+RIGOu4gsFPWE\nXifdCVNpJRqRxmF3c2lxLkOJkmXWmoSeMgWtOneqNNLGuFYHJ+Q2Ru6cQtqCYXj/cbLFIF2np440\njLxVTKs1287SCTPwNQfv4lCwkC5bS6JHVCEHcrTjE9kHWmESBkZ+d6X54Xd8N191y1cxG0nod9HP\nVolrh0NtxTOKyACxYiIkKrQhxkkqN2IltCNx2nrZAzi06N939ZBFJYZoeZnOopcKXvPxJ/njD1qS\noNF6Rg6Ykii0Z8jVKuud46RRjnEJ2sUYSQPkJNMCLADe9B04lbAaSsZnNfK/8pXe3hY5fx0Pxj10\nkFkil5BqQRVl3k2BQeIgbvl+8iEuZeSTbD+lSfiNRcc/P+iTga/Y8LbJ9NW+0OrM6w+CEETh5uKA\n5fq7THt0Oi2EaPP//bthziWGiZRTaWUYzlFUkHSI0hQd3DitsLvXk//6O/jNL5N04haDvGJYam5e\nXGSrtcIo2aTX9tdBR20IfXF0opBOUFkLpiJ+3//Pfya32Kw6O299dfPZ1fIyl0alBCX+O06qAdHh\nQ+gofJ8LHT75WsHGPdMkqbQVcUvzxsW7uTO08QWIX//1cPBVlx3/emNPAbnRFS5sIabDjiLdHCah\nQjNYXlFpgt3aRJrS7y+pBCYLVjA9RGrbTNreDJBXrS6mkNwSNp+N73wtJYLEOTo3+Ysv9aQBCYAv\n+/a7+Ja/5SdOgiAyvhfxWw+9FfCuGoBEtWlNVrEYjgy8DNBTE6J9+/g3X/5vOLzP3+G1hPNLnpEf\n3tjk//plw0HRQymHjCwIUEuLiEjypL0TKxOUKXjsDoV1FtWC4cADfiufUIZr8gfWT7YiXfZ+88BC\nYzehijskoTozXvLX49DWjLQSj8iiDGSMDDfNQ9kxbJIgQtJQmYKsClY46f3jJu3hpCIOOvU4MPLI\nllw4uMzf/aq/xwde824+8opfZCGaAnk82UQFFt6uCjqhpenh9mFuX7gdgH0YUjuiCjmQdxz5Mt77\n7e/ljsU7/AcOyU6Ar77960jUdEUENKA1bm8igsZf39wTJzyQR8rvIFQXrAaJxRyeTtg6EbnQ9pP/\nsTc67v6Wi4j2Au2eP7c3HN/i1ccLUjML5BZ0TtQO+2DGm9y6/7+TyBLjUrSNcRII3TUvA/LXfjvi\nHz9NET5nZafjuBPAPwp+54PJQgOWysQsGIWOfFOtVmDXxO1t0ko7sPMivP+o4zXhPB5yyBjemue0\nV30vlejIbRz93u/l8W99PQBfectXNsdZCm2gSXv0em0S3UIEciWCJFoz8knYqUqJCuIWKqwSBYY0\ntGK4GAqi2klGoS3Owa1Ly3z07l/iw/f8HMuddrjGWdPgrIwkkQNtHKwda3YKqlwLaSuSu++m+2Vf\nAvgd3WSyfawAmEjQC7JJUg5QC4uUndB5dLENQpAk0xyOtJqobTi8eDt/5S3/e/P4i9FnBfYYkOuq\nbJKdJiy/OzmIMOm1Cv0ssiRsbhB6kmQKkYYMvh4itWkmbS8NmqoTVO1FTKHY3w+2sjteRSkFiYMj\nt70SghxANm0sdPC2Hre9bj9CCWJH6DEi+MY7vc+2/f+09+ZBsl31nefnLHfLrfZXb18kvSfpaV8A\nCQkJJBkQNhbIamGWDswy2KaxjWc8M/YQZujxtHvstntiPLi7DdELdoCx3bYDwh5HG3u6bccM3T0Y\nMCBkkECs2pe3VVZu957545y7ZFZmVdZ7WUs+3W+EQvVuZd08efLe7/ne7285KZHLAK97jo5cZWHF\n5ojP7bc353VL11GtW/W26sMZtxHCtw5EXPF98J89i9QGqeHgz72J2QcfRPsSDxBCo+IOf3vQVWlG\nMm3lTGXlHC03Jx33VbeCWRJWs13BvfgcXV0l9Gbtv/dbxXvw2YK1os8R6ACUj3I57Hsrj9DUgd1r\nFOsPhpkidwtr1MAIhec8yKZn8N331yLgkblDdLShpVeZ8ZYya0WsPk8lSRejs1RNTuSHXYviuaRH\nlKzSUS4v3lNcMlvIz/Wr+U4kgyQIBIHPw3s+y+N7/j47linyRKETQCuaQuBlRO4yFQ7n75Mq8kpo\niTyUyua2+zX8qiu+6pwl7Ek8Z531FISJtVbCvQFzb3kLT112Fze2FL5cpWtC4kT3WSsEaz8DYYOl\nGUuKfdaKa9Sl3cYhlshdWwfjU48lsQ7oqS6Rsx/wK1mwU2nJsWX7fi1H5Gm75JZe4aNPPM3Hnnga\nXrBtjYnmmL3/jZj99qnoZXtfxl7XlXAu7XXi14gqPmFcwY9d/rbjy3SR6TTdrkGiC14VXXFFcfJ5\ntNvs4pmmbVFQ8/MnkMNzddqqTdtrsthwG37oSnZtdj2FNtCNE3jqIbTIO2YKbZh5/esJrrKxKhUN\n6wGY96QBm5mkGnW6ri9Q2/0/1EUit8kSVBb6uh360eQ7H8K0EXmvm/VaiVNFvmqsegK0K9f2Ipcq\nl5ayhxoR2Un2OucQ3Ti7aWdC+8ULU6VTbRB3JAvPSFoeqOVlukLiGwPVxVyJBzmRp9CBskrOSGaj\nfbxs38sAiBr546rXa9IVq0gkXvcc8y+/MfudiOzF0AzztqvxoZsA26JXOOulfvst6IUFglATGIEQ\nirMHq3zFdVr0q4WLpt3MFHlK5F2/AWaVjrOoVHyKnlch0PMkGPzDVnkdetZkrVhbukmoQtA+0j39\nLFUe5TQeuBQ7FbczIm87Iu+Fsxgh8XtpLrchcO/bdlvSCRNBb47Q88B3ZLTyLJEj78rqaaqO1Jer\ny1wxfwUVBItxl8g0swKM0Bu4QYSw35fyQa9VWJEO+atLP8mZhafyP/HSHGCryI1WrEqJjtMb1I79\nwJ5LUTP2WkgVeSV0GVFpwVpQ58R9N3N44Sm+P/s8YU/gu70wuwqCJIZeBxkG7P3gL6Jm5zDSI2TF\nBrETZfeoXbgUantB5wU/RfzTB2wb5qK10uq47AynPEOvgu+nTakCal23GYjqEolckad9spUnOb7P\nbWXn9S8gbd1kKY6hcQAwNujqnu7SQPOVC1dyYs51aExVRdAgqGq8OCBwVc3S2XjKtbyI205s0QW/\ngnLZJXX1TBakf6ppv69GkC9ch+er4GJQ++fSrJgo63zY9QQKQydO4KmvZGm3AOybY/EnfpzwWnuv\nqRFEKwJ33CR43Say0SCp2zGs1O3YIi8vTKrdcpKg0bNEHhTuyVKRQ0dGWelt4gp+qi1wG90zW3Ee\nW+g6/6W7tAQK11oCv7tiidEp8rnQZWuYBp36LABL31Z8/YCgI2I6gIexJbzp43q4lsi9QOEbm3yk\nvXxaU2sFwOs26bkNlsPW08y97W3Z76Rrbr/qw3OV79ORLdSle/EOHXK/dx8gcsov0riqeZ659Qix\n25qt6HPqeDWzmzrkF5NImhmRC7d9nZfsYVWAt7yMUZLFM6Bcf5eWd85aE8pHyRhPvkDkn+KJmWVa\nfrogtAm7gO9llaedaM42XkqJ3EsI3ULcxkdJge4eJm5eiq8lpBknzWeJUmul+Ty1grXywIkH+BP/\nCmp0qLLKqts+L9RDLuVoNrNrBhE4jz4sEKRwZBfEVoUnWtEVNu8ackV+dOYo+sB+EKCjGHRIJW1h\n665P/BqLVx3h9f/kzfj1Bo0kHFDkMfRaWazijhNLNKoVAs7RNSFJojBKwM3vhJ/+QpbiOYjL9lqi\nLSrytlO2+oWH7YHaHmrOckiUR9RKiGWI8BN+8jYb+7EeuWtT4Uku3++yS1T/AmLUWapBA+bdU0k0\nl41tubJMpCMun7uc47M2ADrnbDWCWrZQ1Dqz9n1Cl9et0l2+7P+V6IEOUe4+qquniZMAJXRmrdQL\nRH5ovoJJfEyiWZxxKZ46yloOd3yFZ+B0s2sVOTmRp++hlvajKwmqmt8/RagwXRybCAyq0UC4xfzx\n0N7TVZ0T+aG33GYfCCsLWTwGtmZTCZgyIv/+Tf8DZ6R71GzbFJ7ZtnsMBhqhVem+axSfBuL8UKHd\nI1PYcUTuFPlcxZ4vEDN0G1ZVBSuSrx+wHd8SwViK3A8VHgJt+ok87a8NNl2u0nLNvGa6qFqudmRo\nb5hVH1b9s3x28bMsHGlQu+MO+/u0Q5sjcj9Q7A+dgiys+FE1Xzh0L/fIu0l+Aal4lbbrCKlcv5Sk\nNU9LGLTnEbuK1VQptfSKVeTK56WXfplLZv6IWGj+5PYH+YLrG5EqcuNpuq7veCewijzo9kBAU5Mr\ncuMxG3n4p95E8/H7CZTMSbf5PJFT4ZWVFzKbZbmyjJaaJd/mYNfEKudMaBcENeRSDmdsYHoIQkdQ\ngcrz+1NFrmP7X+wKSdKx4Ij8SOMI/oGD6JmqjXn7VSKX5hrJlMjzBeTk/uvZIxvZgtBTEMUx9NoZ\nkb/95Ue5dO8cAWdJ0JjYAyVsUN3PSWsQyi1gxfTDVtMuwPrMY9ZjP/oKZtx1Hksfv5mQqADhJ/yD\na1w5eiHYqTzJZfvyazNczTsuVsUZq8Zr1kZJr0eA+4/fz6ff8Glqfo1XHnol14TL7O+lRF4ndAtF\nrT3n3tItnO46uwFr1ajAt0FT99ka6mlWCanoematzAT5512o+QgTQBJQc0SZKD8nck+iMTy30sE8\n9RDPkn83umCZ7HuVZunO5aHznGY5KZfvrxoNfBcU/aZ0DccKilx3XK54qcjXotmJsx4KtO0quDep\nE7hNVxu+K4+uWqJNPV4vUPguqBR0zvUp8kV3gVfULPFMnnb0tQMi21vTEvlSTuRDFHkQaqfIRVYC\nDKCUzCrLvG6T/c/bL/iZS/sfWVNrxW38TkKNE8t1anemRO5eX5nPPlPkFJ5fyHip1nNi0r0WbjN2\npM6Pe90mHQwIiWrZz7jaqrIqDJ4SxHvtPEhnkax6ZzOPfH/jCRaDR+ihWekk+IHrjhi3CTsGPC8j\n8nY454g8RgYeXQFR5pH7zFV9zrlt5nxdJPLnMmul2jlHI0nQQrEQuSCjF6KTFjVWOW2i4Woc7Pc1\nzFsmJ/BQFRW5i2ck1lpJsxIqbiwpkR9rHGPxp97H/p94nRtPNStEitKgauF9RRSRtFqoGBIBiRQE\ncQ96q/2WifIIXUGRcOmbG0G6J7E+Re6qM7Vow+X3gg6YcfdErHz0aoyRgQ02dl0hUiHYqT1JGOSE\nU1vJtxdoyNNQ35en0BWI3FNe5o1fv+d6PnHlj2dPVgR128uGnMj9jMjt/KZZPerV/7ObjtRaeZpV\nE1D36rzghMdMmJNxPdAoQoQJ0Tq/97yeq0z2JJ4xtM48hzjzff48uQnlVLlfINnaK+8huuWuofMc\nuKZ6yu0KJBsNor0HaHnw9fhJAKqpxwvozrPWdvKreIW59LdgdyBIy5CmBM1OL9vVw3dBlNmOR6UX\nAV0CVwod1mc5B1nfbi/U+PMCY3rMnHkcer2MyJfc7iA1PU9vLifyRw4ITrt9OX2DvXg3UOShEOik\n/+IAFyjpxXi9FRrN0zwHiKX+RzgZusIlH6Qx/Pa77qFyZIHk4C3M3Hcf1aPfhac+n9k7nq/orFoS\nDEKPdM+7Wi0Clz9sFblTlVF+4QedJp2kAzokXDkNi5AkilUd4ymJ2bsEfI2l9jd57J7neeHcU5b4\nlA9xB0/EdNGstHt4QQh0UXEb3QXjKTrpJsvBnAt2JsjQoyd6RCr3yOcqHo896za30DILdtJ8jkrV\nBTuN4S1nzvKyu/4JOg026widtPFZ5VQcEAz64ylueS+4dqKDSK2VQBcVuVOkPeOI3B6vmrREXqGF\nx/7aftQJBc0r4FuAX6Xm1XjDZW/g5d/6kn1t4UlAhiFJa9VuGq5sa1Ydd2D1lL2uUigPL9u8EITa\nmMiFEEg1oMiLRH7yPgAWXDC9Hcwju2BEiPTPQlrs5lUIvNwjV4XFMWifsht4C4/5pAWN/UMV+RoE\nhachv07gxFS6L2gQuhRgAQmGtis0U5fcmo0DLJE32ctM4PO4W3fmKgUiDz08GdIzBllY/NICtban\n8DHUz9gsm/+YXM/twmYH+WHhPnz9/zHyo0RVjxVAueCwajRY+LF38C7xRzx/7jtoYwgyyyZBrj4H\nlQUQol+Rb5G1MmVEHudE3rU310xbEsZ14AzaNVcKa3OWyAuKvDrv8Zj572mctcdS9bW3Pocxgtlg\nCQJ7cZ6e1TRDciJ/+fth5kBWZDLcI9cEdr95fH+AWEIJzRjdbRI4lR8t9gfgUg889gz1JKFStYuG\n9H32/8r/Bv/pV6D1JXDpl7pwcYSFi7FerwDP2b7hSYeuu7BrlcKjcrtJO26T6JDquZw4WtKglcDs\ns8UzMhAkJ16ALzgvWXkQd/Dp0UJzrt3Dn7PjSK2VJFDEqSIP5m1PaxMjQ48uLaqueKuNx2zFJ3a2\nha+ktRmEtIq8Mku6z8veOGbvgZcXJjvE655FCMPzvWC0Ij/xmuHHGWGtOI/c64GOTfZ0VHMFTcJo\n9lUPotLGban69qsIIfil234Jnny3PdanyENMq43uGWurGKyt0joFe07mg5Iensir/sSozzUApRXd\ndpHInbXia7jUKsyFuVme8L7OY0fvpR3MYERk6xIKRO4XFHmRyFWoWAleQJkqS3FiiTxdgCpjEnlQ\nI3D7xtU69m8yIgeQhrZxRO4IPLUoP2lewmfjwyyGX89ONxfmTyC1UHNAv4Jmt9W/AHVTa0XgmYQ9\nTdua+KvJUV4hemDyMWyEat23RC574HmIMGQxOMz39mri7lnqBryefdrWootIiRxn3wjAbM1+nTCF\n1koiNZgE3/mNtRZU3F6TCNcn2Fkk2QYMgSLSEd00Kkquvg7MzLL67f+GG2ZfjZ5fxAAPL9gAUPoY\n5y9eZv9oHUXuBcrmkRtBOPBlSRcJ93orLD/9Ob6w9H8ys9QfhBMu0ybxDY0kyTIBMtz+s/ATf52/\nn18k8pyMGjOu3DyxPZI7GrTQzNQq2UaqldYqnbjDk37I/JmcyK21IhH77IKWhD6tuIVA4EvfEm3c\nwRM9uihW2r080yHuEHZtgDBOFblnPXJhEkRkm0BVXMVgy/jMV/LFzNfKBs28KiQ9osTkGSDQn0Lo\nVbLWoc93/bUZK2MgC3YWrJU0f1jFVpF3nHdbd0HfPc9ez89c94H8JKmaLwZU05/9YvzDWSu9hJ6E\nAAFx2yryVBwAKB9P5s28pDfe7VlUoTpQubVy74fAs59vT2WJh+Z+i9lTj/D4/tsx8deIj79QsFYi\na62ItYq8+g/v4+naU5wNnmcxjp21sglFrgLQQebBL/T2ojxJGLgGbgbbW9zZQ+l7V2cDRCD5l+Ye\nPm9OMFeo31ioppXGUPUVH3njT/LvHnh/P5F3nCLXEt8kLHS+T09FPM0syqUK1mrDs4EGUW/YsYqK\nxj9wACEESqqsAC0yBt22/r2iA889mtmgwqly7UnUsFjOBDBVRL7a6dmNTUmy3N6oGVN1u7+fEyuE\nSYKu574t2FUw8iI6hfs9VV976iE/eOJ2XnXiEFEl5NdufDMfveIegNwjTxNeM488v6BSeIHCS+wj\nTjgQ0EhzyXWvSawNnzv2CHNRv3ebWiu+TtjXi9cSufb7bpqiIo+inMhnajWEFHiuz0TsKSpehYVq\nQNeRaG21SSfu8N1Vn0q7kxVOrArQUiD3W7VlQp92r02gbP8Ka6108YjpGM1KJybKiNwq8lgLEtdj\nZFU1MFIjTIyIfLpCUHUk38ZjrhCYDdIb0BHha1td3hodzT9/kcgLvvIzHd/aMptESuB9WStucdfO\nWmm7J4tlt7dpr3WQG5evXzuO4tjSnwtqVEYhZnUV0Y3paggR0FmB9pl+IlQevigQ+RgeOeTEJ6Ql\njJ7L/tBX3Zu9ZqmyxGrQ5fovfZjb/t9foNn9TfxF00fkQgr8UKO0ylQxQKNe5W8u+QP+w+X/mqVL\nXw1X/rBNiYTxiNw9nWRNuToSP1R5gDgxSJkHCtP3Pnn7fg689VISYX3w2SC/7+acVVgLNEIIlhsh\nB2ajPiLP02cF2hiWk6c56+8BRHaPBpX83lkPswv2u1656SaO/O4nsuPLrjV2BYFuWa9ciw4894hN\nkHDwArVltgpMGZE3OzGJsESe7iUYNHvMS0vcXw4SKsYgGi7rIks/1E6R5+fK/FAp+I0338B1h2ap\n+Ir/+/BNPOHKwDNrJX2ETtMPhyny0GbPaNOvlgGuPb4AwpL048f2ESvBUqX/HKm1cld3hV9/+tmR\naXPZ+xWi7ZUoJ6OKZws7tOvxLMOAmldjruqnpR80zlmPfOUbBgEEzpJaFQatJPqAJfI40LTiVu4j\nKw96bTx6tFwDoijNdCgSearI3QbQwsSYMCAWgkqRyAupkhkZuwyNO3qS98zaIg2E7F/YCj8/3wvO\nT5Gnm1YXrBXcNSF7CTqGlhvrcazS+rbZQ6X43WbWSiGrJKhjv+yCtRJGYAxJs0msBCESzrn89QEi\n9wpErsdU5KnKU57s+5vidbgYLdL2QJqEoHMGL4g4WD/YF+wECCKN9iWqsIjUq1U6epWWt8LiTe+E\n6gLMHob9N8DBl4weWHqfpJWmvsyCs16os0U0Mkk/kbv3llIwO+u6dYaahjtfoAJ8rQi0pD5gjSgv\nH3e6q1bLF3gYjooneVosEGiJ5xS9rlQYB8v7avx+tU3j5AK6UMKftoyIEOhV27JACUdOlbwC2A/1\nlhL51HnkSmqkifFjazp5Ky32+nYyHwk9ZpIe0qURKncjeoGioiv9RD6kDDdyF37FKYVMkavxFLk0\n2FawAzfgtXceYPlQnfpN7+Kz5jlM8rscm+tPcxJOkVd1wowhJ4kRKCryqusvEagAJRVh1UOtuCq5\nIKLiVZiv+JwWBoyg0lrlVPMs9b+P+dpBqKrTtHo2/dBXErW4SFtBEni043ZOdiqA+BSamBVXbl6d\nD6gf8pj5r99EGehqkW0U0ElC4DTCJPTcDVd1NkWiAirFaH5K5GkuuRf12xTFPOoCkZ8jIhyT8IpI\nSaRPkQuB8P3MWkmJ/ACnOUOVM9SIiovGMGvlhn9oe2kUipDS1NLkzGkSLQmFhLNPuoHM5n+r/D4i\nV2MuUKly17pA5KJf0e+t7iWqzgC22OwtB29jz+Vvgsd/2b7YfZar7zxAfSHsswCiqk/dq3O2ezbv\nZeOF8J7/tP7A0jiBC/wKIQgqmtWzXZuumyryOEarXiY0iu/dcMq5EXk0XEvd9Durh5r6wNPvKEVe\nN3BEPMXfdE+wWAvQ4Rw88QI6Gs9aObpQ4R33X8Frr93fdzwnconnettkO28ViNwL1KhSgIlgqhT5\najcGqREk+M7uluda3OQZugpWQqgmBll3QQYXWPPcY1xniCIvouq7PFenplIiT5sqcfgWuOwHYPnk\nmr8tRqb1gCKPaj5Hr11k4d3v5h3v/Dk++bpPcWSuv3l9qshlIKw62uBbL6qtmlMVaee/o9cusuy6\nNDYaixybOWYVuTul12uiPv9V6s8lfP3yhFBan3xVglYCXwf85fWClZsvpx23cx9Zec5a6bHiNuWt\nV31e84Z5ak2rRnoKEmdJxN20kCah51LNKs7GkV6U2ymsVeToMCfswacTXSByExHoCSly7HUhuzE6\ngaZTVpXE8G2zTKAlUha+l4zIC9bKzAG46o3950wD2WfOEmtJKNRwRS41+nwUuc4VeRYo9FXWQwYg\n0hEfv//fZ//24iZSSBvs9KvZ9Xbja45w/OZlhBTZZ/WjXA0vVfp7da8Ll7JatJlSn9wPdWatVOIY\n7a4ZI8ia0AGZ4m6EHjPOWkm/s2qgqQWjiTyt7GwrgzaGUHR5pNVgseZn9+jg0/MoCCH4sduOMVPp\n542cyFX23am0wKlA5I3FiJmlAbt0gpgqIl9p9zBOkevY0PRBJAnJl7/I6T227WfFgKy7Tn7uO/YC\nxVWLV3HbsVdl5xpG5Kkir7tigzNtm9ObKfKZg/C2fz9SkadQ63i2WimuXj6y9vhe6zl689U8DW8d\nZO8noBr1b6pw249cxhVzlihedemr+bU7f425ik/XBQh1b5X6732GWMKZY11CUbBWpMCTHv/21YrT\nd15nPfLMWvEhbqNMj5WevdkqvkLofC47isxaiV1mkTQxHZfrHjkiV34/kQepCks/uxcViHwgF9zL\nVdSFKHIlVN6/3EH4PqbbwYsFTaesImP4djJgq0DWE3wjGyyNf8Rnz2C0IhAK3GN/v7XSr8gHBcHI\n8zu7QmmB9lKCWjsnKsqJRPTstU1nZW08Jj2vm9egoqn7dbTQzBb2wB0LQX2AyF3WWagygRDFXbSL\nqxjZL2Aazo6ohzpX5O7vlushy41+Rd2nyOMusWdbEadX6OPJHIu1IJsfHWxeBBSREblQWQ8X7eJv\nabAT4AfecZK7f2ytAJwUporIf+qu48zWKwjXFvWUu79bX3kI4UqKK0Jar1OpjMj9UBOogAeveWt2\nrmHWStV9qTNRQKSjtcHOdVCs2NJDbqKNEJ44wfG/+WvCg3Mjb6wiioqi4lRsVFCqacm/DCOkkMxV\nbUFO18QIDJWvfpu/uF6wV/cInUfeVVZ5pPnavaTXr8hd1oqmR9t1gqsFGuHln72rTJa1ErugmzAJ\nLZfJE6Ztb/2wz9v2B4KdVpFX+o+l8C5ckXvS48N3f5gHTjzQd1z4PqbTsXnk0ub0B8Y4f3zAiUwX\nuA0W3vRpKzl9hvn6Hh7QBVXbl7XS75EPI+NhyBV5HqRUQxY3USBy6Voz0F0deb2lXrUfWRJdiBas\nit8Mqkt9Qb+06KjPI4+7+K5xFgNfZSNV5AVrJRUWv/HmG/jH9101MOaitdIl9iQ9rCIHeMLMW2vF\n3T/nc68WkQY7I6Hw3MKvMiLPFflgJtCkMVUe+d6ZEKU9pEsreqEG+58H4pjZSw4Bp6gI+0gpowjP\nBT5S9SqCtcUfRVS8fPXvI/IN/Orie8D4j8SD0EtLVqG1zoz9fjrIo//ZpgrkJf3SpSbOO2ul4zJX\nnqsLPv5KyQdPd6mo5zHCELsLLSXybtK1wU5VCHbGXZTp0XWXTjXQCJNfRh2ZZFkrSdcgscHO1YzI\n3U41/ihrpeCRj1LkRWuF8LwUOcDtB25fc8wq8q7dfMHlfAvg22Y5e2LLx+EWuBHVo9k5M0V+lsUT\nJ7gpKFxPA8FOKRIUHWL8vmtqPaQEoT2ZEdMwy0D4vt1rMkkQHbdBSrc5ciFKzxtEmuuWrstIa1N4\n8Hf66i6KijzLWum2s23xGFDkoWeDmo1QZ2X5kduNY+/MWn9bFoqoVNKh50l6JsFzRP6kmefymo/u\njZ6nzSC1miKpc0UeBhDTR+RbjakicoBEKITLDz9w9Br4zpcBOHTltfjtL1FNN2eOIhbU81xz5wH2\nHHHBFj8n8mE9h9MbtRF6VHSFJ1as77tZIh83SDUUe07CyjMbvswLZPa+nvTQUhMVlFVK5Olnnq/4\nfD7o8ZiKuevkpfzmdY/RCgRHej2OV/6MPzv2ZuQzbuFzMYFu0qXdazOTWknKh+4qioSeU+TVQCN6\n+WXUljGucwBJL7FEnsQ0g7RNQYuuUYRB0Kek82Bn0SN3Pw8SpbNWYiNY5fyyVkZBeB6m00XHhp6y\nVh3Ad8zyWmulsR9+8NfhqvvXPWfW8Cx2XTeL3RgHgp0AWtjNJdYUlo06f2atyKw/yTBbRghhq0yb\nTUTrGTBmA0UukVqgPMlP3/jTY41lDZZO9P3TL3jkqRVY7bayjS/EkDzrX33gWq7a36DhWxFQrMYd\nhJACqQRJbKwi15KuSTKiezJV5GljsUkpcunlVZ8zS1C/PW8stg2YKmsF7Ga+wvVQuOSSm7Lj1auu\n43999jneil39RWQLHO548+XZRS0LSmhosNORcd1dZLErzR6LyMMLV+QA/ND/Dj/68Q1fNhisiXTU\nb624bnfCKfLZis/3dMKXQ8GR3/49vnu5VYJHuj0ieZZnqxpP9SvyXtKjFbcKwc4gS1dLFXkt0Hkw\nAmjJJLNWTMFaWXFT6HVW6AqPiq8ICvOUkfpQRT5ordjP1hQRIPqU/YWiz1pRNj8Y4DvJnv6MFbAB\nwpe8u88LHXrOcCBXPcs/r2eVuoDd1QBQ7hE92KQiV55E+bk6HzqWtMWzaUHzeUfkwz1+pSVBpPuC\npheKVJF7oeL47HF+cfFW7mw28bEVpsNy5++7/gCX7an3pR+uh3Q+ZNyl6wl6JGhj6KB5njqL9YK1\ncoEioOJV+JHjP8Jteh4hQKuerWN5x59uGDuZJKaQyFW2K7t2exjqPXvQ+y/l3pUmV3hWPUbXXEN4\nVX9woWitMITIQ63QUjBX8ftsinE88j5FfiGr/Jg3Tfp+6f8rutIXuMutFUsavpbUXYR/Joy479L7\nOKyqzLgWsWd6Gu0eaz1VUOR96Ye2RB+gS6rIVd+i2BK9LNiZ9PKslXNu9xTdaWJ0yMsvWyQcV5Gv\nsVZc7/a0he0kFbnvk6y6xUoJIgRdNE8yv1aRjwk5isgHi2ncvEuRNnQa74G5z1rJFPnwazAdi1AG\nTn0LuqODnUrLiec+px65H9oF4sGFG4iMwTc2c0qusygHKiBUYV817jBkRJ506WpBN4nRBk6pBQyS\nxaqfW1AXGOwE+NDLP8StgeUiX8cXHEA9H0yftYJEDBB5cMXleUDF3fQHfv3X1vxtkciHWStSCj76\n9pu5al+DX/wvBSIfy1opBDu3MKiRvUeqyN2TwC+89BfYV8sbMA1aKwBzVZ9WL8bXkp+96Wd53+kV\nePRhOkbR7JErclEIdvbaea51YR4yj9zXmEKC/qrsEbu0T3qpIo85k8Yrei2qlQXedfsxvvFM3h7A\nTx+p0/TDdbNW7PHVrSByzyNZsURuFbnkGb2XBLnWIx8TfUTu+3mQtBjohJzIZRfi8RV5qmKVltlm\nDKMyXtJUSEvk39kw2Kn0hIk89cjTDRzcYu0nNi40X19fbc+Gs5klMwppkFYlXToKeibGw3DG3wMr\nsFgPqByWLB6qEY7oP75pOLvsntu/Q+OVd07mnJt5+21/xwtEIhTSNTFSMw300hKVG2+y6kZ66z7O\nFDNVhlkrAK+63C4ORUWe5ZGvgz5r5QIDKOMgU+Tuve4+cnff79W8K4qanc2OzVU8TjXd5htSox1B\ntghodmK81GuVCoFYG+wseLs9FBVfIaUgKdzsq6KXeeQmU+Qxp1IiNyZTpMODnY60vWi0R+7+viUr\na85zoRC+R3zqFOCCnTrku+ElcA4i7/xul2K2iPC8PG1xDZHb+ZUufz0Ys8HSsMrOUdZKmgoplbFb\nta0T7KwvhBPPtEjzyDPh495bdV0V9QZPs798+y+zFK2fy55m7MikS0cbesZaK6uuKd5iLWB+uc6b\nPvDS8/4ca9/UfqeHLglgabxq0Uli+ogcme1cI4KAS/70T6z6FMIW6sxfOvJvZTFrZYgiL6LoN4+l\nyAsX4LDUr0kjJfBRj4bRDTdw5BOfILw6T8+aq/o8fbawzVVKiPisduO+zRk86a1NPyzMQwdN1d2M\nQvcr8sTZQyZ2e6iamFM6gcTl82ZEno89WNdaGe6Rt902byPb2J4HhO+TNAuK/OBL+UPvrfDssxO0\nVlIiH7BWXGxCiC4G09cTfN3zpwp0oCBovbGIqAZnvr+uIv+Bd1419PiFIKymPU7S3GC3m5fbOWuj\nheMle9dpCeBQtFY6ytBLenbDl7kDLDcDZqMJqfAi0u90GzNV+t5+R971ApAgM0UugwDVKPQsefdf\nkm24OwQbpR8WkT6+SSHzPtjrQCqrhnrd5MKCnWNCaoGQYqQfJ4SgcuMNfcduPjKXVa8CWfZHy3i0\nOjGNwgWupc498mJBkEPXFKrqCkTeKxQEiYJH/rzsWSI3Jrvoi8HOodZKddGWvF/a/7SB8kBIOimR\nT1KRex7Jykr2Wep+HZEWXJ0nkYs11sooj9zNr+jRY/wFKlXkxRL90daKJW0xswxnHs8rO4eddwss\nwv3HZ7nzzSfYf2LWHnD3WVrWPgkRlPrsKu7QUgaDQTf2c8Utr+P/ueyu/urcSSEj8sX1X7dFmDoi\nN0YgCoq8D2p9chZK2SBnYau3UUitlXECnSm80Hae2w5FLoTgwInZLLVyHLzvruP9B9xTxyoBzW7M\nQq2wi5DyaLoMlTzYudZaSceC1tDr0VWAgBgDbtPiLx8RPOU1oddvraTBTl0oB88yKHRotzm778PD\nPjzoiJ6evEcufZ/E9WjvSftkptzid74euZASEQSYdrtfkRdTDyG7foXq0hHjL1DFrJU0C2O0teIU\n+exeOP29dSs7twJSSa6+82B+ILVWUiKfwOJRVOSrEkCgX/JuxOWv3TrC22FFPnVZK0VFXgzkjYs0\nyLmRIk9zsr0NFocisiKdbfDIAe57/w2cTDfPPR94ubVS9MjBBjzPdS2hDSPyorUCub3Scx89EWRE\n/n+9vMKZnj2XZ/L39ZRADBJWUZGvh8vu5ju164ERGy+fJ4Tng8vk6WmXDeQ+5/kqcigQ6HrWirvW\nZhtf5FPVztjteYdbK6PSD11Pn9l98MJj2N0Oto/I18AfUOQTIXK7wYswMS3X92ScONcFIbUBSyIf\nD0lBkRfzwsdFquI3tFac2tsoZ7WIjMi3IWtlIih45J1e0ueR1/06T5yzBVGjFHltCJGnCSyJAOGI\nXMh8USgqciFsDngfYRVL9NfDm36Hh5Zfb8c3UY88vy56yi7oKYFHgyX6mzlvammsS+ROZPgdvq+T\nzStynVd2jvbI3TgWDuXb4I3R22fLMGitjNmDfT0oLZHKVuSm1+M49ugF4ZoH4f6P2ha/O4ApYZwc\niRG5Ih+0VsaACAL3aL7+F5t65JuyVgK1pn3orkZK5MZ+xqIiv3L+Sr763FeBQqvXQtZKd1CRu4Wx\n6/jDFIhcFuIWmtwjBxvw7CPy1G4Y0phsEGmBzsQVuUNP2gU9XbDWFARtApki7/PIZwde5Ln3zXP/\nxzq3+96KW7SNzCNP0w/ni/bGDiry1FpJqyInsCjbClc7J2nH0y1X5LUluPbBrX2PdTCVRD7SIx8D\n0vcRnrdhtVrmkY+RsZLCCzXakxOthNtSeLlHDqBlfjlctXgVPTfPwxR5F02tEGgdtFaMELiYJ6Kg\nhjxDn9peo8jnj8Fb/xCu+MENh5961pMuCEph0w+jrG/6hVgrfYo8Jc5ooCLUzW9K5OM2A+tX5Ovb\ne8Hx4wSXX46YKRL59lUgrsEaa2Uyily5xW3bFPkOY+o+3SQU+UaBTsiJfLMe+XYEOicGp4xbrsln\nUZFfvXh19vOw9MOuUQMZMM5aUTbTxwiQqSJXOakUrRWwJOwN7hZ//J6xhp8q5GCCc1603HpKUPEq\nVExqrUzIIz9yG7zml+Hwrf0vcuX6iVs4x1XkfcHODRT57AMPMPvAA/DUV/ODu0CRT9Ijr874VGv2\nu+qmOxJttSLfYUwVkRtjnCKPQYgNfe5hEEEw1t+dj7USRHrssupdgTRrxVji8Aoe+ZXzVyKFJDHJ\n0PTD3ppgp7NWtL1pEimQbmMJ1afIzRpFrs9zQ9pUIYfn0cZ2FIYp8ksaNWYrHpcsnr9yzSyNtLLz\n1n+09kVufhO1tmBq3XMXrZWs18oGc9LIq4B3lMiVB9KbaPrhrfdfRvPhmMd/P7dWSkW+i5AkTuEl\nPUvI52FhiMAfi8jTgqDNWCs33XuUK16+b+MX7hYUslaAPkKteBUumbmER089OlyRo4cGO3tK2MVP\nQPrt6EJjKFsQVPDIPYmS53fzXn1ghqv2N9jT2PyT2SgMEnlFVzi6WOWLH3z1hZ03LFgro+BUY+wW\nOn/MBa6oyBf2Vzl81Tx7jqzdV7YP4axVw+tUdm4b/AqqMzlF7gWKcMbO94vFWpkiH6DYhCk+L1sF\nQPqbs1Y2o8hnliL2XzZ7XuPaEbjFqu2I3BsolEjtleEeuRqZfugpD1M4lSr8nWf6091Ct4nu+eCG\nw3P86U+/Yu2GDxeA4rXRVf0VvheCPmtlFNy8xLqGr+TYhSuq0GslqHi8/qeupza3wf0hhG3DW3jf\nHYNXQTM5IgdQjQZGCs66j5b2D7pYcUGzJoT4B0KIh4QQiRDi5kkNahRi14RJJr2hTa/GwWatlc14\n5FMHp4xXTarI+4njmkW7i33Nc71O1mStrA12dpVVP8Utu3TaDAq3AUxBkb//nhP8zN0DhUo7iH6P\nHObD9VvUjn3eaAwinzkAD/42X5171aYWN1lQ5JtCRuQ7rMi9CqE8i/YF9fnxNkPeCHphgfZv/RL/\n+QpnO13kivxCP91XgPuB35rAWDZEEl+4Iq/ffRfdx5/Y8HXno8inDkGdpLLEY6fcfqEDj/JvuOwN\nLEaLHGocsgcGFPne4n6JabDTeeRFieBpH7rgpWZLwSO//fjOlDSPQjGP/J/f8xscbhyeyHmz/O2N\nBMjJ+9j31KMcmu+s/7oCiiX6m0LdEbm/89aKL1f5sQ9dgz83uTzs4OSVxN/sb818seKCiNwY8zCw\nbel2RUUuovMj8tkHHtj4RRSCnZvwyKcOyuPs+x7i0//LZ4C1RO4rn7sO39X3+hS/++Ov4OCRXK2m\nwc6esrulFLfsSm8inbL7Oju87DSKRHvF8tXrvHJzkOMocoefvPNSfvyO8XeXSTtvbrp3+C5S5ABB\nozF2P/5xUOxbfrFbK9v26YQQ7wHeA3D48PmpnCTO+1uL86jq3Aw86aGFvriJHPC0a44C2cYSI1Go\ncj20ONN30xWtlYby+n4XeC4rJt24d0K+81agSLTnkxU18rzjBDsdpBRIxie0A5fP8YPvvZbFQ+vv\nHboGx18Nz359rOKrLYVXsU97erL3Wlh48nvRWytCiL8A9g751QeMMZ8a942MMR8BPgJw8803m7FH\nWEDcy7NW5Hn0WdkMhBBEXnTRE3mxCGjDNMDiXAw8qhZL9D3p9e2GHrhqyZzIp0ORF6s8LxR96YcT\nhpSCo9eeh0V15Fb7307Dr27JtmjF9hov+jxyY8x41RnbgH5FPpmgyHp473Xv5eTCyY1fOMUoFuOs\nKcwZRJG8Bxa4LGtFph55fi7fKSMvLdXfqI/KDqIYRJf+JBX5+NbKiw5BHYIN0iXPA8WMoxe9It9N\nSIOdchusFYC3nXzblr/HTkMIgZKCODFrPPI1KCrpweCRC3b2tPXWRYHIo8xaSYl8FyvyItFOkHTz\nYGdJ5Gvwiv8Obpj8vfZiUuQXmn74RiHE94BbgT8VQvyHyQxrOFJrRSQ95DYo8hcLUm98MP1wDYoq\nfEDhFIOdg4o8dMooI/KdzlteB5n1MUY/ns3A278PtEbNzW384hcbFo/D0dsnflolVUbgpSJfB8aY\nPwb+eEJj2RBJL9867HzTD0usha8k7V6Ct1GFpVQgpN2FaYDkhNYYrTBC4EkP4RaFGEPoO2slvZl2\nsyIfs1/9ZlG55RaO//Vfoecnk5deYjyEOqTb6V70RD5VlZ1xXEg/3AZr5cWCVIlvqMjBZq4MCQAL\nz8M4e8WTXmatJEDVKXI9BR55SuCTJnIhREniO4A0BfFiJ/Kp+nTFEn1ZKvKJIc1W2dAjB0viQ/he\naO188rhPkScUdltKfcrdTORbpMhL7AzSFMSL3SOfKiLvU+RbnH74YkLaY2XDrBVwGx+vfd3MD7+e\nJ5c08Ad4qkDkAqJ0a7faHnjNP4X58YtdthsZkZdByYsCacDzYlfkU2WtTKJpVom1SBW5HqcLoQ6y\nLn1FVF7yEsybfgiw6keqIdaKF8Gt751o9d6ksVXWSomdQZqCeLET+VR9utIj3xpsziP3wAyv50qL\np7TUfdZKZdBa2cUorZWLCy8WRT5Vny5T5EqiGjtcVnwRIc1WGdsjN8mI81jy85WPdOdMMFT9aSTy\nUihcDEg98rLXyi5C2jTryL/4MLPXXLbDo7l4kCrx8Yg8ABMP/VWqyD3pZRtQJwKq3vQEnEpFfnEh\n0pF9QtzFdt4kMFVEnlZ2Vq6+Elkpb7RJIfPIx7VWkuGvKxJ50VrxtCLS0XQQuWs1UBL5xYFABVNx\n3V0oporIU498UruIlLDwsw1qx00/HP669IbxpIdRghhH5FIQ6eloQCaktFWdJZFfFAh1eNHbKjBl\nRJ565Olje4nJIM1WGUuRN/ZB3B36q3QTDk959LS0RC6s4v/grR/kSP3IpIa8pZCeV6YfXiR41aFX\nUffrOz2MLcdUEXmWtTLmXoYlxsOmPPL7fnNk1krNr3Hjnhs5uXCSh7Ski1PkSnD34bsnN+AthvC8\nMth5keCOg3dwx8E7dnoYW46pIvKkZ5BaXPSBi+2Gl1V2jjGv6/SN1lLzsXs/BsDD6iEADGMuELsI\nwvdLa6XEVGGq7rA4TrL9CUtMDln3w3E88jGRxjFizMY7D+0yyGoVGe3eDo0lSgxiKhV5icliU4p8\nTKSZMIkANWVEvv+f/WrZbrbEVGGqiHzPkTomOa9d4kqsg7yyc4KK3HPnEtu3OfekEF1zzU4PoUSJ\nTWGqiPyKW/dxxa37dnoYFx20nLwiV+7JyUwZiZcoMY0oDecSGYFPMiipda7IS5QosbUoibxERuCT\nDErmRF4yeYkSW42SyEtsiUeunUduyiusRIktR3mblcgUub8l1kqpyEuU2GqURF4izyOfZPqhU+Qj\n2rKUKFFigihvsxIs1AIaoZ6oR+55bqPlUpGXKLHlmKr0wxJbg7fdcpgfunbfRPO9M2tlyoqBSpSY\nRpREXoJAK5YbaqLn9EprpUSJbUN5m5XYEuREXiryEiW2GiWRl9gS+M4jL4m8RImtR0nkJbYEWks6\nGCibnJUoseUoibzElkBLwe/X2jyzt9ygoUSJrUZJ5CW2BFpJntAGEUw2iFqiRIm1KIm8xJYgzUmf\nZEfFEiVKDEdJ5CW2BEpOvqNiiRIlhqO8y0psCbai7L9EiRLDURJ5iS1B2knRm+A+oCVKlBiO8i4r\nsSUoFXmJEtuHkshLbAlKj7xEie1DeZeV2BKUWSslSmwfSiIvsSUQQqCkmOiuQyVKlBiOsvthiS3D\n//S6K7ntsoWdHkaJEhc9SiIvsWV41+3HdnoIJUq8KHBBz71CiH8mhPh7IcSXhBB/LISYndC4SpQo\nUaLEmLhQA/MzwNXGmGuBrwO/cOFDKlGiRIkSm8EFEbkx5s+NMT33z/8MHLzwIZUoUaJEic1gkikF\n7wT+bNQvhRDvEUJ8TgjxuWeeeWaCb1uiRIkSL25sGOwUQvwFsHfIrz5gjPmUe80HgB7w8VHnMcZ8\nBPgIwM0332zOa7QlSpQoUWINNiRyY8w96/1eCPF24IeAu40xJUGXKFGixDbjgtIPhRCvBf5H4E5j\nTHMyQypRokSJEpvBhXrkHwbqwGeEEF8UQvyrCYypRIkSJUpsAmIn3BAhxDPAt8/zzxeBZyc4nEli\nt46tHNfmsVvHtlvHBbt3bLt1XLD5sR0xxiwNHtwRIr8QCCE+Z4y5eafHMQy7dWzluDaP3Tq23Tou\n2L1j263jgsmNrexoVKJEiRJTjpLIS5QoUWLKMY1E/pGdHsA62K1jK8e1eezWse3WccHuHdtuHRdM\naGxT55GXKFGiRIl+TKMiL1GiRIkSBZREXqJEiRJTjqkiciHEa4UQXxNCPCqE+PkdHMchIcR/FEI8\nLIR4SAjxM+74h4QQ33fFUV8UQrxuB8b2LSHEl937f84dmxdCfEYI8Yj7/9wOjOvywrx8UQhxRgjx\n/p2YMyHEvxFCPC2E+Erh2Mg5EkL8grvmviaEeM0OjG1o338hxFEhxGph7rasIG/EuEZ+d7tgzn6v\nMK5vCSG+6I5v55yN4onJX2vGmKn4D1DAN4BLAB/4O+DkDo1lH3Cj+7mO7cV+EvgQ8HM7PE/fAhYH\njv0q8PPu558HfmUXfJdPAkd2Ys6AO4Abga9sNEfue/07IACOuWtQbfPYXg1o9/OvFMZ2tPi6HZiz\nod/dbpizgd//OvDBHZizUTwx8WttmhT5S4FHjTHfNMZ0gE8C9+3EQIwxTxhjPu9+Pgs8DBzYibGM\nifuAj7mfPwa8YeeGAsDdwDeMMedb3XtBMMb8NfD8wOFRc3Qf8EljTNsY8xjwKPZa3LaxmV3Q93/E\nnI3Cjs9ZCiGEAB4Efner3n8U1uGJiV9r00TkB4DvFv79PXYBeQohjgI3AP/FHXqfewT+NzthYQAG\n+HMhxN8KId7jji0bY54Ae3EBe3ZgXEX8KP031k7PGYyeo9123Q32/T8mhPiCEOKvhBCv2IHxDPvu\ndtOcvQJ4yhjzSOHYts/ZAE9M/FqbJiIXQ47taO6kEKIG/CHwfmPMGeBfApcC1wNPYB/pthu3GWNu\nBO4F/pEQ4o4dGMNICCF84IeBP3CHdsOcrYddc92JtX3/nwAOG2NuAP5b4BNCiMY2DmnUd7dr5gx4\nM/2iYdvnbAhPjHzpkGNjzds0Efn3gEOFfx8EHt+hsSCE8LBfzseNMX8EYIx5yhgTG2MS4KNs4ePk\nKBhjHnf/fxr4YzeGp4QQ+9y49wFPb/e4CrgX+Lwx5inYHXPmMGqOdsV1J/K+/281zlB1j+DPuZ//\nFuupntiuMa3z3e2WOdPA/cDvpce2e86G8QRbcK1NE5H/f8BxIcQxp+p+FPj0TgzE+W7/GnjYGPPP\nC8f3FV72RuArg3+7xeOqCiHq6c/YINlXsPP0dveytwOf2s5xDaBPIe30nBUwao4+DfyoECIQQhwD\njgP/dTsHJvK+/z9sCn3/hRBLQgjlfr7Eje2b2ziuUd/djs+Zwz3A3xtjvpce2M45G8UTbMW1th3R\n2wlGgV+Hjfx+A7vV3E6N43bsI8+XgC+6/14H/A7wZXf808C+bR7XJdio998BD6VzBCwAfwk84v4/\nv0PzVgGeA2YKx7Z9zrALyRNAF6uC3rXeHAEfcNfc14B7d2Bsj2K90/Ra+1futT/ivue/Az4PvH6b\nxzXyu9vpOXPH/x3wEwOv3c45G8UTE7/WyhL9EiVKlJhyTJO1UqJEiRIlhqAk8hIlSpSYcpREXqJE\niRJTjpLIS5QoUWLKURJ5iRIlSkw5SiIvUaJEiSlHSeQlSpQoMeX4/wGAXD5mHSjj0wAAAABJRU5E\nrkJggg==\n"
          }
        }
      ],
      "source": [
        "plt.plot(fhatbarhat_mean_spatio_temporal[:,0])\n",
        "plt.plot(fhatbarhat_mean_spatio_temporal[:,1])\n",
        "plt.plot(fhatbarhat_mean_spatio_temporal[:,2])\n",
        "plt.plot(fhatbarhat_mean_spatio_temporal[:,3])\n",
        "plt.plot(fhatbarhat_mean_spatio_temporal[:,4])"
      ],
      "id": "1fbb0280-6d27-49e1-b00a-3d3ac3231a58"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "#### 2) Random missing values"
      ],
      "id": "df4b4574-ba8d-42aa-b4c4-aba338b9a7d6"
    },
    {
      "cell_type": "code",
      "execution_count": 145,
      "metadata": {},
      "outputs": [],
      "source": [
        "w=np.zeros((995,995))"
      ],
      "id": "3fd94abe-8944-405c-9b1c-455e6ed6af52"
    },
    {
      "cell_type": "code",
      "execution_count": 146,
      "metadata": {},
      "outputs": [],
      "source": [
        "for i in range(995):\n",
        "    for j in range(995):\n",
        "        if i==j :\n",
        "            w[i,j] = 0\n",
        "        elif np.abs(i-j) <= 1 : \n",
        "            w[i,j] = 1"
      ],
      "id": "e7dc2546-0e8b-44f6-aa0e-bdb8fa141f81"
    },
    {
      "cell_type": "code",
      "execution_count": 147,
      "metadata": {},
      "outputs": [],
      "source": [
        "d = np.array(w.sum(axis=1))\n",
        "D = np.diag(d)\n",
        "L = np.array(np.diag(1/np.sqrt(d)) @ (D-w) @ np.diag(1/np.sqrt(d)))\n",
        "lamb, Psi = np.linalg.eigh(L)\n",
        "Lamb = np.diag(lamb)\n",
        "fhatbar = Psi @ fhat_fiveVTSrandom_mean.reshape(995,1)\n",
        "power = fhatbar**2 \n",
        "ebayesthresh = importr('EbayesThresh').ebayesthresh\n",
        "power_threshed=np.array([np.array(ebayesthresh(FloatVector(fhatbar[i]**2))) for i in range(995)])\n",
        "fhatbar_threshed = np.where(power_threshed>0,fhatbar,0)\n",
        "fhatbarhat = Psi @ fhatbar_threshed\n",
        "fhatbarhat_random_mean_spatio_temporal = fhatbarhat.reshape(199,5,1)"
      ],
      "id": "0d335c20-2270-4e23-ac48-ff8624a97b54"
    },
    {
      "cell_type": "code",
      "execution_count": 148,
      "metadata": {},
      "outputs": [
        {
          "output_type": "display_data",
          "metadata": {},
          "data": {
            "image/png": "iVBORw0KGgoAAAANSUhEUgAAAXwAAAD4CAYAAADvsV2wAAAAOXRFWHRTb2Z0d2FyZQBNYXRwbG90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\nxniR4P8H5UWxrVVzb/8AAAAASUVORK5CYII=\n"
          }
        }
      ],
      "source": [
        "plt.plot(fhatbarhat_random_mean_spatio_temporal[:,0])\n",
        "plt.plot(fhatbarhat_random_mean_spatio_temporal[:,1])\n",
        "plt.plot(fhatbarhat_random_mean_spatio_temporal[:,2])\n",
        "plt.plot(fhatbarhat_random_mean_spatio_temporal[:,3])\n",
        "plt.plot(fhatbarhat_random_mean_spatio_temporal[:,4])"
      ],
      "id": "fe2c6d70-fb15-427c-adeb-6d6cf84f8543"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "#### 3) By 2"
      ],
      "id": "bfc50087-803f-42db-bf72-3aadef631e82"
    },
    {
      "cell_type": "code",
      "execution_count": 149,
      "metadata": {},
      "outputs": [],
      "source": [
        "w=np.zeros((995,995))"
      ],
      "id": "e0d7f27a-749a-4b46-879c-1263a505b059"
    },
    {
      "cell_type": "code",
      "execution_count": 150,
      "metadata": {},
      "outputs": [],
      "source": [
        "for i in range(995):\n",
        "    for j in range(995):\n",
        "        if i==j :\n",
        "            w[i,j] = 0\n",
        "        elif np.abs(i-j) <= 1 : \n",
        "            w[i,j] = 1"
      ],
      "id": "409be929-9a42-42bc-8410-e5b2c5e9a421"
    },
    {
      "cell_type": "code",
      "execution_count": 151,
      "metadata": {},
      "outputs": [],
      "source": [
        "d = np.array(w.sum(axis=1))\n",
        "D = np.diag(d)\n",
        "L = np.array(np.diag(1/np.sqrt(d)) @ (D-w) @ np.diag(1/np.sqrt(d)))\n",
        "lamb, Psi = np.linalg.eigh(L)\n",
        "Lamb = np.diag(lamb)\n",
        "fhatbar = Psi @ fhat_fiveVTStwo_mean.reshape(995,1)\n",
        "power = fhatbar**2 \n",
        "ebayesthresh = importr('EbayesThresh').ebayesthresh\n",
        "power_threshed=np.array([np.array(ebayesthresh(FloatVector(fhatbar[i]**2))) for i in range(995)])\n",
        "fhatbar_threshed = np.where(power_threshed>0,fhatbar,0)\n",
        "fhatbarhat = Psi @ fhatbar_threshed\n",
        "fhatbarhat_two_mean_spatio_temporal = fhatbarhat.reshape(199,5,1)"
      ],
      "id": "044007ee-e10f-440e-bc27-a300d4a98ccb"
    },
    {
      "cell_type": "code",
      "execution_count": 152,
      "metadata": {},
      "outputs": [
        {
          "output_type": "display_data",
          "metadata": {},
          "data": {
            "image/png": "iVBORw0KGgoAAAANSUhEUgAAAXwAAAD4CAYAAADvsV2wAAAAOXRFWHRTb2Z0d2FyZQBNYXRwbG90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\nAABJRU5ErkJggg==\n"
          }
        }
      ],
      "source": [
        "plt.plot(fhatbarhat_two_mean_spatio_temporal[:,0])\n",
        "plt.plot(fhatbarhat_two_mean_spatio_temporal[:,1])\n",
        "plt.plot(fhatbarhat_two_mean_spatio_temporal[:,2])\n",
        "plt.plot(fhatbarhat_two_mean_spatio_temporal[:,3])\n",
        "plt.plot(fhatbarhat_two_mean_spatio_temporal[:,4])"
      ],
      "id": "0f3e0a1e-1139-4d08-82b0-a0c4772d7039"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "## 3.2.linear interpolation\n",
        "\n",
        "### 3.2.1. Temporal\n",
        "\n",
        "#### 1) Block"
      ],
      "id": "d8d9af98-62a7-4454-8fcb-4dc8809d813f"
    },
    {
      "cell_type": "code",
      "execution_count": 153,
      "metadata": {},
      "outputs": [],
      "source": [
        "w=np.zeros((5,199,199))"
      ],
      "id": "89423b8f-88dd-4651-a394-fa040640458d"
    },
    {
      "cell_type": "code",
      "execution_count": 154,
      "metadata": {},
      "outputs": [],
      "source": [
        "for k in range(5):\n",
        "    for i in range(199):\n",
        "        for j in range(199):\n",
        "            if i==j :\n",
        "                w[k,i,j] = 0\n",
        "            elif np.abs(i-j) <= 1 : \n",
        "                w[k,i,j] = 1"
      ],
      "id": "80d2c6cc-04d7-4805-a995-9513fcf5f767"
    },
    {
      "cell_type": "code",
      "execution_count": 155,
      "metadata": {},
      "outputs": [],
      "source": [
        "d = np.array([w[i].sum(axis=1) for i in range(5)])\n",
        "D= np.array([np.diag(d[i]) for i in range(5)])\n",
        "L = np.array([np.diag(1/np.sqrt(d[i])) @ (D[i]-w[i]) @ np.diag(1/np.sqrt(d[i])) for i in range(5)])\n",
        "lamb, Psi  = np.linalg.eigh(L)[0],np.linalg.eigh(L)[1]\n",
        "Lamb = np.array([np.diag(lamb[i]) for i in range(5)])\n",
        "fhatbar = np.hstack([Psi[i] @ fhat_linearinterpolation[:,i] for i in range(5)])\n",
        "_fhatbar = fhatbar.reshape(5,199)\n",
        "power = _fhatbar**2 \n",
        "ebayesthresh = importr('EbayesThresh').ebayesthresh\n",
        "power_threshed=np.array([np.array(ebayesthresh(FloatVector(_fhatbar[i]**2))) for i in range(5)])    \n",
        "fhatbar_threshed = np.where(power_threshed>0,_fhatbar,0)\n",
        "fhatbarhat = np.array([Psi[i] @ fhatbar_threshed[i] for i in range(5)])    \n",
        "fhatbarhat_linearinterpolation_temporal = fhatbarhat.reshape(199,-1)"
      ],
      "id": "060566aa-243a-48fe-a4c4-386701bb1b48"
    },
    {
      "cell_type": "code",
      "execution_count": 156,
      "metadata": {},
      "outputs": [
        {
          "output_type": "display_data",
          "metadata": {},
          "data": {
            "image/png": "iVBORw0KGgoAAAANSUhEUgAAAXIAAAD4CAYAAADxeG0DAAAAOXRFWHRTb2Z0d2FyZQBNYXRwbG90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\nhNzhcDh2OU7IHQ6HY5fjhNzhcDh2Of8/qbxHLZN7YoQAAAAASUVORK5CYII=\n"
          }
        }
      ],
      "source": [
        "plt.plot(fhatbarhat_linearinterpolation_temporal[:,0])\n",
        "plt.plot(fhatbarhat_linearinterpolation_temporal[:,1])\n",
        "plt.plot(fhatbarhat_linearinterpolation_temporal[:,2])\n",
        "plt.plot(fhatbarhat_linearinterpolation_temporal[:,3])\n",
        "plt.plot(fhatbarhat_linearinterpolation_temporal[:,4])"
      ],
      "id": "d76123a9-849f-44b9-820b-dbd91cc483a3"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "#### 2) Random missing values"
      ],
      "id": "1954a4c6-12a7-4938-94ea-ac37e3ab9493"
    },
    {
      "cell_type": "code",
      "execution_count": 157,
      "metadata": {},
      "outputs": [],
      "source": [
        "w=np.zeros((5,199,199))"
      ],
      "id": "b878bc94-c0f2-4629-a388-db07b41df5b1"
    },
    {
      "cell_type": "code",
      "execution_count": 158,
      "metadata": {},
      "outputs": [],
      "source": [
        "for k in range(5):\n",
        "    for i in range(199):\n",
        "        for j in range(199):\n",
        "            if i==j :\n",
        "                w[k,i,j] = 0\n",
        "            elif np.abs(i-j) <= 1 : \n",
        "                w[k,i,j] = 1"
      ],
      "id": "a3495e38-6613-4cb9-ac1a-d534dd448d56"
    },
    {
      "cell_type": "code",
      "execution_count": 159,
      "metadata": {},
      "outputs": [],
      "source": [
        "d = np.array([w[i].sum(axis=1) for i in range(5)])\n",
        "D= np.array([np.diag(d[i]) for i in range(5)])\n",
        "L = np.array([np.diag(1/np.sqrt(d[i])) @ (D[i]-w[i]) @ np.diag(1/np.sqrt(d[i])) for i in range(5)])\n",
        "lamb, Psi  = np.linalg.eigh(L)[0],np.linalg.eigh(L)[1]\n",
        "Lamb = np.array([np.diag(lamb[i]) for i in range(5)])\n",
        "fhatbar = np.hstack([Psi[i] @ fhat_fiveVTSrandom_linearinterpolation[:,i] for i in range(5)])\n",
        "_fhatbar = fhatbar.reshape(5,199)\n",
        "power = _fhatbar**2 \n",
        "ebayesthresh = importr('EbayesThresh').ebayesthresh\n",
        "power_threshed=np.array([np.array(ebayesthresh(FloatVector(_fhatbar[i]**2))) for i in range(5)])    \n",
        "fhatbar_threshed = np.where(power_threshed>0,_fhatbar,0)\n",
        "fhatbarhat = np.array([Psi[i] @ fhatbar_threshed[i] for i in range(5)])    \n",
        "fhatbarhat_random_linearinterpolation_temporal = fhatbarhat.reshape(199,-1)"
      ],
      "id": "ffb866cb-5a62-47f5-b733-581888a598b6"
    },
    {
      "cell_type": "code",
      "execution_count": 160,
      "metadata": {},
      "outputs": [
        {
          "output_type": "display_data",
          "metadata": {},
          "data": {
            "image/png": "iVBORw0KGgoAAAANSUhEUgAAAXwAAAD4CAYAAADvsV2wAAAAOXRFWHRTb2Z0d2FyZQBNYXRwbG90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\no8bzBDXh16hRo8bzBDXh16hRo8bzBP8/gD/3KPG+qkcAAAAASUVORK5CYII=\n"
          }
        }
      ],
      "source": [
        "plt.plot(fhatbarhat_random_linearinterpolation_temporal[:,0])\n",
        "plt.plot(fhatbarhat_random_linearinterpolation_temporal[:,1])\n",
        "plt.plot(fhatbarhat_random_linearinterpolation_temporal[:,2])\n",
        "plt.plot(fhatbarhat_random_linearinterpolation_temporal[:,3])\n",
        "plt.plot(fhatbarhat_random_linearinterpolation_temporal[:,4])"
      ],
      "id": "dce2d5d3-2e02-4617-bdb6-3aa8964c6ce1"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "#### 3) By 2"
      ],
      "id": "a104e99f-52b3-49ab-b43c-bb3a950dfaca"
    },
    {
      "cell_type": "code",
      "execution_count": 161,
      "metadata": {},
      "outputs": [],
      "source": [
        "w=np.zeros((5,199,199))"
      ],
      "id": "1a1cb420-e574-438c-81e0-f21f04344650"
    },
    {
      "cell_type": "code",
      "execution_count": 162,
      "metadata": {},
      "outputs": [],
      "source": [
        "for k in range(5):\n",
        "    for i in range(199):\n",
        "        for j in range(199):\n",
        "            if i==j :\n",
        "                w[k,i,j] = 0\n",
        "            elif np.abs(i-j) <= 1 : \n",
        "                w[k,i,j] = 1"
      ],
      "id": "95353ee3-6d8a-4c67-be75-aa9f95f97e83"
    },
    {
      "cell_type": "code",
      "execution_count": 163,
      "metadata": {},
      "outputs": [],
      "source": [
        "d = np.array([w[i].sum(axis=1) for i in range(5)])\n",
        "D= np.array([np.diag(d[i]) for i in range(5)])\n",
        "L = np.array([np.diag(1/np.sqrt(d[i])) @ (D[i]-w[i]) @ np.diag(1/np.sqrt(d[i])) for i in range(5)])\n",
        "lamb, Psi  = np.linalg.eigh(L)[0],np.linalg.eigh(L)[1]\n",
        "Lamb = np.array([np.diag(lamb[i]) for i in range(5)])\n",
        "fhatbar = np.hstack([Psi[i] @ fhat_fiveVTStwo_linearinterpolation[:,i] for i in range(5)])\n",
        "_fhatbar = fhatbar.reshape(5,199)\n",
        "power = _fhatbar**2 \n",
        "ebayesthresh = importr('EbayesThresh').ebayesthresh\n",
        "power_threshed=np.array([np.array(ebayesthresh(FloatVector(_fhatbar[i]**2))) for i in range(5)])    \n",
        "fhatbar_threshed = np.where(power_threshed>0,_fhatbar,0)\n",
        "fhatbarhat = np.array([Psi[i] @ fhatbar_threshed[i] for i in range(5)])    \n",
        "fhatbarhat_two_linearinterpolation_temporal = fhatbarhat.reshape(199,-1)"
      ],
      "id": "109ece2b-85df-4a56-8501-8fec200aec31"
    },
    {
      "cell_type": "code",
      "execution_count": 164,
      "metadata": {},
      "outputs": [
        {
          "output_type": "display_data",
          "metadata": {},
          "data": {
            "image/png": "iVBORw0KGgoAAAANSUhEUgAAAXwAAAD4CAYAAADvsV2wAAAAOXRFWHRTb2Z0d2FyZQBNYXRwbG90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\nJUpcIygJv0SJEiWuEZSEX6JEiRLXCP5/9db/E5/6YOAAAAAASUVORK5CYII=\n"
          }
        }
      ],
      "source": [
        "plt.plot(fhatbarhat_two_linearinterpolation_temporal[:,0])\n",
        "plt.plot(fhatbarhat_two_linearinterpolation_temporal[:,1])\n",
        "plt.plot(fhatbarhat_two_linearinterpolation_temporal[:,2])\n",
        "plt.plot(fhatbarhat_two_linearinterpolation_temporal[:,3])\n",
        "plt.plot(fhatbarhat_two_linearinterpolation_temporal[:,4])"
      ],
      "id": "0669bbbd-b745-4394-bbf0-38765d339909"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "### 3.2.2. Spatio\n",
        "\n",
        "#### 1) Block"
      ],
      "id": "66d2d013-a3ba-40f1-8b42-f69f43857010"
    },
    {
      "cell_type": "code",
      "execution_count": 165,
      "metadata": {},
      "outputs": [],
      "source": [
        "w=np.zeros((5,5))"
      ],
      "id": "71958d57-961e-497a-a2b5-c76e3c7bcf30"
    },
    {
      "cell_type": "code",
      "execution_count": 166,
      "metadata": {},
      "outputs": [],
      "source": [
        "for i in range(5):\n",
        "    for j in range(5):\n",
        "        if i==j :\n",
        "            w[i,j] = 0\n",
        "        elif np.abs(i-j) <= 1 : \n",
        "            w[i,j] = 1"
      ],
      "id": "c4d8518e-2cbb-4f80-9c56-b8c63a60e1c0"
    },
    {
      "cell_type": "code",
      "execution_count": 167,
      "metadata": {},
      "outputs": [],
      "source": [
        "d = np.array(w.sum(axis=1))\n",
        "D = np.diag(d)\n",
        "L = np.array(np.diag(1/np.sqrt(d)) @ (D-w) @ np.diag(1/np.sqrt(d)))\n",
        "lamb, Psi = np.linalg.eigh(L)\n",
        "Lamb = np.diag(lamb)\n",
        "fhatbar = Psi @ fhat_linearinterpolation.reshape(5,199)\n",
        "power = fhatbar**2 \n",
        "ebayesthresh = importr('EbayesThresh').ebayesthresh\n",
        "power_threshed=np.array([np.array(ebayesthresh(FloatVector(fhatbar[i]**2))) for i in range(5)])    \n",
        "fhatbar_threshed = np.where(power_threshed>0,fhatbar,0)\n",
        "fhatbarhat = Psi @ fhatbar_threshed\n",
        "fhatbarhat_linearinterpolation_spatio = fhatbarhat.reshape(199,-1)"
      ],
      "id": "f3b887f0-a705-49bc-a0ee-7be7745f8f3f"
    },
    {
      "cell_type": "code",
      "execution_count": 168,
      "metadata": {},
      "outputs": [
        {
          "output_type": "display_data",
          "metadata": {},
          "data": {
            "image/png": "iVBORw0KGgoAAAANSUhEUgAAAXwAAAD4CAYAAADvsV2wAAAAOXRFWHRTb2Z0d2FyZQBNYXRwbG90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\n"
          }
        }
      ],
      "source": [
        "plt.plot(fhatbarhat_linearinterpolation_spatio[:,0])\n",
        "plt.plot(fhatbarhat_linearinterpolation_spatio[:,1])\n",
        "plt.plot(fhatbarhat_linearinterpolation_spatio[:,2])\n",
        "plt.plot(fhatbarhat_linearinterpolation_spatio[:,3])\n",
        "plt.plot(fhatbarhat_linearinterpolation_spatio[:,4])"
      ],
      "id": "8d69a874-d869-4c8d-a77c-12685ef84880"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "#### 2) Random missing values"
      ],
      "id": "d5248dc0-6ab9-4079-99bc-40a9c11840fa"
    },
    {
      "cell_type": "code",
      "execution_count": 169,
      "metadata": {},
      "outputs": [],
      "source": [
        "w=np.zeros((5,5))"
      ],
      "id": "cf70876d-5f90-4870-b2e7-4839f8b29e6a"
    },
    {
      "cell_type": "code",
      "execution_count": 170,
      "metadata": {},
      "outputs": [],
      "source": [
        "for i in range(5):\n",
        "    for j in range(5):\n",
        "        if i==j :\n",
        "            w[i,j] = 0\n",
        "        elif np.abs(i-j) <= 1 : \n",
        "            w[i,j] = 1"
      ],
      "id": "6f2909ca-c6d4-4754-a8d6-a8136f28b8e7"
    },
    {
      "cell_type": "code",
      "execution_count": 171,
      "metadata": {},
      "outputs": [],
      "source": [
        "d = np.array(w.sum(axis=1))\n",
        "D = np.diag(d)\n",
        "L = np.array(np.diag(1/np.sqrt(d)) @ (D-w) @ np.diag(1/np.sqrt(d)))\n",
        "lamb, Psi = np.linalg.eigh(L)\n",
        "Lamb = np.diag(lamb)\n",
        "fhatbar = Psi @ fhat_fiveVTSrandom_linearinterpolation.reshape(5,199)\n",
        "power = fhatbar**2 \n",
        "ebayesthresh = importr('EbayesThresh').ebayesthresh\n",
        "power_threshed=np.array([np.array(ebayesthresh(FloatVector(fhatbar[i]**2))) for i in range(5)])    \n",
        "fhatbar_threshed = np.where(power_threshed>0,fhatbar,0)\n",
        "fhatbarhat = Psi @ fhatbar_threshed\n",
        "fhatbarhat_random_linearinterpolation_spatio = fhatbarhat.reshape(199,-1)"
      ],
      "id": "c2496f47-cc51-4870-bc52-6bdcd1b4ea52"
    },
    {
      "cell_type": "code",
      "execution_count": 172,
      "metadata": {},
      "outputs": [
        {
          "output_type": "display_data",
          "metadata": {},
          "data": {
            "image/png": "iVBORw0KGgoAAAANSUhEUgAAAXwAAAD4CAYAAADvsV2wAAAAOXRFWHRTb2Z0d2FyZQBNYXRwbG90\nbGliIHZlcnNpb24zLjUuMSwgaHR0cHM6Ly9tYXRwbG90bGliLm9yZy/YYfK9AAAACXBIWXMAAAsT\nAAALEwEAmpwYAADf5ElEQVR4nOz9d5hs2Vnfi39W2KGquvvkycoSAgmEJGQsDFyDbTA4gO81DwZH\n7sXmAg7XNva1fZ3AAWyD+WEMBmMyGCSRk5BksGQJISTNKI00M5qc5+TurrTDSr8/1tq7qvt09zln\nps/Eep/nPH26u7pqV+29v+u7vu/3fV8RQmAVq1jFKlbx/A/5TB/AKlaxilWs4umJFeCvYhWrWMUL\nJFaAv4pVrGIVL5BYAf4qVrGKVbxAYgX4q1jFKlbxAgn9TB/AQXHy5Mnw0pe+9Jk+jFWsYhWreM7E\nbbfddj6EcGqv3z2rAf+lL30pt9566zN9GKtYxSpW8ZwJIcRD+/1uJemsYhWrWMULJFaAv4pVrGIV\nL5BYAf4qVrGKVbxAYgX4q1jFKlbxAokV4K9iFatYxQskVoC/ilWsYhUvkFgB/ipWsYpVvEBiBfir\neE7HA584z3SzfqYPYxWreE7ECvBX8ZyOd/zX2/nU+x5/pg9jFat4TsQK8FfxnA3vA94FnPHP9KGs\nYhXPiVgB/iqes+FdBHq/mtq2ilVcUawAfxXP2fA2An1wK8BfxSquJFaAv4rnbPgE9N6vAH8Vq7iS\nWAH+Kp6z4TpJZwX4T2+EAHe/E/wqd/JcixXgr+I5Gx3DX0k6T3Oc/gT83NfCA//rmT6SVVxlrAB/\nFc/ZcHbF8J+RaCbp6/iZPY5VXHWsAH8Vz9nokrZ+xfCf3rDNzq+reM7ECvBX8ZwNnzTksGL4T2+4\nNn61qwrn51qsAH8Vz9lwduXSeUaiA3pzecAP3uOms2t8QKu40lgB/iqes9HbMleSztMb9soZ/vg3\nfoN7//gfJ7TtNT6oVVxJrAB/Fc/Z8HYl6Twj4a5cwzenz+C3t/H1Sv55NsQK8FfxnI3elrkC/Kc3\n+qRtddmHBmvSV3stj2gVVxgrwF/FczZWhVfPTMzmcwAm0+llH9sB/VUDvvfgXniLxOn7t/vr+lrE\nCvBX8ZyNlYb/zMTFcQT6zfHk8g+2Ln29SvB+z3fBT3zlVR7ZcztmWw2/9B9u477bzl6z1zgUwBdC\n/LgQ4qwQ4pP7/F4IIb5fCHGvEOITQog3HsbrruKFHW6l4T8jETpJ50pcOh3Dd+7qXmTrIdh+5GoP\n7TkdbR0/q+nmtatvOCyG/5PAVxzw+68EXpX+fRPwQ4f0uqt4AceqedozE74DencVgG+ukuE7A/4q\nF4nneHTX83xy7RxNhwL4IYT3AhcPeMhXAz8dYvwBcFQIceNhvPYqXrjR98NfSTpPa4SrqbR1nYZv\nru5FvI3/nudhW8f73no39cz0O9Z6cpWf1VXE06Xh3wws788eTT+7JIQQ3ySEuFUIceu5c+eeloN7\npiN4T/voY8/0YTznYsXwn5kIyYcvrsCH3zP7q5V0vIXw/Gf4Zx4Y84l3P8rj92z113P1bGf4VxBi\nj5/teZeGEH4khPCmEMKbTp06dY0P69kRk3f9D+77iq/AXjxok/TCjHc9+C5+5o6f2fN3XaXtSsN/\n+uL33nYPd9z/2QDIq5F0rtqlY18Q7ZeraWTz3oV+x/qsl3SuIB4FXrT0/S3AavJ0ivbBB8Fa3NbW\nM30oz7r4rft/i7d9+m17/m4l6Tz9cebBMdvT4wAId3lgCu4qAP+hD8Q++5A0/Oe/pNOxee88Ll3H\n9fS5L+n8OvBXk1vnzcB2COGJp+m1n/VhL1wAwFeXL2R5oYUNFuP3vgFWks7TH955go8bdnUFDL+3\nY14J4L//++B3/3V6oReGpNMBvrOh7/46n7SEazSnWR/Gkwghfh74EuCkEOJR4F8CGUAI4YeBtwN/\nCrgXmAP/52G87vMl7PmYqwjNqt3s7nDe0e7DJHtb5orhP23hfcD7yBOVu/z12mn4V2TLNNWiE+cL\nJGm7kHT8YsdqA23tKAaHAs874lCeMYTw9Zf5fQD+5mG81vMx3PkVw98vrLe0fm/A71srXCM2tIpL\nw7uAD4nh73NelqMD+iuyZboWut2cMxB8HKco9koBPj9iuh0XzXltKYZZ//Nq0l4TwF9V2j4Lwp4/\nD6wY/l5hvNmX4a80/Kc/vAt4rwDQ/goYft9L5wp0adss2il0wB+e34nbOx/cAuCBs9N+vgNAdY2s\nmSvAfxbESsPfPw7S8N1Kw3/awztPCBE2dLgCN4m9ClvmMsPviq6ex7LOL3/kUWbjTsP3vYYP186a\nuQL8Zzh80+DHcTZoqFcMf3dYb7He4vdgen5ly3zaI0o6keFnV8Twk6RzJUlb20QpBxZfn8fVtm+7\n9RFGSR6zLuzYqa4A/3kaLrF7AF+vGP7usInh7cXyV5LO0x/LgK+xlwXkhQ//Shh+s8Tw0wLxPHbq\nVI2lTIDvre9NCLCSdJ630en3sGL4e0UH+Hvp+CtJ5+mPZcAHLtteYQH4V6Lht5dq+M9jScfVrq9I\nddYviIuAarpi+M/LsOdXDP+gOAjwO4a/smU+feGdx5PRG6Mu117hqjT8JYbfA//zOGnbLN6bs6Hv\ngz9Yz1cM//kanQcfVgx/rzhQ0lkaYr6yZj490bFQE5KF8DKAPwtDHr7lj12ZLdO2S9q93fn1eRhi\nCfD9koa/drRYafjP1+g0fFGWq7mfe0QP+G4n4DvvaM3iZyu8f3qiA6XtsB5/cBnAf7x4Ffe+8s/T\n1FfA8G0NhJgX6G2Zh6jh2wZ+6s/CY7cd3nM+hVBmGfB9P6N5dLRYMfzna9hz55FHjqDW1wkrwL8k\nbEiSzq4in7d8+i186LEP9d+vZJ1rHyGEPl+yHTbiDy8zBMXEgnucuQxwe7cAd2eWJJ1DBPzxY/DA\ne+HRWw/vOZ9CaBM/S0voGb6UguF6tmL4z0S888F38g3v+IZr+hr2wgX0iRMrhr9PdFLObg3/9Ow0\nZsn5sUrcXvtY/ozHV8jwjcjj1/YyWvxy8tebayLpmEcf5L7fOsXs9nsP7TmfbHgfyNNbm4kI9s4F\npBK85otv5kv+8mdek9c9/Nrd51F88vwnue3MbRhnyFR2+T94EmHPn0efPInb3Fwx/D2iT9ruYvjW\nW+SSW2Tlxb/2sWx/XQD+wXknmwDfmsucn+W+PM5ck0rbcz/ys7STjObB04wO7VmfXDTWMwwCcom1\nnpDaI0stuf6lG9fsdVcM/4CoE3uZ2/k1ew2XAF+UJb5ZAf7u2E/DN97sAPwVw7/2sQz40xAhM5iD\nnWVGlADYy0k6dmlBX26cdkgMv7r9k2z/zgfiUz4LKtpr4xgEEKXCiyhJehsZ/rWMFeAfEHVq/1rZ\na3eBuO1t1NEjyLIkVCvA3x37MXzjDcovAf5Kw7/m0dlgAaasAWDbg+8NKyPDd5fD7WWGvywTHZKG\nv/nWtyCHBYiAfxbcZ7V1DIJAdYDvY7dMtQL8Zy6atF2dm50M35w5y5nv+ndX1vL1MhGsRWRZYvgr\nW+ZyOO8IaTDaboa/knSe/lheVGdhCFwB4KuO4V/m/NiWB7Xm03kW2yR3cUguHT+boY+MkFnAV8/8\nfVa1Dh1AZpIg4tt0LlB7z7y9dlbUFeAfEJWLF95uhj9997u5+FM/Rfvww0/5NYJzoHRi+M/8VvPZ\nFG7pZr+E4buVpPN0x07Aj5KOqQ+WO00H+PbyGv5/On6Uf3nyOCwTrEOSdIIxCAVS+6eNWH304U2+\n8Sc/jHWX5iFq45EIlBZ4IQg+MK0M52Yt7/jk6Wt2TCvAPyB6hr9Lw3dbm0C8iJ5qBGsRWq8Y/h5h\nl272Sxh+sKiw8BysJJ1rH8ufsZFR0nEHMPwQAlYNgCsAfNswF4KplDutnodUaRvaNgF+wNfXboTg\ncnzwgYv87l1nGdeXLlq1jQxfB8urzt+HahqM8Xhg3l67/kErwD8gGre3pOM2rx7wf/eh32W72d7x\nsxACGIPQGlkWK4a/K5ara/dm+BKRNM+VpHPtY1nDdyoyfNfur4eb1hFkXJQvq37ahlYIKiGuHcMX\nIQJ+89QBv7n/AeYf+ciBj5k38djtHotWbRwS0G1NaSpUa3DW40R08FyrWAH+AdFJObslHdsBfntl\nxRHbzTZ/9z1/l9+8/zd3/qK7ELRClIOnxPC3m20+8PgHnvTfPxtjmeHv9uGbYJBeI5Peu2L41z6W\nP+OgO8DfX9JpJ4vFwLrLJCNdgw2CJnBNNPxgDEJ6pA6E5qkvIud/8Ad54p/8fwc+ZtrEY99rk9IY\njwJ0cEjvIITYQA1oV4D/zETP8HdLOptbwJUz/G6HsBu0uk6CQmdPmeH/yj2/wrf8zrfsOx3quRg7\nJJ1dvXSssyivUCaeo5WGf+1jx6LaAf4BlbbNdEFgLtsd2bZ82bsl3/or7OnS8T7wln/zIe659czV\nHjbQMfwI+P4QkqJ+OsWlORb7RZd83Y/hqyDwfo4IlhBcLL4i0FxJK+knGSvAPyB6H/5+kk57ZYDf\n7RDsru1p11BKKIUoS4IxT9r5M7MzXHD7Tod6LkbXVgH2YPjJlinT+11JOtc+lgFfq4ImZIQDJJ16\nqT3AZS9r13DjGbjxAvh2tvSi8RqYXKi58OiU849Mn9Sxh9YghEuA/9QZtK8q/PTgY5m1+zP82kZJ\nx5kpwntCiJW2fiXpPHOxnw9/oeFfGZvuAT/sYhbJnCyy6NIBnnS1bQeIuxeV53IcyPCTLVOln++W\ndH72jp/lPY+851of4gsqljV8rXMaMvwBhVfNbInh+8tAjW3YmMKwgbpdAtIk6WydjaTLNE+OEAXT\nIoRFaI+/nEX0CsJXFcEYnrj48J7T2ABmB2r4Hh0A1yCDRQQRh6CwknSesegYvr1wAb+k119t0rYD\nfLeriKQf+5ZcOsCT1vGf74C/F8OXKGRK5i63R77jwh38+w//e9766bc+PQf6LA/vAz/7Bw9RX67a\n9XLPs7SoZioCfjigl047W9wfzh+s4YemYm0mIuA3S1JJume2O8Dfw/FyJRGMQWAjwz8EwA9pdsXX\nv+2reffD797zMR3g+z1auXZJW2wdNXxkbKAGK0nnmYrGNRACb/5Hb2Xzp38aSDNo5/Hie8qSTjqx\nQi0x/Cep43cM+HkL+Hu4dAQK6XYy/BAC33vr9wJwobrAKuCOJ8b8s1/9JO++6+xTep4dko7MqUMO\nZn+C0iTAl67BhYOhxp6/GF0rHurZkpstAf7WmXhfPHmGbxCYBPg85fkJfh6PR1eGc9W5PR8z6zX8\nS1+rMg4FYCpEsIiQAF+sGP41jfE+nlzjDS44Bg2U4xpzOiaL3NZW/5irZvi7HQfd2Det8EVszvZU\nGf4lr/EcjoN8+N14Q5UWgi5pe9uZ2/jg6Q+ylq2tAD9FlZj9+elTq/NwS5JOpjMaMjig7UhTxXNW\ntGPsfgx/8yHYegRz/uLieCdLgH9oko5BhBapAwRxxQ67/aLrxzNsFuaO3TFPx2r3cJDVrUMidjF8\nn5K2K8A/tBifr/iF7/wQ83HLwxfmvOFf/Q8++vDmJY/r5JwjKV/bsfpOzoErt2Xuz/Dj9/dNH+T/\n+9C3x9d5kgy/Y8DPJ4a/w4e/S9JxaXck0899+v7B8YMAfOmLvpQL9YV99dUXUjRp0MaF2VMEuR1J\n2wj44oBumc3cIr1BmxlueQ7ucvz634bf+vvY84v7qp0safjpet468xQBv2lj0raIvX38+OJl/uLg\n6AG/Dfs64zqGv5ek0w+EaWtEiIAffFjZMg87HnrfnZx9eMqZj9zHQxdnOB84M75Uh+xW7R7wqz0A\n/woZfp8L2A34ybpwod1iLBuq8jjb56f85PsfuGqbYa/h704MP4fjoKRtxza7pO13vPVWjPP953Dj\n2o244C4pdnshRttdZ09xMPZODT+jJkfsw24B2sqibYXyLS5IxtUmb/vQ9+6UU+otmJ3DXFicp2a2\nDPgOaxyTi/Eeap8Cww8SfuFY6vI5vpTkXfFzhdBLr4PmUrmxi1nH8Pe4l5u0GIi2jpKOUAQXVoVX\nhx1bD0S9rTpzga15p3vvobElVr4xS3NT92L4lwF8Z6Ldaj9Jp7NlttLTasEnX/s3+J3f3ebbf+MO\nPv7o1lW9r2dSw3/4Uxd44ON765hPJXbYMnfdVCEl3oRKE5gujJnUtgf8m9duBuB8df7Qj+u5Fh1j\nvDB7apLOsvVVCU0TMsQBSdumdmg7RzmDQ/HO3/8u/vWdP8HjZ29fPMg20Ex2AH47Wy688myfqyCA\n1OIpSTqVFtw2TPfzeOtJPQ/sdNLtJ+mEEBYMf0/Aj+dEtk2SdCDYVdL20GO6FQGhmVu25kn33uuE\n2J0MP6Qkjb1CSWc+bvnRb3svj929dYCkE0HaCE+bgdFD6lm8ELaqq/PTdxr3bifQ0xEfeddD3Prb\nDx368x7k0inmKeG9XgAwtC2Ndf3Nd+PoRgAu1Csdv2OM558yw18wTyUVDRnSH8Dwa4+2NdK3OBSb\nk0fj8cyXzomtoZnQbk7pZH43Wy68smynhO3Jm9eeFOCHEMBanArUaY6Rn2xd9fP0h7Qkuw6aS69N\niHmTbiOzF6Fsk0dftdGWmR64smUedkyn8cNvK9szfLNXUiV58E9MdzP8rf4xBzH8C49Psa1ncqHq\nu25eklBNW20jPK0GL3U/B2J8lYD/TGr4znicOfyL9KCk7cZ2OmdHortpaBta62l9i0Bw/eh6YMXw\nYQH4F5+ihu+W7hMZJEYWqIMknY7h+8jwt6qomzdmSbKxbWT4m3NOH0s/Wm5f7F2fsD354vWdtsz5\nRfjwj152gn13n1oFdR5XFT/d2vGYr/i+9/IT73/gwOfpn28J8Ift3oA/W1qY9mL4HeDrtkV0JM2z\nKrw67Jg2MXnU1o7NeceK9yiMSFvVU52kk06y29zEr61jhWQ+27+PyPjcosdLlYpTduvQXdK2lY5W\nQ5AaZ+Pxnfndx3nvW+6+4vf1TLp0rPG4a3CRdoBfqOKSz259HF8vHIt92QfO0Nio4Req4OTgJAAX\ntg5v53H27Iz//O/+gP/yP+7h37/jLr7tbR9ne3lhfvD34CM/fWivd1jRAciFp+jS6a2vePBxfKE6\niOE3IWr4wuHQbLdRtmnMUiWtrcHMcVtzHjmZwLhqef+g5Kc21sFb5tstWakYHSmwrV8A6Kd+GX7r\n22D7kQOPu7NPWyUWDH866X/vfOCu0xPuPjPZ688v/RyWAb8Je0o6yz3t92T4iSBlxqakbToWworh\nH1Z456lclABM43pJZ8+kSjqJx5PEsmD4FzGjDaxUVPP4mL3aIYwv1Ok1w/6FV52Gj6PJwAsNQSED\ntE9UPHLnlTsJnsnCK2f85UfYPYnoNPyhHu7Q8EMIbEwjOJjjsf3uwLY0JgJ+pjLW9Ro5kgvv+w9w\n/nCGVv+v33sE+eCcX3zHvfzQe+7jlz7yKJ9YzrXc9pPw7u86lNc6zOgAZHNu9uzNfrnwPsR/CfCd\nbBEhYGWOOqB3U9v6BPgeJzRbCejb5dYJtiF4cOOGx09Ehutry6+tjfjxoxsQYtJW54qsiGTIdu2D\n61SgVW0dePxdRXxk+Ok9TRfFXZNkzd6rjfGen8cVSDrTpQZte0nGJr2Hwljk0j3rWDH8Q4vZdktI\nb7ltfa+T7+mTTQz/6C6Xjt3cxKxtYKTGNS31XXdx1+vfgHnssR1/Pz6/YPidPLQDjCen4e7ficci\nXJJ04gU9DMDcMj5f4X3gR993P//xXZ8+8L31SdtnwKXjbJR0fuS99x3qtJ7u8xpmwx03lQ2WjVk8\nj5Ok4Q+cjRq+rSlCQPzCX+OkabmgJMwOJ6HcWem+7U0v5a3f9GZg181s652Nv54lscwYu13t1cQ3\n/OSH+Y7f+FSv4QcacAErS3S49P22jz7K+B3voG2JgC8DXmRspXPYLDUj/LFRxlvyDfBwYV0wL4Da\nMZaSsZQE53DGo7XsAb/X8bsWDPXBTqxe0pHQdAx/yQnU7dImhwj4yz3t9wT8dE7KdifDf04UXgkh\nvkII8WkhxL1CiH+8x++/RAixLYT4WPr3Lw7jda82OhCGuN3cPIDhdyC91gH+bKHht2vrPeC3Dz8M\nxmDO7OziNz4f/95Zv7dL5xNvI7zv++Kx0Ek68Wo87iTCx8VicrHiv773fn7tY48f+N56SecZSNpa\n42lbx3e+/S7ee/fhuXU6wB/owY6byjhD5mOf9Qnx/ZadpHPxXvL5Ftz3bk7ka5xX6sDioKsJkwD/\niUce4+7xrcCum9k8OwF/2fWxp1Pnjl+Hn/7qff/+oQszbn9su2f4Zd2CDziZo/ewJG699a08+g//\nEc6Bcg1aBoKQbIskp3bNCJ3lfwwLPuZiHubCBgnwPUdOS77w9kDlaqzxqGwJ8DsPe3OFgJ8kHaMX\nDN/NpnzND/0+v3PHGcZVatB2hYNRdmv4zR6y1jLDtz5w5oExP/VP3k+dqo9t59IJbgfDF6N7qP3W\nFR3Hk4mnDPhCCAX8IPCVwGuArxdCvGaPh74vhPD69O9fPdXXfTIxSTKLNjOMge0r0PAHVbIOWEto\nW9zmJs1oAyMVrm0JqTJ2d5uFZYa/Z/M01/S5pkY6EIvpTde7xWn5xJ0XODdpLqu/Xv/IjG98p8O6\nq2dwTzWcWTSkqg5R2ukZvh7u0PBtsOj0GY1TljsCvqO1FXkI8Lc+zImTnxUB/4AWvlcTJt3E24/P\nefsjP5+OcRfDN9Vlk4hPdywzxj29+I9+CO5/z77TpWrjODNuesBXvolFQqogC5c+n59XhPSaIlgQ\n8e+mRGBvugXYNTRCUM7iPXYxMXzZeN50m+Tr/5dn286xxqPzAxj+cu+dPaKTdFqteoY/3xpz60Ob\nfPT3HuMPfuB2CFfP8M3GgEETLjEUwKLKFmLh1ebpGdPNpscg27VV8TsZvlj7NG3+qSs6jicTh8Hw\nPx+4N4RwfwihBd4C7E8XnsEYn68geEazJzBW9Ax/P5eO8IG8gnmn+1UVbnubplzDSo1vW3zy5C47\ndtraUk+7Hi9+78IrZwnJh9ayc1zfdUvDIj5+Z3SZzFpHdcDos8/49JQ/+ZGAm8/2fczjWxV//D++\nh0cuHjyH9GrDGk/wARFiF8BDe94lhr8M+MaZ/vMap14uhbM0xtO4liIEyIecKI9zQalDY922Sdvw\neg2Zsn9+N+AT4BlYdA+KHYC/l1OnWxD3aa1dG8+Zcd2DlPQtuAj4Cn/J+w1t08uT0jvatOusifJb\n050P21ALwTDlYy6skwAfjm4LcgtjO8MZh9KSrOwAP91HTUqy1tvcu3kvf+5X/xwX60vzXr2kk2c4\nJbAqUI/jYmHO17RbLUW4cobvq3j8zdHRvj782a6kbWdqaNJuwtolhr9D0nGYPRbRw4rDAPybgeU0\n+aPpZ7vjC4QQHxdC/LYQ4rX7PZkQ4puEELcKIW49d+5wi3nGpycU7Ta5mWCc6LW7vTS22tasVyAQ\nnD0af+a2twl1TT0YYqXCty2hTgx/CfA7OQeilW3PpK030DF8LMrvzfAfeWTBXg4qnAnpuV29v3zx\nwPkZ952b8e5fuYf3/+I9+z7uaiKE0FsyFTzljozL0QN+tkvS8YsB5uMEVoW3NNZjnIkMXw84WZ5k\nU0mcOZwFzi4tuKPto+kYd0k6cGgS0mFFYz0ycYg9d4o9494P8B3WByZVC8EhnY3TmdKA8t0Lqm8a\nQtqxyuCYJnOCCpE5td3r2cjwR1NBkIHJEGalQLWBE9uQGxjb+hKG39aXavj3bN3Dfdv38anzn4Lx\n4/BDXwjbMa/W3ZtNHhdpk0EznaW3npKniKtg+PF6qo8MGOxry1xO2vp+d9TO489dmvErdzF8Jx0u\ntE+5udt+cRiAv1dXpN1H+xHgJSGEzwX+M/Cr+z1ZCOFHQghvCiG86dSpU4dweIvYPD2lrC+ibE1r\nJd29up9Lpyu6OnM0OUJOx2nydTnCSB3LtZtLGf5yrsBO5z3g+zYwvrC4uTqGX2N7AAM47gUEz6A6\nR7PV8tk3bwCXKZxJ7CtUB8wYTUm37QenPHLnky8tXw6/NJz6z4gP0h7iIPZlSWdH0tZbpI+f13bH\n8H1K2npDDqAyTg6vwwvB5h6s78mEbz1VkifWtk8AeyRtIVaPPkvCtg7TOE6uFUixj6TTLVR7AFcI\ni2Ze43mDCA7lLdY6girSi+x8v6Fpe4YvvGWa7MfaRcDvihqxNbWQrE8EYegJIko6o23BoIXcwdhU\nOONRWpEXcRHpJZ2k4X/sngf5+KORHD48eRjO3YV9+FNw9s54PKlA0uh4TE0GNlXz+vRcRYiJ1itx\nMXUafn20ZFhDbRse29q5yM9bx1En+KOVxrolhv/wJ+Hxj/bfi2Bx2YLseeEQsqV9Em6qK4nDAPxH\ngRctfX8LsCPDGEIYhxCm6f9vBzIhxMlDeO0rjk//wROcfazh+MU70a7G+gXA7nWSa1v3RVcdw7cJ\n8Kt8hJWK0Lb4PRl+OvnB0zzyaA/4193/WfzCd8VkH97S9fVqxE6GLxDkZspo9gTHHPyZ190EHOyj\nvhKG37mR2truYKtPJeySXPBvs5/mprPvOZTnhSVbZrbTlmke+wgqLZCbaeJS7lxM2gZDjgAhODG6\nDoALzSEtbsYzUzAuz7M2Ph6PcQnwP0bNb4yGO2eyPsPxuz91J8c/MabMFMdHxd6STrdQ7cHwly2C\nkyq2AVDOYo0HnRj+rvcbmiZajIkMv3tW7RPDd4uFsRGCI1Nwo/g68wJys+CQ42a2YPjl3hr+PQ89\nxgcfjID/yOQR6nsf5J5fuYH63vvi8aR7s14C/O6+JSVP8xBfc3oF8247SWe+kTNo4exkwl/4rzvn\nSU8byyuN4vObDDu3C4b/kV8hvPd7+u+ld/iy6P/uhosW7dtrZs08DMD/MPAqIcTLhBA58HXAry8/\nQAhxgxBCpP9/fnrdp63mfevsnPf8909z/anASx5+J9pWWFS/D9lT0nE1J2Yd4HcMPzpxXlzflhi+\n3ZvhX6jJMkFmZni7kHR0k1NPTdyuOUNIF1kdzA4NH6BoNhlU5zjqJW988VFg/+ZXkfGmoph6/0Wh\nm7xjWx9v2EOI5QpbG3Ly+vBkuE63H+rhIjHWTLC//NeR6fOaJPDIvaM1jtZbChEv67Uylm7OzP55\njauJYDxOwjyboEy8SZc1/J/PHd93/OizyqkzPl+RTyy5lpxcy/cmDR1g78Hwm6XzO6taRHBoZ3HO\nIbJO0tn5nL6pCUsM36QbTfsoqTR9h9OKVibATz1u6mLHUzGrq+jS2cOWaeZR7lwXFW3S0R8eP0z7\n6OOAwJ6L+a9e0tHpfstFf5/ItEMt0mm8ElnHV3NEWVIPFNqDrRs2dy2k88bS3dHOLjH8eYM3DakF\nVJxnOxj0f/c1v2d480NPXDNr5lMG/BCCBf4W8E7gTuBtIYRPCSG+WQjxzelhXwN8UgjxceD7ga8L\n10qk2iNO37+NNZ43vWKMDB6NBQQpYb+vpHO8A/wj6XGnnwDg9dXvYKUE0+KqhsnaLTvGHc62GkYj\nEMHtSNp2Eo6zPmr46ZzWwiL9bsDfZlCdQyN46TDeWOf30fBb1yLTc/kDGH6fnLa+Z/jn5ue4b+u+\nff/mcrFccOXIyOrDYdMQFzKB2Flp20ww+F4CczJ1HRQCO5vRBEceR0swyKMUVh+Sho/xOAVOWEQ6\nl8vXThU8lZDPKsBvKkvWBgZScHyU75O03R/wa+u4gQscY8y8bpHBo7zFGY/M9tbwQ9PuZPiR6/UM\nv0tyNu0UQuD4BNrE8E2+8/VndR19+Hu4dHxK2p7Kqv45H548jNuMC0FIWnsH+G2mWK+PU+UCkqsu\ncx3gx2Pcbz7GjvdXVciypC7i35TVpYx81joK0d3vbsHw3QDvDJ2+IL0lDEf938ng2GjqZzXDJ4Tw\n9hDCZ4QQXhFC+LfpZz8cQvjh9P8fCCG8NoTwuSGEN4cQfv8wXvdKw6YLRM0iGOVr8aoqDmD4lak4\nMg9A4PxGYviPR6VqXW5xVM7AGM5NCj78pn/C1tbiOZzxKOGRwUWts99KdBdA4MJ41jP8JhhGcg2A\nrI0XcdFsMUiTdMxWyyhX+zJ8400P+FwBw1d+Uen3nz/6n/l77/l78fetY7Z9dfrzMsN3IadoDxfw\ntdRkKsMFF5Pe7RwrRA/4Xlgg+rzFubO0wZEnv3eZReZU2cMBfGEDXoWos3aL95KVsSZQS3FoNtDD\niC7BueEFx0b5JUwUODBpWxvHD+ffxz/Lfpamjn1fpHc46xF5Yqa7AH8yvbiD4SPjMbzoXMb3/KjF\nzZPLpZ2wVkFuYb6WWphkO56Kqq37wiulJVKJ3oevbdy5HZMVbTr2xyaPYbajLz808X11Gn4thnzd\nx/4p2xufhzKOm48OKNM9WF4Nw59XiOGAeQL8gbXYVI3cxayxDFUiJXbReqQJI7xtkSK+jvQOhguG\nL4KLFuNrULkOL5BKW5PsdGJ8EVGW5GVkH0UQKCn6ZOZyNLZi1ILQoS/WMI/HrL/KAzfqC2AtdZtA\nu14CPusRwSO82zElqAcJ4zmzNe01/ArD8TwmAYukNxfNFmuzuMCcf3TKibVi34lFxhtUeq5wQNK0\nY/h5iMlW7wMX64t9z/iPvOthfvHf37rv3+8Vyz10bMgZmMMH/Fwm7de3YOYYRC/pOGFBQBAKfe4M\nbfAUCWwGOgH+IQGwcAGvfQT8NLKvZ/jeUQkwQmCXm4M9w9EmG+CGE4xytaMCtI8Dkra18VT1ZzJo\nT2DbKOlIb/HGo9KC6tudu8pqvr2D4R/V8fq6+WLGi8+B2o6vV7dzTiRn5STynUsAv65brHGoLH7e\nWaEiw7cNKuV41pnvmAcx3oxqcWh2MvxGrKGCpik2UNbz+ps3Yr4HOJoSp1cE+HWNHAypEi4MkgVz\nOdE6ax0DlXaBdtGWovUjgrNkKr5xESyMFgxfeEtu7bM6afusj47Nis3zqOPHyBI6FkFwbJjtreGb\nGYM2IJcA356NM0EfW3spp+Q2ytSYVHDkllZk7wIyOERw2OU+O0uSjmnbnuFXtBzLYhKwbLbisTVb\nFO0YpOXcIxNOrOX7MvzWtb0meKCG7wIygEoXuW0dUzPtcwzzcctsa39L2P/5Ex/iB9+9sy+N3aHh\nZwzs4Q0c6QFfdcm+BPiCHnC9dAgpCEKSXThHiycTETXKZBus3OEAvnSBoANeeISPr99fO6aiTlv4\nunl2AH7X8gJgzcIw13u3vugY/h4+/Kqx3D75i2xVn49tbbquYxJS5fHzNbsAX7ZmB8M/JaNLqmjT\n3OY6tVgwU45P0jyD9fi3IXWzvJgWgLppk6QTny8Cvu0dOi4IRn6KWUrqT7cSw99VI9OI1EdL50jr\neN11G/3fHO8B//KSjq/myLKMVcHAqPWA2yHDzBpLKdM1aj1+ieEHZ9A6Ar4sMkS+kHNlz/BXgP+k\nw7axcMNtb6KPHiPX8SI7milyJfdurWBrcjti++jLsVkC6q0xUns+Vb4BqQLSttRp9zCZLnnvre8L\nKjq/7UAPoAMJ63GmXWj4tBzTMcHYMfwsdRYs8ppzD084eQDDX9bwf/9Tj/EzH3hw78/Be/JlF2Hr\nmZkZla3wweOMIywVieyO2x/b5o4ndlY12qWKQhdyRnZr8cu73wmf+IU9n+tKwnpLJrOe4RtvwERJ\nRyQV1AmLUBIvFMXFs7QhUKh4A5XJRVIf0ML3SiOEgHIQeobfSTpdXqShSmb3uj248vOpxsX//t+5\n/89+1WW92u0SWx22MMjV3pXQZm+XzoPbD/Kj7/s+TBgiyAjWLhi+A10MmbmjfOh9jvv/4D7847FC\nVLZuB8O/SUZ3W2ES4CcnTN3OeoZ/oQP8dK91nTMb4wkBlJbce3aK7hh+kj7Pi2OUfoZNbbEB2lRU\n5XcZKqyI15FVOcIFPuP4gllfDcMP8wo5GDDN4n0yaADhdiRaZ42lTOYB5wKz9LytH0bAV/EY9bBE\nLQG+8I5ixfCfWrTbU6StqW69DXXsGFm22MZpJfexZVY05R/l1s/4u0gtCIm9ydxzWl6PkAFpDfOk\nJ952/8X+hHsXYsm0dz0grGfrC0nHepxt+yRuFVo29FEAjm/exfGLd4CPDoMj2YzNJ2acGmT7ziRt\n/QLw61l9CSh3YV0gWyqbsK1jmqxtta37xWm/IRO18cx32dbee/97+v87MtbcVizR/5Vvhp/7Wvjt\nf7jnc11J2GDRYsHwjTPQzjFLGn6QFiEFdTZgcPEcDYEczYUf+3HCBz4Sj/uAjo5XfCzGI4CQub0l\nHVtRpWukaq8dwzdnz3LuP34vzT337Ji8tFd0cg5A2XpGucK4Pdrv2r2TtreduY3JQxFYQ8hQ3iF8\nZPjBg9ks+fnz388nbiv47Z98iF/97vcDII3rGT7BcYuMZoc8daol7TIaO+f4JOAFnF9LebKhwgm4\nJ5VudgYgmQm+6gd+j21jMY3jo//zLL984Tt5x4XvwAUNoeZ4eZxSlfhEvkLbtT1JrRUS4HuZIxyc\nyhf60Vpi41fE8OsaMRywpeN9MmwAaXaA9Lx1pM0K3nqe2Iyfcc/w1RyCRY9GOwBfBkdp3YrhP5Wo\nHjuDrKcM3vhGTnzj/0Weki1HtUJLsY9Lp0YywMucAoVNDgGVBx4X1yEkSGtxKRE7mbd8/+/G6lVn\nPdKb6NJJz72Wr/UygLcBZ01suSKg9YZSRD20qM/x+k/8IE0JHsHJbEIIcMJKLs7aPYcpGGeQ6ceF\nNUz3Aez9GD7A3M777X/fnGopQghUxjFb0oDPV+f5rTt/Y/F8IWfdj+HcXfDxn4fyCP1ElycRnaSj\nZbwhooZfJY9V/JkXDikFTT5guHUO6QKf+2sTzn73dzP5pV9BBaj2mTl6JTE3c9798Lv7z6QH/F2S\njj17miotptU11PDP/af/1Lfq9rOD7aZtqiL1QFEHBglYLmnRsY9LZ27n3Lz9GQBMmxwdQs/wCYLt\nuwSZqPiyP/Uor7zuQTabWPcgzYLhCzyFbBDektkEsOn1Gxs1/ItrCj97I9JL3FDxrX9TcfurU2/8\n5MkXSjBvHa2A6WbD7/+PKRftLUzNLYzt9RzjPMX8IreMbkSltiZ9n6vE8FNJHkHmCL9w6HgCeYBC\nyyu2ZcpywDQ5xHILYg+G35Er70Iv6bR+SO1blGwQeORohCyWGH5wFNZdszGHLwjAt61H+ZYbv+Pb\nufg5L+KjF2Ni8lSZo6TYx4ffIFJisPAKk06KygNnOYZQAekcLrH09Vzx/vsiK3fWI5yJkk66BpYB\n31lPcInhSwgEdHqtapBu0lIzy0pukFHiWa88zoc9Rx+2vu2TtiPCJSy8C+MC2XIngNYyMZHBVbbq\npRyzR2LPuIDzYYcGfPfFu6FaPNaGjAwLT3w8/uCmN8JTkFOMNyipdmn4s2TzUxAcCI9UgiYfMty+\nwB/9ROC6OypEUYC1DBBU+/SIuZJ454Pv5O+8++/w+GaUJSLge2RYAL554gnu+eq/xssf6Rj+4fj+\nd4eva7Z/5VdRp2LNYgf8+0XH8LeyQFZ7BinxOTdL14d3C6DfJelMqznXT14GQPAFa1oigu9nsLbj\nwI35nYzKMSO9hQsZwTn0EsMXOIQA5Vt0iIAvEiGpTcWxScGnP/NbuPmhv8kNk1dQOMnmuiBTncEh\nHrPUaUcl4OLj8fP93FEkG5U/yo3yLLltOSbzfvxlx+x7SacD/I7pp+aJExHluvUyu6Ke+J2kM5fx\n73MLCLMT8FuL7vL51uMTgDdhxD04brooUdaQvfjF6F2STmn8s9eH/1wIawPKtYii4C13vYUzJrpf\nrh/maCX3aZ62BPhOYvL4UalhxtgVUdJxDp+khYFSff8MbwPCGcRSNW2UdNINV9k4xzLQnwGd+ozM\nE+DLgaLKStbbTcq1jHwcn3uvwpnWLQB/Hb+jcdOOz8GFvqIQoG4avuS2lr/xDrcT8PfYIXTa73IX\nQOMNhdVL36fs9qMfil9PfSZ4u28XxsuF824Pl06VNHwNwfSAb/KSe175jbzm/JfTbmiKV7+aYAyl\nkNRPEvDNmTNMtqM1drsbmJGZmCgOCiUj4NszZ8B7NrrWLofl+98VfjIB7ylf9ar4/WUAv2vU9WJ1\nB9IFPvPen+Nf6Z/Y6dRZslSGXQVU9WMCHTLy5jxeFBzJdcpNpX4wleeIOo1tK1Soo7Qy30IEFho+\nDmRAuhbVAX4yOjSmIoy+jmb0WQDktkSneyQZ6chtuqbSAtAV4WodeFnxYQDm/ggbckweAkesJkuX\n/27Ad+n1O8BvJvG9b8uAtIGNUl+VpDNPdtNsF8O3zlMb3xspvAvItIsKKB7cknzuAwop4cZv/5fI\nYlF8IINNDH8F+E86rAXpWqwW/Ob9v4lRAWlrjucaLcWe7ZEb10K6QKSFabrg5LBk22ecyRXSe3xK\nHuZC9HMsnfNIG4tUus3DWr5GZuPHvTlp0Li4GIiuxDo+z2yYGk0NFe1gRJhOOHnLGiENX9+rn07r\n2oWk49yOeZo7PgfvWV/atk/mM177UOAN98Vq4F7S2ePva+N4mXiCvLmw9HyWwi500IoO8D8M5VFY\nS72QniTg7nbpRA1/hqGTdAwkScfmA+bD6zk2P8n85euILCYZSxTVkxz7+NBf+suc+oX/BcA0DbEP\nmSXgkF6iRIidEFMjriy9zNX6/r/zg9/Jf/nYf7ns4zoJR5+6bsf3+0WXtH2tjsB44v7388XyEzsl\nHbNsNth5nsxW/Lo+uZ8gCoLziOCitz7FEX0aZyqUr/BkuHF05Pglhl/LLA4zT9eHTNeZPbeNKW/E\nEN1vmc/7lhlFYvR5IhRCpcFFqablxhsa1lTcUVf+KEJYihA4Xi0IzQ7AFwHfEZIE+PU4vvexDNB6\n1kt9hZJOhSwHVKLl3MnXkdsMhOllmO7+64shXUAufc7nxwOCUKiNNdTaEF1k/VzbKOmsGP5TCmvj\nIIYPnLuVi/VFjAbtajaUQu2j4de+BTpJRzJPZdlqfcjp8sP8wpHoG/Npa69ZJHy8DWCiZ7mzXq5l\naxyZxsde2Koi4AeBSEit0mttD+NzHD2qKY9u4CcTiqFGpITqXh0zlwuvCuf2ZfjGBT57a9HmaDqf\nk1vQdpeks4eGX7WOH82+h29sf27xfMHEiz3F3Kek3JlPwfGXg+r8rE9O1rkkabvk0kFkgEPgUUri\nshKvCgSa+hXHEDo2txsIRf0kp4DZ8+dR56NbapYA32ctXnokCqVC7IQ42wn486vspfORMx/h4+c+\nftnHdQuLvi4B/mUlnXhA12cPxvczM+TC7mL4i2M17c7zZKvUDrrZJsgMb0UqvFp8nhvyNL6tUD51\nnxxHCbLvliksM5WjXY1ItkjVpGv+wQtYVTItoqyoXdEn4zvAL1y6vhLhahLg33zdhEJMCSIw90dp\nhSAjcHS2AMqO2Ye2RUgWJv+O4W9P49hDCb51rJfZZRl+8D5W2g4G5PMBt3/2/80gvAGk7UF60sTn\nEAlXvPMIu/jMNt2QIDXabsEv/w1UUUQ/PrEQqzBhpeE/lbBOoHzLrz/0dpRQGBVHrwkbyJS4ZMSh\n8QYbPKTmCwMvqdIWU66tMRt+BNuZEPqtq2DWutgu2HqEqWPSNnQa/zoqbVcffPDsJQy/e8LNtXji\nX3nTgJe+5AbcZILKJCFdPOPqUvBa1vAL63a0Zt35OXhevbkYxTieVWQWtI+VxfYAhl8ZxxEx46jf\n7O2Axhlyt5B0tkLnrfNw/GXQdVO8yv7w3/GB7+A7P/idvS0zS5PAooZfYYQgkBGSpKOUICTPvZcZ\n7jNOJYZvGEhNFa6eLYUQCE2DSF0VZ7Pk/MhMTBR7iZYe58FPk8WuA/yrZPjWW2w7he/7HNh6eN/H\n9Qz/ugXDf3yr4gfffe+eFs1Ow19TUZZq/ZAcu9OLv8Q8rdkF+E0gECjSgBHvsh2SDkCpLuBNhUzv\n2W1vxcd2/fCDY6oLlKvx6XpQSdLJHt7G6pLNYXz+zOeotNMdKUkAso7h687RFs/lLSfPI0TE8A7w\nixA4sgPw43FGwA/gukRyYvjbE0ImaQi41rOWq8sy/C4RLIcDVBuvS+1zhLA0KWHXMXzRDX13geVL\nsPVDvNRoWrhwHyov+rxIZPjhUNuML8cLBPBBBcu94/t49dottFqgbUU7N3smbWtbQwi9Dll4wTzP\nGK+/hLPrBSE73QO+S/qyJD5PYz3OeYRpYp+MtAMYZSNkYvGPPRIBHy9IvyYkuefsWgRHVTjU+hp+\nPEZrSUgMfy8GYtyC4efOMq/djpYHXcjJmBvnW/3327M5mQtoB3Mzu6yGX9KyRtXri9bb/oaUrmUc\nFr5mjr0MVGJUV2CL/P6PfD8/9amfYrvZ5lfv/VU+dvZjO1orQAL8dhZ1XKEBh5QeqSQiFVvVeYa8\nPjJ8jKUUmponsT02BkJApjYA8/Q15G0E/KCQ2u9k+Akr5lfZS8d4g2kmEexTS9+9YiHpnErfz/nt\n25/gu9/1qR1SXz0ztLWlrS1KGAYyAmobhuSYnQx/Kd/gdgG+b8Cqhiz93Ps8STqpVUkuQVYE01A9\nnKyP49THpnfpGKY6R9samxZllT6n4uEpVpfM88jwlcsRieGvS43QkCWG390nj+eBl7/+FKdGZ2nI\n8IWm8kdoEZzYhrVp997CEuA3CBkQ6bk6wG+mNSKXNIl0HdGXB/xu2pUoB8h07augQCwY/jQx/LAL\n8AsR3+egTZKOtFBvo4qs74kvvaVoYX6NWmy/IADfeYkKlq1mi+vqOUZHicfUBi1l32Omi2k7JbeL\nGbMDL6jW3shtb/g2bk379g7wveoAP8akNjFp20aGH1Lzr1wtLubx2c0k6UBIko6zEo/n1lfBic+a\nMLhOINc3cNMpSku8i0Ms9roglzX83Hiun3l+7B+8b4cPG2D9sfsJcpEgms1rMhuBqqq3DgT8unX8\n21NrfODIrN9B2GDJfIb0Bulb6lBSpeTzDknnCpw673jwHfzAR3+AX7j7F7DeMm7H+7RWqLCICPjC\nomRAKoFKbqnpQJPnQ0SWJB2VU10ynuHy4ROTU1UEsnk3DlPXEfBRaOFjD5XZboZ/dTer9Rbb5TkO\nmM/av86SpHPn5P2sverfMGkWev47fuR23vPfP01bWXJZkYsI6k0YkuH2TdruZvihFTjVotL5CxQL\nWyawcXJAKzIwc0I3TCjtdnyy0iphmekM5WpcKoTLDARrGT5hQegF4PuibyK4ITRCi77DpkiSzkPK\n85Xf/DlIM2EWShho5v44L3pE8Fd+QnPdXTGHIEtP6GZEtA1CsgT4qWtn5RgMNRtpBVpX6rKSjk/S\nnhiUqCRnaqcQSy6dzhbdkbQO8LuFt3AlVmYoYaHZRhVFv2uKDB++4qN//cDjeLLxggB8GyRaRBA5\nuX06Ar432Mah1aUa/rgdU5jFRZt7idUFQSo+Luf4+uYe8G3apnaVl5MEDKKtkoYvKXWJFrqvDi3b\nhkI4/BLD90bihef8UHHicycIV6E21vGTCVILnPGsFXu7CJYLrzLrOO4kpnHU852PlXWNUwXd/nJe\nNeSW6FWfXzg4ads0vG9YcNdgoQEbZ9BOJ8C3GDIukMrVj78M9JVLOuN2TO1qfuCjPxA/x3ZySdJ2\nbuaptYIgCE0gAr6QAmm6VtYZhR4ukrYy64eWXE10W/csfYZ1An6fNXiRGK6MVtmFhp9a/F5loZfx\nZjH+8kDAv1TSOVc/glA156pFMr2aGC48Nu0B/xwbaFHRyONkWKrWwt3vgt/9Vzt62bt213G3Ci+b\nHvBBIrzvwenIqQFNyMibTUgShEmAb1LjMIVlmmU7GH7WBpp77oFu5KGe43HgBj3grwmNygRHUrHW\nBRPfX++EayZMQ4kaKOb+KMVUIhAc/+gZrAQKjzWW//COuwhNjZABlQawyERKmgZuMJv8X7f/cnxN\nKZm1bk+bdhchdaMNZUGWhq/LoNkQ4wXg1xYRdjH8IBjIeG43TIlVORILzQSd651J2xY4xJ5Uy/H8\nBPyf/nPwof8GEFsFBIUUHh881zcTWh3nclrjY+GVuxTwy3ZhLSuCwiWXwGYu2Nj+DG5qvhkns16X\nZBfg09TJxSPJwhGUVHRJ4JFtyaXD+GwB+FbgRQJiIcDMkGvrEAKK2BNlvciY7KHPR1tm0kWt67uA\nLk+jisfU4FSBxkDw1HXbyxDNbPPAStu6njGRklotbJ/WW7TPkN4ivcGHjIudjn/85Vcs6fjgmaRS\neRccpSqZminGG7TU3Di6keuG1/GWT78F386wAoLICDiU9EgpkN05FBlZNoSUtC1VEXvcXGUeoRuQ\nkacdlWkcloBXbX+essTw3S4N/2oLvay3mAT4n7w94yPvemjvY+pe59hR0Bo/nzO38XMbd/Ndidf8\n+HxFUzlyMeNd7k3ITNIc/Wwy4Zg3Bu76DfiDH97B8N2uIjnRKoJYBnwIwsWGdcCx64c05OTNRURX\n3HQxstgm1whvUcIzX2L4AciM4Myn7sam5naNbHHSxvbJnaQjNFJLXuLjY37ynkgEZq0lhICvJ8wY\noIaaKhzFJT1dBJgMIGjAet796XOEtiWomCOAJcA3mszOkclZNEytEKYHyDrmkXhu/EiQ23hsKihu\nUOf6SttpY/pe+NAxfNEz/KEtcSpDiXgfZiosMXyPBMZiSR49xHh+Av5jt8GF2OO9HxacLtLrrcMo\nkM7ELnx7aPiTdkJpYgIQIPMSl6blbOvA9bNbWHevZT64rtfwu0mP0wT40plYgo7kwuZ1MfGY2vYO\nrYlgEfROwE9a86xch3aO2lhPz9USAmyUe2uMy90yc+P6lq9+10ImmwqncrT0KG8wtemdJc18u2f4\ndg/An84v4oVgJhdJKeNNAnyD8oaA5mLYwOsBrF2/JOkcDIBzM8cHz1e+7Ct50fqL+KpXfBU+eMbt\nuHfp/P3P+/vcceEOfs1ewHiBl5HhSxkQS1ex8poiG/UMf6CK2PLgKp0zXVl+mRxLtvG0AgJtz/C1\njANQ6u0Itt3iebW+/2gSiH989/0bfPoPTu96QMwpudkMpEQMh8jhED+fU7m4CCwDvncB2/o4/ETM\nmTHAj9YxYUQI0H7qIvUcMDOoF2043C4pStoMRIPacf4sPm0nj5waYEROaTah2x1uxeNoMhUTvNIz\n0xpta4JQeJlRmMBDDzzcM34jDVYalM/YaAd87XjCF8gNhBb9JLhPTz4R31uILT58M2VKST7SeC/R\ndtgf4XgITgEO2raN51KGfsSiIicgaH2ODjXaxWtjlNorbO9R3NhF/cH/Gf+Tn6boGL7XXCfP7ZB0\n9PKt5yPg52KOExYVBniVRYYPZDK2nRbe9o1PtsOQaxHPT8DXRc9cOvDqPtyRXMOqKOk4E2Lh1S4N\nf9JOKNqFpJN5hU1b1FkukYkpmGwN14FaAtlZklxE6paJULjqJpRQhAT4A+/IcDhU10ATWU0IiTnO\n1k6BmUeGT1w8AI7me9vGljV8bXzf29vvel8yMXylYyGMq02sEgSa2eRADX9cR8/zVArqNFjC+jia\nMUo6hhA0H/KfyfQlf4JYXtnZMg8G/HFqNvbmG9/M2/+Pt/OaE68B4GJ9sW+r8Kde9qd43anX8aNi\njA9xMQ6iS9ouvNfKa4p8hNAd4JeR4V+lrt71qdEOtA24NtCKgFsG/OTD7wHfRYZZ+f0Z4l6xzPDr\nWlFPl85xtQXf/Qq451346Qw5GsUq7rLAz2bUPgL+ZKl/T9d+Y+vsnIIpDRkqVxir2XI3IW+fce8T\nN8bHbi9cW97sPE/a5EjqSxi+dhdRYZMbX3kUI3KGZgvRdtW38XNrs8TwpWOuNSp1LHWqjGRq61yv\n6TfSYmUkD4Gcf35hk8lFRx1CLOYCGlHRdRucNpZQT5iFAcV6vMYGCfDDKGM8FDiVlEtTRYYvIets\nw4DJRng0uavRyZo6SHC7Od//eq0/fQ/5usVqS+4iw5dBcUJs9lbKaW3RSz2rgo+SjhSGVlWIMCBI\njSK+jhamb7bYxTQtJocdz1PAH/Q3eAdeQnar6RFQAelNL+nsxfALE3Zo+I+fjGBdlbrXGZviCB29\nDHSSTuentUjvCEJRz25AeXrAL51FY/FB043WPXX+Y3GLB0zXTkA77Rm+SIvX+j62sejDj69/MMOP\nGn6WSZRv8a1bAH61SPrtBfizNAh8W0naNEjGBosKGdKZlMjT/Bf31TzwJXH7faUMv5NzNtKEqvU8\nvu/KVj3gCyH4vOs/j9PC42SJlxqPjRXPcgnwQ0aWjRY+fD2gkRJ/lWMO/dJcgWEDtAID+LCQdJSI\nGn7otHUHIyeouTrAN95gUl6lbjX1zCxsltuPxtmtWw/jZxHw+fB/QzZn8LMpresAf6ekE/8DuZzR\nhAxdKBoTHS0AdZMGgm89uvi7pfNknCFzBWo34OORYsr1s+/n+I0jjCwo3ZTQafjJvmp0qsoVgbmW\n6HQNN8WQsoWwfZE6DVBppcPJlixkdLOgJiay9G72tJUG0i593lpoI8MfJsAv3TpWB+Rfei1v+aMy\nAb4gmHmSdBYMPx5H7E47nj3WA3439epAwL/3YcpjBmOm5DYxfBTH1GbP8GetZaSWoNUFCAIjPI2u\nCCLaMlWa9puJum+2aEZx4ZrtHgxwSPE8BfyiLyjp+sJ0Q7DLMCCoEDV8G+s59tTwl5K2Kihcl4Ty\nqi8Rr8vj/d90BVbzBMgy2MTwNa66CaZm4foJHk1sy9AxfIKmIN4Us8ExaOfII/HmFGlyz3q2dyXg\ncmsFbX1/4V4C+G2DVQV5IZGuBRN6GcJWSzf7HnmCWWrbPJOSehbBPzZty3qGL7rPpfMQXyHgdwy/\nA/ruK9ADPsQFoRUwV0Vi+BYpPEIuLmPlNUURK20xpp96VR+QDN0rlgfJDBoIRuzB8GP1cpgvCq+G\nTtFcRWWvDx4XHDZE11ZtCrwLi0V3fj490OKnU+TaCC7ej1QWP92mDfG1dzD8pfOeizkNmqxUtEZR\n+7SYJsD324+n4xD4JZfO3M7JbYnyFXrZZSUcNlfIlMdxMsdb0Tt3bNqdGK3StCuotOwZfrW+TmFA\njLeoywiYrXBYaclCjk0afhsUXsnI8EWIu9/Uu2baWEQ7ZRYGDDfS9Do/wmUwevkG99wsMAqCEwhb\nEUyLTwzfJ8dWXRwFIFQX+sUodTtma763pGM3NzHntimPtTTtrGf4IihGYroovKot69niuo0MX9JK\nT6PnODEiSI3sGH6o+zkDbn2YPn/NtYjnJ+BnZc/wbZpKv5kYrAolQoFy3ep6qS1z0k44YmQP0LlX\nvaVSBrXE8I/1f9Mx/CoBsvAOl4Q84Uvkkk+6JPQefZcYvgiaoYjAPh1sgDfoI5HxinTsa5liuk/S\ntmP4Wbsk6exq+6zaGqsH5Hlk+MKKXsM3S1LRngzfLABzOovD3K1PDD8lbbuEW99zXV8d4HcMv/sK\nCfBDgA/+V44kr/2W0L2GL8Slkk6er/e2zFLHG6hqnjzgDxuQVtEKsKHFpx4qmlh4Rap4zSwMvLoq\n33/nzjHB04YhId2SvawzS4DvzILhz84hdcBPxpgE+DN7qaQDkIuKhpxsoGiNpPbxs63TEHbGEfCn\nDAhLie1pNUOHnCxUSL8s6Xh8plBNB/gFvpU94HdV2kZHDV/IQKUFOgH+fBQBX04nVD3ge5w06CWG\nb4LES4Ej+vEBRM/wHdLMmFOwdjS+D+03cJlg5NJxZJLgBdLWBGNi0tblVGmn3yTAV80YGSxKgUoL\n5X4Mv7kz1kiUxwytnZMvuXS88EuFV5b1bAlaPYQQ/f5VNsHo9ejDDwnw3RTh43AZ1uL7qTsb4CHH\n8xPwddkn6ToN3wmDCAEZBqCIAEX0zeyWdMbtmCNG9gxfB9WP1JNL/78cw29Vsu8BYby4iLyHYDwB\n2c1EwTIgF/ExsyyClN5IN+UsAuJaFn3Cu6sql5O22oVe0nG7GL5qo4afFTLKMEtExi03Rdur8Mou\nknuzeex9YoNFkPW2zK7ZXN0VfV0pw292Mvy1fK3/nRYaNh+A3/5/2TgTb7hxEASp8SIB/i5JJwJ+\n0vCz6HaoliSPKwm/NDls2IYF4PuGkGye0ZbpIUk6uQPtFfVV+P47wLfB92AMsXgKgPnFdEAR8NVo\nDWbnkZnHz6ZYEuAvtWQOy4AvZzRk5ANN20qqDvDbVPU6jQniyS7A356m2cq+Suc2XRPS4XKNSou6\nUwXOiP5+6mepqKjhCwFzTc+i68EaZQtqNqUuOg3fYaUh87p3xrVe4pXAkfWA30k608YiXc2cgo0j\nOUKCDuu4DNbSezCZIjgoafGtwclYEVulxboDfJ2IQFkKfBU7e27uw/DrO+6Ijz1maE3Vu3QECivC\nUtLWspYtAbYPhKBopOsBH6FQpKrd2ePINBJVDVLPICO4FvH8BfxOw287wG9YD4F5GIAKqCTxZIFL\nfPiTdsJGI3vNXXnZNzdTQffl33WxAHyPZJirHvCFd9QqOXYAJgsA8VJjK4nwpFa/MBdHyZKmN0vn\nWgSD3NiA1KlxqGNnz8Z6tn7xF7EXIxgsJ20DYmHL3AX42iTAzxXKtyi3uChd8rELsQ/guwVgzprI\nOo0zCDRS+HTDp52P3S3pHOxa6TX8YqeGD4nht5FBb9TxcRPvekkH4RE7AF+hs3XQcWdQqiTpNFcH\n+GGpr8x1fp3CDKhFwPiWPOvaacSkrUhJ7MLGJnj1Vfj+TQeU+F5ugWXA7xi+xc+mieGfjwx/NsOL\neJyzpRzF8nkvxJw2aIpBhrWCuY+70ipNn8qqs1Qhpw16x8I8maX35GYIWOj40uNzjUqSjle7GH7X\naVnqnuHXyveSTl2uI4Fie0KTl3jhcEHipEEF3ZOsJlmhHZpO1ROJocyrGukNdcgZFZpipBFiA68F\nuTPoEGgzhfeCAQ2+bbFKoYLuO1z2gJ+uqUEJ1aRlo8zY2ofh13fcQXY0RxUBs8TwBRorwaY3P20s\nQ7m4t7oWC7UMtHKCySLDl+l+F5OHESEy/KxIO6Qn1/7psvE8Bvyk4XcMX7VsuMDE56m1ccfw9/bh\nj5Y0NB3ixQIgvVxi+AtJxyNZKzR13ynP0iZjtgrELFT3WKGxtUIEOCfjTV4z7AF/2gGGmaNPnIDp\nFgDDlEfYeuIMT/yzf874t38b6AqvEqtXBZK9NXzdNjiVkxU6tqtdAvzOSVgMs719+H4BKLVZJG0F\nWQ/4C4bfAX5KPF3GITNuxwgEa1lk9uvZLsBP7PDINPaEmVmLlxmeRXvk5RByiNDxtX/ttvPpmK6W\n4S/86df7o5RmjYkMmNCQp+fWBLy1iDRKL3dxe/9kAN8SqMIegN9JOt7gZjPk2lov6dj54hhv/OSD\nqZhpp6STiTkNOeUwNedzNwBQdew0OGpyLDsBfzqNgF+m874M+KHIUP0urmP4SeJxCg84mTR8AXPl\nFwy/jO9xMJ7RZiVB10CWXDqa0AG+F1HDJ0NmHQNKckxaYGtyykxRbiiEPILLov125AONVtH7LlqC\nsZgkL86TpbSTY7MO8IvAfLvh2DDbl+Gbs2fJ1iNkNqbqNXxQtEL0rSmmtWWUmr956GtEaumxYkqQ\nioCOlbaAGD/E0a37OLb5aYosuQvN1RcLXkk8TwG/uETDt7LhqHdMXRaHl3SSTmBPDX/U7gR82Wv4\nC4bfFV1J7BLgLySdJussoRBmi4sodAw/BC7IdZTQNGGAFpYywKzTgNsZ6sRxSA2pBik5Oe1HuMXn\n7JK2HjDZwr97iYZvDEHmZKVCedMvYhDrAADKtWzPbpm1X/RcqZKeb5MzR8qwj6TTVdpe3qWzlq8h\nk+MpU1mcAcxOwN9ICUadmmAFYYGdkg6AI49JW+CBM/F8XO3YwdAsjvmEjQNHpsLRuoY8S+ddgF5a\nGHIHwutoA73MvNku7JKFc77M8KddY55UQevaaMscDqC6iNRhxzH+6V+6gws/+ZPx2F1gsB7ffyHn\nNGQ94I9tBPx6ybdek2N2Af4sLSajlBvovfgyEIqMLJ1jr0tcK/tuj15ojAYhswXDl65n+E1a1KX3\nGD0gKAMh6xl+SHma1ieGLzQyNU4Toqt6jotQRcEw1xRHFF4dxWkJtmbkPU0mk6TTEOwC8Luq67o4\nSggO3aSFLXfMtluODvN9GX6YV8jUhqG1dc/wQdMgCOk6nTaWYXLpOLUA/Ep6QlgQj84qLrYe5MWP\n/Q6vvuetlCLeW3414vAqIhssfPidpCPnHHGOqVWp90o8qSpcquFP2gkDs/hopFc9yKugkOxMqGgR\nAX9UaJr0esI7mo7hI/BLg0uczCLD9wErA5nMaEKOwjISklmnl7Yz9PEThNRydpAuouk89TZJ/cu7\n5mltobB6GfB3MfzUojUfZEjXIsPC+uVT87ZylGGNv2SUYhMqNlzaDid5xzhDEFkqW4/yDsLs4dI5\nWNIZt+MdiVqgZ/ta6l4YPnIxdpLsGraRAF/sYvjOa0i7oZD6nVRXOZRkOWm7bqJ0N1Etjasp0mKi\nCOh68byZjYBfCbGjgvWgMEtFWvO9GH4C/GBT0rboJkAFaF3fgjevbd8O2IfA9S87gpRwRJ2mRTMY\nxWMeu9iWwYYCkypO65DRonacpyq14e4AXyaGL1SAokB3gKTLHZJOkBHwpczjACABlUouLu9o5eL6\ntKoE3ZLJPDF81TP8OjF8L3O07opVEthW8ZgaMoa5It8QWH0sAn4zYRg8tYpJ2wGR4bepzUcnl0ZJ\nZ45OTHqgLfXUcLzU+yZtfVX1i05jmx7wg1TYIPBJBpw1ljKRM6cFqqvAlh7pFjvlzobN/HzfJn0Y\nLqbzvQL8Kw9d9CDRyRNG1Rz1nrkTiOWk7T4afmkWoK6DXGL4qtfzu8i1JwjFeiYXgC8DJgG+DOCW\nXDpBZbhagg84KchljvMKL2EkNNOu/ayZo0+egItxW1+ki2ieLsjxFO7+8Glq1yJDoM0V5gDA7xK7\n2UCj/E7A71rHlmvxZ3bXmMOampuTNt/JOzbYBPhJ0iFDiHqJ4XetFQ6WdCbt5BLA73T8yPBTJWS9\njQxh0ZJZpmEkieF70uLuAg9PutkE8Ua/2jmzPsk0VkJp4rHMs5rGNZR5t7PzqGSZdQK0ExAyaiEI\n7ZUtMMuAX/l1wJPl4hJJJzQNOIdMMypl8hCWBoIZUbYerI0J2wDXvWSd//vvxQElTcgYJsB3LLzo\nXc6gJtpcxRLgd72D1hJAiZDOoeoYfsr56J1JWy80rQYlcmRweAWVaBCA9A1OLAqKvBwgMkMui1Rp\nuwT4TmKVin71bkFPAGkSK68oKLREb4DXQ9psAPWYkY/OIIJgSE2wljZV9XbzUbwqwM/RqZ1IqeL7\nPaEzNmd7ExQ/nyNTzqRpFvdWECrOtk6L/KSx/b1qlejbnlTK9Z5/iH2GuuiqxbMi5f1W7ZGvIvSC\n4XdJW6srjjjP1AqkEr2Gr7wgLLF85x1TMyU3C7lDBr1w6XjVT+XpIssCXig2NLRJQpK5wokO8AMs\nsQavcrwTCB9wKqBkhvCBR4afxWjtRmZdL5Z2hjp+AhLDL1KCt9tu33fuCL/z43fQNg7poSkzbLbo\nwXGJpNMDfp626AvAF34n4C/r+H4+5yWPTDnpHKUP1KT8iDcEoRGqA3xJrhvqLmmrr0zS2Yvhd4Cf\nyaxfvCWw7n3fMhdhdgC+0WkhMp6PPjbDC8WajjuF+mpbKzQtXkmmJSgbj8UUbQT8rCu4CWQJ8OeD\nrtK2IAhBc4WuoGVJpwpHKMSMwXDJlpkYftelUSa66NNur2whnx+Nx2xdvzMTUvR2yoac0driXLcy\n6empCKsVOV5kiLAAum484nrq1ROSg0woEEURu8mGAPkA10pU5iF4vIyAL2UeG+oJqER8PeUaLMuA\nXyK1o1AlThqkl5Cs0JWXOCXxMkN31mXRWT8j4AdVIoRArSeZJj8OzTYj7/v5FUNfg3WYJC/WSwVR\n2lc9wy9lfH9HpdpX0vHzeS/pNO3iebxQOB9HRLZpWlXR5dG06O+7uXJk7WLn17V76T5XAJkFjIqD\njK5FPE8Bf6m1QuvjeMPMctQ72qDRQvQXt0oWuk7HnyYmqJd8sLP8ll7SibbMnR9bkcWt7IYOiwHg\nhcKlBFEWAmEpERRUhjcyAr4MaJEjAsxGN7A2uo5pB5Bmjj5xvGdPeefoSZKOc4EQQI9LlIe20Bg9\n6F/nksKrZNfMhwXStwiR4RO16HTxMjHBZR1/+zd+k7/1tinXzTxrHppUIGacJUidGH68eId5u5B0\nZMfwLyPpNOMdzhxYYvhiwfABjniP7pLN0uBZuHQ6wJ/ODefP3cLdr/pabthINkR7lYBf1/hMMS8g\n2CFWGHw5wwXHIE993aEH/NkgVtrK1AGyqreu6HWWGX4tT1DKCWXhaWYm+nc7wK8SaCbn1zl9FOgA\nP77HYG0P+FIu2km0aEajBbNvVdLAE8M3ssCJrCdBsDQ8xSYJIgGi0AvAb12L1AN8K1GFQhLdU0aD\nJPZ4nytFm9w1Mhgci/YGghKZOUpdYMVOhu+CSgw/Q3cMPz2P64bEp9YMMo0FbfQxaCaMQmCeLpGh\nq8F5bJIXnV4QuczP+8LDruhxIw0y2mvEoK+qKKWxE/CD1AQXP++um2dHzrxaknSUo2iavlvtMsMP\n6RqWOmA0fMaRVaXtlUen4YeAaWzsfa/hiPMYNJmU+MRYkkurZ/hdEZBaAvzzJ76wl3RU0KhlwA+e\nIhd4oVjX0CY5Q2QSl5489w6RCpuCDngVx8XhPU6BEhkyQJZJRtmIeSeBtDPUiRM9mGYd4FdpIEU6\n9nyygQoBU2YHavhd7iEf5ahuCy67qT3xRhjswfDd9jYSOFYFRkFSJzdR12xNSIdIRSQDZReSjpQg\n9RUlbTtLZhc7JZ34fi+YF/Gyi6/rJR0hDSEsGH6rIxv9H7c/gRYlm0dfxXWj+LzVVQK+bxtcpmhK\niXUls3ybLO8SfBFobm4foKxT87JhLNzpxvjVT4LhNxxNgG+jpFNvQcrnuLTI+wRMj6sT8VhaKOZx\nFxOs7VvyiiXA97KgGC6Azsp4zJ3v38kyVn4uMXxTO5wwqO4i60BbS0Tnn5+PUXmSdAY6AX7S8NFI\nb5kqTRCCICLg+7BYeCQlKveUusSlhawbP2iJ1e1eZnQ1TEJY1guNS5JOSFXUMp2XRh+H4Bl537tx\nhiECfsfwg9a9qytzi2uiCPH/w+R2283yQ9uCtRHwZYbth5/UeKEi4LumL4zUiJhsVguQnUvHoJFk\niVQqYSDtyLsdm1CBNgNRHyyDPtl4fgK+Tj3fncHUFuVbjBIc8Z4WTY7Ei451pJbA6UbpPOFdNS1A\nIbNdhVfLCd0WncUirTUVsB27zSWu69/jAyJdCIppLBpKgO9lgKBRAbJMMcpGTLsLsZ2hT5zYUSQG\nMK/jxdgtUoPJEaQHWxwM+E15PQDHX3QktlYAfOr22QF+z/CXAT8N3lg3kmHQ1LJrwJMkK2FQKe9Q\naEuzrD+qhWNqv9hT0smWAD/JMR+f/1le9dBf6ncjUrZ4XJ+0bXU8zrd//AkyqaiG13NjGW+oq51C\nFeoGm0naUtP6AfN8G5XH5x+mHjCvmH+Sl9b3x/cwjJOcJPF3V1rZa5ZYdRM2KOWEImsi4HdFVywY\nftNOcEHwqIpTr8pGUTZJnzfNTobfDS7RBXm5VKqv47FVxGS0S60q5NJuwzUBoxuCg6BV74GXmUSm\nCtl6PkHmQ3wrEWWGIkk6KgK+CI5JlzxXCoEjLDnDtC/ReWCYlbFXDiDS9WhQWCVxMkN3t5swbAwy\nfJuGkCTAR3Q9+KPVcuQDVaLVo64eR6a8S6bReTymbCnPUviulqKrtt25K+0mXUkdYONG2iT5ZmIe\n7+fE8DvAzwCdqWjlSjFXlmGtyDuMERZGceH2cpGMt5lANFfXcfVK43kK+OlCsDW2MkjXYjQc9R4T\nNLlQuI7hJzK6m+GLJY96LhYuHek1CtF1Q0b6FqljkdaaDIsqRw22l3RcX4ouxSw2/rIibjVlIASN\nAvJcsZatMTNzQICZo44f7xm+t4FRrqhS+9aOfI2mR5EhYMs82TK75OViWxq8Z77+YiQ1a6fWeobf\ndfvUSRffC/CbaQSIkZGMyPriFTnvWk+bvi9IIcNCw4eYuD1A0mldS+3q/SWdJVtm60coP1hMQRIt\nfonhN1m8kS6OG2QSRU/4nCwExu3VavgNNhOYQUbDkFm+jUySUSfpODSDNGlqOzF8mZKSV1rZa5fm\nwzZ2SCkmlLqintlF0RXg0yLftNtcZJ3zOi6Qwzpj0KQEoWn7RV6qpQ6hqkBpiUpul0xdROCodeyY\nGXQZAX/pWHwDVrd4L0ArROc4y1UP+O18gspLnJGIQYGScSxomwkI0Yc/6SpOlUII17co8ULHRneF\n2An4KansUFilI8MX3a7FsjHICIkAhGRBdvWUvB1j5NH4mQTPLAH+sDNvJMDXuUDnaUD6EuCLpqZc\ny9BdK5ZdDL8fbagDbNyCtem+ERVeKHACuczwA+hMXgL4ZSPIU02IwsIwWn69SiRGBWwuUJeZvPVk\n43kK+EkntE2SdFqsWkg6hVC4jrEkTOw0/L7roFtm+MtJ2zxWCq513zcoFRn+SIFKOjkq9JLOQIBO\npXNCxi1gB/hOebxVKAR5HiWdqZlCNowM/+TJ3uPsjGe9zKjTdq8j8GuzE9FeOsixetgnt5YZfqhr\ntjdeRqamCKUgJYa7fv6dJ79M72sH4E8i4K8ZyUAUzJKFTNadpGN6sMiFX0g6EK2ZB0g6u/vodLED\n8E0FQtKEESLoxaQhmQA/MfwmSTrHc923qy4aRelhaq5ui+ybhlaDGeY0ao1Zvo1Q8flHRQIaFEUC\nlM2hQARQXB3gLzN8Y0pKNaNUc9rK4icJ8IXEdyMEzZgL4QjnVUy4DhtFkfRkZ5qecERJJ9VrpPsh\nH6T23HKbQkypZJqNqwYEmfUkACA0EqfbKFVkGbJznOUZukyDS+ZTsmKIawVhWCBliLZMFV0sH3+Z\n57bXJi1aK6QM6LQ7rop0TIVgLR/09+NOhp80/K5VhTAcGWgwc7YfHHAyzc+1swlFvYlLgD/yHqOS\nzTHtcrre+7pQZInhF80C8H3bMDqSQ8pd7ZZ0FknzABs3LQBfVrGQygvEEuDLQFxYlizDTjoGraBw\n8bgjw4/nwCXAFzrgMol8NjN8IcRXCCE+LYS4Vwjxj/f4vRBCfH/6/SeEEG88jNfdN1IyB1thG4fy\nDUYJbrYWgyaXCpsknc7HbHdJOstaYyZ078yRPkMFGB3pRhu2qKxj+L536IcMbAL8oQjkyTMvRIVH\n4VsZh1qogE8XT5lrRtkI4w1tHgFfrq0hs1jNGgFfUye255PeuF4dxwuJG+QYPez9vcuAPzk9pimP\no4qa7Wa7z2H4ZJ3sBk0UPcNfsL06Af7QKIZiwEwKrPOoOvWUEW2v/2ZyqdIW4uJ7AOB3n/d+DF8J\nFYErG9KK+LPcdR79Fhdcn7StE8P/3FOLxcPPIQ8s8iJXGCEBvhsexcuMWb5FSIDfSToeTd42uCyj\nzhN7Dknu6BKLl4lOw5de4ZymzA1lGnZdbyZJZ3Rdz/Cl3eJC2OCMinLMWiMYpLfmrFlIOksMXybA\nLwbxHI/kFgM5piZVimdlBPzlJGIr8cr0gK/y+Ly6yFCDuOCZaorOh3gjCYMBStEnbYWXPHHc8dCR\neEeI0RCRS7IgcAKmo/gZ5qViPR/guvtxScM3KsPLKBUpkYGwbJQZo/PnefwPjvH62/8gnoeqomg2\n8SKe95GPiU+AMi30tmP4mewlnXK+1H+oaRkeKfDzeO1eIumkBnlR0rkJn0YvatnG/j8WpGv7aVnS\ng8rUjrYfXjjKhh7wFQZGkeFbpTFKIQS4QvWtKw47njLgCyEU8IPAVwKvAb5eCPGaXQ/7SuBV6d83\nAT/0VF/3wOi0PdvQ1AblWrS5jmNJwy+ExmiPwPd9LjpJZwH4C4afi4X3XvoMhYh9uINHhCjpeKk5\nX92B6vrYaIFNFq6hBN1V88oGJxTOdJV4AZ+qeosiavgAs3wAZh5tZydOoHA4mwA/rf7dU6qgqcqT\n+EGB1UM0LZ7QDzQBeOK+LQD00PLJ85/Es4vhH6Dhd3NKS6cZ6SGVFGxX8x7wpWj7viAZYSfgq+xJ\nMfzu+0xmEfB1SUsCfJ8AXzUEFhOvqgT4rzq6yGPMt6HwML/KObOhrmlVwA2ixjrPpviU7Fwr4utH\nht9gi5KubCPvAP8K++93Lp3SxvNeFp5SbMXn2EoN69avx6ctfsEm8+wYZ3QE6/UmevEBvDULSWcp\naStSlWk+iOd2TWxRynGftBXZgKDyPg8DIIwi6JbgQeQ5uojApcsC3QH+fEaW53gjcYNhv9M1Ou50\nvXBsp9so+97vYPqqV5MjaDLBbBg/p3KgWS8GS5JOqgNB0UpFkAoVDIoMIQ1HBhkvvfNeAIapxYKb\nzSibLRDxvBTmCDfP/3esKikS0WpliZGGMte9pJMtLcqhaRht5LTJDrtb0gnpteRwAMUG3pc4YZHa\nEaRCuGiD7Vw6woVLJJ3I8AOFT4AvLAzjwm11gUktO3yu0bvqYA4rDqPp8ucD94YQ7gcQQrwF+Grg\njqXHfDXw0yG2efwDIcRRIcSNIYQnDuH1L43EaOrtGdvTCcddywn/MuA2DJpSJSdBsMimReAJkzOE\n8gjb9RbHpuDFguHnUi/10slRxISMcjMEDUorEPDRM+9A8q2IYLFSYJOOeIKq73UTZEVgAfheemwC\n/LLQhFRh+kgxxDVb5O04JW4t1sZB5k03UDsIskJhGsf4yMtBKNp8ROGmTMUx2iXgPf3AOI5KHDXc\neuZWXt0z/G7OZwbCM02l3Wa8De0JyIe41O+9sCUjtQ42cG7zUVQnEYum7wuSEbjYWB68eIHaVRxX\nGm1mHAsBIQSmsXG49iAjK1S/wI5EyeyxR1GZoBxo1lLyuau0DbqkTWPfMt/JPSkRmzTeWR6f6/oi\n4yIwqM6xLU+x3hzFCc3kvgfxZAxvOkE2KAnew+wsQuX9jdeFb1sqJfD5TdBA0cxYn54nE4FBZ4sN\nGt22zIfHCFLS5IFcpH7mZhZnr1YVfjplq90mBM+x4hhCCKrGclEMOX+2YtCuc6SKW/us8CgXrZin\n7x+ThRtx4Tom1SZNcQTjttge3cjmbESbrXG0dWx3jcxMu0PSaeo5+JwT7Qy7tUU+0BRiyrqcgZxw\noX05lVpH5gN8W6PDohOrMhlhaGK9SB7bcTAGXZZkg7g4mbNnKNcFFqiKAag4erKVsbrcCctWMqGv\nf9ZrUR89jaNhvH6KcUpWloOcjXLYA74UmhDABhWdNSb2pdIiB2E54SpueSDCxnCeyFk1Z9DMEeSc\nNa/g3IVv4yZzI9sbd1DaB7GqwIo1nLCUmSIrUtLWLiSd0DYMNnKqcUtxVF7SE7/T8Mdra1QiYPwQ\nqSpQMR+BSwy/sRxnjDAn0FmGCAvAH1aGUW0pR5dKOlbneF2A1PiyIGuubkd6pXEYgH8z8MjS948C\nf/gKHnMzcI0Af8B99Zt5x3dfBEq0rThVxAvMoillRpULpKnZ+J/v5D/c/CFe/BPvA+DYuc/nv/6u\n5dGbUptWQrRY9ZJOTLAqLVB2jGdOLWIDKNHGbt7SOwyu9+H/5fkvck6k7bOKIHX6+jdz78u/Gq/+\nHU2dttpDTZG6+P2lwRzaOxE//0W8df2zkd7gjOflZyyj2U0ANM5x4uYRj9+/xZ2f+VdgGyjh1KP/\nk9kN1/Wj9wDOPVGzNn2U35n/Fz5yO3yPis/hZI7JYo7CCMOX/+If45vC/4973v5jfN7dvwHf9mkm\ndoNP/aF/xixcz7FP3c7P/MaHOf+Ku9BtYn2yRqZEcSbg0cce4cKXfDNv+fIvY83/bb78x7+Levav\n+dJv/Bf8zLf+OlV2lLxUfMN/+KIe8O/+p7fygfLVCBx/8eTfYvTKL+Cvf/B74HNK7HjMfT/hab+o\ncxTFRTFLgH/n5A48BU+Uya2RPORHt+7micEpvvST/wqAn749Omry6m7+xk99Mx/6iW/jcx/9Cb7s\nRTfxHZ/xV/jSL/zH/Mlf+pN8y+d+C59b15y77u/iJvFz+n/f9hiDJg1++aF/AF/0PQQU549/Bfce\n+Txe2sL7/wjc8nAFJ+CTj5/lP//Hd/MX7tzm5ff+Gjee+SAAqTMOt77h2+IizTp/jX/Tn6cHn9hi\nTcVF9913vBl4M5yJ55UvAM7Ff38Z+L0v/PecmL+NL/fvxFPil3z4P3fnL/HSe+/hSz+8wb946B/w\n6Z8E89e+j6HaYkTNfHvKdjngxyc/jT/yAV5XTsmw/PYnT/NPf+V2vmmmWa+3ozY9LBgeH8JZGJ44\nhk61DYN//v29CPRL1WMM5BO8SGhaJWPhkbRs5waBYD1fJx+dpwXu+Jx/2b/fjSMb3Li+0Wv42CE/\ncvbnYe0urIw5DOlapMgRwnDi4z+Lcp78mGGU2oaHecWgjp/sL1z4HrpRiFYP+OCgRHzht5M7zXYx\njpW5SdLRS+02fNNw7vbfxLvX8Qo9YXOWGP5b/hKsXY/XXw7ANx6DRx74Gf64/CvcrCrQkiAVMjH8\nlz3wVj5S/jt+8ZF/R3byZsTa9f1rfPvPtYzm56lOxM8vFxVc/9lw3WuYjU6iJsDf+SjhH34LWbvF\ntYjDAPy9Gjfv7hx1JY+JDxTim4iyDy9+8Yuf3BHpgqmL2thDR36RP/KBj9F+zh+Nv8oKcpXxY39C\n8rUPFHipuaU6S11eR1mfZXh6k+lQMHpJ2goKkEEuGH7I4gKgJLOX/3feM5zz5+sTwEsQzqGCQASL\nERaTNPyPijdyk4x9YIKMK/d4/aWYfIOyGPD6m07CvXBiveDlN30B//aL/i31+7+fM2bMj+iKSsXC\nJmc8a3VAp/yC85CVgXe//If51ncc48zrTvKh8gJfePERToc/TDve6j+SZu4o2m2azPPXP+ebODn6\nfe4FXJZjpOYWA2dH8I9e+o1Mfr+h8XHQBu2UsXoRs9GN6FChZxsUFs49fD+6SckvNeslnVccHfIF\nNw0Z/gbcMPsMinA9R2fw0L33Yusmgr00tHWsJu388RVH0K7CqgHnB2/guvNxIMb9d21wy6fP4KzE\nplYQOiTAVy0gOXPzp3nXa9/L354+zkWgSm0VbjjzYV72p/8wP3jxvVx3YYs/dlvDYze+mSaPbF5t\nPsijcsSWUjy0fR+tb3li9gSPTB7hdU2DU8eYHLvA+Uef4AvedJFHlWNgG049fAsAPiisPkJuLvLA\n+rt4zek3cfHEywDYrmacOT2hyY5w9hWfwdvfcBuZzHjtydfyp1/+p5n9zoisuZfBLe/lN9fWuOW8\n5898sObGLzbcMP0U5lM/xnw4xAk49kdOYe/YpJoW/OQX17w6P8FdF1/El55+KdLexMhYJiQffgL8\nc/U5Xo3BTTX2yDp6e8LRIx/nDe2voI7lXPjob6HqC9z9yr9AGL0MwRk0ljufGLM5M3hZsjabEZxA\nDQZ86bf8P/CD38fnfc23cd/2fXzvV0n+ykv+PK858RoeuOcT3PfK83zWBxu8HGC0ogC+eroFZ17O\nn/iKb2GUjTjxmcf4hQ8/yl990Wk++sR9nLjlGG988//DG4Xg7EPfTPgUuGYDG2rus6/mRdn9FIA0\nFUrkCGk55S7iAX2TZ3j3dtyRVBUnLtzOmfyTfG35e6yp0/zW5rdjdQntccJQc2b4Hj50U+Czspcu\nJJ2uqGxYEJqW9uwDwOt4cXiCefvK+Ltzd0Ezxq9/MQDX5ZpvuPlPsP0JQe5nCB1nVedGIAY12eQh\nWjSWkoGfItQN/T34ti8KhHNfyr+58a2ceNEvcXLrfti4Gb71A7zmj93PfGsMR1/MTV/z9Wz/oXuu\nCOquNg4jafso8KKl728BHn8SjwEghPAjIYQ3hRDedOrUqSd3RNmgH358uvgAZbPJxij5ZvOCQmY8\ndlKg1ku8zCm8YTx8MXXIUHXL5IgmjxsCjAi4dqGF9wxfCf63W1ruO7XJxy5+PP6yrhcMX/hewz8v\nb+l764eurD21Vm6RvOZUZAFKS3KV81Wv+Cq+dvQy/vd5188lIIPFGk/u6beJAUkQljNrd3Hz47/H\n6IYp//OzPoB446sRwfXSD4BpA8rW1Jngq1/x1YySS8LrglYqypAxUPDH9atSCXzSwZsJjhLpWkbh\nIqJruLV9AW1SR0Yx6QFfe8kXvST+7Zo8giDDC4WYVrQXk71TRGbV1pY6OUm8yMjTfNat8sW4lKe4\n6/EJ1eYUpxYl+YoI+CpVf47ZYuvY4/yFcWqFnHTYzMx4+Y0t99/8BI8ObuPmx3+PvHkYr+LxSTvn\nkeTsqG3dH4sNFt+2IBSzozN+8eZX8PrPtHzZG07xRS/eIr8uMjQf26eR2W3ODt7P+vTh/twYWzNM\nttjpkXVu/YITfPQLr+OTX3wzR7/2L+DUgLJ+gOzou7njhvdzMX8/N5z9MDfd8BKyZs715z7CsHkf\nL3nk9/iiVz3IKyfv55X+Lu644f28+rO2uL94JcIbjCtRaVhGsLbX8C2GQhiCk4SXRPulrM9yYnCW\no6qmbLe55dH30sqaYCWoHI1nc1qRhQBCkjdzghPowRBdFHzZ3/9HKK1ZLzZ4/2slZ7/8DRz7uq/j\njf/8O9k4pWhlm5K28V57mW24bvtV/OEbvhCAo+sFnywcG1/+J/l59WZO/aH/A6kUUkq+7g2RkBVN\nV4WqsMniKptZrNyVFtlUNDmI9TjC0o/HhKpBecsT5UU+e/hObsruBsDpAUUdn+PeY7dxJm8ol5K2\nupN0RkXsVVTF63ODJs7NBWim0M7xScO/Pi/52hu/kFMmZ50K0myE3CqUaLDVlJkY4USJFu2OpO17\nP9vzjpd9PsWG5SXDTyIEfb+pF33my3n1m18PwBv/5F/mS7/pO7gWcRiA/2HgVUKIl4mYYv864Nd3\nPebXgb+a3DpvBravmX4PoAt82ryEVKk4KlOVaVGSp+pSmQmczChdSyWHnAtHyRqHLyUusUkndyYw\nVYg+fKklr9cbXB8kszR1KLQWFYgavnCYpF+WqQUBgO8AP/XjNiLjZB53I0ovnY7hcdZmSU9P/ea9\n9WgXkHS9thWIxbQrlbo46sEAGRymXbL82YB2DW0WJ0plyVXidIGVGi8LlDDYM4+jXIPvSuCbCU4M\nyMwUHVpIHvh2stUD/lCNF86gFprUzbArXnOqRM7mNBfi+ylSQy5TO5rknvFCo33qS+OH2HTDNY1H\n121ka/05SC12U3XmuBkz1IPYl18E6tSoTrnYGnegRn3DfyvmOFXinUe7igsJVFrX0qbErvWWUNdp\nQY2vKVwDw8gCUi0RPiiC0IDBqDg2U6RcjXE1w84BFhTr+ToDPaAyFU1tQUi0mWFT9XRX4h/Kk7GI\nB5iNApkDHySu9jBK1kKZMSoUAYcIkpBaW7PUS8cEQ47BG7Ano4XTTcbRJttM+hoOq2psE/rE7tak\nYi31cSmaOd6J3pXTxTD536dLDelmZoZRNnXLTFWowjAOQ7JURXokJY3PjOM5L5fGAHasW1dd7Yog\npASubKYoIsP384omA7+RkrvnzyNSUdokLeSZqAkErBowbKOBY2tYYc2AQkcNXwmP6jp8DjS+qRF1\nvC5HoWXeJU3bKbSz3qVTlAVkQ0woyUQFeQJ8p5DK4JspRpbYUKBDjV6ubRAO55OhpOvt1DUYfJri\nKQN+CMECfwt4J3An8LYQwqeEEN8shPjm9LC3A/cD9wL/DfjWp/q6B4ZeMHydLt4sDVHIi5I8fcgi\ni0nL3BnmDDjPEYo6EAqJ0xsEGbsgmh0MP7ZBUEog8xFfYVVvvwxOISE1jfKYlLQtrI3FGYBPkk6T\nGL6g4HgC/K7vNwCDY4xSP5Y29Zu3xiNMQIrYASgg8Zh+2lUH+NnaAOFdD5ohhDiw3TXUWWw9rAsF\nweN0gREKS4HGYM89sQPwQz3ByVEEfN9GvylgpmN0aj080luxbW7wuCb07Wu7oeZWl6hZTbsZ9fo8\ntdxtqyWGL7O+k+DcDXDphjMmFq1ZtegRpESXtE2A344ZdbMJVKBKDF+5mmBahnrU906yMnr6z13c\nRruKrQQqtW+oU8925x2+aRBCL4bM23YJ8ON79ejUmsJEE4BvEQi0F7jQLgDfazaKDYZ6SGUrJpM0\n9NzM6SbZdbOFvT7ezyaYjuLfeyPxjYdBsgKq2Afeh4AIsn88zmFTC2yDocAQDLRrBXUGYTyNc4ab\nSWT1gBUNvgnI5BA5P56ykdw9RT3HeYkoFv1vgIWTbMmJNDVTWm3jNLeuiAjLmAXgbyRb6Jlx/JzL\npTGAKoG/TrbILLAA/GqaGL6BuqbOwK4l++a584iqockFqkhDXUQgyIDVJYME+JujCmOGFJnks7/4\nZv7QTY/1rx0GkjAbI1N76UEwcS6z9xHwzYyQkrZ5UUI2wPiSTNaIxPAzq1CiJZgZVg2wIUczRy21\nq0A4RLdT7QF/YQ55OuIwNHxCCG8ngvryz3546f8B+JuH8VpXFLrAoxDC95Po87SQlkVBkTy55JHh\n59ayxYCLYYNhM6cqBE6tEaQgCLGjVbAMCdS1BFHyNbXnvx25Ac7EeaaOqLcb6XBJ0smt6SUdr6Ls\n07VACKLkmD7Gw2zvZPiDY2RAIXNa6ZDORJtlWnyC0Olf2/cDyrqLb1gigsMlNHHWE4JAuRqTawpV\nIPMCbWu8LjBS40WGpMFfPIty1xM6wJ9dxGZr5GaKKnxvVw3VBG1vAjzraswFfQPSN4RW0KYBFSFo\nELHoRc1qmq0I9EWzDRra2lFTk8nkt06AP3Ml1qXZnq1HNQa3xPChQHiDFovq6A7wtRbUyS6qbWT4\na8O1vjCsUZGpPf7YadZ9zVgcjT93hqYbmuNtLyl1w+lZYvhCB0RwieFnhGBTG9xksXQZNpjFMPmg\nWc/Xsc5S2YpxAvy8nWPp+rp0j80QSU4br6WftQLXBhjF95jpnFGucAQkAp/Os3CeynSyVEsRWrwB\nUyhsCUxnSww/tVUQNaotkenzu7A9ZS3tdMpqjvcSke8EJS01pSp3AP6snVFnlqbM+NjLNTfdG22H\n4zC6hOGfTeM+C70A/E5m6WzSuRCo1JdIVFMEGiEsom5pMjAbBVBFhl+3tJlA50PoRiyqmLQtqzTE\nvqgxbUmpFcdvGuGvaziXXtuWknBxhhzEaywPNtoru6E57QzvK+oMhtlgieHX/aCd3CqkaMltjdcj\nrM9QoSJzpr+GMgE6S59l99nJ5xjDf1ZGNsAHjRAenXZUCQv5hv/t1eRpVRVZZJaZs0xDyaNijWED\nOg84NSLIWLC5Q9LxOjJ8LSAb8NKm5q++/hsA0E5RisTGhSOknjPa2X5Wp5M77VZClBzNUhJxB8OP\nPxvpAS0utodoHD4Bvpc62jtpF5JOYmliUCKDxyVbZtf5UrsGUQwRQiCKAuWayPClxpKhQ03YvJha\nJ8fPyG9foM06ht/0Uleo5mhXoFzNULWQaZSvCa3AdICfGJrTJdmsod1OQFfHds8//Dv3cNvDZylF\ntoPhz1yBTa8fGb7HLnUBhZgn6Sowx+2YYZp03X2GUkZpDWtZz0d9x8J5FgH//OlzFKFmkmaPNr7t\n5SVn296eGATk0iOCXwC+DPH7xPADBqvou02WLsPvAvyNbCNKOrZiPE4212bWzzTurlNf1/gyDimZ\nrsdjs23AtwFfJslOFQwLjRNxgHZn8RXOMW+7/vyW3FkI0BSSWQliOk+MMsSCKsCLmtBKZJJ0tmcz\n1tLCNajnBCsQxaUsdJSNdgD+xExw0mK0ZjrazfBTgWDZSTodw1+SdPROKBoI0bdZEPMxkujSkQnw\nmyMRnO35c6i6pS0UWbG4RqItusSrEuENTlqCG/W7im4R84DLA76u0InhZ85RtW4J8OfY2YQ6i/cj\n2QATBmSi6ndGmVMIYRiKmkpcj/UZ6/IMeqmSOpNQZBke8dyVdJ6VkTR8KWzPnPIk6bz2lhM94Aft\n8SpH+sAklDwmhgxayLTFyVHf5W8Z8GNvfJBKxvYHpkLlnXykKXAIb7HS4xPKaOsIQuGxC/tZ93xi\nyFDGLbLcxfAB1lRBIyzSG+Znl3qrSB1bNLAYYN4Bvi3yyEATW2oT4CtbI1MzMVHkKNtgVYmRCicy\nVKgJ4+04vzTVIfiti5hsjcxMUa7tpTLqChVKtGtQMkCWo1yDMAqb+pW7rohGleRzQzuJF3k2je/j\nzMWK87MpG2k2qEo2ubnLsZ0TyXpE4/vS+MV5MH2R27gZM+oAP4FIVigEEIzhSLGOTotincdj2Dy3\nxYCaWdp51d72kk5omsWOTMCwaxaXD0EPkNL1DN+nXZZRUdIBKFwBwvWAH0IWNfwsAf4kdd1s5nRq\nTJ4usVBV+CJKfNupmts0AddGrRlAq5JRHutivdSYWQIxH6hTv3UTWorE1JtCMitATeteQujyBIEa\nYRQyjW3MgmWUtG3lakINMt8p6QCLFiBEyXBmZjhhEV5T+E7Dtzs0fCUF64Xm3B4MX+pFfyqAQkhE\nGncoZtuxIEtaVG2oc0E7zBF5jjt/HtkYTKHIyg7wBa0UWD3A6iEyNUaLgJ8Wx7SIGR0r4kNryBKZ\nUt4zNy4mbAFshZls0eQwyoYEVfQMX3a7aq8R0jCkYdO8HIAb9Z1kSxXeuZAMcoUjtoeIL/b0SjrP\nU8Af4IMCbJ8M6yQdVEbetUpVHqdygoOxL9hMDcQKP8HJAV4SJZ0lwNc+AolUArISTIUuFi2GC+GQ\nwdFKF+cnBo+0Fi8VTrq+g2YXA3U0JgrgEkkHYCQzGuEQtqG2S73uZUYQCkvTM3yRkmU+LxDeEZJL\npGuTEEJDkQaCyI7hq4JWZng0KtSIBPghbafHm+dxekDeTtGuwQkdt6imRYWiH7JBXqB8DUZh6wov\nZCxIIWr4eWVo0yzeLA0jlzbQ+oZ1Ey/6LN0EM5vjEuCLALShZ/h52YGbQyUWPrdz1lK5rUoMLkvd\nIYOxHC3X+89oWkTA374wYUjDNHUpbPxC0vFLgB8QjPotVAHFGkI4pI+Cipc5XhiCCr2kk7tYJFSk\nBIDwOev5eq/hTxPgDeoZhl0Mf17h9VEgMEkstp0Z8AKf3pPWUcM3UuCFxiV7rHRhIenQUiTGWheC\nWSnQ86YHmD7RG2qk0agkNbxO3s//lmomux3XbkkHIuDP0/mqbIUPHict0mtynzo/YhmzkHQANgbZ\nngxfCBErU1PE2Q9Jw59ux3yQMOjW0mRQ6xx98iT23HlUHQE/T2QGXdDI6NKxekAIaSF3w36Rkek9\nNVnMYwTryZuuv1aISdtmUcdiJpuR4WfreDmIbTVE1T+PdgqEZUDDZvNitHKc4C50uqYClkJqTozy\nPp8HrBj+oYTSeDIEZonhdzdtTqG7WZQu9qZ3gk1bMks3wVAbnBgQJCDjBKUuuk6NSieG7xpU2j1o\nr8iCTwzfgQAZHMo5gtB44fspWF0M9JG+q6VaujEYJoaPosbsGE4BqculUDiavgFcx/BdUSCC6+Ys\n9JKOEy2DlDsQeZRjnIqSjkPHnjjTDvDjhXz+YrzotZ2i0sXrVIFsDTKUyNQHv8sJSKOxdYVbSrI6\nVZK1vpd01HQTnUmUDxjfsJ56CSlbYwlURmNDXHBUABp6W+boWPwqgt2RgBomO41Ou60sLQzBGI4P\njvSSzqxIu4jtGUPRME8LRR1cz/BFYwjp517AqNuV6RyK9aglBwc+J8jYeVWJ0J+jzOcE6SkTmAsK\nNoqFpDNP82KH9RwL6BDI0m7M1xVBriN1YJ40+2Y7LURlSmzqklGhaIXspUKIQNUxfEtLlhK4VS6Y\nlZDP2vgeWDB8QoWyOSr9/E+rD3JzGKdznj6P4mCG33110iKQFK4rWpQ4VC/pQAT8rk/NctIWUjvh\nFAUgu4lsk8jwgzBkjafOoNUZ6tRJ7Pnz6NpiC01RJjeRKqhFJBpWD3CiYoiEoJcYfnxPrQbTbhKc\noEz9ioSD1npcvQB8Nx3TZDDM1zA+7YZEjcyWJB1pGImazflNXHd8hrJjsq6zp7AUIuMH/uIbybod\nk5Agd34G1zqen4APOFEQliSdTsNH5WQ9w7d4kRGcYNMVtAl4R9rhKPBJ0lmOrCvAUqJv0qbS8ATt\nNZqADC5JOpGJYl2yPjqc8juer5Qbfc+bbuEAFgwfSY3dA/CThhkWgC8TW3B5hlwC/LbpAL9hkBi+\nKAq0a7CypJHRK6+wiFkVAV8WtHrIZgKbLExQZgnwjY0DLBLgi6JA2QZlM1xT7bBRdgnXJrl0lGvJ\nCol2YH3LMDF8adpYpm+zXtLRBHwrsDomoofJjhcZ/uLzGHUtAdJWLi81KEWwlhPDhaQzLtN4xgS6\nVddaOdhew6dpF5IOMOxWC1VAvoYQBhE8Ku24nGzRKvSSTu4yvPDk6eJRoWQtW+8Bv5q1BFx0QznB\nwIf+Og1Vhc+OInLNfD1NpNpM7qE0wDxTJcNc00rZ230hjrCsOsAXpgf8ee6ZF5BXdsHwE+BLV6Nt\njkrtSG4UF2ILi+CjtAeI/FIWupat9Qy/B/zUXqNMjcVqodBSIMTiuj4yWBzvbsBXSww/C6Lvq8Nk\nO47glBWFgSaHRmn0yVMR8FuLKzLKYcfwc2pCL+lYWbGR6EGv4acdTavpO2uOUt1KZ61t59v98bjZ\nlDoXDPN1Wp92pKJGFR3D1yAsefBsTo9xw3XpWkifjReOQuTcdHSATC6mp1vOgecx4HuRg3D9kOJM\neyLlVj3D9yIWigQnuGhyQrpBNrTDkkdL3tLFamRL1umTHcMHZBrqrbxChZS0lQ6ERASH8AGjcpxw\n2CWUkq4hl2uLpGq+dAMURwDBeoBKmB3DKYAeUJclnV7DLyPDJ0R9dcHwG4Z6ScN3TVw4siz2Jxct\nviVp+IpJcYzxLE3tkmNkYitWFUjrQBSIZIuQxYDMViib4et6R5K10997hu8aslyQhegmGZkuB9Ji\nBTRO9YCfhYBrJFYPULZeDPIIth9PCTByDvRgp4afZQRrODlcMPztQQvBE9JnUokO8H1vEaVt8bID\nfMGgs0HpAop1JCbu3Gzqiy8MmVhIOtoVeOEZpEVDIFmTEfBdcFSzFs8cATgnKIPvpUc/r/DGI4/f\nxGyYzudm+ty7BmZZ1PAbqfqJZSax6HmawOVo0WkuwTwLTEsoakeQOxm+8jUS2bclvklcwPhhzMek\nz1fuwfCH2bAH+llqQtbJlR3gV2Q75ByAjXKxeCxLOvF9JasoAU1MSMtgkN5SpLW4MFGGaYRCnzhB\n+8gjHD/XUB8pGZUlLgiCKqiSD9/qklZVbKR8QKF3avhtFkEfWNxjSZJaBnxfRf//qDiCSS1FMlmj\n02wE7RVBOmbmZnyQXH9TmpXbLHY/ZfqMe2fO0+zQgec14GcLhi8DOSauqEJQJFnDy7h1t05zvs2Q\nNoLXUDs8GV7A8jRDKxuyrmumEn1XTm3TFtgrZGqtYKXDK4EMDi8VVuUE4XvAF8FR1hfJGPa+8XJp\n0DRSwuAoI++oaC8F/ASiJtR90rbbXtoijzuLIJg0lja1bHWyYpQAX+YR8K0sEVnS8IXBNbJndpv6\nGPM6tZJVY2Sa3+pUERdSUfaAr8sh2ka26OtmR5K1W5zaafx75RqUgiIIHC2DNE5S+RZHwHvda/iD\nYAlO4vIh2lZ9wRjB9TN6AUbeQbkRG9mRAF9rgvn/t/fmUZJl913n525vi8g9q6pr6X1Vr2p1a5da\nlizLkrzIi7BlhJCxZ2QD9uBhwDZo4DA+MIyBYc4Z4AAGDAZjmwFGY3lswAYbGINtLLAkS5ZkbW1L\nvXdtucTylnvnj3vvixeZkbVmVaaq43tOncyMisy48d6L7/ve72+rONpfmnj4hUPXQ0LvOMbh4I2c\nbRW+KKvZQdtA+MIOELZBhmBzpcZoSTtFTNmURlgKNbmB96wnfIDxoKIR/liUjcQ4SDpZOm44ROY5\nlbAME7CR8IMtaVROkWpGSrWWzjg0BNsYnPPPFSU6ZGltmYZBJpDO5/Q7SzsvQNUxyOuvnWOcpXJF\na+eAt/92wg/q8US/GQZ6RMJPw41wgJmyc2CSmgmQ6R2WTii+Oi8d2gmEM2hivANwjqyEkYGxUuj1\nddxgQGUEH3/nPSzkhjEJTiUMnMVJTZksMtYDFkLGz84snVJ3CT/EukJKcDXYmCxuVHoPP1tu63K8\nwg/Wo/V5+C/U9wBw083B6mkJvyGNhB99++vs38MNTPgNCU40mMan0Zl6q91CmaiOZaysTHixSshi\n/3DjaKymkUy1N61UiQl3AJ+lE2ZqVl4JKKsRTvjWCsqCkj54KhS19Nv8KgxBNtUmuh6iyBlulqSF\nnvbwAfJV+k3NgLK9GNv3F8ijYkQWrKi4VWySFOkaBIIzW2Wr8Es1ohe6cUYPvxYpIklwQqFETVNO\nCP+8WmJU+mO2IM8jh+GDrTNU5XAyQwTm1HmOroZe3Y7HU3nz0c+vK4e0FQKHVpbEgaUkK2Njupoa\nh0O3aZl5sLKavI9uRuh4d7MNyMmWuFdXkC62KjHJtM+RrmuOFkuE+R1s5b6kXsY8//D3SjqE3/Hw\nGyfIdlo69SbCNagwiKWSFVqKKYVfC4dBtQOrc9drCb8eWmoZ2ks0AoObEP5wgB0MEXlObWsGKdiz\n/rlV8H2iwq+EryMBGIfd4cYwNBTDIoJVuKUbtsLpaGo18e+Z+PRVuAFI4ahdjm6GuDhpao+gbST8\n+NUGSycNCn+bZJfCnyL8XZaO//msdGjrEKiW8LOxw9SesMZGMBYSc8K3jPjn71qlWV/yw4HwKb7b\nNjZQKxiaEb1wQ4u7irhrqYxgHAhf4K9PQqPEZtQh/HHFOIEiW2mz9owYYvKo8DVKjjlT3UKvqClW\nQivvEAdoREMW63/k3NLZd1hhsKJB1776Ulfb7R01CR+8RoRCGxK2yOgFT1Illtoq33Ovc4QqOUaF\nB2IePoAKne2kUwgnffM0bX2fbBcIXxmstK2Hb5pNdDNC2oThZkW+MOPk5yv06jK0Vpgm/NYmoSQP\nAb8YeKuNnycqkJwZlG2WTtUl/DRF12MamSITg5Ua5UpsJdGR8MUCZeXnA/eTDVSYENSoFFX74dgi\ntFQwvZ4P2iJxY9tWxgpXU4aUv0ZNhqcr0XCMLYzbIg155NJWCAXCqTZom4X3Xad9VD3CRLXtGpAT\n5dmrx0Hhh+12R+H30x46VL0OUrz1FHYQpfDnY4SbePhdhY+gEFHhJ5D2kc0G0jXIUCZfRoUf35tN\naYRDOUkS+v1nrmgJ344dVSD8upZo5yZpmYMhdjRC5t7+GaRA2KHVJhxrXfg8fCZD6KugjreHE8/Y\nBjtzw1QMIuGPJjn4AEnI6hl1cglqCmQz8pNj2DtoO27GVLZiK+Sru3BtJ+FGuD3L0ukQfroj914b\nCUqwJR3SgnC6Jfx0ZNu+/6MExlKw+A3fwK0//VP8+ssUuc5ZzDRjEiqRMO5sLLbTIUUQEDFLJ97E\naiMZd96fbCoIcTrbCdqKsvGWTrY6Rfg6DHSPCv9Mc4rl5RpST/gmjMCsRUMWYodzhX8N4C2Zhsy3\nLUGVm+0dVesM5dyE8F3KlstZrMc4osKXvrClo/BrNWlGJpWcBG1L3zZXWQVOIq0PzkqhWkunkQYn\nLFVQlKrZ9NvpRjPaKskXZpz8fIV+OaTukEm7lvDaQzsgbYO2QeHjEPgYwpmtknLkawNKY+m3hJ+0\nSl6lPZzQiOBbxy6fG7ZH3RSYahuTNu3za5WiagNCtQrfFF6Bgy8UiutLyg2q8KFoVIqO83BdzSoj\nUjFN+Fr58u9KeHLMQtOX2nhLJ/YmcViQk11ErxxBujjx8DMFRuOqGikkqvFtEqwE2QyQsbArRLzH\nuNbDF1XdEn4D5PEmExW+8oVX0sVMj5IUhQp/SzYpFX7qUzb2RWZJk7WEz1hRqmDTWOUtnTZLZ4Qd\nDpAdhR8xDr2DtMkpjKIRrrV06qDwJ4RviRphU1Vsh78zLJm0YmBC+N0BSw05wg4RSXg/exReAQyq\nQavw+yEt0gSFv0WK0bMtnUTLdhZxhDYSXWgq4ZCNQziFDp/RbGRJw0fAe/gSmaYUjz7KqBmR6cwP\nB3KGEs1YdKa9ZcN217EzS6dJDeM7X9c+V9oSF2zbSPjOgSydr7Qt1qjCDdiIEUlQ+FmpeOBfGc5W\np1hdA5IwpGc08fDzaHO2Cn9O+PuGCeE7/wHtED7KkDhHJUL2g0vZJqdfjRkngBA0jR/FtjNoG+EV\nfgjahj7pfgyi9K0VlEUK7YerCEUjFVZaqpAuUrpNdDPG1pLhVkXen6Hwi1V65YBGTQhfBkUabZIt\nOySLMcWQeVBZH1QkKvxRg7Klb5xmunn4/v3LpPA9vcOFOAy+63ad0rgCXW8hjZsQvk5RITVNhA+k\nyvtt2mY9dm0WUTY6S20mhB9tbelKaptRC4upI+HXJNpnaFQu5N3HrbnK0M3QN3ADr/DVhA2LaugV\nfrAFkiwGbWO1s6aWPptH2CGSaOv5gzcStApfllWbK904QSa7Cn8RIQk7KL/GkSrJkGgVA6EpjcsA\nQRaqinWdkMcdYaUZ67BbahQaRxJI2A6HuMEQkWdB4cfrz1EGwaFNTpH6wqv2xhSIbBAagDlhqWuJ\nSDVDO2Y7839nOKqnFH4Wsno6ffZoRA5uiEgvbOmAt3Oih7+YB1Vr/bHdIsHInQo/ZMvo3dRz60Nr\nLN+3TAVB4SuMjIRft4Q/MrQK3jl/o/aE7z38sVVTCn8jH2LsDoUfPitNohjGFC7858wF+4fxFqgU\n1wgEPsCbZsutwnfUpCGDKa8Ui8+uUVGwsq5bha9H0e5qyHYR/tzS2TdYNI1oSIKHz3izs5VKAuH7\ni6myCSWGfFz5qkSzSlNbahzdIcRVHPFE9PCDwg/DF7TV4HSwdBwShQyEb6XBSctYNjgsxm2gmiFl\n6RhulmR7KfzRNo2cBJSKUCkaFfSgGZHGFLsQtG1sgxS+MOjMdkk5rlHNiLGBhbTr4QeCS0MgN0zk\n3QgfhkGVYF0fVW8j1YTwB0WBil3/wjEUeQ/dhJzj2mfVCNuQlBs0KqOWftiKCdaDqodULvded0fh\nJ0agHVTEys/Y7jfxQeFA+M5ZRCfXvzfe9gq/tXQ0QhtcLJe3ikb5AdfCjRBhB2ED4ddCMAjtcmXp\nx9YBNAjSOOZDZ97SUc4HxQMGSUni9KStg01wjRcDaVD4tsIrfAe6ShkFwreNf49TaZmjETIvaGzT\nKnxpHHU4/toU9BIdBIn0hXCB8Ksydh/1vZRkljBuxmwHrhmN6ikPvyj98SzriSKuRY5jhAoKfy9L\nB3xK5na5Ta5zitDaQAdLZ5N0Tw8/3eHfAzz85ps58cRNbUM5GoUOoiwbNWRRb2lH/CTWtqZxDbnO\nWcg022QMyKYU/jAZkYUAe4wbxF2LTQxjOSF8ZSvfAwqg3PTDT+LNWINI+p0054Y0BMtLo9kufO/7\n5aNJS/hqFDOYmrYGpuWheZbO/qFx2kfGa3wnx9FGR+EnpM5REYtUEhAVxbhhIyn4sVv/Gk3tdls6\nHYUvpxR+IHzfKR9pG0oFUhqEs6ENgsYJx7Oi4Zfv+qfcMvpVdD2mGltGW5WfkbsT+Qr9csv3aQkK\nv0iC9xvUwrYbYWys1A1ZOrb2E6iE5Ox2UPjNiFLDQsfS0a3CD8QZAtLnEv++RnWCEwvIZhuhJ4Q/\nynOyaqLwh/jAb/x/V2vfIbMZousRjczYzrzCN2moY6i2aUio0Kh6Qvip9pZO9PB1JHyrfZA7VH86\n1yA7mUC90SZkS23Q1uxQ+IlVNBL61oIb4URMzZ1I242x99tlWU+CtnYvS6dD+Kbylk7id3TSpggb\nZtSOwpSskSclY1MkkqEJvVQqhxZq0jxtOMSGLJ3a1R3Ct9ThfJlQeBVXYKVuO63G2ctWWJpaovKU\nYT1sp1SVHYVfK+iHG+K4nBCkryTtEP4eWTrgLZ2taoue6ZHGnPQgBjbId1k6MS1zZ0pmhFGSKpJ1\nrVuFn45r0irGqlzskcYwiIxMeYX/56o/ws8f+6OMO3/zfzr3FCfHx6det+2lk2gGnep3X+8SKnzL\nLegfmVhgxoFOgsL3/BAJ//95S85Wz8+1WD3e6xC+X58VDVm09OTcw993WLS3CxqBlMB4YypY0lX4\nDQlCDlDyXrazBT5tb6GpLDW0A7JhWuGrTpaOGj0PgHQJAh+0HWvQwiCFwwk/jBnpeMaVfPbIR1iU\nZ1tLxbkdKZkR+So9a6c8/MIExaAnhB8DfjoUzzQuKnzF6W3fdE3XXuEvhgsxtlYAEDFNNVz3G71l\nAMra4EQPabeQyiGd9U3cshwX/HMpR4xEjjCmzfiQNqE2OboeoZohVmZspz5oa3Ltbw6hbN00KSpU\nMktbY5TzNdKholk6cEa23T5VqAWwOKSZ9GnvlYOg8Dt5+FrjqhBjsMHSsQ7ECGRK4zROVqhQEXt+\n7LOtZMfDrxBkU0HbBYRywTLzGOqKBP++JA3SJoig8KOHX44aCl2Q1mHmbbhxp5Uf1G5a9rbYjQ1k\nnk0pfGUcdTi+WmqKRFMHYrTSoJJY5OXfvxMWWwtknjFqRvQW17HCt6SOCn+zJ+mPwi63hL/dP8HH\ndD+0ixihW8LffW12e+JvVVv0TZ+8TVH018YG+Z4Kf2dKZoRRcZQOuEpi1AikIBvVUwp/FMYYxrhL\n9PB/x93G7zQnphT+I9U5tku/jtbSCWt1qWEoo2IHqMAZf+OutiFbwgb7L5Z2V+MGJSvGaNKwY3Um\nZbt3E9oOKFb6nmt0hhhGwq8nMZyO03C9ceMSvlPUokE3omPpTBR+4mCkvaI7vfIgj44l545/P+eO\nvoXzg5KmtjQ7LJ2poK0WEE6gGLzoe+aEC0PamrESKGmQWKxQGGNQxheVAORGtgob2Dtoa523dEKw\nstCbYS3BF7cNeqbCtzghGZR+aLiuR5RasJR5whcdwrciDhQJqWrLvlPnsFQ42UfbLWTwOVUzpk57\nNOG5So4oQy5/GxMgpUwLn0ZZj7FkbGVgVYrJDLLX80F0fDBT1VGdVhjpCT925VRO4oqg9ushahw7\ncVp0l/CdCx7+NOETFH7qvKXTt7YNNI9sDycrFoN9tDE+59dR29bDry2kcRegQh6+nFb4Y1OR4Jt5\nKSyZzFvCj5ZONfIf+DRU526b0Git8haN6dgsOIeIWTpZtOssVYiRaKm9pROe3n9tRnS3VCgaslhc\nJZB5yqgesdpbZ5BCM6zaPjobBRTjmkbUbA8qtp/8UX5l8H7/vsUQ0wZt91b429V2S/hZJPxgn5wn\n2+Xht4Q/w9IBSJScWDpOYMQYmWek46r18J12lIHw44jMTGf0E40Q8DtPb1B2G7HJbZ7eapCCti5A\nZBkoRZOnDELrjGEKwlU4kVAwxpUVJH1caFcto202akALfs6+ljQOQMEwKI6xWD+NCBYp6QJy7Av9\nGtlQJOHx2E5hrvD3D43zg0lMLcJwjmaXpbNdvMBd7jf40qm38FVb6+Asw/4jbIVeHxUgOxfsV9/5\n5vb7rsIXw7M+7z00HJOuYaQESqUIHE5IFoqsHcIC0E9UW/QCzA7a5iv0rA1B22nCjwpfUKObmCoa\nUs1cjRQWh2JYNlSjClWPKA0sJYHwOx5+ZUNvfquwCOzqsn+N0QIISa9+kSZkYHjCz9sYghLblHKH\nwncZVVKg6pG/CQjJdp5SqxRTv4DMU9RoQvgyqnlbY4SfVRYJ39QWczS8P2pUKGSxzvr+54ASktS5\nKYUf8/BdFSwd5y2dnnOIsFM7xwJCOHrB3plW+KHq0wnSrsJP+sjYMiNgbCoSYQLh15xcWEQHwtfV\ngEZWfOpL5wPhB2UciqjSCszJx9HRNw6QeTGVpaOSjocvdOi6GJZ11wI69GiSNir8BldLRC9n3IxZ\nzVbZyqAZlO20q7OFw4wtpRqx/Zwgr/uojVf6961GJK3Cv3DQdrvcppf0Wg9f2gxB4xun7bR08gtb\nOlqJducCoV9NLycbl21aptCOUbjhRoWfqxwpBf1E88UXt7llvfBDfoBUbHO+lGRGtW0eZJJw89/9\nu/zuG29hEG7og0D4YLjHwoee/BG23dF2GJAMAfRq3FCbnL9av4csvIbBMChuYqF6ts3QcbrnFQMN\nVjRt0ePc0rkGsE5SyQbVBMKHKUvHOEfZVDzKh1nY+D1GsuK2L/4MTvV44EuhB4matnTuOnJH+323\n0pbx+aDAAwnbYOmoxFs6UmORxJLYzFr6S8mkvw/MzsNfPEHfTVs6qdhEuKptXSCs38XAJEuntoHw\nhWJYNZSjBt2MGWtYDEFbvb7W7jDGwY83L/weg6yAokA2JWnl+7Kv22epwnBu3YywpmizcLQcUKli\nh8LPaIwv3ok3gUGe++liz/06UgzRoajFNBmiQ/iJsigLNnrRUrN0d0iDMxIZbhQWhw6kU6jQpixb\n3OHh6zZomyCpg4evwk7teeH72/fDeTsfcuZFbbEhxbWygpSuwp+kZUYMTYWRKSIxKFcjbUIaCN/U\nAxox4j99+gVwhiQQ/lAKKgVp5dAmR9dQd3aTkywd/7P38IM9pQyJlu3NrREFOgQeo6VjhcNVAhfS\nBteyNQYZuI6Hf74APa6o1Aj1gvf4Ze3HIdZySLJUI/IctbbGTvSSCeFvVVssmIVJ0Ha8xoJ6gfOd\naVcRmVEkWu6p8I8spFO7ai1KZJ6SjctW4aMdpdut8AEWQuuNP/TqW0kzhZSgxZgSves1+294PSwt\nsC0nhC+pcRiO4zP9tuwa1TBYpQvhmhg3WO13I7GPf9b0qJJl+tUzbWwv7pwdlkbUFMFOnQdtrwGm\nCD++yx0Kf2xLNENe8dG/zs+t/TK3fOnXEIy4dSi47eF1vtBziHjxienmTkqHTnfhb0oacB2FbwRa\nZ0jhsEL5TIpwvR1rGpYfWuSWv/IX278309I5ci+J7oEUU4QPTWvpCOpW1UWF39gGKf0gaq/wfQ79\nWCsWf/yNcO5LmOPHufsPhrTCUqOrAeZLn+N0fx2VZahmTFGFIJR7Dnv0bv8atsLJvCX8VG7T6AJh\nEj93lwZBRqNydD1GhaDaIM1oZIpRI5/iGSpCkyZDOIMIFbhG2OCohyyZNMXFtsCpQg/O+bhAM0CH\nm1ecdkW62LZFTgsNnaBttHR61qJ0IHzpG9QVIWNnO2bp1Bbb2mOQtFk66W4P31nGuiYVKdIkKFcj\nnGmtG10PQY5InM+EWXCeUEdIxmbi4evGMep1FECWhuPmf5TGUcdK3tB2+rvf5AVILbNOfYP0NQrC\nQYfwV7NVtlMBg7L18DcK/7RGlSg7vcOo1ZDkuOLe3/h19MoKO1HoaQ+/Z3r0QrdKh+PNi39rqhd+\nF4uZmeqF38V6P+UnPvDq9mctRog8JR+PW8IX2jEOFmfscDohfEOqJe9+7BRJrklyTf2WP89Hk8d2\nFXoBpCrdRfiIhCURK7D7lFuKRoBdDmnP4xqrBImWPqlDQDb25zWtN/11Alji8aixsqEXrZ55Hv7+\nw1pJKSyqDmmZMJWHnzvHsCmRzk+8L5oX0c5SpE/zxcTyNd91P7WdEL5ScqpfvYw3gtheIVwo4BV+\nKX02hRQ+V9o62d54jtUNQifkR1fbvzczaCsV4sTLSUVDMXiO+9Nf5dbitxGunlg6tkYFS0eHitYX\nhy+yFWyIctxQlRbVjLBSIl/8XXjhMwDkRRjCgCAbnUY//yzP9dZQuSd8ha+y7XEaefIB/xqiBtLW\n0snUFo32lo4gVC+LjEakaFG1Cn+U9nFSkfQSlLaY0SRoizOtZZV0UuQAnJ60StapRmxt8OqP/xWq\nwe+TBMLvBwIkW+TOR4/wzj/6EItr+VRaZuJEyNJxJIHwzwqvanN604e9trhA+KUVJKLyH1KpIFlA\ndjx8aSsqA0ZmiMT4auHGkNYFmhECh5JDEicYVg39xhPDUNASvpYaXTmG+YQEXUv44fozlqop0Y7W\nlnj4lmUArMgx4Xwrq4iDREQlaEL8YzVfZTsDOagmCr/nv7qQfbaRvuhvFnhLx/SWZto54Nec65zt\n0ls6/aTPQq9HJcfUt/0mp9JPsNWZdtXFHUd6nFrJZ/xVj7xTjWvEGLKErByTlQ4nQEvHOFwv3aAt\nwNsfvInvf8tdrPQST/iFwbzpf+K73/oIb7nv6K7XylTGdojpDDOJFA1gWCLOBu5TbcCZJcjD56sa\nNVgpMMp3AlVKkpb+WjJ20NbuNC5W9G+ylZyll+xQ+AcQtN2XmbaHEV7hW1TTJfxJwUNhLcNmjGAE\nZKwEiyFZHvLhpuKvZZraupbYpRYTkocJ+escOI+k8R06AWiohcDoHCEcViqcgzj34FjdQKHbnu0z\n++hEnHyM5KkvIJ3l8eX/TMFphKuwMqRX2rpNxdNB4f/0p3+a75KvAqAuG5zDTy+KrxFaSEg7Rsua\n2mqy0WmEczzdW0XnGaoJFaLleYypSG592L+GaHAkob3CiF5vhDO9dranFT7l0ZJg5KQ69zO3LPGK\n5yBZXkGqCrU58fA94Yd8+aimW0hK5z/MJk+wW6fR5Ta1VKQhAF1EyzddRCeK2x854o+N1pO0TCfZ\nkr5vfpJYsLAZrJxU7CD8ZqLwKydIXTUp8kr7EAqvwO94Kg2p8zc9WVUIq8mqPsb5eIMR22TOMiw9\n4VeypLFmSuGr2jIoOtfAHgpfx4wRJjvORmQkrcIXOOmQ1iEaQVN40umbPs/1FPqpqk0zPB9i3iKk\nJT678EW0rim2b6LWQ2S0IPZAoYupLJ1+UfCPH/8h3n/H23jy/A9hf03OVPj/+LtehZK7bwQR3a6x\nWowhS8nL02SVLzBLcYzD9dL18AH+x6+5Z7K+xaSt5v3uN9w+87VSnbIVBqSUuSYTFicMvbCDKCkQ\n5xueWYEiJjWMG2rpq4XBc4MZ+89j0gzav23Ddfts+pN85Oan6KffSfgF/3Wu8K8ela34y7/xl6ms\nbxEgmwnRdi2dwjkGtkSGXvbrwWJoFpaoQzOyxjpfYEVQ+B3Cj3nPrcIXFht6u0hqKiFIkwIpg8K3\nE2vpaFODNG2r35n+fcTJx0jC9tKZJahHbcYOePtItgo/FEzVg3bQihv796LrMSKuOc7TbCpMGLWU\nh3zxp/JVdJ63RJ2PziASR3H7K/zfUQ6s9oPJmxF9XUEyIfxGjLC6j0NhlGvjBIN8KRyuDCnGmNAC\nwDQZDtO+p6QzIEbVQxySoQt+eJHQbG8hmppaSNLMq6peqMYlW5o6dLE9MkAuJI2CQiakIY91EGIH\nKf2p31O1xYaS4KoRGKp2cAg6RSgDIWQqmworBYnKQy1CCY0ir/voxgeBtRzRp2ZYNeT1AiO9hXKG\nUk8Uvqotg3zycbRhitpmzL5JbWgbvFt0NCIPOy+fhy8k5CGDuC7iTixj1E9Itr3Cd1K0xVgqEP7p\n4mk2F5/x79uM2lzyvdBP+rw4fBGH84Rv+lRqTLJ8M2cf/aP+nM0g/MyomY9HxK6ZEAnfkJcj8kph\nE0nqaAl/p4ffxRPvuYe3/pH7L/geMpUxtiW1kVS5QUoLwrQV3s+XMDpT8syyoBc71I4bmi7hK4Ee\nedGQBAsTwIYJeqO0wglLLwvX2Txou38w0vCvn/zXWCuwovFKZ4alU1jLoCkRwUI4sh3y2xeWsM6T\n/S6FP2XphO9jLr60VCEKr0RNDSRJQSbGlMkide2mFb7UJGELn8+ycyJOPU4a2ik4kUA99sO5A5St\nEEHhRw8foInWyDimU44w8TjUkfBLTGgjmYVq4S9lK0Hhx5L2M5zNFlH9JdAarRy2UTQ6RTcj+moM\nSQ/Zi37liDLxnq/RkzF5vdKTsS5ypBiiBv54J02Gc6b1xBMmhK/rEdYpRi3hp9itbUTjB8pkhSek\n3ngbTK8dGhMRm6cBFFLSSFjSGf3QMqAKmTF6J+E3jiZ8GMdW+F1Hp42Dn3oVFXUYdKEKn4fflNBI\nsqqPshvUEowcUjjLqGrIyz5Ds4WyitL4tsiJU0gH2/mEzF3mz+WZRcFvf98bWLplSCUEZgbhW5GR\nqGDpBOsw5qxXvVBhqjPKhcxb+wMFRjKKH4eQpXK69xTPrvw6tz358zR6o8022QuFLnh6+2l/DpJe\nG8g1ytALBXazLJ2LwaQThW/ECBZyeuMBt5f3U6SaVGdtG4ydHn4X/ZWMxfW9rSPw2UaNa/gP77qN\nj75qrY19ydqv/988/WkYNTy3IjBiovBLAXkIAislkU2cfLWb8MvUklpLmsRK23lrhX3F3ct3I5z0\n3TKtg0jOHe8sd46Bq9oMnvVtf+HYpWUAqsZ6hS8nCn/K0tnp4QtLmS6BHbM0+CKVEGRJxk3qWZzU\n05ZO04DSqNBAaqZ/H7F4koVgLzxdj6AeITqN1IStW8KXSqFib5WwxRehqEk3Y3rxJlDNIPzQD+iZ\nYg3TK6YI/7ncB29llmEMuEbRqBxVj1nSI2TaRy15Qpd2xKB3EnAs6802c6eogsfZK5CqQtQNiBGm\nSYNuDR0IY68cQDdDLIpRCH4lR1aon3kG2dQ4pUiCwi8GZ+D4w5P85nhsjIaQlqmtpFaCVV2woKPC\nD1YYi1O/pxsYhXbB4wYMZRuIA7ytE27C8Vykuo9aWkSMtqEW5FUPYbdopB+UYZxkVFmSqmBktvx6\nDGSlIwme+lY2ub6adHJNPPvyE97SQaA7vZ3ihLRGpiRR4TsfSMzDYSyL0GZa51SL/jjWA4U1kmEo\n1or+/+niaUb2Ge548hewibskhf/Zs59FCsnLVl/W5uYbaVoyvJCS3wu7LJ2bVpA4jj31FEo5ElNQ\nhoyl1sNXuwn/UvDwEW9V/vi9z3Du1lVk4AMX2kPoLX+MnlsBZ9N2oNDAWpbzkLARd86u9ju8gCaM\nehxlDblzaLMjO2eepbM/uHvR+3iNaNCNpe3YpSbb8p61WCDcyFnfDCcqEFdtHbW1k5J1LaZ8djnl\n4YMKF8rK6V8mcRs0QpAbw6reIIkFPeEmcaz2lo4Qnuz7y7sLW1oIwfvXHgHgx89/ht+TTBS+syjn\nMDFoqbW3B4Rqm4K1o3ybMctx6kfw8GmqdtZvNjpDLSQv5kukWYoK4/qy8Rn+89ITfv157nvhWEFl\nekjrdw0y66NC6X4M0t597LOs59uh5/+Ite0Tfj29PsqED5UYk9Q5VqSEDu5t+2T/t4aAZOw8kax/\ny7twTbiRaY1K/Gv2mwaOv3z3oTOToG2O4YGjD/FKvcTRmIcfSvWlmxB+rvMpwm+cxLh6mvCTBUQI\nbkoXgsK6R3LHncjxAFs6sroPbpNGgUkUwmmGZUMyzhmaTRIUtQ4KP1hyWx0x6jqEX4XXqgTozkc2\nKnxHhgmZJtIppJoQ/jgPXSJ1RrPsFXgVCD8q/CT7Eh8//u/RPRCDIHwSeXHCDwT/I6/7ER5cf5CV\nbIVXH381D60/RJFcOeFLKSYV02KMO7oMQHH+NFI1ZEm/VfY7g7aXi4ePPEwiEypbUZii7YdU1/69\npdv+fTy7LEhETlNbrHVsW8tymEgWeUE2W1MTk4ZPnkUox7CoKayb7MDn7ZH3F3cs3An4cmbtHOgd\nWyipKUJ/9FEk/K0GKwT0/EVeN5a6ce0FoPRE4QvBpLVrnHqlLKba4uYv/VuCcCTXCTIxHH3ho/5l\nW8Jv2pP99d/3CI+987YLvp+bv+5/B6BpGj6apa2qlLZGN5CG8W0iKPxHjjwCgfCzlvBHHJWh0GtK\n4UfCP83zxQpWKrJEt0SWjc7wmTUfAF553/voP3AfAJv9m0nKF1FA0Vv0Act+n2Lz3/LQb/9dTh3f\nRPZ6SBxHkt9lfXAKgI1MIpf93xZuQFYXjPUSYKmVnlJIOuS/f9L5DKH8rttYfPvb/e8ajUh7LDSW\n9aaB44/sPnCdoK2ra5Z6a4ikjxb+hhe7dFo7IfxCF6gGmiASrJN+19G1dE491qbYCleinEPrHumd\ndyBtRTMC5TSi2fbBvdzHKQajGlWmDPUWmVA02k9wiq0xtjqc1VX4Vcg5r4VAi92Eb0XSKnzhJEpK\ninG4vmOaqkqxy57EqoHyXSLDx6GnX+A/3/Yh7ly+ExFaLbjlI/Dgt+4+ph18zyPfw998y9/kXXe9\nyx9Pafj7b/v7vOLYKzqWzpVRTPTxtRjjFg3j8HmRoiRJFnzTNNswbIakKkWKK3udVKU8ctRfO4Uu\n2p177JiZjvzX55dBy6LtlLlZNy3hR/En7BYuEH713PNs/NpnWL59gE1KcmcRLf/sEKDXETcc4deN\n5a/+7PnwU1BhZscdVQiKcIGE88nqJlT9DBO2omVjg4c/CczINirfOWyB8B8//l95+Lf/NstbI7aC\n6k+1Aa05ev6TAGRJyoIuWLW23c4duWWB3tIFFD4g2i6EsC0mOfnSecJPRHx/irfe+la+7d5vaxMB\neoHwdT3iiOgQvrVgK0ziSFKBqYc80/MFNpmRbRA1G51BhDzs9Q/89/Qf8oRvqk2OPvNhBHDy6Lp/\n+aUl1s8/zZHTH8dkBbLw/25KP9W+lx988if5yTtzEA5dDUjrAucUznnCF/WE8COJfUHegwM+9NGn\n+Ye3+d1GlRWQ9Pipp5/lvRubcOLlu49bJw/f1ZVvtbB2J3r7i+AsSRPnB0yUbM/00JbOTFuJdp2g\nLcA3/g2EieesIncOmeQkd9wZbliBNOwWVkJvxRPt6JkXkI1iaLbInKKJHn6wdIaqadMgm2wG4QNm\nD8LPQq/8nuyhteboOf+c7TVv4+Q6h+UQ1HaCxkhCPRHLZ/wxv3P5TpIQ83FHb4W7v2bXMe3igbUH\neNPNb5r5f6mWLBeG9VkV5JeA6OMrxtz1W3+JZDHc0ERJli0DUNqybY18NXjlMV9dnJu8LdyLyKqU\njZ6kMrCkV9vpcRt1zXKwy6IoxG4R8wfO/pN/jLOW1fu2QJReeMWq/XnQdv+glWRZevuAQFrS7A6S\nFEGiDcPJyiqwi/1WkYyD9x23a0pPsnS6Xn4k/GPrI5Y2nkRbeMH4/HojDcIYVutnecXX3sq7vvqr\n+Wdv/Gv+oKtLz4gVYYeiLAykbBW+sDXK4mdlSokQgr/0hr/E193xde1a+zZm6QxZjS0CqoHv1wvc\ndet5HnzlMgDPFp7wc6NIVYNwDU09oOhPetYsH82RBu7+3X+IFT7ThhCsU0tLrGx6ZZkUCyx9yzdz\n5Ad+gN9/+R9of/+MPcevL2RkKxXZcIus7vkqZCy1Msh60qDOhAlKmRNYBb/62Rf4h88a/vF3/0X+\n28teD6bHbXVNoTJYn6TjTY7bxNKhqr2nf+870XqAtDW9sUK4hLFN2zbMPdNDNw4ro10ifEtmNX1T\nbjO/XEVhLegMffTI5MMPuKDwl273O07zeX/jG5ktCiGw2pFVtH10Rsoi8tzPY+iIij0VvomEn7Zj\nG+5ZvhelFDeddTTKsbUUZrmqDLU8CWrXRjJMBb23vJk7f+kzHN1U3L50+6R9QX51JCqE4N/8wBO8\n77W3XtHvRx//T9Tfy9On3snykg/yS21JAuGP67En/Cv07yMev+lxwCt8vaM4K2kyxms9/tPvfZl1\nfZwyEP52M7F02gQOt90S/rl/8S9ZeMMrSfoNTtbkbtIuYm7p7DPuWI0XdsikMLvzXovwiR0tdjI7\nlpfQkfDrkGfdIfluimaLmKXTn2Q01OFDr6Vm5T3v4dgP/Wle+813cvzkGjcv3kZY1CW/n5jyaCxs\nd6pupW3QDWTKTOIUATqsYaLwB6zSCdoG6+Su2wc8/jX+Bvlsz9+oMqO4bfRJXv6xv8GWMW25OsCJ\nu1d44587Rjr8HGXsDRQJf3mJpc0w5i7rUTz6KKvv+0MUL7uPOmSCVGrM76QJ6XpJf3uLrOr5tFUs\njdbIatJfKNpNiQMrBZujmsY6fkOuofK8fV1uemhXwBbCjbJpcNZ6pa813PYG9PIC0jUcGaUIlzKw\nhixYfP2kj6mhkYpG1CDYrfCZEL6j8vagyRFCkKxOUkNds0Wj4NgDnlDcs37nOTRbFEL68vwKTJh2\nNRYNMs/9eMNOtlIZhEslBFpM3mer8Enath3OWoQU3HQWBkuCoZ143EW+0KZiVkZgpOGmP/tBNIL/\n45OPsJgsTjpS5hfedV4Kji1me1bUXgzR0vkv7i6+ePIbSIMNKJUjzf11Om484bddKK8QDx95mFzn\nrGar7Q4/QpDCSkHfOUYi5/RTXuScVa4N2k5sIK/wnXM0586R3BEroRvSDt9PFP7c0tkX3LrqFWks\njonTbboHuBcCnYPlm9rHzMpqm0Y2igq/6+F3ArgtwsUmFyY+cGMmhJ8/9BDL3/RNk+fH/juXcXeP\nCj9zmm0hETZmZHiFn+kEsYPwk3Dh9hxAQyUrjlifDko1gCb2h0nQR4+y+d7/jl8+5XPtUyNJE1g5\n91nK/hIPnpjOby+SnHECZaq8sl6/169naYk8WAJpMbkBri9mPNf/fcBPDauE4PRxSzoOCl9oLA6r\nzRThx668ifWtazfDaLknX9z2zbdM7s/piUdnH7dwo3R1jatrhDb+uN/zdiQ1q+OUI9W3MrDaN1+j\na+kIrIj9aap2nGX7t8NNv6GkcBYZhuGk6xMBYa0fXnP8+BpQM9jwx2RotigQOO3QltZGGSmLzHNE\n4YefRFQuDmlhB+HH69C0Ct9ar65vOuvYXJZtUDNVKbnO2QibtarwM3aTUydZ+fZvx/z73yRXaavw\nZT7Z1R0EoqVTCXghvZV0Ke7WHWnhLcRxM2bYDK/a0klVyk+986f4zge/E9OxdEosTmS+syYwEhlP\nf/YcOlO8IF3Hw49ZOpu4Bgi7StlbCu/BtWNI/X/EsW9zhb8vuGU5DvQIHxqz+46ah4M9WJmUW2dr\nR9BhKz+swu6g9fAnQdtZCl/2Jz5w2gsZCrNOaCR8eemWTlTvuVNsS4FqJpaObnwF4C7CDzeJ3Amk\nG1NpWLYWlm+FatQqfFTIFvoj382ZUByVG9W2xH3wgdv4g6++ZepvpzplZALhf99vwtJJ/6eWJjeG\nJJsQ/kqR8MXlTzMwGzQhm+STN0tMvY1EUauCxvl2BrKa5DEnqT/OiYVGwsbI/651ob2uEPAH/y94\n4k/NPGwi7uyqKhB++Pm+r0OKGoaWdfcaBo1qCT9/7jPoxnv4LhC+tuUuNRaL2BpR8fhojAjnNT02\naTRmm02ckiRGUakx52u/kxqaTXp+6+B/Z9u/r1JZRJYhM984LaKKc30RmA7hSyURwjf5Eq3C9+0H\njp2DjRXZKmAhBD3Ta6trx0ZN0iiPHgXnKBpDUvnBHnE490FBJ76AzAIvqqOIcGkJ5Uh7/jMbFf7V\nWjoAd63cxWKySNKJnWyoGitz5PJRfrp+M8/07ufpz56jd7IHApbz6SwdyzbOgQ3zIkWxgBOK80pS\n2I5InFs6+4ubA+E3W76ceqLwu5aO//Bv99Yow9a4f+RYR+H7D5luFf4kLXNK4YfOeCLrt76nziYK\nfxd2DkG4BAghwBiv8KXsWDo12kKeJLssnTRkSaRIhBtSGcFY5NA/FhR+IPyQbrjamxBaZlSravTa\nKjuRqpR/9oTk3z+xPPW4Wpr8LLOJJbDWT/j4kd/kJ1/xF0DAohN8ZMVQyTAcQiWUziLSFNFV+LFp\nWuPVbVT4cY0A3Plm6O/ukQKzFH44H3d/LcporBMcGZyjbBxZ2HIvvvi7gfDlROHbHXn4TAL3VlS8\nY2swUfjHfVuHRoxRTY0N18yLnZiN1KssOdMSvtkKbaq1QORZO8A8ogqWzk6FD37n6URX4TtEU5PU\ncG5F+wHfgRB7psdGEeoLtG0LpUTur8m8kWSV7/FjDsBu6MIkyvv4AjZKx++nR1h/YJPFm0dkhT/f\nZbM/Qdsuks7A9oU1jVUpemGJP1P/92yNEs49N0Af868Xg7bxWmjYwjmNC2MmRZLyfLHCWaW4tTMz\neG7p7DNOLgbC3/QZJW0DqG7QNnw/yJeogs+YrB1pg7atpRNnYKqJpaOmsnTCxZYUyF7IxggpkTMJ\nX0p421+CB999We9JaE3mFOekRLWWToNpHLk2uxR+HgjboJHNNo12nJGrfodRDacsHYC13oTQMqOQ\n4ffVym7Cz1TGR+6R/N5d03naanl5st6OQlwuDA6NlQ1GGl4rCj6WpQyTiZovrUOlCYxHLXklYcus\nG0fNROHHNV4UgeBdVUFVTRS/yVALS1ihOX76Kaomdjz3bRp0A076wj0AaXcHbWW4ZiQVD5RlOyYy\nO+lH6Vm2UBYIzzsfrkGtau4Rf5a+pC36M9uB8BXIo+voY8emCd9WII338HdcU8pIrNOth28tfnwV\ncHZFM6pHpOFm5Qnf/95Q2slA+8yvvagkSSD8VF29h3810InEhMDtxrDi85zkyEObZKdWSMKxHjUj\nf0O7RoR/86nEE35M1X7OX6/Vmn/OJA8/7va2oK5xYU6wSBN+p++3Jnd0J7Ko3THF64WrInwhxKoQ\n4peEEJ8NX3f3UfXPe1II8dtCiI8KIT5yNa95KeiFCyUOqZjl4RfR0kn7VJHIV5bROxV+m6XTUfgz\nsnQwOarnFdMoBChnEj7A674Pjl24x8dOCK1JnN8edi2dN2yNSJRqiaV9f0FhCwSy3gLlOKOOTAg/\nZsOENeaJaqsjMyMvrPADgewin46lIzofnFQrVJgTup6v82iyxrNacz7bbp/T4NBpCmWJMhLZlOio\noKz3QbfGHYU/o9XtrGMGE4Xf1mMAOk9xUnH09FOUtWVtS/Dgk5aedV7hC4kLPYy8wp9WY3H6Ud+N\nEYAIJJSEXHfrAuGHD/codL3M9YCqceSi8tFoIDnnj0OlYOGDP8jJv/ZXW0tHCknVVKCMt3R2HnMt\ncU61N0lnHQSFeWZtWuEXupgQvmomhB8arKU1rcJPDljh3//6E7zy628nM9ITvguZdwvH2ptRG7RV\nVxe07SLNJu9bZkGpF0toKXDPjdGpYjP0PNqZh1+LLag6hJ8kfCrNEM5xa9W5Xr+CFf4PA//OOXc3\n8O/Cz3vhzc65lzvnHr/K17wobBMrKAPhxyHMnTtqphKkcwySnDIWqq6s7PLwY/m6z8OP33cOW7Ro\nTIEMmTqDkP4408O/QgitSZ3inFSoZhK0fWRY4pxEyJ2EP+kAKZohQ5PxM8sf8BZUNYAypFSmk2Bz\ntHVyo1pLRq3uJnwjDUqo3YS/PCH8nWPxlPR/ez1f54n+bQCc7p1v/78WkBQZrizRxttWppgot5G1\nvutnKHjLk4sr/Hijd9HDN5PzoRKNy3scedEr/Df+Bvzgv7D03KUp/F7uVd+qDVOowo3f9OKat9CN\nQ4QbcZn5ayZXG5SNJRM1Ng8xghfO+WOgwPYz1PJyG7TNdbB3lPGWzgzCt063LZGtA8oRtYSzS2Yq\ni6UwBRuhX8+2qlvCj5ZOVolW4SfyYAn/5L0rPPjESXqJ5vyw4vM2Ev7xlvDLpmRYX33QtgsTPHwn\nLcjQVTZd8o3SNirWT/Y4P65ItGwFUhSAtdzyWWFjf03IJOFTGm6tatLuRLN4Di8njrdPuFrCfxfw\nE+H7nwC+6Sr/3r4gEn6bpZPEtoCTi1iolMLBwDVUodRfrayQBFIfB8I3nWIr2VH7LToKf0L4/g6/\np8K/AghjSJzmnJLIDuFjAcsuS2exN7FbZDNkS/d5trjHW1DVEEaBbDsdJmORTGZUa8nMInzwW/6d\nN7RphT9NkLHx1Fq+xs2Lt3J3WXKmP2klWxMqUsdjlAJpK1RvotwGoYPpXUf67RovhlbhlyVY67N0\nAqQSiN4Ca89/iapxHH3Rq9te7TNnrJDYoPBls9vDz4INkoVqYBmuMRP6zws7QFraXUUTAvk5Z6kC\n4YtI+M/5PkalprVy6lj4prLW0vEKf8cxN5LahuCtlDgLYjzi7BJUSk4RYs/0OB90wLasWg8/ZuQk\npSVtPfzrbzfMQi/VbIw6Cr8/UfjXwtLRMWhrKqz1okiki97qrS1Jrjk/qFjOTTuXIFo6ldxGVDW2\ntXRSPk3J/WVJIzpc8BU8xPyYc+4ZgPB1dvQMHPCLQoj/KoT4wFW+5kVh69jnJFTnRfLpHuBijUJq\nhvVwivCjwh/tLLxS3cKrzmGLHQWTBWSwdLa5BoQfLJ1aCHQTK20bnBVhmtZOwp8od10NGMmElV4S\nFH6X8Hcr/FRLRFD4esZ4O/CEf2FLJ93x/InC59bX8eCwzwuLA3CTPjF5VPgKlK3QxYTw42DrB076\n9V6SpRN79A99IFh0LB2lJRR9Vl54CjsasfaivwYWaq/waYO2ziv8HYSvwvBqIWoq54fUw6RgSNlt\ntO0EjvOYNfUCdV2TihoR+l7I5z3h1xpv30Cr8DOd+UZhKnr4OwhfCxobKzgl1oEYDzm35Kik4Pz4\nPEuJPy9dD39LliwYLwpkSDZISkdaOcZGHLiHH1Ekio1hzRfccazQsHzLlMLf76CtSgw4i9UlTe2t\nNpEseIVfO0yqODsoWzsHIOsn5MuaJjZeG3ghs8WYZ92Y+8c7CL/th38ICV8I8W+FEJ+Y8e9dl/E6\nr3fOvQJ4B/DHhRBPXOD1PiCE+IgQ4iMvvPDCZbzEBFHhf/drfDphq/C7BPWNf4Oif4KNcoOhCvbN\nyspuD78z5KBNy+wq/Du+Cr7h/4QTjyL7wcMP/cW12Mctm9EYF7o7RsKn8b07GrtL4Re9TopkNWQg\nEtZ6SfDwBzMV/mov9WQvRBvImxW0Be/jX4jwd1o6WSDM9XwdbnsD/x8/wIuLk/bJTkuSIsNWJUpa\n7+EvTHLBo3sfawLSS1H4IUjrhoOpnyFsw4s+0jY8+OVPkIbkoF7pMA04IbHYyXhDtdPDj4TfMCJp\nhUIkfG23URZkuMmkuUb0nuGW5LfI6k0SKhLp++eIM/5cVAqq0MMoevi5zjtB29mWThOarzkpfFfW\npqJKHZUQnC/PsxhsO+/h+2t3IOt2ELkMlo4sK7JK+LbNB2zpRPSDwh+S8atv/Cfwqg+0hD+shoyb\n8VUXXnWh0jCqU42wtVf40vRJVCD8RHFuULVFVwCPveNW3vL9d1KHS7IJrdZ/f+hnC7xsT4V/CC0d\n59xbnXMPzvj3s8BzQojjAOHr83v8jafD1+eBDwGvusDr/Zhz7nHn3ONHjhy5kvfUEv4da2F7ne62\ndChWKdIFnt56mrEGqyWy12uzdIadoG2+YCgWknZ+5bSHn8Bj7wcp22rbSl0gLfMKIbTBhMZMrYcv\nHK5/0neQ3BG07arjpBowlJlX8KbwbRUGXlV2Cf91d67xxD3+mOv1dWSvh15ZnrmeTGUXtnR2jMaL\nKuxffXSbj3/5HHZ8ksHScUzlPxwm1YgkxZUVCus9/E5LhzrYKw+eXOLRW5Z55NTsdXURz3v8AO5S\n+Kn/+2/6/K+3jxchW9UJhRWWJA4w36XwY1+mmhGmFQrFUsLRjU+RVp9DNSDNJC5y+uiT3J3/Kgv1\nGVJRkQrF+QJEqAGo1ETh77J0lPa7ux03HqUlTcjxrhEMxg2irmi0j4ucH59nOfXHqjAFz67Axm3r\nfOEmQT+JHn4Yuj0YkteC0SEI2kYUqWZj6I/JxvrLIV9u13a+9DfK/QzaiiTxU8zEAFv6qWxC97wQ\narzCPz+sphR+kmlWjyzQxA4LQeE/U70IwF1lhe1ywVdw0PbDwPvD9+8HfnbnE4QQPSHEQvweeBvw\niat83QuiaWKv8mDpJDH3ffoAF7rgS5tfotJglxYQQuxKy9RS8G1/9pU8/OZT7fzK7uSrLqKlU8Xs\nv30O2hqnEM5N0jKVxN32VWCbXUFbXUyCttl4yJiFQPjhWGw9649HZzv8rY+d4u/9YR9TX37Pt3PH\nz314z5mmC8lCO8i6XWOSIIsCtJ4iV4A715cB+N2n4UO/9RR1Aw+t/K/oMDg8yRNEkuDGY4q0IRud\nwSxO3kO0dFZ7CR/6Y6/nDXevX/SYRavChnGK3SwdqQRWKIZLa7z8mU+3jycheckJiR/mGBX+NOEv\nrwiWzn+ejOcYk7TXjVKSR09/mLx8Gm1BhbhBZhTPNt5CWWzOkFKTCt166uAtnUj00cvPTd7x8MHs\nUN7KyHYoOVIwqiyiqaiNY0DDsB6ylE4snXEi+H//3Ffx+ROio/DDcRoOSCu8wj8khN9LFNtlTHMO\nfa/CNXt+fH7q5/2AMAZdDynFedx4A4AGQ6IlsnGYbLelA55LmpieGQRGnJW7YK23oyIWj4OQsHAT\n1xtXS/j/G/A1QojPAl8TfkYIcUII8QvhOceAXxVCfAz4L8DPO+f+9VW+7gXRBm2b6OFHhb/jJJmC\njXKDT94icK/zbQXiRTXq9NLpr2TtVr3bNXMnYh5+3Nrtt4evrfCqMRZe4ULK4W6FH1NEAXrjEWPZ\nY63fIfzNZ726F3vcvJIEc+LEnuv5kdf9CH/ysT+5+/eWl5AzbhJHw+5nNVvj/KBiXFuyJEOFeEdR\nJMg0wZUlr7nnLPd/+ifQC53+ROHrYn7pxzRaFc2G/+B2g7ZKS2xj2bjtHhSdRidl7Hu8U+HvEAsL\nCY/91l9HqwFjZ9rrBkAmKUkjvKUTFX4ieab21spifZaEijudYrDobyROK5wQLdG3Hn6r8JOg8Hd6\n+JIwIoA01QgEoqlxGs6G6UtR4WupSVXK8wO/EZ94+P44ueGQtOJQKfzYZhlABdss2k3nwpyJfSX8\nJOHBT/4Dnl78Ny3hV06TKoF03rI7N6jaoqsILTVFyNyygfAHokILn5A8RfjHH4EfehJW79i3dV8q\nroqRnHOnga+e8fjTwDvD918AZjQrv3Zo6h0KP6YozlD4AL/wKsn3fJMvz58o/JClI6fJ3Q9C2YMk\nW0uH8Lv7q/C1rTyJxC6gwvqUQ9sgdviBnvD9IHJTbjNWx1kpEhgFVR4J/wpx18pdMx9XS8u44WjX\n49F3XUpWOTesKOvGb5NDtWmxkHqFX5aI7S2UrdFLHcIPls5idunHNKYbRoXf3XVILWhqy+Yd93Ls\nY7/m0xodnC2XWAYcigZHKiLh7+ilE1J9K6kZkrLesflElpGWvrupTuIAEsVT9QJIWLZnMdTcT8Lq\no3+As5/8ydD+o24nOUUPP9NZyMPPfdB2lqUTCF8q4esuXIPVjnPWE/5iJ/W20EVL+G2lbRYV/ghT\nuUPl4fe6069knEfhg8obgZD3W+EvbH2JzSrB2TAMySny0KVUaMm4trsUPsBCsQKc6xB+TR5qINxO\n8XcVn72rwQ1Zadsq/DDAmoUjfgu1Y+ZpYSaWxFrms1F2Bm2VnCb3JNOYPVRmDNpW10DhY7QneztR\n+Er6Pu/UDWLHjUl1evuYeshYGV9N21X4HSLYL6ilpZZAuojFWmvZGucGJVXjMEogQ1fEhQU/BJzQ\naRDALHQsHfx81PQSsnMiZOHPb7MRCL8TtFVKYhvH8E7f+C056p97bhybtkic2DtoG7OYfiV5PX+5\n/o6p2a0yTUlqUA2o0Dc/TxTPVylOpSw7r/BRCXo9ZEGFmEAcyt1aOnra0tlN+ILQ8j8QPghncR0+\nigof/DX/3OA5YDKxSkhfaGe3tjC1Y2TEoVH4xZTCnxzjnunx1PZTwP57+ADUNfX2eWQzprKKLOyE\nyyA8ukHbiIXQbdZue5tyW4xbjrH7mcBxFTgcq9hnTCydUJF695vhZZMmXxFR4WupWQzj8nZ5+DvU\n/Nf9sYfJF2Z/GKKHH8cm7ncevhoRSH8StKWqQ9B2h8LvkK6uh4xVwmo/mRSKbT0L63fv2/ra11pb\no35xd3bVu+58Fyd6J/iVj/T5nXO++CjRElloKGFpsUBUnhzrs2eQvV6b+gjew1/IJrnPlwLZKvxo\n6XQVvqSpLeM77+P3F47y8P09yue+yEbZB85DUPh7BW1jFtIX09v4T/aONksHvGI2tZtW+EbhnID+\nUVbPnsM4ASZFhbRXTzRDNsrgG+/I0mmUxgmB2RFL8ArfgQIpBUIIhGtwemJTxbRMCES55YkyEn48\nVvXZUA9wiCydfofwu7bZ48ce5xd/7xeB/Vf4AKaB8dYGph5RlZYsKPxxsP+W8t0KfynMk6i3vMAY\niJI8xEnsIdkx3aAKf4elk6awvtuCiHff1Wy1JZKdzdN2Kvy1k32KxdknT+2wdPY7S0c2DuU6Hr4M\nfWKa3QpfmKwtPNP1gMYkfnscFb6tr8m28sj/+AOc+NEf3fX4LYu38K33fCvLheH0dkljHYlSyAW/\nnuWVYjLt6cxZZL/vCSwc/1o4FrPLO54TD3930FYpgW0culfwPV/9g2QP+njFVhl3FQorHGkk/B1E\nm9xxJ+ndd/P8qhcRXYUvshRTg7agQ6+lWJXZFEdY4xwmKvw1H3yON5BoU3Q9fIBRCMrrnT19jKSp\nHagEESwd4ewU4XcVfgzUAm2WTjxWzRlvAY4OkaVTdCyd7mfxLbe8pf1+vz188A37qu1NpB1RjRoS\nYjWtf14v3Z0WvNT3hD/c8DfOTbzC36LYbekcEG5Qwp+2dHZmjEREhR/tHGBXawUtL11RmptvxmnF\n88vXIi1TIxsbLB1/I/OWTj0zLROVIlzjK1ZtjSny0HWzk1lzDQg/OXWK/IEH9vz/5TzhfEizM1pw\n+9e9GpoXuf+NDyCCrdGcPt3GQ2K8pMYr/MuBMAaM6Sj8TqVtUPhxR1cve+Kuy5huKbG4dszizqCt\nOXaUO37uw5xfWEUFZd3+7TTDVBbVQBJqQGIriCo/whrnMaHHvj7iCV+F522GVMCuhw8wCNeS2Zke\nqqUvNFSp/zQLiXC27cQJtFk6wFRmVZf8RZ7TnJlU/B4Whd8N2nZ322889ca2zmU/2iNHRMI3NZhx\njXJjxsOGNBB+bN9XJLs/26t9n9I82vA3zi18jcCzd3wLR17+jn1b49XgBiX8oPBDAKzbQ6WLqPDX\n8gnhR6U2LGcr/AshOXWKsz//t/j9o9eO8FXHw5cq9Ilp6l1BW6REuAbdhLTHXvigm47feQCBo6n8\nZSV57HV38sf/3rexspS3H7bq+edbeyyO8fOWzuUfT5nnNJuhRN7sUPi1a8/3+Qe/wz8erDwRFP7E\n0plNKlrKXaJAZCm68ufKxC6a4X2M0zWOiHPtFK1YySxTP6AkEn7XwwcYhBuT3kFuWkuayoKOYw69\npSN0TCvWU4VJ8ZrXQk8Rpbd0gsJPDhHhJ10Pf0JXi8kir7wpzKLdx8KryBXaQlqBtCPGg6rtploF\nD7+Y0ctpLbTpLrd8uuiWG1Logrv+8N/itq96/67nHwRuSMJv6qBuosLfi/D1xNKJEEKgpWBcxw/M\n5R2iXj4h0X3N0jEaUTcoC0m5yR1Hn+OofM53gWysl/s7IF2DDgNFsv4swt//oO3F0E1n2xmAjbZG\n/cwz9F77Wv9Yq/DdFRO+3Zjt4VvrSGIflKCcTRVHEyksjixm6exBgEpOaje670NVFm3BhAH00dLZ\nTtZYZQPjRqAmHr5MEhbMApvVNOFHhT+MluOOG48yfqdCvoJohrig8GOMcDldntp9RFXfS3rTu5I8\npzl9GjhcCr9Id2fpRLzzjneSyGRqB3O1aC2dGrISJGPGg9rHXIB2AuQMwl8NhF9vbyHSlGFz9eMX\n9xs3JOHbxnmiqCsQYlfbgYh48XcVPvit414e/sXQzfzZ1ywdraFuSBsQOB592QYLetxaOrsUPqBU\ng668ws9jxsuUpbO8f+u7RCx3gl07ibL9sB0/zvr3+JZLcfZAJS4vJTPCK/zdaZmxPYaOW/Vg2Zhw\n3oVTWAF5mG2wM2gboZXYFdgXaYYJw1qSVuH7a3AzOYoSjuXtJ0GnyDRFLiwgkoSFZGG3pRNU+DC2\nbthJ+Nq3U7Cv/B5EtTkh/NAfqhuwhck13w3YAog8a9v6jhJxaDz8/h5ZOuATAX7pD/zS/hJ+J2ib\nlQ4lx4wHFfHKG7m9FX6W+2PqtgeIJGFQDab44DDgBiV864ujqmpPdQ+zPXzwufdX4uHDtC+6n710\nhDa4uqYXlIbOFhFa46rSB21nKHylLUb4nPgiVq0eJktnh8LX697PvumDf7ZNqZz0Gr98Dx9AFHlb\neDVdaRsINKjcKtww07grxHv4RST8PRSvFGLXLlBkKSo28Ou0VgD43LG381F7B8aO2r+p19Zawo9Z\nOrWtUUK1SnsoZhN+e3weeh+kOU4ohGtQyr/+TjKM13z3OgWmZthWen8DoVeDYkYefoQQYmp3vh+I\noiN3hqwCJStG2zUmbPxilk5hdn+2YztuORgjkoRhPZwr/OuBpnEoJXBVvWfAFmZ7+HB1Cr+n/QdJ\nC31ZKYQXgzCe8Ps2zMvNl/3NLKZlzlD4iSoxa44Xs0XSk6Fq9hoHbS+GCxF+9vDD3P2r/x8Lb31r\n+5i6Wksny4mJ6tOVtsEiCedojMRJSV6N4zOwAo7Jc/7HPWoWtBRTGTrgg7YRcXcZLYCzVcJ3lT/I\n2cV74agfgrPy3vey9I3fsEvhK6HaNsWD8BI78/B1iA00TsLaHW3Q1ob3t4vww/nfqfBjRhPADz7x\n51lIpqeZHRSm0jJniJr9RhSIfVKyEpSucdahK0/0o9DddZalE2NEelwj0oRBPdjVfuSgcUMSfrR0\n3EUU/l3Ld/GmU2/i8WPTM1mMknvm4V8MUTntq52DtyNcXVOEBmoyzdrHqOuZttXX/KHbqL/6Id73\n9j/Pwk3H/IPKQJyLeiCEPyGsZKelI0Sr8iO6QdvFGbnPF0OXyKa7ZYbeN9HSseBMQhFm6grnPfy3\n8hu+FL4/u5GfkjMsnc483/ia0dLZGNWcYZFfedO/hDf9aQBW3/eHWHrXu6YJ3zYoqdo40FDOTgRI\nQxHgeFD7AkN84VVsl91NyYSOpZPstnQiHrv19TPf60Ggmw1zubvtK4GQErSmJ1LSClSQ9npksTi2\nqibEbXavJXJNMrYIk1Dbeq7wrwdsbX1jsapqKxhnoZ/0+Ztf/Te5qTfdxKjrLV+uwjfKYKS5JoRP\nVVGEEkqhNSIxobXC7KDtkVe9FnfC9+toh5QLMbF1DoDwuwUr5hKqZiMx1+DbO18mZKdr6CwPP66m\nqi3WJPQC4UskWlQ86D4LD3zLnn9fK7G7/Ua30ji8ZrR0NtqU1N036J0KXws9IfygzHcmAqQ9//No\nu8KloXLWWWx43Z0Kvw3aXsDS6R6zg0Y33/1yP4tXCpEkFM6QlaDTMARn1FAB50c1hVEzd+/x+pJA\nE67tuYd/HdAq/Lqe2sZfKrqK7XKzdMB/mPYzQwe8UnR1TdH3+eJCKQgKf2ZaZkDceq52yTIS/jVo\nrXAxGCXbbXp6CVt0pQXKSP7Rd72Sdzx0+d0FRT6b8Hcq/LKx2CShCLN+hVMsE7z/B75pz78vxeyg\n7c7X7Cp82B2wBp9quFlu4pzzHn5X4d/2OmC3ws/DlLLRVtU2B5SiQYg9CD9YjrFxWvs+OsdJzmiN\ncVDIzWRe7/VQ+OCVeiR8E+bXMmgoBZwflnuO1+y6CXUYjTpX+NcBtrGXZOnshe6FdSWqomd6+67w\n0RpXVRTRe1XaB3Kryg9AmaEYAR44scQDJxa551hnC3+ACh8mKn+nhz8LSkt0Ivmqe4+S7vEeL4Su\ncmVHt0wAGXvRN5bGJL4DKSBRrItzfEreDSu37fn3Uy13rUt2BrhHwRFJYnMUFP4MS2AhWaBxvqVx\n4xq0nCj8Qai92HldZf2g8LcqnJ4QPs6vYSfh5+Hcx8Zp7Zo7ls6sXkgHBSFEm4t//RS+oVdKlIMk\nD+d2UFMJx7lBNTNDB6YFRSm9FXTYPPzDUe+7z2gah9Lyigm/q76uRFUUpsA6e/EnXgaENuAcq8qr\ncmE0sldgh0PfY0HOvgjvOtrn5/+HN04/aArv4+/40F8vLBeGp84NZ6rcnVBaYi5hYPle2NvDD9PL\nYtC2tjQhNdOFjJhFscV/Tl7Hyy7w97//LXczCEV67etkXYXv1x5HMl5I4cdA6Ua50WbptEHbMDdg\nT8LfrkjDLk+KBm9WjS8jLTNv176zTcdBo0gUW+P6inbbVwJZFCye9Tu9NBxfrG+Zcn5Ykc+osoVp\nhT8KhD9X+NcB05bO5d/TrsbDB79tviYePvANp77W/6wU2X0vg7rGnj+/Z63BTJj8gr3wrzVWQuD2\nUhS+VKIN3F4J9vbwg6UTavSqxlIHhexCUFuKho+mr7zg33/k5mVee+d0lld3nm98Ta0kRomJh38B\nwt8sN3cp/NhFc6dVmGQKKQXDrsKXDUL473cFbfVswo87oe4N8rAgWoB7tSXfbxQvf5Sl330WgHyx\nM1cZx/nhBRR+h/CHYczp3MO/DvCWjsRV5ZVZOp0L61JU6E5cC0snvo8sjn5SmvyhBydPuCzCLw7M\nzgFYKi7d0rnvNcd5+M2nrvi19vTwQ9A2HrVxZalbhR/63iB5Krn9sl9zVtAWfBzlS2dCqws929IB\nT/itwr8I4QshSPvGB23DNdcIuKVe4/sf/X4ePfro1POP9o7SMz3uWJ4evhFvjN1sncOCWG17vTz8\n3uteiwztWfLFRaSMrZHh/KBqA/C70OGaQZh2ddgU/o1p6dQxD/8KLZ3O1vFKrrGXH305R7aubB7v\nXmgHco9D2qBW6BMnUGtrNKdPX57Cz5ahqS76tGuFWG27My1zFu549OqOY9fDn1L44bWNmDTLq9S0\nwj/tFtBXEDeYDtpOrr9X3b7Gz33saf+6ewRtYaLwp4K2gfBnCYm8b6aCti+qNX5j/dv5Px5+28zX\n+LXv+LVdWSbRhpqKeRwSXG8Pv3jNa9vvTx69nbSnGG5WVAI2x/XeQdvO9bWFt4TmHv51QAzacpHC\nq71gYtn9ji6Il4rvfeR7L/t3LorwPuwoZJEonxqWP/ggW//hP+wZtJ2Jt//lgyX8y1D4V4spi6Jz\n848KXzp/49ka11SBnOtw83zeLV3STWnXa87Iwwc/JD4S/iw/uuvhN7aZqrQdVLM9fICs5wnfxdz7\n5QXe/aZX7Lm+Wdd0a+kcooBtROyYqa6TBWmOHSW5607Kz30eWRSkhfWEz95tFSDk8CsFTcMGXpjl\n5nAp/BvU0nHIqwjaxg/j9VIUl4J444oKP1bWZg8/5H/eI2g7Eyu3zpwPcL2w3p8MBbnW2NPDD0Te\n1JYiVWyPa8qgkOtw83yWlZnZNBfDLA8fPOFHXNTScTVa6vaxF4Z+qMysdN8sWjph/SvLBa+/6+JD\n3ruIx+kwevhFopCC1lq5Hui91qfByqJH1vPnsBST9eyFyDej6OEfMoV/4xL+1Vg6aqLwDwuiNWCH\nE0sHIH/44amfvxLwrY+d4se/8/GZU4P2G62HL+VU9klU+LZx9BLN9nhi6dRBlY8wV1TO3yX8bmzl\nltWCk8t+PTODtqYTtA0KfyFZYCVd4cnzTwJ7KPy+YbhVQfg/mV5BRXJQ9uIQEn4/1dctQydi8Z3v\nQB8/jjl5gjTsSGNr5HxGH52IyDdxCNI8aHsdYBuLlD5LhwucnL1wKBX+Tg8/EEn2oA/cxqHaXwlY\nzAxvue/YdXktmYVg5M4RkB2F3wsKfxwIM2brWC4tzrD7NWd7+EKINqNnFuEbZdqe+DFLB+DmxZsp\nrQ8C7mXpjDuWjrxAdfleEIc4S2cxN5c1y3g/UDz6KHf/yi+jV1ZIC3/Mq0tR+OE6qzRIIQ9N19GI\nG9TDv8o8fB2HTRye+6HY4eHHIiK9ssLNP/Z3ye6//6CWdqjRZp/sIPyJwrf0Us12WTMKdklsS9Cw\nu4r2UjCVh79DcHzjIyf4yJNn2tTUnYg98WOWDsCtC7fy8Rc+DuwdtLXWUeL/pkov/+Y/sXQOn4f/\nXa+/nTfds79JEJeD2L6iDB7+XkFbmFb4hS72tYHifuCGJPymvrpKWxOU/WFS+DFo60Y+W6Nr4fSf\neOJAlvSVgFax7rgOYh5+U0dLZ6Lwm3BsLbuHm1wKhDG+xsG5XTeaJ+45wr//02/e83djP53a1lMK\nP2Kmhx8IaWw90d9ols5NSxk3LR3cjWinwt8zLZOOwlfi0KVkwg1r6exPL51D5eEHwupm6cxxcUSr\nYi9Lpy4b7v39ErNRMwoEa0M+vtijK+JFX1OIVuVfbpZY7Ikf2yODV/gRe3n4AGPrv6rs8m2ENi0z\nO3wkddDIWg/f/3wpQdtKHz7/Hm5Qwm+uNktHHUIPP1aBjkKWzhWkm74UcTFLZ+PFEavPV9zxfMMw\nNBxrws1UK3VF/XtgMq7xcs9TVPixPTLALYu3tP9/IcIf1pHwL9/SEVKy8r730X/z3ruPlyrSNkvn\n4pZOjBlW6vAVXcENaunYxqLklVs6MVB3qBR+9PB3BG3nuDCipbOXwt8+73dMJwaOM8K3HYgtCr75\nsZt52xsuv9IWJpk6V6Lwn9x4kr7ptxPTbl6YWDqzpqi1lk4TsnSugPDBTxqbYzfaLJ3wc7FHLx2Y\nTL2q9eFLyYQbVOF7S0decS8dfQg9/DZLZzgn/MuByDIQYrfCD1bN9jlP+BKBVseBSdD2npuWuHn1\nyj60cQjKlVo6tatbhb+ULrGcLu85RS2PDdRCLuCVKPw59saJu5e59/XHeUaHDpiXYOmUh1Th35CE\nn2Qak6urtnSud+7vhTBR+DFL54bcnO07hBA+ELkjW0ZIgZSiJfzT0tKTPlXUhnx8fRXHOI45vFzC\njz3xu1k6ALcs3NJ2ztyJJNcIKSaEn88Jfz+R5po3v/e+SdD2EtIy67mHf/3wnf/b63nV199+0SHm\neyEG6g6Twp9k6Yx2FRHNcWHIPJ8ZvJdGMjjv89s/bxqMSLBCY0MV85X00YloUzOvQOFbZ9ksN6f8\n+lsWb5lp54C/qWU9zfY4xJ4OYWrlVzqUFG1frQtm6XTSMg+jwr9xZWIcXH0FhVcxFe9KcrCvFdpK\n2/FobudcJmSez7zxKyWoxw4EnJM+IFcm/dbDvxrCj0HbyxUcsZXCudG5KcJ/78veu6vzZRd3PnqU\nT/zHp4C5wr9WSLSfdX2phVeHkfBvWJnoKh9iuZr2yIdJ4eu1VQDqZ56d2zmXCa/wdx8zGadeZYpB\nyMCoTB8XFH6yh4VyKbiatEzAe/gdS+fB9Qf5tnu/bc/fe8033UGxEEZH3nrLns+b48oRkzkupfDK\npAVr2dqezzso3PCEfyXkGNsj7xxOfZDQ6+tkDz6IK8u5wr9MiGI24ceBGqbQDMKpLs1Cq/DNFewO\nI2KmzOWeq0j4QBu0vRSkheHN77ufhdWM3srhU5Y3ApKw47twlo7/v//5if+F993/vuuyrsvBVTGa\nEOIPCCE+KYSwQojHL/C8twshPiOE+JwQ4oev5jUvFa61dG4MhQ/Qf4vPkZ4T/uVh9b3vZfnbv33X\n41HhJ4WeKPykjwvVrOYqdlJtb6MrCNpGdBX+peC2h9f5w//r69o0zTn2F7Gfz6V4+CdXb6Of9Pd8\n3kHhaiXsJ4BvAf7jXk8QQijgbwHvAO4HvkMIcc0bv1yNpXMYPXyAhVgUM7d0LgtL3/iNLH391+16\nPCr8rJ+0hF+aftt6+mqydESWgp6dRnkhdBX+fk9Nm+PqkGhJquUFhWDkG5EcrqZpEVdF+M65Tznn\nPnORp70K+Jxz7gvOuRL4GeBdV/O6l7S2SPhX0FrhUGbpAOl996GPH58r/H1CVPj5gmEswOKozELb\nV/6qLJ00u6IakKtR+HNcWyRKXjBgC7Ri7LAS/vWQECeBL3V+/jLw6r2eLIT4APABgFtuufLgk6uu\nwtKRh6/SFnz63cq3fxvDj//2QS/lhkBU+P3FBAQMcUHhK6gh1Vee7VK85tU0W5uX/XtdG+ByPPw5\nrj0SLS9o50BH4V9Bx9LrgYsSvhDi3wI3zfivDzrnfvYSXmMWa7q9nuyc+zHgxwAef/zxPZ93Mdxo\nWToR6997DcYnvkQRO2YuLPsP51A6qqTP0d4Sz40hT648n33xbW9j8W27Z8peDEb6nvjDerhn3v0c\nBwOjxIX76DBxFL5iFb5z7q1X+RpfBm7u/HwKePoq/+ZFMSH8y//QJIew0naO/UdsoLa4mCIEbAso\nk0V06lW2PKAYzkKy4Al/7uEfKiRaXjBDBzoK33yFEv4+4DeBu4UQtwNPAe8B/uA1f9X6ahT+4euW\nOcf+IzZQyxcTeolmIB3l8dtpbl0nOXsWkx6MpbKYLPL84Pm5h3/I8O7HbmZcNxd8TozbyPQGJHwh\nxDcDfwM4Avy8EOKjzrmvFUKcAP6+c+6dzrlaCPF9wL8BFPDjzrlPXvXKL4L9sHQOm4c/x/6iDdr2\nDUWiGAhLVSvOvFCxdqp/YNOKYqbO3MM/XHj3Y6cu+pzk1lvQJ44f2ky6q1qVc+5DwIdmPP408M7O\nz78A/MLVvNblYpKlc+WFV3OFf2MjBm3zfkI/1QzlmGbU8MKXt7jvNbPCVtcHkfDnHv5XHpbf/W6W\n3/3ug17GnrhhTeqrKbyKaZmHLQ9/jv1FVPhZz1Ckk/YK9bhh/dTBFc3MFf4c1wo3LuHH1gpzD3+O\nPaCUIMkUykh6iWYoJklhawdJ+CYQ/tzDn2OfccPuGfej8GqepXNj4+R9Kyjjz3Ev1TwVT7eAtRMH\nr/DnWTpz7Ddu2CtqPwqv5gr/xsZ9rznOfa/xU6566aSfztKR/MAydGBSbTsn/Dn2GzeshG0VfnIF\nM231PEvnpYZeMvHwD9K/h46HP7d05thn3PiEf0UzbecK/6WGfqqxWtJbTjl178qBrmUetJ3jWuGG\n2zO6umbzl3+Zc//8nwNX1tOizcNXN+z9cI4deO9rbuWhU0t8w8MnOKD0+xbztMw5rhVuuCvKVRXP\n/M9/DtnvcfQHfxC9cvlqrW2PPFf4Lxncvt7j9vXeQS8DgKV0CfB9deaYYz9xwxG+zHNu+6l/SnL7\n7VfcRtjM0zLnOEDct3ofH3z1B3ndydcd9FLmuMFwwxE+QHrXXVf1+4e5W+YcNz6kkLznvvcc9DLm\nuAExN6lnYCHV/OmvvZe3P3Bw5fVzzDHHHPuNG1LhXy2EEPzxN1/dLmGOOeaY47BhrvDnmGOOOV4i\nmBP+HHPMMcdLBHPCn2OOOeZ4iWBO+HPMMcccLxHMCX+OOeaY4yWCOeHPMcccc7xEMCf8OeaYY46X\nCOaEP8ccc8zxEoFwzl38WQcEIcQLwO9d4a+vAy/u43L2C4d1XXB413ZY1wWHd23zdV0+DuvaLndd\ntzrnjsz6j0NN+FcDIcRHnHOPH/Q6duKwrgsO79oO67rg8K5tvq7Lx2Fd236ua27pzDHHHHO8RDAn\n/DnmmGOOlwhuZML/sYNewB44rOuCw7u2w7ouOLxrm6/r8nFY17Zv67phPfw55phjjjmmcSMr/Dnm\nmGOOOTqYE/4cc8wxx0sENxzhCyHeLoT4jBDic0KIHz7gtdwshPgVIcSnhBCfFEL8ifD4XxBCPCWE\n+Gj4984DWNuTQojfDq//kfDYqhDil4QQnw1fL38C/NWv697OcfmoEGJDCPEDB3HMhBA/LoR4Xgjx\nic5jex4jIcSfCdfdZ4QQX3sAa/urQohPCyE+LoT4kBBiOTx+mxBi2Dl2f+c6r2vPc3e9jtke6/pn\nnTU9KYT4aHj8eh6vvTji2lxnzrkb5h+ggM8DdwAJ8DHg/gNcz3HgFeH7BeB3gfuBvwD8qQM+Vk8C\n6zse+yvAD4fvfxj40UNwPp8Fbj2IYwY8AbwC+MTFjlE4rx8DUuD2cB2q67y2twE6fP+jnbXd1n3e\nARyzmefueh6zWeva8f//O/DnD+B47cUR1+Q6u9EU/quAzznnvuCcK4GfAd51UItxzj3jnPtv4ftN\n4FPAyYNazyXgXcBPhO9/Avimg1sKAF8NfN45d6XV1lcF59x/BM7seHivY/Qu4Gecc2Pn3BeBz+Gv\nx+u2NufcLzrn6vDjrwOnrtXrX866LoDrdswutC4hhAC+Dfjpa/HaF8IFOOKaXGc3GuGfBL7U+fnL\nHBKCFULcBjwK/EZ46PvC1vvHD8I6ARzwi0KI/yqE+EB47Jhz7hnwFyJw9ADW1cV7mP4QHvQxg72P\n0WG79r4L+Fedn28XQvyWEOI/CCHeeADrmXXuDssxeyPwnHPus53Hrvvx2sER1+Q6u9EIX8x47MDz\nToUQfeBfAj/gnNsA/jZwJ/By4Bn8dvJ64/XOuVcA7wD+uBDiiQNYw54QQiTANwL/PDx0GI7ZhXBo\nrj0hxAeBGvin4aFngFucc48CfxL4KSHE4nVc0l7n7rAcs+9gWlhc9+M1gyP2fOqMxy75mN1ohP9l\n4ObOz6eApw9oLQAIIQz+RP5T59z/DeCce8451zjnLPD3uIZb/73gnHs6fH0e+FBYw3NCiONh3ceB\n56/3ujp4B/DfnHPPweE4ZgF7HaNDce0JId4PfD3wXhdM37D9Px2+/6943/ee67WmC5y7Az9mQggN\nfAvwz+Jj1/t4zeIIrtF1dqMR/m8Cdwshbg8K8T3Ahw9qMcEb/AfAp5xzf73z+PHO074Z+MTO373G\n6+oJIRbi9/hg3yfwx+r94WnvB372eq5rB6ZU10Efsw72OkYfBt4jhEiFELcDdwP/5XouTAjxduCH\ngG90zg06jx8RQqjw/R1hbV+4juva69wd+DED3gp82jn35fjA9Txee3EE1+o6ux6R6Ov5D3gnPtL9\neeCDB7yWN+C3Wx8HPhr+vRP4J8Bvh8c/DBy/zuu6Ax/p/xjwyXicgDXg3wGfDV9XD+i4FcBpYKnz\n2HU/ZvgbzjNAhVdW332hYwR8MFx3nwHecQBr+xze343X2t8Jz/3WcJ4/Bvw34Buu87r2PHfX65jN\nWld4/B8B37vjudfzeO3FEdfkOpu3VphjjjnmeIngRrN05phjjjnm2ANzwp9jjjnmeIlgTvhzzDHH\nHC8RzAl/jjnmmOMlgjnhzzHHHHO8RDAn/DnmmGOOlwjmhD/HHHPM8RLB/w9mM46MzoiUbwAAAABJ\nRU5ErkJggg==\n"
          }
        }
      ],
      "source": [
        "plt.plot(fhatbarhat_random_linearinterpolation_spatio[:,0])\n",
        "plt.plot(fhatbarhat_random_linearinterpolation_spatio[:,1])\n",
        "plt.plot(fhatbarhat_random_linearinterpolation_spatio[:,2])\n",
        "plt.plot(fhatbarhat_random_linearinterpolation_spatio[:,3])\n",
        "plt.plot(fhatbarhat_random_linearinterpolation_spatio[:,4])"
      ],
      "id": "6275a523-e3b5-4c43-a23a-de7ea5be9b37"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "#### 3) By 2"
      ],
      "id": "80896ae5-38e9-40eb-8718-dc3cda4a04fc"
    },
    {
      "cell_type": "code",
      "execution_count": 173,
      "metadata": {},
      "outputs": [],
      "source": [
        "w=np.zeros((5,5))"
      ],
      "id": "c3a8d47c-6114-465a-8b02-d77c0faeb552"
    },
    {
      "cell_type": "code",
      "execution_count": 174,
      "metadata": {},
      "outputs": [],
      "source": [
        "for i in range(5):\n",
        "    for j in range(5):\n",
        "        if i==j :\n",
        "            w[i,j] = 0\n",
        "        elif np.abs(i-j) <= 1 : \n",
        "            w[i,j] = 1"
      ],
      "id": "94f08600-51cc-4f98-a076-3a87d79aeeaa"
    },
    {
      "cell_type": "code",
      "execution_count": 175,
      "metadata": {},
      "outputs": [],
      "source": [
        "d = np.array(w.sum(axis=1))\n",
        "D = np.diag(d)\n",
        "L = np.array(np.diag(1/np.sqrt(d)) @ (D-w) @ np.diag(1/np.sqrt(d)))\n",
        "lamb, Psi = np.linalg.eigh(L)\n",
        "Lamb = np.diag(lamb)\n",
        "fhatbar = Psi @ fhat_fiveVTStwo_linearinterpolation.reshape(5,199)\n",
        "power = fhatbar**2 \n",
        "ebayesthresh = importr('EbayesThresh').ebayesthresh\n",
        "power_threshed=np.array([np.array(ebayesthresh(FloatVector(fhatbar[i]**2))) for i in range(5)])    \n",
        "fhatbar_threshed = np.where(power_threshed>0,fhatbar,0)\n",
        "fhatbarhat = Psi @ fhatbar_threshed\n",
        "fhatbarhat_two_linearinterpolation_spatio = fhatbarhat.reshape(199,-1)"
      ],
      "id": "5cc25cfe-ed99-4069-a675-7d30eb90f107"
    },
    {
      "cell_type": "code",
      "execution_count": 176,
      "metadata": {},
      "outputs": [
        {
          "output_type": "display_data",
          "metadata": {},
          "data": {
            "image/png": "iVBORw0KGgoAAAANSUhEUgAAAXwAAAD4CAYAAADvsV2wAAAAOXRFWHRTb2Z0d2FyZQBNYXRwbG90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\nwuICNwAAAABJRU5ErkJggg==\n"
          }
        }
      ],
      "source": [
        "plt.plot(fhatbarhat_two_linearinterpolation_spatio[:,0])\n",
        "plt.plot(fhatbarhat_two_linearinterpolation_spatio[:,1])\n",
        "plt.plot(fhatbarhat_two_linearinterpolation_spatio[:,2])\n",
        "plt.plot(fhatbarhat_two_linearinterpolation_spatio[:,3])\n",
        "plt.plot(fhatbarhat_two_linearinterpolation_spatio[:,4])"
      ],
      "id": "53e70297-c231-4c2d-ad76-61b743fbdf5b"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "### 3.2.3. Spatio-Temporal\n",
        "\n",
        "#### 1) Block"
      ],
      "id": "7f777d16-3d82-4708-b77d-a880bb2bf221"
    },
    {
      "cell_type": "code",
      "execution_count": 177,
      "metadata": {},
      "outputs": [],
      "source": [
        "w=np.zeros((995,995))"
      ],
      "id": "8bf2c767-0b63-474b-bbbe-746c21428cc8"
    },
    {
      "cell_type": "code",
      "execution_count": 178,
      "metadata": {},
      "outputs": [],
      "source": [
        "for i in range(995):\n",
        "    for j in range(995):\n",
        "        if i==j :\n",
        "            w[i,j] = 0\n",
        "        elif np.abs(i-j) <= 1 : \n",
        "            w[i,j] = 1"
      ],
      "id": "b32b44f5-0529-422f-9fd0-1404ab7fa72e"
    },
    {
      "cell_type": "code",
      "execution_count": 179,
      "metadata": {},
      "outputs": [],
      "source": [
        "d = np.array(w.sum(axis=1))\n",
        "D = np.diag(d)\n",
        "L = np.array(np.diag(1/np.sqrt(d)) @ (D-w) @ np.diag(1/np.sqrt(d)))\n",
        "lamb, Psi = np.linalg.eigh(L)\n",
        "Lamb = np.diag(lamb)\n",
        "fhatbar = Psi @ fhat_linearinterpolation.reshape(995,1)\n",
        "power = fhatbar**2 \n",
        "ebayesthresh = importr('EbayesThresh').ebayesthresh\n",
        "power_threshed=np.array([np.array(ebayesthresh(FloatVector(fhatbar[i]**2))) for i in range(995)])\n",
        "fhatbar_threshed = np.where(power_threshed>0,fhatbar,0)\n",
        "fhatbarhat = Psi @ fhatbar_threshed\n",
        "fhat_linearinterpolation_spatio_temporal = fhatbarhat.reshape(199,5,1)"
      ],
      "id": "738d1b6b-290e-4860-9f73-956340e78227"
    },
    {
      "cell_type": "code",
      "execution_count": 180,
      "metadata": {},
      "outputs": [
        {
          "output_type": "display_data",
          "metadata": {},
          "data": {
            "image/png": "iVBORw0KGgoAAAANSUhEUgAAAXwAAAD5CAYAAAAk7Y4VAAAAOXRFWHRTb2Z0d2FyZQBNYXRwbG90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\nNWrUuE7w/wOgiC8aSWiapAAAAABJRU5ErkJggg==\n"
          }
        }
      ],
      "source": [
        "plt.plot(fhat_linearinterpolation_spatio_temporal[:,0])\n",
        "plt.plot(fhat_linearinterpolation_spatio_temporal[:,1])\n",
        "plt.plot(fhat_linearinterpolation_spatio_temporal[:,2])\n",
        "plt.plot(fhat_linearinterpolation_spatio_temporal[:,3])\n",
        "plt.plot(fhat_linearinterpolation_spatio_temporal[:,4])"
      ],
      "id": "52d30cd4-085f-404e-bacd-26380b7d9ae8"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "#### 2) Random missing values"
      ],
      "id": "dd9654cc-4930-4a1d-8ac4-043e54447ab0"
    },
    {
      "cell_type": "code",
      "execution_count": 181,
      "metadata": {},
      "outputs": [],
      "source": [
        "w=np.zeros((995,995))"
      ],
      "id": "52bf64e9-faf8-45e0-a082-3ad37d78036d"
    },
    {
      "cell_type": "code",
      "execution_count": 182,
      "metadata": {},
      "outputs": [],
      "source": [
        "for i in range(995):\n",
        "    for j in range(995):\n",
        "        if i==j :\n",
        "            w[i,j] = 0\n",
        "        elif np.abs(i-j) <= 1 : \n",
        "            w[i,j] = 1"
      ],
      "id": "33bf554d-ebeb-41d0-bfbe-b546eb2a4480"
    },
    {
      "cell_type": "code",
      "execution_count": 183,
      "metadata": {},
      "outputs": [],
      "source": [
        "d = np.array(w.sum(axis=1))\n",
        "D = np.diag(d)\n",
        "L = np.array(np.diag(1/np.sqrt(d)) @ (D-w) @ np.diag(1/np.sqrt(d)))\n",
        "lamb, Psi = np.linalg.eigh(L)\n",
        "Lamb = np.diag(lamb)\n",
        "fhatbar = Psi @ fhat_fiveVTSrandom_linearinterpolation.reshape(995,1)\n",
        "power = fhatbar**2 \n",
        "ebayesthresh = importr('EbayesThresh').ebayesthresh\n",
        "power_threshed=np.array([np.array(ebayesthresh(FloatVector(fhatbar[i]**2))) for i in range(995)])\n",
        "fhatbar_threshed = np.where(power_threshed>0,fhatbar,0)\n",
        "fhatbarhat = Psi @ fhatbar_threshed\n",
        "fhat_random_linearinterpolation_spatio_temporal = fhatbarhat.reshape(199,5,1)"
      ],
      "id": "bc817120-7e9b-43df-a755-487400d8cc82"
    },
    {
      "cell_type": "code",
      "execution_count": 184,
      "metadata": {},
      "outputs": [
        {
          "output_type": "display_data",
          "metadata": {},
          "data": {
            "image/png": "iVBORw0KGgoAAAANSUhEUgAAAXwAAAD4CAYAAADvsV2wAAAAOXRFWHRTb2Z0d2FyZQBNYXRwbG90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\nqFChwiWC/x9QqCzyWRWvQwAAAABJRU5ErkJggg==\n"
          }
        }
      ],
      "source": [
        "plt.plot(fhat_random_linearinterpolation_spatio_temporal[:,0])\n",
        "plt.plot(fhat_random_linearinterpolation_spatio_temporal[:,1])\n",
        "plt.plot(fhat_random_linearinterpolation_spatio_temporal[:,2])\n",
        "plt.plot(fhat_random_linearinterpolation_spatio_temporal[:,3])\n",
        "plt.plot(fhat_random_linearinterpolation_spatio_temporal[:,4])"
      ],
      "id": "062ed5a2-c6e5-47d8-bfad-483fe2065ee4"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "#### 3) By 2"
      ],
      "id": "aca6a476-75ee-4246-abab-e20036446810"
    },
    {
      "cell_type": "code",
      "execution_count": 185,
      "metadata": {},
      "outputs": [],
      "source": [
        "w=np.zeros((995,995))"
      ],
      "id": "e5c224d0-73c5-4a75-96ca-5a1e33a6a1f3"
    },
    {
      "cell_type": "code",
      "execution_count": 186,
      "metadata": {},
      "outputs": [],
      "source": [
        "for i in range(995):\n",
        "    for j in range(995):\n",
        "        if i==j :\n",
        "            w[i,j] = 0\n",
        "        elif np.abs(i-j) <= 1 : \n",
        "            w[i,j] = 1"
      ],
      "id": "4d1a0dc5-59ea-494f-bb8f-239577d76c2d"
    },
    {
      "cell_type": "code",
      "execution_count": 187,
      "metadata": {},
      "outputs": [],
      "source": [
        "d = np.array(w.sum(axis=1))\n",
        "D = np.diag(d)\n",
        "L = np.array(np.diag(1/np.sqrt(d)) @ (D-w) @ np.diag(1/np.sqrt(d)))\n",
        "lamb, Psi = np.linalg.eigh(L)\n",
        "Lamb = np.diag(lamb)\n",
        "fhatbar = Psi @ fhat_fiveVTStwo_linearinterpolation.reshape(995,1)\n",
        "power = fhatbar**2 \n",
        "ebayesthresh = importr('EbayesThresh').ebayesthresh\n",
        "power_threshed=np.array([np.array(ebayesthresh(FloatVector(fhatbar[i]**2))) for i in range(995)])\n",
        "fhatbar_threshed = np.where(power_threshed>0,fhatbar,0)\n",
        "fhatbarhat = Psi @ fhatbar_threshed\n",
        "fhat_two_linearinterpolation_spatio_temporal = fhatbarhat.reshape(199,5,1)"
      ],
      "id": "2976d888-5371-41c6-af08-97b458b4107d"
    },
    {
      "cell_type": "code",
      "execution_count": 188,
      "metadata": {},
      "outputs": [
        {
          "output_type": "display_data",
          "metadata": {},
          "data": {
            "image/png": "iVBORw0KGgoAAAANSUhEUgAAAXwAAAD4CAYAAADvsV2wAAAAOXRFWHRTb2Z0d2FyZQBNYXRwbG90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\nAnuAqeURAAAAAElFTkSuQmCC\n"
          }
        }
      ],
      "source": [
        "plt.plot(fhat_two_linearinterpolation_spatio_temporal[:,0])\n",
        "plt.plot(fhat_two_linearinterpolation_spatio_temporal[:,1])\n",
        "plt.plot(fhat_two_linearinterpolation_spatio_temporal[:,2])\n",
        "plt.plot(fhat_two_linearinterpolation_spatio_temporal[:,3])\n",
        "plt.plot(fhat_two_linearinterpolation_spatio_temporal[:,4])"
      ],
      "id": "ef4760f0-5a09-4d40-96b9-bfe94e5563bf"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "## 3.3. original\n",
        "\n",
        "#### 1) Temporal"
      ],
      "id": "94fb8f23-47be-4805-8fcc-f666d74c647a"
    },
    {
      "cell_type": "code",
      "execution_count": 326,
      "metadata": {},
      "outputs": [],
      "source": [
        "w=np.zeros((5,199,199))"
      ],
      "id": "8b521b72-7a4f-4f52-8f0b-c1b207e76216"
    },
    {
      "cell_type": "code",
      "execution_count": 327,
      "metadata": {},
      "outputs": [],
      "source": [
        "for k in range(5):\n",
        "    for i in range(199):\n",
        "        for j in range(199):\n",
        "            if i==j :\n",
        "                w[k,i,j] = 0\n",
        "            elif np.abs(i-j) <= 1 : \n",
        "                w[k,i,j] = 1"
      ],
      "id": "feff8ac9-fb2d-4db3-943f-b746c1def8ab"
    },
    {
      "cell_type": "code",
      "execution_count": 328,
      "metadata": {},
      "outputs": [],
      "source": [
        "d = np.array([w[i].sum(axis=1) for i in range(5)])\n",
        "D= np.array([np.diag(d[i]) for i in range(5)])\n",
        "L = np.array([np.diag(1/np.sqrt(d[i])) @ (D[i]-w[i]) @ np.diag(1/np.sqrt(d[i])) for i in range(5)])\n",
        "lamb, Psi  = np.linalg.eigh(L)[0],np.linalg.eigh(L)[1]\n",
        "Lamb = np.array([np.diag(lamb[i]) for i in range(5)])    \n",
        "fhatbar = np.hstack([Psi[i] @ fhat_fiveVTS[:,i] for i in range(5)])\n",
        "_fhatbar = fhatbar.reshape(5,199)\n",
        "power = _fhatbar**2 \n",
        "ebayesthresh = importr('EbayesThresh').ebayesthresh\n",
        "power_threshed=np.array([np.array(ebayesthresh(FloatVector(_fhatbar[i]**2))) for i in range(5)])\n",
        "fhatbar_threshed = np.where(power_threshed>0,_fhatbar,0)\n",
        "fhatbarhat = np.array([Psi[i] @ fhatbar_threshed[i] for i in range(5)])    \n",
        "fhatbarhat_temporal = fhatbarhat.reshape(199,-1)"
      ],
      "id": "c5db916a-e73c-44ca-9a37-e90b79677085"
    },
    {
      "cell_type": "code",
      "execution_count": 329,
      "metadata": {},
      "outputs": [
        {
          "output_type": "display_data",
          "metadata": {},
          "data": {
            "image/png": "iVBORw0KGgoAAAANSUhEUgAAAXwAAAD4CAYAAADvsV2wAAAAOXRFWHRTb2Z0d2FyZQBNYXRwbG90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\nggleIvj/AY3LDZvYbEqrAAAAAElFTkSuQmCC\n"
          }
        }
      ],
      "source": [
        "plt.plot(fhatbarhat_temporal[:,0])\n",
        "plt.plot(fhatbarhat_temporal[:,1])\n",
        "plt.plot(fhatbarhat_temporal[:,2])\n",
        "plt.plot(fhatbarhat_temporal[:,3])\n",
        "plt.plot(fhatbarhat_temporal[:,4])"
      ],
      "id": "0f66fd78-902f-4d99-a613-81a1a3a8b1d7"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "#### 2) Spatio"
      ],
      "id": "9fd7c14b-2da1-4d02-b366-b84a58446f6e"
    },
    {
      "cell_type": "code",
      "execution_count": 330,
      "metadata": {},
      "outputs": [],
      "source": [
        "w=np.zeros((5,5))"
      ],
      "id": "e6abc148-aef6-4af2-b7e0-0493d261de52"
    },
    {
      "cell_type": "code",
      "execution_count": 331,
      "metadata": {},
      "outputs": [],
      "source": [
        "for i in range(5):\n",
        "    for j in range(5):\n",
        "        if i==j :\n",
        "            w[i,j] = 0\n",
        "        elif np.abs(i-j) <= 1 : \n",
        "            w[i,j] = 1"
      ],
      "id": "d4f9dfd9-394f-4171-be52-9349cb5e65b5"
    },
    {
      "cell_type": "code",
      "execution_count": 332,
      "metadata": {},
      "outputs": [],
      "source": [
        "d = np.array(w.sum(axis=1))\n",
        "D = np.diag(d)\n",
        "L = np.array(np.diag(1/np.sqrt(d)) @ (D-w) @ np.diag(1/np.sqrt(d)))\n",
        "lamb, Psi = np.linalg.eigh(L)\n",
        "Lamb = np.diag(lamb)\n",
        "fhatbar = Psi @ fhat_fiveVTS.reshape(5,199)\n",
        "power = fhatbar**2 \n",
        "ebayesthresh = importr('EbayesThresh').ebayesthresh\n",
        "power_threshed=np.array([np.array(ebayesthresh(FloatVector(fhatbar[i]**2))) for i in range(5)])    \n",
        "fhatbar_threshed = np.where(power_threshed>0,fhatbar,0)\n",
        "fhatbarhat = Psi @ fhatbar_threshed\n",
        "fhatbarhat_spatio = fhatbarhat.reshape(199,-1)"
      ],
      "id": "77d4cc12-055c-4ff0-bf99-ad7ef735a78a"
    },
    {
      "cell_type": "code",
      "execution_count": 333,
      "metadata": {},
      "outputs": [
        {
          "output_type": "display_data",
          "metadata": {},
          "data": {
            "image/png": "iVBORw0KGgoAAAANSUhEUgAAAXwAAAD4CAYAAADvsV2wAAAAOXRFWHRTb2Z0d2FyZQBNYXRwbG90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\n"
          }
        }
      ],
      "source": [
        "plt.plot(fhatbarhat_spatio[:,0])\n",
        "plt.plot(fhatbarhat_spatio[:,1])\n",
        "plt.plot(fhatbarhat_spatio[:,2])\n",
        "plt.plot(fhatbarhat_spatio[:,3])\n",
        "plt.plot(fhatbarhat_spatio[:,4])"
      ],
      "id": "dbd48750-e325-45ff-aa3a-495a1f30e328"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "#### 3) Spatio-Temporal"
      ],
      "id": "c0e5ea04-7fed-40f6-ad12-402da18a7d9a"
    },
    {
      "cell_type": "code",
      "execution_count": 336,
      "metadata": {},
      "outputs": [],
      "source": [
        "w=np.zeros((995,995))"
      ],
      "id": "fca02eb4-264a-407a-8dc6-6c42762667b1"
    },
    {
      "cell_type": "code",
      "execution_count": 337,
      "metadata": {},
      "outputs": [],
      "source": [
        "for i in range(995):\n",
        "    for j in range(995):\n",
        "        if i==j :\n",
        "            w[i,j] = 0\n",
        "        elif np.abs(i-j) <= 1 : \n",
        "            w[i,j] = 1"
      ],
      "id": "9ff8f670-e27d-47e6-a5d9-aee50babf45a"
    },
    {
      "cell_type": "code",
      "execution_count": 338,
      "metadata": {},
      "outputs": [],
      "source": [
        "d = np.array(w.sum(axis=1))\n",
        "D = np.diag(d)\n",
        "L = np.array(np.diag(1/np.sqrt(d)) @ (D-w) @ np.diag(1/np.sqrt(d)))\n",
        "lamb, Psi = np.linalg.eigh(L)\n",
        "Lamb = np.diag(lamb)\n",
        "fhatbar = Psi @ fhat_fiveVTS.reshape(995,1)\n",
        "power = fhatbar**2 \n",
        "ebayesthresh = importr('EbayesThresh').ebayesthresh\n",
        "power_threshed=np.array([np.array(ebayesthresh(FloatVector(fhatbar[i]**2))) for i in range(995)])\n",
        "fhatbar_threshed = np.where(power_threshed>0,fhatbar,0)\n",
        "fhatbarhat = Psi @ fhatbar_threshed\n",
        "fhat_spatio_temporal = fhatbarhat.reshape(199,5,1)"
      ],
      "id": "c1011ea1-de32-4675-afca-38973c59cc31"
    },
    {
      "cell_type": "code",
      "execution_count": 339,
      "metadata": {},
      "outputs": [
        {
          "output_type": "display_data",
          "metadata": {},
          "data": {
            "image/png": "iVBORw0KGgoAAAANSUhEUgAAAXwAAAD4CAYAAADvsV2wAAAAOXRFWHRTb2Z0d2FyZQBNYXRwbG90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\nDRo0aPA0QUP4DRo0aPA0wf8PeAeTdij5aTYAAAAASUVORK5CYII=\n"
          }
        }
      ],
      "source": [
        "plt.plot(fhat_spatio_temporal[:,0])\n",
        "plt.plot(fhat_spatio_temporal[:,1])\n",
        "plt.plot(fhat_spatio_temporal[:,2])\n",
        "plt.plot(fhat_spatio_temporal[:,3])\n",
        "plt.plot(fhat_spatio_temporal[:,4])"
      ],
      "id": "350ea715-402d-4ea4-ad7c-5fa84066c296"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "# 4. 1로 돌아가서 반복\n",
        "\n",
        "# Original f 진행한 것과 비교"
      ],
      "id": "9e597d82-ef79-4ef7-857f-aae8f156a92d"
    },
    {
      "cell_type": "code",
      "execution_count": 346,
      "metadata": {},
      "outputs": [
        {
          "output_type": "display_data",
          "metadata": {},
          "data": {
            "image/png": "iVBORw0KGgoAAAANSUhEUgAAAXQAAAD4CAYAAAD8Zh1EAAAAOXRFWHRTb2Z0d2FyZQBNYXRwbG90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\nAABJRU5ErkJggg==\n"
          }
        }
      ],
      "source": [
        "plt.plot((fhatbarhat_temporal[:,2] - fhatbarhat_mean_temporal[:,2])**2)\n",
        "plt.plot((fhatbarhat_temporal[:,2] - fhatbarhat_random_mean_temporal[:,2])**2)\n",
        "plt.plot((fhatbarhat_temporal[:,2] - fhatbarhat_twomean_temporal[:,2])**2)"
      ],
      "id": "a8503d0b-7a6e-4e04-86c6-93200537405d"
    },
    {
      "cell_type": "code",
      "execution_count": 347,
      "metadata": {},
      "outputs": [
        {
          "output_type": "display_data",
          "metadata": {},
          "data": {
            "image/png": "iVBORw0KGgoAAAANSUhEUgAAAXQAAAD4CAYAAAD8Zh1EAAAAOXRFWHRTb2Z0d2FyZQBNYXRwbG90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\n/wFBsPpVc7g5SAAAAABJRU5ErkJggg==\n"
          }
        }
      ],
      "source": [
        "plt.plot((fhatbarhat_temporal[:,2] - fhatbarhat_linearinterpolation_temporal[:,2])**2)\n",
        "plt.plot((fhatbarhat_temporal[:,2] - fhatbarhat_random_linearinterpolation_temporal[:,2])**2)\n",
        "plt.plot((fhatbarhat_temporal[:,2] - fhatbarhat_two_linearinterpolation_temporal[:,2])**2)"
      ],
      "id": "836301a0-ff98-49d2-9356-07f6f8e2f745"
    },
    {
      "cell_type": "code",
      "execution_count": 348,
      "metadata": {},
      "outputs": [
        {
          "output_type": "display_data",
          "metadata": {},
          "data": {
            "image/png": "iVBORw0KGgoAAAANSUhEUgAAAXQAAAD4CAYAAAD8Zh1EAAAAOXRFWHRTb2Z0d2FyZQBNYXRwbG90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\nEGSEniFDhgwbBBmhZ8iQIcMGwf8P/8RbNUpMjDMAAAAASUVORK5CYII=\n"
          }
        }
      ],
      "source": [
        "plt.plot((fhatbarhat_spatio[:,2] - fhatbarhat_mean_spatio[:,2])**2)\n",
        "plt.plot((fhatbarhat_spatio[:,2] - fhatbarhat_random_mean_spatio[:,2])**2)\n",
        "plt.plot((fhatbarhat_spatio[:,2] - fhatbarhat_two_mean_spatio[:,2])**2)"
      ],
      "id": "d601f425-98b1-4922-a41d-d3c3c9d450dd"
    },
    {
      "cell_type": "code",
      "execution_count": 349,
      "metadata": {},
      "outputs": [
        {
          "output_type": "display_data",
          "metadata": {},
          "data": {
            "image/png": "iVBORw0KGgoAAAANSUhEUgAAAXQAAAD4CAYAAAD8Zh1EAAAAOXRFWHRTb2Z0d2FyZQBNYXRwbG90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\nVQAAAABJRU5ErkJggg==\n"
          }
        }
      ],
      "source": [
        "plt.plot((fhatbarhat_spatio[:,2] - fhatbarhat_linearinterpolation_spatio[:,2])**2)\n",
        "plt.plot((fhatbarhat_spatio[:,2] - fhatbarhat_random_linearinterpolation_spatio[:,2])**2)\n",
        "plt.plot((fhatbarhat_spatio[:,2] - fhatbarhat_two_linearinterpolation_spatio[:,2])**2)"
      ],
      "id": "78ecf101-22b5-4eab-b1ba-e4d0ea6847f4"
    },
    {
      "cell_type": "code",
      "execution_count": 350,
      "metadata": {},
      "outputs": [
        {
          "output_type": "display_data",
          "metadata": {},
          "data": {
            "image/png": "iVBORw0KGgoAAAANSUhEUgAAAXQAAAD4CAYAAAD8Zh1EAAAAOXRFWHRTb2Z0d2FyZQBNYXRwbG90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\n1AAAAABJRU5ErkJggg==\n"
          }
        }
      ],
      "source": [
        "plt.plot((fhat_spatio_temporal[:,2] - fhatbarhat_mean_spatio_temporal[:,2])**2)\n",
        "plt.plot((fhat_spatio_temporal[:,2] - fhatbarhat_random_mean_spatio_temporal[:,2])**2)\n",
        "plt.plot((fhat_spatio_temporal[:,2] - fhatbarhat_two_mean_spatio_temporal[:,2])**2)"
      ],
      "id": "ebaff6f6-dc24-4042-b386-d605afd196ab"
    },
    {
      "cell_type": "code",
      "execution_count": 351,
      "metadata": {},
      "outputs": [
        {
          "output_type": "display_data",
          "metadata": {},
          "data": {
            "image/png": "iVBORw0KGgoAAAANSUhEUgAAAXQAAAD4CAYAAAD8Zh1EAAAAOXRFWHRTb2Z0d2FyZQBNYXRwbG90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\n"
          }
        }
      ],
      "source": [
        "plt.plot((fhat_spatio_temporal[:,2] - fhat_linearinterpolation_spatio_temporal[:,2])**2)\n",
        "plt.plot((fhat_spatio_temporal[:,2] - fhat_random_linearinterpolation_spatio_temporal[:,2])**2)\n",
        "plt.plot((fhat_spatio_temporal[:,2] - fhat_two_linearinterpolation_spatio_temporal[:,2])**2)"
      ],
      "id": "16d6de5d-3eff-4d78-9328-496b7ebe9cb4"
    }
  ],
  "nbformat": 4,
  "nbformat_minor": 5,
  "metadata": {
    "kernelspec": {
      "name": "python3",
      "display_name": "Python 3 (ipykernel)",
      "language": "python"
    },
    "language_info": {
      "name": "python",
      "codemirror_mode": {
        "name": "ipython",
        "version": "3"
      },
      "file_extension": ".py",
      "mimetype": "text/x-python",
      "nbconvert_exporter": "python",
      "pygments_lexer": "ipython3",
      "version": "3.8.12"
    }
  }
}